--
-- PostgreSQL database dump
--

-- Dumped from database version 15.7 (Debian 15.7-1.pgdg110+1)
-- Dumped by pg_dump version 15.0

-- Started on 2024-10-06 08:24:10 CEST

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- TOC entry 4848 (class 0 OID 19759)
-- Dependencies: 296
-- Data for Name: datasource_types; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.datasource_types VALUES (1, 'internal', 'Internal Table', 'Table inside the same database instance.');
INSERT INTO {schema}.datasource_types VALUES (2, 'external', 'External Table', 'SQL table in an external database instance, but of same structure.');
INSERT INTO {schema}.datasource_types VALUES (3, 'csv', 'Local CSV File', 'Standard csv file source on the database server machine.');
INSERT INTO {schema}.datasource_types VALUES (4, 'local', 'Local Blob', 'Any kind of local file without I/O capabilities. Generic fallback type.');
INSERT INTO {schema}.datasource_types VALUES (5, 'netCDF', 'Local netCDF File', 'netCDF file source on the local file system.');


--
-- TOC entry 4850 (class 0 OID 19768)
-- Dependencies: 298
-- Data for Name: datatypes; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.datatypes VALUES (1, NULL, 'blob', 'File Blob', 'Any kind of file-like-structure. Reader will only return file paths. Not for use in production. Can be used as a placeholder for custom data management.');
INSERT INTO {schema}.datatypes VALUES (11, NULL, 'array', 'generic array structure', 'Arrays are a series of data objects, without index.');
INSERT INTO {schema}.datatypes VALUES (12, 11, 'iarray', 'indexed array', 'Array with additional index information for each element, that is not a datetime.');
INSERT INTO {schema}.datatypes VALUES (13, 12, 'varray', 'named, indexed array', 'An iarray that additionally has a name property of any valid metacatalog Variable.');
INSERT INTO {schema}.datatypes VALUES (14, 11, 'timeseries', 'timeseries', 'Array indexed by datetime information. The datetimes need to be of increasing order.');
INSERT INTO {schema}.datatypes VALUES (15, 14, 'vtimeseries', 'named timeseries', 'Timeseries that holds an additional Variable name to describe the content.');
INSERT INTO {schema}.datatypes VALUES (16, NULL, 'ndarray', 'generic mulidimensional array', 'NDArrays are multidimensional arrays of common atomic data-type.');
INSERT INTO {schema}.datatypes VALUES (17, 16, 'raster', 'Raster data', 'GDAL conform raster images.');
INSERT INTO {schema}.datatypes VALUES (18, 17, 'vraster', 'named raster data', 'The named raster images are not implemented yet.');
INSERT INTO {schema}.datatypes VALUES (19, 16, '2darray', '2D-array', 'Special case of NDArray with exactly two dimensions.');
INSERT INTO {schema}.datatypes VALUES (20, 16, 'idataframe', 'indexed table', 'NDArray with any index except datetime information.');
INSERT INTO {schema}.datatypes VALUES (21, 20, 'vdataframe', 'named, indexed table', 'idataframe with additional name property of any valid metacatalog Variable.');
INSERT INTO {schema}.datatypes VALUES (22, 16, 'time-dataframe', 'timeseries table', 'NDArray indexed by datetime information. The datetimes need to be of increasing order.');
INSERT INTO {schema}.datatypes VALUES (23, 22, 'vtime-dataframe', 'named timeseries table', 'Timeseries table that holds an additional Variable name to describe the content.');


--
-- TOC entry 4838 (class 0 OID 19708)
-- Dependencies: 286
-- Data for Name: thesaurus; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.thesaurus VALUES (1, '2e54668d-8fae-429f-a511-efe529420b12', 'GCMD', 'NASA/GCMD Earth Science Keywords', 'NASA', 'NASA Global Clime change Master Dictionary Science Keywords', 'https://gcmdservices.gsfc.nasa.gov/kms/concepts/concept_scheme/sciencekeywords/?format=xml');


--
-- TOC entry 4860 (class 0 OID 19826)
-- Dependencies: 308
-- Data for Name: keywords; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.keywords VALUES (1, '894f9116-ae3c-40b6-981d-5113de961710', NULL, 'EARTH SCIENCE SERVICES', 'EARTH SCIENCE SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (2, 'e9f67a66-e9fc-435c-b720-ae32a2c3d8f5', NULL, 'EARTH SCIENCE', 'EARTH SCIENCE', 1);
INSERT INTO {schema}.keywords VALUES (3, '41adc080-c182-4753-9666-435f8b1c913f', 1, 'DATA ANALYSIS AND VISUALIZATION', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION', 1);
INSERT INTO {schema}.keywords VALUES (4, '02d92216-70c6-437c-8c15-2b76f2132921', 1, 'DATA MANAGEMENT/DATA HANDLING', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING', 1);
INSERT INTO {schema}.keywords VALUES (5, 'dc2088f9-ffb7-41c3-b0a1-856ecfec89de', 1, 'EDUCATION/OUTREACH', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH', 1);
INSERT INTO {schema}.keywords VALUES (6, '09d00879-6d96-4df4-9f50-73bd761118d9', 1, 'ENVIRONMENTAL ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (7, '464de0a5-2bb9-4172-9fd3-1634cbc4e739', 1, 'HAZARDS MANAGEMENT', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (8, 'a1fedfa9-569f-4313-8ce1-db95513c5469', 1, 'METADATA HANDLING', 'EARTH SCIENCE SERVICES > METADATA HANDLING', 1);
INSERT INTO {schema}.keywords VALUES (9, 'e1f20631-b5b9-438c-b5c2-b1fa0fce100a', 1, 'MODELS', 'EARTH SCIENCE SERVICES > MODELS', 1);
INSERT INTO {schema}.keywords VALUES (10, 'a3a5d0dd-0e8f-4649-8a55-25f9251e1008', 1, 'REFERENCE AND INFORMATION SERVICES', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (11, '1d550f3a-1c8c-4ef5-beff-74cfe7794f12', 1, 'WEB SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (12, 'a956d045-3b12-441c-8a18-fac7d33b2b4e', 2, 'AGRICULTURE', 'EARTH SCIENCE > AGRICULTURE', 1);
INSERT INTO {schema}.keywords VALUES (13, 'c47f6052-634e-40ef-a5ac-13f69f6f4c2a', 2, 'ATMOSPHERE', 'EARTH SCIENCE > ATMOSPHERE', 1);
INSERT INTO {schema}.keywords VALUES (14, 'fbec5145-79e6-4ed0-a804-6228aa6daba5', 2, 'BIOLOGICAL CLASSIFICATION', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (15, '91c64c46-d040-4daa-b26c-61952fdfaf50', 2, 'BIOSPHERE', 'EARTH SCIENCE > BIOSPHERE', 1);
INSERT INTO {schema}.keywords VALUES (16, '23703b6b-ee15-4512-b5b2-f441547e2edf', 2, 'CLIMATE INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (17, 'fa0a36c3-2503-4662-98cd-7f3e74ce9f80', 2, 'CRYOSPHERE', 'EARTH SCIENCE > CRYOSPHERE', 1);
INSERT INTO {schema}.keywords VALUES (18, 'fb93d937-c17c-45d0-a9e3-ca5c8a800ca8', 2, 'HUMAN DIMENSIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS', 1);
INSERT INTO {schema}.keywords VALUES (19, '6a426480-c58f-4b6b-8e35-0975b7f6edb5', 2, 'LAND SURFACE', 'EARTH SCIENCE > LAND SURFACE', 1);
INSERT INTO {schema}.keywords VALUES (20, '91697b7d-8f2b-4954-850e-61d5f61c867d', 2, 'OCEANS', 'EARTH SCIENCE > OCEANS', 1);
INSERT INTO {schema}.keywords VALUES (21, 'c7245882-84a1-4192-acfa-a758b5b9c151', 2, 'PALEOCLIMATE', 'EARTH SCIENCE > PALEOCLIMATE', 1);
INSERT INTO {schema}.keywords VALUES (22, '2b9ad978-d986-4d63-b477-0f5efc8ace72', 2, 'SOLID EARTH', 'EARTH SCIENCE > SOLID EARTH', 1);
INSERT INTO {schema}.keywords VALUES (23, '83150c54-5da8-4ee8-9579-19b95a8dc10c', 2, 'SPECTRAL/ENGINEERING', 'EARTH SCIENCE > SPECTRAL/ENGINEERING', 1);
INSERT INTO {schema}.keywords VALUES (24, '57383ac5-614c-4b84-9202-e137b000422b', 2, 'SUN-EARTH INTERACTIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS', 1);
INSERT INTO {schema}.keywords VALUES (25, '885735f3-121e-4ca0-ac8b-f37dbc972f03', 2, 'TERRESTRIAL HYDROSPHERE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE', 1);
INSERT INTO {schema}.keywords VALUES (26, '4f938731-d686-4d89-b72b-ff60474bb1f0', 3, 'CALIBRATION/VALIDATION', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > CALIBRATION/VALIDATION', 1);
INSERT INTO {schema}.keywords VALUES (27, '794e3c3b-791f-44de-9ff3-358d8ed74733', 3, 'GEOGRAPHIC INFORMATION SYSTEMS', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > GEOGRAPHIC INFORMATION SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (28, 'f082ad51-4ce4-4ffe-be50-6753c4f997ae', 3, 'GLOBAL POSITIONING SYSTEMS', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > GLOBAL POSITIONING SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (29, '997dc5a6-d83f-4d59-8c5a-1d901b069830', 3, 'STATISTICAL APPLICATIONS', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > STATISTICAL APPLICATIONS', 1);
INSERT INTO {schema}.keywords VALUES (30, '4698858b-bf39-4a2c-9713-e41757739eff', 3, 'VISUALIZATION/IMAGE PROCESSING', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > VISUALIZATION/IMAGE PROCESSING', 1);
INSERT INTO {schema}.keywords VALUES (31, 'c75db4f8-716c-47a8-a2f4-34e5a48296b0', 4, 'ARCHIVING', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > ARCHIVING', 1);
INSERT INTO {schema}.keywords VALUES (32, '434d40e2-4e0b-408a-9811-ff878f4f0fb0', 4, 'CATALOGING', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > CATALOGING', 1);
INSERT INTO {schema}.keywords VALUES (33, 'e0d7fb1f-5233-4664-8e83-3c65ca344f41', 4, 'DATA COMPRESSION', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA COMPRESSION', 1);
INSERT INTO {schema}.keywords VALUES (34, '9916f643-05b4-4f0e-91e0-59922c6e09fc', 4, 'DATA DELIVERY', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA DELIVERY', 1);
INSERT INTO {schema}.keywords VALUES (35, '0f3573bc-3cb7-4cec-a5bb-1bb6b7ab9057', 4, 'DATA INTEROPERABILITY', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA INTEROPERABILITY', 1);
INSERT INTO {schema}.keywords VALUES (36, '07291e32-fd39-45e8-a603-7443cb780976', 4, 'DATA MINING', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA MINING', 1);
INSERT INTO {schema}.keywords VALUES (37, '80e34388-3d24-4ff9-8d23-784fad52c432', 4, 'DATA NETWORKING/DATA TRANSFER TOOLS', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA NETWORKING/DATA TRANSFER TOOLS', 1);
INSERT INTO {schema}.keywords VALUES (38, '86cbb2d3-6783-4d9b-9dc1-b0aea78f98ea', 4, 'DATA SEARCH AND RETRIEVAL', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA SEARCH AND RETRIEVAL', 1);
INSERT INTO {schema}.keywords VALUES (39, 'fc757c55-83b4-400e-9d23-25bcad230603', 4, 'MEDIA TRANSFER/DATA RESCUE', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > MEDIA TRANSFER/DATA RESCUE', 1);
INSERT INTO {schema}.keywords VALUES (40, 'cc9e67fc-eafa-43cc-879f-0cb56b25bc39', 4, 'SUBSETTING/SUPERSETTING', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > SUBSETTING/SUPERSETTING', 1);
INSERT INTO {schema}.keywords VALUES (41, '31ab3c10-1f10-4372-82d4-4c0c4be5999f', 4, 'TRANSFORMATION/CONVERSION', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > TRANSFORMATION/CONVERSION', 1);
INSERT INTO {schema}.keywords VALUES (42, '97675827-9b0a-4d13-a795-d4a3e78c476a', 5, 'CURRICULUM SUPPORT', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > CURRICULUM SUPPORT', 1);
INSERT INTO {schema}.keywords VALUES (43, '9f8a6a52-df35-487d-9a74-74b76943e0c0', 5, 'EXHIBIT MATERIALS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > EXHIBIT MATERIALS', 1);
INSERT INTO {schema}.keywords VALUES (44, '247b151a-2f56-41f9-8a19-51e34a64d61e', 5, 'INTERACTIVE PROGRAMS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > INTERACTIVE PROGRAMS', 1);
INSERT INTO {schema}.keywords VALUES (45, 'a9394dee-8c4e-47a8-b630-6549ac1cb717', 6, 'AGRICULTURAL ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > AGRICULTURAL ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (46, '7f71a0a0-3da7-42b9-b134-c0a824dff971', 6, 'FIRE ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > FIRE ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (47, '13b8bcd4-7566-49e5-9975-ea15470474ab', 6, 'GEOLOGICAL ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > GEOLOGICAL ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (48, '370eba54-962b-4e59-9686-86d5c5ab9c88', 6, 'HEALTH ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HEALTH ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (49, '7406a787-6ab6-429f-bc09-9a86d393e114', 6, 'HYDROLOGICAL ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HYDROLOGICAL ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (50, '39f5a91f-c5b6-4aa9-a0c6-05530306f17b', 6, 'MARINE ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (96, '25be3b9a-9d4c-4b5b-8d24-b1f519913d90', 12, 'AGRICULTURAL PLANT SCIENCE', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE', 1);
INSERT INTO {schema}.keywords VALUES (51, '09d1435d-99de-4149-ba64-d98c3335a383', 6, 'SPACE WEATHER ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (52, '89554e78-d69d-4a38-b7f1-78d9e1e4aa57', 6, 'WEATHER/CLIMATE ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (53, '6b2fad63-2230-4d54-8f31-fee604d1f977', 7, 'DISASTER RECOVERY/RELIEF', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > DISASTER RECOVERY/RELIEF', 1);
INSERT INTO {schema}.keywords VALUES (54, 'd7aa220d-4012-4ab1-98c8-0cc4157a48f3', 7, 'DISASTER RESPONSE', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > DISASTER RESPONSE', 1);
INSERT INTO {schema}.keywords VALUES (55, 'c9a13e09-98de-4ace-8d4c-b01aa04347f4', 7, 'HAZARDS MAPPING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MAPPING', 1);
INSERT INTO {schema}.keywords VALUES (56, 'a2e9c7b9-96fd-449f-91db-7ab5e2dd679e', 7, 'HAZARDS MITIGATION', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MITIGATION', 1);
INSERT INTO {schema}.keywords VALUES (57, '5c14b001-518f-460b-90fe-139bf192d1f2', 7, 'HAZARDS PLANNING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS PLANNING', 1);
INSERT INTO {schema}.keywords VALUES (58, '5aad0680-cae2-402b-8311-3fb4ddc892bd', 8, 'AUTHORING TOOLS', 'EARTH SCIENCE SERVICES > METADATA HANDLING > AUTHORING TOOLS', 1);
INSERT INTO {schema}.keywords VALUES (59, '90c21a67-6703-4b59-96ee-c2c602652c80', 8, 'DATA DISCOVERY', 'EARTH SCIENCE SERVICES > METADATA HANDLING > DATA DISCOVERY', 1);
INSERT INTO {schema}.keywords VALUES (60, 'f29a3482-de42-4027-b5f4-87a3f7cd28af', 8, 'METADATA TRANSFORMATION/CONVERSION', 'EARTH SCIENCE SERVICES > METADATA HANDLING > METADATA TRANSFORMATION/CONVERSION', 1);
INSERT INTO {schema}.keywords VALUES (61, 'f41dae97-a5ca-4c23-aec5-378448a14f92', 8, 'SERVICE DISCOVERY', 'EARTH SCIENCE SERVICES > METADATA HANDLING > SERVICE DISCOVERY', 1);
INSERT INTO {schema}.keywords VALUES (62, '7872b9af-8c90-481e-aaa6-a47b736f0828', 9, 'ANCILLARY MODELS', 'EARTH SCIENCE SERVICES > MODELS > ANCILLARY MODELS', 1);
INSERT INTO {schema}.keywords VALUES (63, '3668de06-8a7d-4667-beb8-d04dcac619b0', 9, 'ATMOSPHERIC CHEMISTRY MODELS', 'EARTH SCIENCE SERVICES > MODELS > ATMOSPHERIC CHEMISTRY MODELS', 1);
INSERT INTO {schema}.keywords VALUES (64, '063177a9-14cd-4750-9aa4-ad5d266bd7ad', 9, 'ATMOSPHERIC GENERAL CIRCULATION MODELS', 'EARTH SCIENCE SERVICES > MODELS > ATMOSPHERIC GENERAL CIRCULATION MODELS', 1);
INSERT INTO {schema}.keywords VALUES (65, '640d703f-9312-4f11-8367-30a8bd8fc508', 9, 'CARBON CYCLE/CARBON BUDGET MODELS', 'EARTH SCIENCE SERVICES > MODELS > CARBON CYCLE/CARBON BUDGET MODELS', 1);
INSERT INTO {schema}.keywords VALUES (66, 'ea5ccefb-e390-43d5-8202-33e004565beb', 9, 'CLIMATE CHANGE IMPACT ASSESSMENT MODELS', 'EARTH SCIENCE SERVICES > MODELS > CLIMATE CHANGE IMPACT ASSESSMENT MODELS', 1);
INSERT INTO {schema}.keywords VALUES (67, 'f66e185f-7e17-4b5c-bc4e-523ddfbbe9ca', 9, 'COMPONENT PROCESS MODELS', 'EARTH SCIENCE SERVICES > MODELS > COMPONENT PROCESS MODELS', 1);
INSERT INTO {schema}.keywords VALUES (68, 'c5b13fa4-0069-40ce-85cb-bfbab34c2058', 9, 'COUPLED CLIMATE MODELS', 'EARTH SCIENCE SERVICES > MODELS > COUPLED CLIMATE MODELS', 1);
INSERT INTO {schema}.keywords VALUES (69, '0a22b06c-eeed-46dc-b41b-af44ca94c419', 9, 'CRYOSPHERE MODELS', 'EARTH SCIENCE SERVICES > MODELS > CRYOSPHERE MODELS', 1);
INSERT INTO {schema}.keywords VALUES (70, 'e5f94c93-e8af-4919-827f-9059dab9cf27', 9, 'DIGITAL ELEVATION/DIGITAL TERRAIN MODELS', 'EARTH SCIENCE SERVICES > MODELS > DIGITAL ELEVATION/DIGITAL TERRAIN MODELS', 1);
INSERT INTO {schema}.keywords VALUES (71, 'adfee6d2-ca00-4f02-a570-5ccf0850cb55', 9, 'DYNAMIC VEGETATION/ECOSYSTEM MODELS', 'EARTH SCIENCE SERVICES > MODELS > DYNAMIC VEGETATION/ECOSYSTEM MODELS', 1);
INSERT INTO {schema}.keywords VALUES (72, 'b8615aad-d2eb-45a3-98a7-4adac5bdf5a5', 9, 'EARTH SCIENCE REANALYSES/ASSIMILATION MODELS', 'EARTH SCIENCE SERVICES > MODELS > EARTH SCIENCE REANALYSES/ASSIMILATION MODELS', 1);
INSERT INTO {schema}.keywords VALUES (73, 'f96bf6c8-2f34-412a-b734-b2644f08a329', 9, 'GEOLOGIC/TECTONIC/PALEOCLIMATE MODELS', 'EARTH SCIENCE SERVICES > MODELS > GEOLOGIC/TECTONIC/PALEOCLIMATE MODELS', 1);
INSERT INTO {schema}.keywords VALUES (74, '2eb094d5-70bc-49fa-acb6-4ad07f4c7b08', 9, 'HYDROLOGIC AND TERRESTRIAL WATER CYCLE MODELS', 'EARTH SCIENCE SERVICES > MODELS > HYDROLOGIC AND TERRESTRIAL WATER CYCLE MODELS', 1);
INSERT INTO {schema}.keywords VALUES (75, '46461db7-88ba-446f-bdae-2d1e7f6302c2', 9, 'LAND SURFACE MODELS', 'EARTH SCIENCE SERVICES > MODELS > LAND SURFACE MODELS', 1);
INSERT INTO {schema}.keywords VALUES (76, 'c61a56a3-c08f-4989-92f3-0f0787688424', 9, 'OCEAN GENERAL CIRCULATION MODELS (OGCM)/REGIONAL OCEAN MODELS', 'EARTH SCIENCE SERVICES > MODELS > OCEAN GENERAL CIRCULATION MODELS (OGCM)/REGIONAL OCEAN MODELS', 1);
INSERT INTO {schema}.keywords VALUES (77, '93809fc5-da7c-4ca2-9585-70f09bd99898', 9, 'PHENOMENOLOGICAL MODELS', 'EARTH SCIENCE SERVICES > MODELS > PHENOMENOLOGICAL MODELS', 1);
INSERT INTO {schema}.keywords VALUES (78, '1eb8b98b-73a1-4657-beda-76ab6355dd08', 9, 'PHYSICAL/LABORATORY MODELS', 'EARTH SCIENCE SERVICES > MODELS > PHYSICAL/LABORATORY MODELS', 1);
INSERT INTO {schema}.keywords VALUES (79, 'e49f0aae-c2ef-4fd2-aaf4-ddfad074bb75', 9, 'REGULATORY MODELS', 'EARTH SCIENCE SERVICES > MODELS > REGULATORY MODELS', 1);
INSERT INTO {schema}.keywords VALUES (80, '9a1dd3c3-a126-437e-ad04-9dc0a382d567', 9, 'SOCIAL AND ECONOMIC MODELS', 'EARTH SCIENCE SERVICES > MODELS > SOCIAL AND ECONOMIC MODELS', 1);
INSERT INTO {schema}.keywords VALUES (81, '96400b5a-6932-41f2-a80c-5aba26a2b5de', 9, 'SOLAR-ATMOSPHERE/SPACE-WEATHER MODELS', 'EARTH SCIENCE SERVICES > MODELS > SOLAR-ATMOSPHERE/SPACE-WEATHER MODELS', 1);
INSERT INTO {schema}.keywords VALUES (82, '92471848-b940-4b31-9165-f106457a4616', 9, 'WEATHER RESEARCH/FORECAST MODELS', 'EARTH SCIENCE SERVICES > MODELS > WEATHER RESEARCH/FORECAST MODELS', 1);
INSERT INTO {schema}.keywords VALUES (83, '80a8ca6d-8471-4d49-a99c-fa5954d93a55', 10, 'BIBLIOGRAPHIC', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > BIBLIOGRAPHIC', 1);
INSERT INTO {schema}.keywords VALUES (84, 'b37c3094-6ec8-4429-a80b-b332a7b4947d', 10, 'DIGITAL/VIRTUAL REFERENCE DESKS', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS', 1);
INSERT INTO {schema}.keywords VALUES (85, 'ac44c9c0-d0f1-4f25-b016-b57ca51d511e', 10, 'GAZETTEER', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > GAZETTEER', 1);
INSERT INTO {schema}.keywords VALUES (86, '8f6ad4bb-ab00-4e5a-baee-2c17335ba809', 10, 'IDENTIFICATION/CLASSIFICATION SYSTEMS', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > IDENTIFICATION/CLASSIFICATION SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (87, '20ed3fa4-20fa-4531-8b02-dceda8eac81f', 10, 'KNOWLEDGE/DECISION SYSTEMS', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > KNOWLEDGE/DECISION SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (88, '16d0abc3-8f75-4974-bdb4-df09a04bcfa3', 10, 'SUBSCRIPTION SERVICES', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > SUBSCRIPTION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (89, '52a71bf1-a099-4bb1-88c2-064203e3608c', 10, 'THESAURI', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > THESAURI', 1);
INSERT INTO {schema}.keywords VALUES (90, '12a00b9e-52b3-44d0-bbfc-d8bb74173323', 11, 'DATA APPLICATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (91, '431eca76-9d34-4f86-b1d3-a0b40221e905', 11, 'DATA PROCESSING SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (92, '46c929ad-8729-4484-8dc5-0a58a4e696a6', 11, 'INFORMATION MANAGEMENT SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (93, 'ca227ff0-4742-4e51-a763-4582fa28291c', 12, 'AGRICULTURAL AQUATIC SCIENCES', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL AQUATIC SCIENCES', 1);
INSERT INTO {schema}.keywords VALUES (94, 'afd084b9-1f4c-4eb5-a58e-689a360e7abf', 12, 'AGRICULTURAL CHEMICALS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL CHEMICALS', 1);
INSERT INTO {schema}.keywords VALUES (95, 'b8018326-a186-4847-961d-8bd0727bbd5e', 12, 'AGRICULTURAL ENGINEERING', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL ENGINEERING', 1);
INSERT INTO {schema}.keywords VALUES (97, 'c9f1a861-2173-4124-962c-759f71b6f131', 12, 'ANIMAL COMMODITIES', 'EARTH SCIENCE > AGRICULTURE > ANIMAL COMMODITIES', 1);
INSERT INTO {schema}.keywords VALUES (98, 'b41894fa-2e3e-475b-b8f0-b6ffdd2d6e9c', 12, 'ANIMAL SCIENCE', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE', 1);
INSERT INTO {schema}.keywords VALUES (99, 'c1f9f5fa-245c-4055-81cf-5230c076c0ce', 12, 'FEED PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > FEED PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (100, 'b98f3a77-397d-41d7-9507-e7a3e47210b1', 12, 'FOOD SCIENCE', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE', 1);
INSERT INTO {schema}.keywords VALUES (101, '22ec2f9b-1f1a-469b-bc09-851d58637ff4', 12, 'FOREST SCIENCE', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE', 1);
INSERT INTO {schema}.keywords VALUES (102, 'd6560f20-3bef-41c6-8eec-9f913329b9ac', 12, 'PLANT COMMODITIES', 'EARTH SCIENCE > AGRICULTURE > PLANT COMMODITIES', 1);
INSERT INTO {schema}.keywords VALUES (103, '199e3af8-4cf3-48ba-8b28-b9b54756b3db', 12, 'SOILS', 'EARTH SCIENCE > AGRICULTURE > SOILS', 1);
INSERT INTO {schema}.keywords VALUES (104, '2e5a401b-1507-4f57-82b8-36557c13b154', 13, 'AEROSOLS', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS', 1);
INSERT INTO {schema}.keywords VALUES (105, '77397026-09c9-44e0-b85f-77b2bc9b1630', 13, 'AIR QUALITY', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY', 1);
INSERT INTO {schema}.keywords VALUES (106, '16bfcf54-f8e1-4c8e-9bd4-a1ac06ea95a0', 13, 'ALTITUDE', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE', 1);
INSERT INTO {schema}.keywords VALUES (107, 'b9c56939-c624-467d-b196-e56a5b660334', 13, 'ATMOSPHERIC CHEMISTRY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (108, '0af72e0e-52a5-4695-9eaf-d6fbb7991039', 13, 'ATMOSPHERIC ELECTRICITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC ELECTRICITY', 1);
INSERT INTO {schema}.keywords VALUES (109, '08fd82a1-4370-46a2-82ea-94c0f91498a7', 13, 'ATMOSPHERIC PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (110, '4ad0c52d-6449-48ff-8678-adc6b2cebcb7', 13, 'ATMOSPHERIC RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (111, '35e1f93b-99b3-4430-b477-0ecafa80d67a', 13, 'ATMOSPHERIC TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (112, '286d2ae0-9d86-4ef0-a2b4-014843a98532', 13, 'ATMOSPHERIC WATER VAPOR', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR', 1);
INSERT INTO {schema}.keywords VALUES (113, 'df160e31-ae45-41a4-9093-a80fe5303cea', 13, 'ATMOSPHERIC WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS', 1);
INSERT INTO {schema}.keywords VALUES (114, '162e2243-3266-4999-b352-d8a1a9dc82ac', 13, 'CLOUDS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS', 1);
INSERT INTO {schema}.keywords VALUES (115, '1532e590-a62d-46e3-8d03-2351bc48166a', 13, 'PRECIPITATION', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION', 1);
INSERT INTO {schema}.keywords VALUES (116, 'b7d562cf-9b9b-4461-900b-50423a8c4d29', 13, 'WEATHER EVENTS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS', 1);
INSERT INTO {schema}.keywords VALUES (117, 'abc6f016-d1f0-4725-b847-639de054d13f', 14, 'ANIMALS/INVERTEBRATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES', 1);
INSERT INTO {schema}.keywords VALUES (118, '14802b53-b702-438f-8c8a-f51506807ce6', 14, 'ANIMALS/VERTEBRATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES', 1);
INSERT INTO {schema}.keywords VALUES (119, '7437925f-7e10-4c96-af36-f3532ec24276', 14, 'BACTERIA/ARCHAEA', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > BACTERIA/ARCHAEA', 1);
INSERT INTO {schema}.keywords VALUES (120, '3546cb0a-27a2-4914-85cf-1774b5c4ed19', 14, 'FUNGI', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > FUNGI', 1);
INSERT INTO {schema}.keywords VALUES (121, '0b4081fa-5233-4484-bc82-706976defa0e', 14, 'PLANTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS', 1);
INSERT INTO {schema}.keywords VALUES (122, '6a2a2417-1a9c-4767-bffd-6b99f9747bab', 14, 'PROTISTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS', 1);
INSERT INTO {schema}.keywords VALUES (123, '85510ccc-5dc9-44ff-871e-775e856714f8', 14, 'VIRUSES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > VIRUSES', 1);
INSERT INTO {schema}.keywords VALUES (124, '6bef0291-a9ca-4832-bbb4-80459dc1493f', 15, 'ECOLOGICAL DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (125, 'f1a25060-330c-4f84-9633-ed59ae8c64bf', 15, 'ECOSYSTEMS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (126, 'c7b5c02c-724d-4a19-b824-98180f3900c9', 15, 'VEGETATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (127, '5273c8c2-d30b-4666-b2d5-0388ce2741d0', 16, 'ATMOSPHERIC/OCEAN INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (128, '76943142-e5a9-4ecf-b496-050dd3d97101', 16, 'BIOSPHERIC INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (129, 'de62c07e-96c6-44fb-a3a1-cd2902305691', 16, 'CLIMATE FEEDBACKS', 'EARTH SCIENCE > CLIMATE INDICATORS > CLIMATE FEEDBACKS', 1);
INSERT INTO {schema}.keywords VALUES (130, '76b8c21c-c221-4724-86ef-c07222cb152b', 16, 'CRYOSPHERIC INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (131, '897b3d65-709c-4739-9ba6-85911295d843', 16, 'ENVIRONMENTAL VULNERABILITY INDEX (EVI)', 'EARTH SCIENCE > CLIMATE INDICATORS > ENVIRONMENTAL VULNERABILITY INDEX (EVI)', 1);
INSERT INTO {schema}.keywords VALUES (132, '112e71ec-c0a1-49a8-82d7-bcb317b45860', 16, 'LAND SURFACE/AGRICULTURE INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (133, 'c9a5b3eb-7556-41a8-a2b8-c015db80e5b2', 16, 'PALEOCLIMATE INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (134, '3d64c047-c4fb-4981-bc91-d5dbc22337de', 16, 'SUN-EARTH INTERACTIONS', 'EARTH SCIENCE > CLIMATE INDICATORS > SUN-EARTH INTERACTIONS', 1);
INSERT INTO {schema}.keywords VALUES (135, '9246fc12-17e7-4473-b9c0-c23e4bfc4eda', 16, 'TERRESTRIAL HYDROSPHERE INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (136, '376a1d5c-2496-4381-981f-bc047af92044', 17, 'FROZEN GROUND', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND', 1);
INSERT INTO {schema}.keywords VALUES (137, '8603db51-3484-4439-8b3b-a06f48e8c686', 17, 'GLACIERS/ICE SHEETS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS', 1);
INSERT INTO {schema}.keywords VALUES (138, '860e2af9-ce29-4f3f-b027-ae3747eb3e01', 17, 'SEA ICE', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE', 1);
INSERT INTO {schema}.keywords VALUES (139, 'aa35a52f-e3d9-41bd-abd2-ec7e1a8101d1', 17, 'SNOW/ICE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE', 1);
INSERT INTO {schema}.keywords VALUES (140, '07a856fd-75e2-46e8-91eb-8a8562d3452f', 18, 'BOUNDARIES', 'EARTH SCIENCE > HUMAN DIMENSIONS > BOUNDARIES', 1);
INSERT INTO {schema}.keywords VALUES (141, 'cdbe5ef5-408d-489d-b6ff-4482ce4a99c7', 18, 'ECONOMIC RESOURCES', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES', 1);
INSERT INTO {schema}.keywords VALUES (142, 'd81b77be-0177-4e26-942c-aa911239482d', 18, 'ENVIRONMENTAL GOVERNANCE/MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (143, '3f4cfc81-7745-43d9-b313-f68cdf72359b', 18, 'ENVIRONMENTAL IMPACTS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS', 1);
INSERT INTO {schema}.keywords VALUES (144, 'f1682ed1-2d9c-41ec-9553-49b9ab55df9b', 18, 'HABITAT CONVERSION/FRAGMENTATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (145, 'fee25cad-7ffe-4ee2-a6f2-8116b8a0a707', 18, 'HUMAN SETTLEMENTS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HUMAN SETTLEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (146, 'd4313915-2d24-424c-a171-30ee9a6f4bb5', 18, 'INFRASTRUCTURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (147, 'ec0e2762-f57a-4fdc-b395-c8d7d5590d18', 18, 'NATURAL HAZARDS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS', 1);
INSERT INTO {schema}.keywords VALUES (148, '085edf65-1c8c-414a-b8e4-a1a08ff08f22', 18, 'POPULATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION', 1);
INSERT INTO {schema}.keywords VALUES (149, 'da2c70fd-d92b-45be-b159-b2c10cb387c6', 18, '{schema} HEALTH', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH', 1);
INSERT INTO {schema}.keywords VALUES (150, 'c8317644-4cb2-4e37-b536-c762f7e670ab', 18, 'SOCIAL BEHAVIOR', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR', 1);
INSERT INTO {schema}.keywords VALUES (151, 'a96e6cd6-0f35-491d-8198-7551d03e1cbc', 18, 'SOCIOECONOMICS', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIOECONOMICS', 1);
INSERT INTO {schema}.keywords VALUES (152, '03d38261-1c90-491b-bc4e-cc4e703e1dff', 18, 'SUSTAINABILITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > SUSTAINABILITY', 1);
INSERT INTO {schema}.keywords VALUES (153, 'a246a8cf-e3f9-4045-af9f-dc97f6fe019a', 19, 'EROSION/SEDIMENTATION', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (154, '8073b62d-a2f3-4ad9-b619-de26f28877a7', 19, 'FROZEN GROUND', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND', 1);
INSERT INTO {schema}.keywords VALUES (155, 'd35b9ba5-d018-48a5-8f0d-92b9c55b3279', 19, 'GEOMORPHIC LANDFORMS/PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (156, 'e5815f58-8232-4c7f-b50d-ea71d73891a9', 19, 'LAND USE/LAND COVER', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER', 1);
INSERT INTO {schema}.keywords VALUES (157, 'f36d71c6-f2ad-49c4-809f-09b4f0688412', 19, 'LANDSCAPE', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE', 1);
INSERT INTO {schema}.keywords VALUES (158, '3526afb8-0dc9-43c7-8ad4-f34f250a1e91', 19, 'SOILS', 'EARTH SCIENCE > LAND SURFACE > SOILS', 1);
INSERT INTO {schema}.keywords VALUES (159, 'cb5cc628-a1b5-459e-934f-881153a937b8', 19, 'SURFACE RADIATIVE PROPERTIES', 'EARTH SCIENCE > LAND SURFACE > SURFACE RADIATIVE PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (160, 'a228b67f-0791-470b-a4ca-71b8da279332', 19, 'SURFACE THERMAL PROPERTIES', 'EARTH SCIENCE > LAND SURFACE > SURFACE THERMAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (161, '3e822484-c94a-457b-a32f-376fcbd6fd35', 19, 'TOPOGRAPHY', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (162, 'f27ad52c-3dfd-4788-851a-427e60ae1b8f', 20, 'AQUATIC SCIENCES', 'EARTH SCIENCE > OCEANS > AQUATIC SCIENCES', 1);
INSERT INTO {schema}.keywords VALUES (163, 'c16bda61-353b-4668-af2f-bbb98785b6fa', 20, 'BATHYMETRY/SEAFLOOR TOPOGRAPHY', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (164, 'b6fd22ab-dca7-4dfa-8812-913453b5695b', 20, 'COASTAL PROCESSES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (165, 'ca154e02-a226-4cc7-8e4a-4474e7eb1eeb', 20, 'MARINE ENVIRONMENT MONITORING', 'EARTH SCIENCE > OCEANS > MARINE ENVIRONMENT MONITORING', 1);
INSERT INTO {schema}.keywords VALUES (166, 'bb04ee83-bf49-4f96-898d-20bb6e92bc93', 20, 'MARINE GEOPHYSICS', 'EARTH SCIENCE > OCEANS > MARINE GEOPHYSICS', 1);
INSERT INTO {schema}.keywords VALUES (167, 'ce4b2c6e-3d69-4cf1-8416-c36e5f9b1b2c', 20, 'MARINE SEDIMENTS', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (168, 'e3b178eb-2d47-41db-aba1-43a05e9e9256', 20, 'MARINE VOLCANISM', 'EARTH SCIENCE > OCEANS > MARINE VOLCANISM', 1);
INSERT INTO {schema}.keywords VALUES (169, '0517ae1f-7617-4f3b-80cb-649178032825', 20, 'OCEAN ACOUSTICS', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS', 1);
INSERT INTO {schema}.keywords VALUES (170, '6eb3919b-85ce-4988-8b78-9d0018fd8089', 20, 'OCEAN CHEMISTRY', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (171, 'a031952d-9f00-4ba5-9966-5f87ab9dfdd4', 20, 'OCEAN CIRCULATION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION', 1);
INSERT INTO {schema}.keywords VALUES (172, '63bc0693-52eb-4ebd-a39e-e77e96409072', 20, 'OCEAN HEAT BUDGET', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET', 1);
INSERT INTO {schema}.keywords VALUES (173, '457883c4-b30c-4d26-bed8-6c2887ebbc90', 20, 'OCEAN OPTICS', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS', 1);
INSERT INTO {schema}.keywords VALUES (174, 'bfa56100-6fb5-4e49-9633-298fa3b45508', 20, 'OCEAN PRESSURE', 'EARTH SCIENCE > OCEANS > OCEAN PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (175, '251c87cd-03b3-464f-8390-8ede2fec28fc', 20, 'OCEAN TEMPERATURE', 'EARTH SCIENCE > OCEANS > OCEAN TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (176, 'a04804d5-1064-48fd-a7a7-8da8e10399e1', 20, 'OCEAN WAVES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES', 1);
INSERT INTO {schema}.keywords VALUES (177, '346cade5-801a-4afc-9652-48d02905bc4f', 20, 'OCEAN WINDS', 'EARTH SCIENCE > OCEANS > OCEAN WINDS', 1);
INSERT INTO {schema}.keywords VALUES (178, 'a46016d7-e571-403a-ab37-7223fd74e68e', 20, 'SALINITY/DENSITY', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (179, 'd73e969a-4b66-4713-8d63-fa3cbb1e25e3', 20, 'SEA ICE', 'EARTH SCIENCE > OCEANS > SEA ICE', 1);
INSERT INTO {schema}.keywords VALUES (180, '68f93a0c-1525-4f5a-9545-5d94191a3dbf', 20, 'SEA SURFACE TOPOGRAPHY', 'EARTH SCIENCE > OCEANS > SEA SURFACE TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (181, 'e3bef663-6116-4f15-995c-38c7cdc9652c', 20, 'TIDES', 'EARTH SCIENCE > OCEANS > TIDES', 1);
INSERT INTO {schema}.keywords VALUES (182, '1ee8a323-f0ba-4a21-b597-50890c527c8e', 20, 'WATER QUALITY', 'EARTH SCIENCE > OCEANS > WATER QUALITY', 1);
INSERT INTO {schema}.keywords VALUES (183, 'dba19648-3f52-48ba-b00b-8527d44c4d74', 21, 'ICE CORE RECORDS', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (184, '486f2c33-2401-4292-9d74-8756ee95211f', 21, 'LAND RECORDS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (185, '45325a01-2522-48d3-bffa-0edf1a934d48', 21, 'OCEAN/LAKE RECORDS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (186, '350c9923-fa80-4f83-8724-2886ac559ac0', 21, 'PALEOCLIMATE RECONSTRUCTIONS', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (187, 'e3fa1998-b003-4d55-a92e-16b42ac0fc17', 22, 'EARTH GASES/LIQUIDS', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS', 1);
INSERT INTO {schema}.keywords VALUES (188, '906e647b-2683-4ae7-9986-1aea15582b52', 22, 'GEOCHEMISTRY', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (189, '5498572c-aaed-4c08-8aad-8b297057e9c9', 22, 'GEODETICS', 'EARTH SCIENCE > SOLID EARTH > GEODETICS', 1);
INSERT INTO {schema}.keywords VALUES (190, '910013d7-1e6a-4d1a-9921-be32d792a290', 22, 'GEOMAGNETISM', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM', 1);
INSERT INTO {schema}.keywords VALUES (191, 'b5cb1fab-7281-478f-bb3b-ff04f900b3fc', 22, 'GEOMORPHIC LANDFORMS/PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (192, 'ec2bf43d-2525-439e-bbbe-0db758e71965', 22, 'GEOTHERMAL DYNAMICS', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (193, '221386f6-ef9b-4990-82b3-f990b0fe39fa', 22, 'GRAVITY/GRAVITATIONAL FIELD', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD', 1);
INSERT INTO {schema}.keywords VALUES (194, 'ba8d7f68-ad3a-4874-bc75-312b24b1b1ac', 22, 'ROCKS/MINERALS/CRYSTALS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS', 1);
INSERT INTO {schema}.keywords VALUES (195, '1e17c8d3-81d0-473c-8f24-d2a4ea52b6b9', 22, 'TECTONICS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS', 1);
INSERT INTO {schema}.keywords VALUES (196, '0a81d67a-102b-4611-a38c-dbfdd7ba4e7d', 23, 'GAMMA RAY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > GAMMA RAY', 1);
INSERT INTO {schema}.keywords VALUES (197, '7a73c724-b532-45eb-a9a5-c77330b61bab', 23, 'INFRARED WAVELENGTHS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS', 1);
INSERT INTO {schema}.keywords VALUES (198, '6182be8b-d006-4327-994d-6f27c7e4d9a9', 23, 'LIDAR', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > LIDAR', 1);
INSERT INTO {schema}.keywords VALUES (199, '66700628-2b62-4466-999e-faeb15ca4da5', 23, 'MICROWAVE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > MICROWAVE', 1);
INSERT INTO {schema}.keywords VALUES (200, 'cda9b483-8711-42b8-82f9-e7d22ce9c62c', 23, 'PLATFORM CHARACTERISTICS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (201, 'd3b7c3c0-e644-4f01-94da-dfebe854c0d1', 23, 'RADAR', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR', 1);
INSERT INTO {schema}.keywords VALUES (202, 'd7ef7608-01f5-4e95-9fd9-7dc2aa36113d', 23, 'RADIO WAVE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADIO WAVE', 1);
INSERT INTO {schema}.keywords VALUES (203, '8799f524-e313-4d2d-9428-8d672d123513', 23, 'SENSOR CHARACTERISTICS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (5116, '53231d78-471d-4afe-a435-b577b7d53b17', 103, 'MICROFAUNA', 'EARTH SCIENCE > AGRICULTURE > SOILS > MICROFAUNA', 1);
INSERT INTO {schema}.keywords VALUES (204, '0f36cd66-d755-4809-ad0e-d67b1b9aff6c', 23, 'ULTRAVIOLET WAVELENGTHS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > ULTRAVIOLET WAVELENGTHS', 1);
INSERT INTO {schema}.keywords VALUES (205, 'c5ff6f39-0c35-488a-96f2-f3498c678e45', 23, 'VISIBLE WAVELENGTHS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > VISIBLE WAVELENGTHS', 1);
INSERT INTO {schema}.keywords VALUES (206, '12156f9d-9731-446e-b9de-a781af653b1c', 23, 'X-RAY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > X-RAY', 1);
INSERT INTO {schema}.keywords VALUES (207, '3a942e8a-d2f2-42bf-9e83-b7b3793b100e', 24, 'IONOSPHERE/MAGNETOSPHERE DYNAMICS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (208, '2e83362e-d8f8-4bca-83fd-bae360ebe94b', 24, 'SOLAR ACTIVITY', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (209, 'cad91f82-7e2a-43b7-b272-2dc77e2791f4', 24, 'SOLAR ENERGETIC PARTICLE FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (210, 'a82d885e-34cd-496a-b34d-17a23ad04126', 24, 'SOLAR ENERGETIC PARTICLE PROPERTIES', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (211, '099ab1ae-f4d2-48cc-be2f-86bd58ffc4ca', 25, 'GLACIERS/ICE SHEETS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS', 1);
INSERT INTO {schema}.keywords VALUES (212, '734f8f27-6976-4b67-8794-c7fc79d6161e', 25, 'GROUND WATER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER', 1);
INSERT INTO {schema}.keywords VALUES (213, '50b8fe04-9149-4b7f-a8b2-b33b1e3aa192', 25, 'SNOW/ICE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE', 1);
INSERT INTO {schema}.keywords VALUES (214, '5debb283-51e4-435e-b2a2-e8e2a977220d', 25, 'SURFACE WATER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER', 1);
INSERT INTO {schema}.keywords VALUES (215, '8c02f5d1-ce86-4bf5-84d5-b3496cdba6ad', 25, 'WATER QUALITY/WATER CHEMISTRY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (4956, 'ecf29317-bd5e-447b-b911-f8bfb153c83b', 26, 'CALIBRATION', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > CALIBRATION/VALIDATION > CALIBRATION', 1);
INSERT INTO {schema}.keywords VALUES (4957, '565cb301-44de-446c-8fe3-4b5cce428315', 27, 'DESKTOP GEOGRAPHIC INFORMATION SYSTEMS', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > GEOGRAPHIC INFORMATION SYSTEMS > DESKTOP GEOGRAPHIC INFORMATION SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (4958, '0dd83b2a-e83f-4a0c-a1ff-2fbdbbcce62d', 27, 'MOBILE GEOGRAPHIC INFORMATION SYSTEMS', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > GEOGRAPHIC INFORMATION SYSTEMS > MOBILE GEOGRAPHIC INFORMATION SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (4959, '037f42a2-cdda-4b72-b49c-bdec74d03e0a', 27, 'WEB-BASED GEOGRAPHIC INFORMATION SYSTEMS', 'EARTH SCIENCE SERVICES > DATA ANALYSIS AND VISUALIZATION > GEOGRAPHIC INFORMATION SYSTEMS > WEB-BASED GEOGRAPHIC INFORMATION SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (4960, 'dad75074-b2f7-4cb7-ae02-02d054f18251', 35, 'DATA REFORMATTING', 'EARTH SCIENCE SERVICES > DATA MANAGEMENT/DATA HANDLING > DATA INTEROPERABILITY > DATA REFORMATTING', 1);
INSERT INTO {schema}.keywords VALUES (4961, '1a2f59f6-76f3-4c57-b70b-de350708426f', 42, 'BACKGROUND INFORMATION', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > CURRICULUM SUPPORT > BACKGROUND INFORMATION', 1);
INSERT INTO {schema}.keywords VALUES (4962, 'f85293fe-eb9d-491a-bba8-46261a38b9bf', 42, 'CLASSROOM ACTIVITIES', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > CURRICULUM SUPPORT > CLASSROOM ACTIVITIES', 1);
INSERT INTO {schema}.keywords VALUES (4963, 'fc889d75-41f3-4f36-b461-1100536c8f50', 42, 'LESSON PLANS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > CURRICULUM SUPPORT > LESSON PLANS', 1);
INSERT INTO {schema}.keywords VALUES (4964, '24b7bc59-3f10-4a0b-b9c1-92ae10feb007', 43, 'MUSEUM EXHIBITS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > EXHIBIT MATERIALS > MUSEUM EXHIBITS', 1);
INSERT INTO {schema}.keywords VALUES (4965, 'fb3b3728-a6ff-465d-8a33-2619a3276cdf', 43, 'SCIENCE CENTER EXHIBITS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > EXHIBIT MATERIALS > SCIENCE CENTER EXHIBITS', 1);
INSERT INTO {schema}.keywords VALUES (4966, 'bfdcc74d-5e53-44e8-bc0e-5170cfa6152c', 44, 'STAND-ALONE INTERACTIVE PROGRAMS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > INTERACTIVE PROGRAMS > STAND-ALONE INTERACTIVE PROGRAMS', 1);
INSERT INTO {schema}.keywords VALUES (4967, 'cd8bdd2c-a0db-4202-b10d-a1760d834700', 44, 'WEB-BASED INTERACTIVE PROGRAMS', 'EARTH SCIENCE SERVICES > EDUCATION/OUTREACH > INTERACTIVE PROGRAMS > WEB-BASED INTERACTIVE PROGRAMS', 1);
INSERT INTO {schema}.keywords VALUES (4968, 'f1c35c74-0b10-46de-9c06-efeda92d383a', 45, 'CROP FORECAST', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > AGRICULTURAL ADVISORIES > CROP FORECAST', 1);
INSERT INTO {schema}.keywords VALUES (4969, 'a394776f-b658-44de-b952-90f4e53d58cc', 45, 'DROUGHT FORECAST', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > AGRICULTURAL ADVISORIES > DROUGHT FORECAST', 1);
INSERT INTO {schema}.keywords VALUES (4970, '8de8b909-8fcb-4ed7-9df3-37f9dd54054f', 46, 'PRESCRIBED BURNS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > FIRE ADVISORIES > PRESCRIBED BURNS', 1);
INSERT INTO {schema}.keywords VALUES (4971, '855dc9f5-ccbf-4972-8828-41e11f2aca7a', 46, 'WILDFIRES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > FIRE ADVISORIES > WILDFIRES', 1);
INSERT INTO {schema}.keywords VALUES (4972, 'a779ee72-d21e-4106-9efa-93e970bc287f', 47, 'EARTHQUAKES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > GEOLOGICAL ADVISORIES > EARTHQUAKES', 1);
INSERT INTO {schema}.keywords VALUES (4973, '8f9d66e9-f65d-41c6-9640-90bd3e155bf8', 47, 'GEOMAGNETISM', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > GEOLOGICAL ADVISORIES > GEOMAGNETISM', 1);
INSERT INTO {schema}.keywords VALUES (4974, 'a8f6e91f-7875-4597-8ab8-64f4b14e8b49', 47, 'LANDSLIDES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > GEOLOGICAL ADVISORIES > LANDSLIDES', 1);
INSERT INTO {schema}.keywords VALUES (4975, 'f342683b-94ee-4ef6-8915-b18a473fafbd', 47, 'VOLCANIC ACTIVITY', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > GEOLOGICAL ADVISORIES > VOLCANIC ACTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (4976, 'bcb42cdb-0ad3-42e1-ac72-8af05c68cf48', 48, 'ANIMAL HEALTH ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HEALTH ADVISORIES > ANIMAL HEALTH ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (4977, '8cc052a0-314a-408d-8c2d-c8245bab2465', 48, 'DISEASE/EPIDEMIC', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HEALTH ADVISORIES > DISEASE/EPIDEMIC', 1);
INSERT INTO {schema}.keywords VALUES (4978, '5e468bd6-a13a-4f49-8cb4-7a0ba69d8ad3', 48, 'HUMAN HEALTH ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HEALTH ADVISORIES > HUMAN HEALTH ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (4979, 'b28c7543-e313-43e5-8a27-2d84098d2e11', 49, 'AVALANCHE FORECASTS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HYDROLOGICAL ADVISORIES > AVALANCHE FORECASTS', 1);
INSERT INTO {schema}.keywords VALUES (4980, '3678d18c-9dca-4743-abc0-1442b4d438d2', 49, 'DROUGHT', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HYDROLOGICAL ADVISORIES > DROUGHT', 1);
INSERT INTO {schema}.keywords VALUES (4981, 'e757b032-bfa4-4976-b98a-838f61a86ea8', 49, 'FLOODS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HYDROLOGICAL ADVISORIES > FLOODS', 1);
INSERT INTO {schema}.keywords VALUES (4982, '9a583e74-34e9-4eb5-af7a-03418d702af6', 49, 'WATER QUALITY', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > HYDROLOGICAL ADVISORIES > WATER QUALITY', 1);
INSERT INTO {schema}.keywords VALUES (4983, '3de6fa74-bb80-4bc6-ae60-1e6fe8ae6c67', 50, 'MARINE BIOLOGY', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > MARINE BIOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (4984, 'c1111b23-9946-497a-8829-b58da3fce720', 50, 'MARINE WEATHER/FORECAST', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > MARINE WEATHER/FORECAST', 1);
INSERT INTO {schema}.keywords VALUES (4985, 'c5563d03-2f68-4dac-a50b-3b8450725356', 50, 'OCEAN TEMPERATURE', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > OCEAN TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (4986, 'a4aea007-d297-4051-8b41-5cdde00b4d1e', 50, 'SEA ICE', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > SEA ICE', 1);
INSERT INTO {schema}.keywords VALUES (4987, 'f04be06d-5976-43d0-94cb-91d5c487d57c', 50, 'SEA STATE', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > SEA STATE', 1);
INSERT INTO {schema}.keywords VALUES (4988, 'd8aee072-097c-496f-8fe7-b65605fc1103', 50, 'TIDES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > TIDES', 1);
INSERT INTO {schema}.keywords VALUES (4989, '6ee1f87a-dc7a-48f7-9b0f-9c529a5645a5', 50, 'TSUNAMIS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > MARINE ADVISORIES > TSUNAMIS', 1);
INSERT INTO {schema}.keywords VALUES (4990, '94bafe5f-b97e-49b3-ad62-494865b799f3', 51, 'AURORA FORECASTS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > AURORA FORECASTS', 1);
INSERT INTO {schema}.keywords VALUES (4991, 'b40d8d03-6286-48cd-818c-20d1680d6453', 51, 'CORONAL MASS EJECTION', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > CORONAL MASS EJECTION', 1);
INSERT INTO {schema}.keywords VALUES (4992, 'ed49aea3-c1ce-4522-985b-1b1b2b2c7790', 51, 'GEOMAGNETIC STORM', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > GEOMAGNETIC STORM', 1);
INSERT INTO {schema}.keywords VALUES (4993, '8cc74c57-9a5e-4f71-a918-73746c150bd3', 51, 'RADIO BLACKOUTS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > RADIO BLACKOUTS', 1);
INSERT INTO {schema}.keywords VALUES (4994, '6e039ab2-beed-4b17-9fb2-41965839f5bf', 51, 'SOLAR FLARES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > SOLAR FLARES', 1);
INSERT INTO {schema}.keywords VALUES (4995, '3b786f1b-aca7-437b-bd86-44f20789da7b', 51, 'SOLAR RADIATION STORMS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > SOLAR RADIATION STORMS', 1);
INSERT INTO {schema}.keywords VALUES (4996, '65475fcc-b696-4b02-a812-f12364046c4c', 51, 'SOLAR WINDS', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > SPACE WEATHER ADVISORIES > SOLAR WINDS', 1);
INSERT INTO {schema}.keywords VALUES (4997, '49c8e881-7100-42cf-9c2e-48f2012e5671', 52, 'AIR QUALITY', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > AIR QUALITY', 1);
INSERT INTO {schema}.keywords VALUES (4998, '392ff7f6-dcf6-4543-930e-3e6e441ad881', 52, 'CLIMATE ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > CLIMATE ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (4999, '8f7c2388-24e4-4f90-a833-6dc166693879', 52, 'DUST/ASH ADVISORIES', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > DUST/ASH ADVISORIES', 1);
INSERT INTO {schema}.keywords VALUES (5000, 'fb47fa33-8b9b-4655-b448-1acf8a629015', 52, 'FROST/FREEZE WARNING', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > FROST/FREEZE WARNING', 1);
INSERT INTO {schema}.keywords VALUES (5001, '10144249-d836-4a7d-adc8-177702595c87', 52, 'HEAT ADVISORY', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > HEAT ADVISORY', 1);
INSERT INTO {schema}.keywords VALUES (5002, '020585ff-91fb-421b-ba24-305d657c2231', 52, 'PRESENT WEATHER', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > PRESENT WEATHER', 1);
INSERT INTO {schema}.keywords VALUES (5003, '0d67baa7-19c7-440b-b658-1bda9a8e09bf', 52, 'SEVERE WEATHER', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > SEVERE WEATHER', 1);
INSERT INTO {schema}.keywords VALUES (5004, 'e6c260ca-4f1e-4ed9-92d8-b50d1927f88e', 52, 'UV RADIATION', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > UV RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5005, '0451cbfb-3c46-4afe-b02d-456beabd89a6', 52, 'WEATHER FORECAST', 'EARTH SCIENCE SERVICES > ENVIRONMENTAL ADVISORIES > WEATHER/CLIMATE ADVISORIES > WEATHER FORECAST', 1);
INSERT INTO {schema}.keywords VALUES (5006, '39a63377-02d8-41a7-814a-41ea7db700c9', 55, 'BIOLOGICAL HAZARDS MAPPING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MAPPING > BIOLOGICAL HAZARDS MAPPING', 1);
INSERT INTO {schema}.keywords VALUES (5007, 'b32eb466-3fc1-4a03-8011-99002f5591cb', 55, 'GEOPHYSICAL HAZARDS MAPPING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MAPPING > GEOPHYSICAL HAZARDS MAPPING', 1);
INSERT INTO {schema}.keywords VALUES (5008, '764e3842-9c3c-4d01-a390-fbccfaa81884', 55, 'HYDROLOGICAL HAZARDS MAPPING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MAPPING > HYDROLOGICAL HAZARDS MAPPING', 1);
INSERT INTO {schema}.keywords VALUES (5009, '9a62a72d-8774-4f52-94e2-f9ad63ce34bd', 55, 'METEOROLOGICAL HAZARDS MAPPING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MAPPING > METEOROLOGICAL HAZARDS MAPPING', 1);
INSERT INTO {schema}.keywords VALUES (5010, 'd454b0f7-d811-46b4-9778-45bb60d7c914', 55, 'TECHNOLOGICAL HAZARDS MAPPING', 'EARTH SCIENCE SERVICES > HAZARDS MANAGEMENT > HAZARDS MAPPING > TECHNOLOGICAL HAZARDS MAPPING', 1);
INSERT INTO {schema}.keywords VALUES (5011, '108318e6-89c0-4e0d-bcad-7bfdb0df49f5', 62, 'MODEL LOGS', 'EARTH SCIENCE SERVICES > MODELS > ANCILLARY MODELS > MODEL LOGS', 1);
INSERT INTO {schema}.keywords VALUES (5012, '6ee8d84e-c829-44e2-8768-3e5342b79707', 83, 'BIBLIOGRAPHIC DATABASES', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > BIBLIOGRAPHIC > BIBLIOGRAPHIC DATABASES', 1);
INSERT INTO {schema}.keywords VALUES (5013, '17d6617a-10ff-45b6-ac16-a7ab8f6aa1eb', 83, 'PERSONNEL DIRECTORIES', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > BIBLIOGRAPHIC > PERSONNEL DIRECTORIES', 1);
INSERT INTO {schema}.keywords VALUES (5014, '2a00621f-4e28-4d16-a183-0658e95d473a', 83, 'PROFESSIONAL SCIENTIFIC ORGANIZATIONS', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > BIBLIOGRAPHIC > PROFESSIONAL SCIENTIFIC ORGANIZATIONS', 1);
INSERT INTO {schema}.keywords VALUES (5015, 'e12352e3-0312-4c12-b62b-25e147193b78', 84, 'ASK-A BIOLOGIST', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS > ASK-A BIOLOGIST', 1);
INSERT INTO {schema}.keywords VALUES (5016, '185f7a64-7c35-4e83-b0f0-7f2012e66c5d', 84, 'ASK-A ECOLOGIST', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS > ASK-A ECOLOGIST', 1);
INSERT INTO {schema}.keywords VALUES (5017, 'c62eddd4-a320-4f5d-8f9c-5f333be0b7c3', 84, 'ASK-A GEOLOGIST', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS > ASK-A GEOLOGIST', 1);
INSERT INTO {schema}.keywords VALUES (5018, '1ee9dd80-6ca8-49a9-a7be-bd965595e1a3', 84, 'ASK-A MARINE BIOLOGIST', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS > ASK-A MARINE BIOLOGIST', 1);
INSERT INTO {schema}.keywords VALUES (5019, 'a9586b25-36da-4e7d-ac2a-b1b24e2f44bd', 84, 'ASK-A METEOROLOGIST', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS > ASK-A METEOROLOGIST', 1);
INSERT INTO {schema}.keywords VALUES (5020, '6621ba11-af39-4634-b07c-811585e91a77', 84, 'ASK-A OCEANOGRAPHER', 'EARTH SCIENCE SERVICES > REFERENCE AND INFORMATION SERVICES > DIGITAL/VIRTUAL REFERENCE DESKS > ASK-A OCEANOGRAPHER', 1);
INSERT INTO {schema}.keywords VALUES (5021, '83cfde01-9ed0-44df-a606-4bcd7350706c', 90, 'CHAIN DEFINITION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > CHAIN DEFINITION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5022, '62d7c667-997a-4a9d-abe1-4cca4519673e', 90, 'COVERAGE GENERALIZATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > COVERAGE GENERALIZATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5023, 'e8087aa7-142f-44d3-ad6e-0a75f17b091e', 90, 'FEATURE GENERALIZATION APPLICATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > FEATURE GENERALIZATION APPLICATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5024, '1ef01bb2-eba5-41ee-b385-8c36e477d286', 90, 'GAZETTEER APPLICATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > GAZETTEER APPLICATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5025, '9047c8f5-3e5a-4073-8cf5-7f4d5ef783d1', 90, 'GEOGRAPHIC DATA DISCOVERY SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > GEOGRAPHIC DATA DISCOVERY SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5026, '617a50aa-5762-4ff3-aa03-c94b5cc65209', 90, 'GEOGRAPHIC DATA EXTRACTION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > GEOGRAPHIC DATA EXTRACTION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5027, '75fbafb0-1f0e-47b3-a9c7-e56dea4b0e91', 90, 'GEOGRAPHIC DATA MANAGEMENT SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > GEOGRAPHIC DATA MANAGEMENT SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5028, '6d77e9d1-d2d1-4b57-a313-0e01e22f799d', 90, 'WEB PORTAL SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA APPLICATION SERVICES > WEB PORTAL SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5029, '4b5c0805-13ec-4d32-81ae-430265d15f49', 91, 'CHANGE DETECTION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > CHANGE DETECTION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5030, '91e02d43-bf56-480f-89c9-ddfca7fc7239', 91, 'COVERAGE GENERALIZATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > COVERAGE GENERALIZATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5031, '72b3df24-a061-4624-ad62-f3794798136c', 91, 'COVERAGE PORTRAYAL SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > COVERAGE PORTRAYAL SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5032, 'c8390ac2-4124-43e7-a83e-87cf5eb40f0e', 91, 'DATA ALIGNMENT SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > DATA ALIGNMENT SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5033, 'c53868ba-608c-495c-a65d-038f53f7267f', 91, 'DIMENSION MEASUREMENT SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > DIMENSION MEASUREMENT SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5034, 'df6cc99d-6254-4759-91bd-3233b6419b4c', 91, 'FEATURE GENERALIZATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > FEATURE GENERALIZATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5035, 'af95fcef-dbe1-4dbf-9969-1e6ca75e7f5c', 91, 'FEATURE PORTRAYAL SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > FEATURE PORTRAYAL SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5036, '85b1ed02-700a-4591-b2f7-c997a676332c', 91, 'FORMAT CONVERSION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > FORMAT CONVERSION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5037, 'd55c5f36-4965-441f-8141-9a3faa17297b', 91, 'GEOCODER SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > GEOCODER SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5038, 'dccb7a1b-91d6-43d8-bb9d-ffb5778a17a3', 91, 'GEOGRAPHIC DATA EXTRACTION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > GEOGRAPHIC DATA EXTRACTION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5039, '8ca62ed6-d6e9-4ab0-97ef-138b0f83f597', 91, 'GEOLINKED DATA ACCESS SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > GEOLINKED DATA ACCESS SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5040, '2a2db13c-c86d-40ea-9fa8-6d2d5bdac08e', 91, 'GEOLINKING SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > GEOLINKING SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5041, '250cc56c-2edf-4774-8970-d69a17f15e97', 91, 'GEOPARSER SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > GEOPARSER SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5042, 'ceeb019c-84d0-4353-b311-04b5a7e305a7', 91, 'PROXIMITY ANALYSIS SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > PROXIMITY ANALYSIS SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5043, 'a2476ff7-0d19-4db9-9834-956351cb0f3e', 91, 'SEMANTIC TRANSLATION SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > SEMANTIC TRANSLATION SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5044, '4a07f23e-e3f7-4cda-880f-c8cdc6b33e37', 91, 'WEB 3D SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > WEB 3D SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5045, 'ff889b84-e12f-40ab-815b-61d5aecf2b63', 91, 'WEB COORDINATE TRANSFORMATION SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > WEB COORDINATE TRANSFORMATION SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5046, '0cf44d92-1959-41af-9890-b916008efbae', 91, 'WEB IMAGE CLASSIFICATION SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > WEB IMAGE CLASSIFICATION SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5047, 'bb0e3a35-d81e-4741-9c0e-3b77bc409cf8', 91, 'WEB TERRAIN SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > DATA PROCESSING SERVICES > WEB TERRAIN SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5048, 'cabd97d6-aa6c-48b8-963b-79248634ce5d', 92, 'CATALOG SERVICE FOR THE WEB', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > CATALOG SERVICE FOR THE WEB', 1);
INSERT INTO {schema}.keywords VALUES (5049, '73098e85-81ed-4556-93ca-ac1e4f4884ab', 92, 'GAZETTEER SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > GAZETTEER SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5050, 'f2115645-e006-414a-bfb6-083d4874a665', 92, 'UNIVERSAL DESCRIPTION, DISCOVERY AND INTEGRATION (UDDI) SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > UNIVERSAL DESCRIPTION, DISCOVERY AND INTEGRATION (UDDI) SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5051, 'd6379bf5-88dd-4ec0-9b15-441db5b10b59', 92, 'WEB COVERAGE SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > WEB COVERAGE SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5052, 'd2e9b10f-3b62-42fb-b906-7b4779170a4a', 92, 'WEB FEATURE SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > WEB FEATURE SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5053, 'cdb4a032-bb7d-455d-b3dc-e88fa465b7c7', 92, 'WEB MAP SERVICE', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > WEB MAP SERVICE', 1);
INSERT INTO {schema}.keywords VALUES (5054, '933bf0ab-11af-40df-a9d9-1b4a809edd87', 92, 'WEB PROCESSING SERVICES', 'EARTH SCIENCE SERVICES > WEB SERVICES > INFORMATION MANAGEMENT SERVICES > WEB PROCESSING SERVICES', 1);
INSERT INTO {schema}.keywords VALUES (5055, '8916dafb-5ad5-45c6-ab64-3500ea1e9577', 93, 'AQUACULTURE', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL AQUATIC SCIENCES > AQUACULTURE', 1);
INSERT INTO {schema}.keywords VALUES (5056, 'c7112a64-be39-414a-9125-f63ab44ecb5b', 93, 'FISHERIES', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL AQUATIC SCIENCES > FISHERIES', 1);
INSERT INTO {schema}.keywords VALUES (5057, '0916afef-a0b7-4ecd-85ba-cc24070470a7', 93, 'TEST', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL AQUATIC SCIENCES > TEST', 1);
INSERT INTO {schema}.keywords VALUES (5058, '18a8197e-3a3f-408c-9c51-e9fe89dd6b45', 94, 'FERTILIZERS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL CHEMICALS > FERTILIZERS', 1);
INSERT INTO {schema}.keywords VALUES (5059, '59a203f9-f818-42a6-8d00-4301385cafc3', 94, 'PESTICIDES', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL CHEMICALS > PESTICIDES', 1);
INSERT INTO {schema}.keywords VALUES (5060, 'f2f37978-d942-43d2-9c51-79e9f5bdfe24', 95, 'AGRICULTURAL EQUIPMENT', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL ENGINEERING > AGRICULTURAL EQUIPMENT', 1);
INSERT INTO {schema}.keywords VALUES (5061, 'd53e1951-fb68-4ad8-8725-d19c10751da5', 95, 'FARM STRUCTURES', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL ENGINEERING > FARM STRUCTURES', 1);
INSERT INTO {schema}.keywords VALUES (5062, 'f12d8026-f24a-4413-91d0-4704c243c9e7', 96, 'CROP/PLANT YIELDS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > CROP/PLANT YIELDS', 1);
INSERT INTO {schema}.keywords VALUES (5063, '2dda92a8-6c26-4506-9881-43b6d9a83b18', 96, 'CROPPING SYSTEMS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > CROPPING SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5064, 'a756fd6b-6208-4af0-ac56-6ee914fc4597', 96, 'IRRIGATION', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > IRRIGATION', 1);
INSERT INTO {schema}.keywords VALUES (5065, 'dcd7a439-6021-4fc3-b3d8-a8936ef171f6', 96, 'PLANT BREEDING AND GENETICS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > PLANT BREEDING AND GENETICS', 1);
INSERT INTO {schema}.keywords VALUES (5066, '213cefd8-806f-40f5-b3ca-05022cde9498', 96, 'PLANT DISEASES/DISORDERS/PESTS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > PLANT DISEASES/DISORDERS/PESTS', 1);
INSERT INTO {schema}.keywords VALUES (5067, 'c7570528-f2d5-42b0-b8e9-d12a2432e87e', 96, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (5068, 'b376a9f9-585e-4567-ba1f-55ef45cfa8df', 96, 'WEEDS, NOXIOUS PLANTS OR INVASIVE PLANTS', 'EARTH SCIENCE > AGRICULTURE > AGRICULTURAL PLANT SCIENCE > WEEDS, NOXIOUS PLANTS OR INVASIVE PLANTS', 1);
INSERT INTO {schema}.keywords VALUES (5069, 'a368da76-b191-4859-bd55-8643f4fab812', 97, 'DAIRY PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL COMMODITIES > DAIRY PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5070, '1e2557c5-d232-48e4-8276-369a22ae6aae', 97, 'LIVESTOCK PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL COMMODITIES > LIVESTOCK PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5071, 'd3ce1677-f3a8-452e-91c8-0ff80e6a3f09', 97, 'POULTRY PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL COMMODITIES > POULTRY PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5072, '26089a3e-469d-44b3-a9aa-231d0a072ef9', 98, 'ANIMAL BREEDING AND GENETICS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL BREEDING AND GENETICS', 1);
INSERT INTO {schema}.keywords VALUES (5073, 'e749bafe-9a0a-42cc-bed8-9b42e3e088c8', 98, 'ANIMAL DISEASES/DISORDERS/PESTS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL DISEASES/DISORDERS/PESTS', 1);
INSERT INTO {schema}.keywords VALUES (5074, '5d1b53b2-7d69-4b7c-903f-d8cf29430f93', 98, 'ANIMAL ECOLOGY AND BEHAVIOR', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL ECOLOGY AND BEHAVIOR', 1);
INSERT INTO {schema}.keywords VALUES (5075, 'e5b724af-b661-406a-ae1f-7cd2730c0576', 98, 'ANIMAL MANAGEMENT SYSTEMS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL MANAGEMENT SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5076, '3c1c65c3-e1ef-4163-9695-c39ff7fb48da', 98, 'ANIMAL MANURE AND WASTE', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL MANURE AND WASTE', 1);
INSERT INTO {schema}.keywords VALUES (5077, 'ca551e61-4b8c-46d5-8590-80cada40ebbd', 98, 'ANIMAL NUTRITION', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL NUTRITION', 1);
INSERT INTO {schema}.keywords VALUES (5078, 'f9cdf3ae-fe8b-4a19-a946-a8c8780d7894', 98, 'ANIMAL PHYSIOLOGY AND BIOCHEMISTRY', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL PHYSIOLOGY AND BIOCHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5079, '3c0bbd0f-6d4d-4036-afa9-03f9b4f8fba0', 98, 'ANIMAL YIELDS', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > ANIMAL YIELDS', 1);
INSERT INTO {schema}.keywords VALUES (5080, '2c31fc22-747a-476f-b76d-fec61220b5b1', 98, 'APICULTURE', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > APICULTURE', 1);
INSERT INTO {schema}.keywords VALUES (5081, '06053150-d796-477b-b305-292442d658ed', 98, 'SERICULTURE', 'EARTH SCIENCE > AGRICULTURE > ANIMAL SCIENCE > SERICULTURE', 1);
INSERT INTO {schema}.keywords VALUES (5082, 'cf9ef34d-ed39-4c8d-bf00-ca1b0bb11363', 99, 'FEED COMPOSITION', 'EARTH SCIENCE > AGRICULTURE > FEED PRODUCTS > FEED COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (5083, 'b9957bbc-3c12-481d-86a0-0f6cf2bb8219', 99, 'FEED CONTAMINATION AND TOXICOLOGY', 'EARTH SCIENCE > AGRICULTURE > FEED PRODUCTS > FEED CONTAMINATION AND TOXICOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (5084, 'fec2eb53-bc69-4d35-849c-c2bedf5dc6cf', 99, 'FEED PROCESSING', 'EARTH SCIENCE > AGRICULTURE > FEED PRODUCTS > FEED PROCESSING', 1);
INSERT INTO {schema}.keywords VALUES (5085, '9244fe19-b86f-4a8d-82bf-c52f804a77e3', 99, 'FEED STORAGE', 'EARTH SCIENCE > AGRICULTURE > FEED PRODUCTS > FEED STORAGE', 1);
INSERT INTO {schema}.keywords VALUES (5086, 'eb9b8c19-3b39-4865-bcfc-d2a12689094a', 100, 'FOOD ADDITIVES', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE > FOOD ADDITIVES', 1);
INSERT INTO {schema}.keywords VALUES (5087, 'e86ea427-f735-4998-af16-9bd619df4974', 100, 'FOOD CONTAMINATION AND TOXICOLOGY', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE > FOOD CONTAMINATION AND TOXICOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (5088, '85d7c19a-6d05-446f-a490-382e7c199e09', 100, 'FOOD PACKAGING', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE > FOOD PACKAGING', 1);
INSERT INTO {schema}.keywords VALUES (5089, 'b153bcea-3114-4809-8e6f-f22cf9a3be87', 100, 'FOOD PROCESSING', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE > FOOD PROCESSING', 1);
INSERT INTO {schema}.keywords VALUES (5090, '3ec3b00e-52e1-4df9-99cd-c93120d97645', 100, 'FOOD QUALITY', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE > FOOD QUALITY', 1);
INSERT INTO {schema}.keywords VALUES (5091, 'b3b14df8-5197-4a26-ae61-882fdba706f3', 100, 'FOOD STORAGE', 'EARTH SCIENCE > AGRICULTURE > FOOD SCIENCE > FOOD STORAGE', 1);
INSERT INTO {schema}.keywords VALUES (5092, 'b3a1e091-0bc2-4c9b-a89c-bd003fdd5889', 101, 'AFFORESTATION/REFORESTATION', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > AFFORESTATION/REFORESTATION', 1);
INSERT INTO {schema}.keywords VALUES (5093, 'b3fcccdd-745f-4299-94b3-e72e37f551be', 101, 'DEFOLIANTS', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > DEFOLIANTS', 1);
INSERT INTO {schema}.keywords VALUES (5094, '7ee9d286-0742-4844-b7eb-b7550d3f782b', 101, 'FOREST CONSERVATION', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST CONSERVATION', 1);
INSERT INTO {schema}.keywords VALUES (5095, 'e5a8c6ed-5b59-40fe-a83b-18b39fb7c31b', 101, 'FOREST FIRE SCIENCE', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST FIRE SCIENCE', 1);
INSERT INTO {schema}.keywords VALUES (5096, '23336b57-1ba3-42a6-9ec7-152285c55689', 101, 'FOREST HARVESTING AND ENGINEERING', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST HARVESTING AND ENGINEERING', 1);
INSERT INTO {schema}.keywords VALUES (5097, 'd2056285-8249-4c11-810b-783600030525', 101, 'FOREST MANAGEMENT', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (5098, '31d01087-d5b8-4474-820c-d84d523dfb39', 101, 'FOREST MENSURATION', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST MENSURATION', 1);
INSERT INTO {schema}.keywords VALUES (5099, '3676ebab-9aa0-43c2-94e5-5d59a34317d2', 101, 'FOREST PRODUCTS/COMMODITIES', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST PRODUCTS/COMMODITIES', 1);
INSERT INTO {schema}.keywords VALUES (5100, 'adeb4c27-a115-4ced-9827-5f022883f606', 101, 'FOREST PROTECTION', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST PROTECTION', 1);
INSERT INTO {schema}.keywords VALUES (5101, '49804617-d59b-4e97-8030-2c4ab79a3057', 101, 'FOREST YIELDS', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > FOREST YIELDS', 1);
INSERT INTO {schema}.keywords VALUES (5102, 'be7f6de0-f51e-42bc-9a66-fff30d809a67', 101, 'REFORESTATION', 'EARTH SCIENCE > AGRICULTURE > FOREST SCIENCE > REFORESTATION', 1);
INSERT INTO {schema}.keywords VALUES (5103, '63317fb1-01d9-4658-93e8-9800c5359454', 102, 'FIELD CROP PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > PLANT COMMODITIES > FIELD CROP PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5104, '41b30b1b-5dbb-4ef8-849c-e1949ad04227', 102, 'FRUIT PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > PLANT COMMODITIES > FRUIT PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5105, 'd23b37cd-5e05-4356-b8b4-df6d7af236d6', 102, 'HORTICULTURAL PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > PLANT COMMODITIES > HORTICULTURAL PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5106, 'eb1627c2-0061-466c-9935-399e53a06024', 102, 'VEGETABLE PRODUCTS', 'EARTH SCIENCE > AGRICULTURE > PLANT COMMODITIES > VEGETABLE PRODUCTS', 1);
INSERT INTO {schema}.keywords VALUES (5107, '7367c08c-304f-4ce7-b716-975f835ba711', 103, 'CALCIUM', 'EARTH SCIENCE > AGRICULTURE > SOILS > CALCIUM', 1);
INSERT INTO {schema}.keywords VALUES (5108, '9315c474-b65f-400d-beba-611c9a6a62cb', 103, 'CARBON', 'EARTH SCIENCE > AGRICULTURE > SOILS > CARBON', 1);
INSERT INTO {schema}.keywords VALUES (5109, '5c05e69f-f6db-4296-abd3-3b07e6093579', 103, 'CATION EXCHANGE CAPACITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > CATION EXCHANGE CAPACITY', 1);
INSERT INTO {schema}.keywords VALUES (5110, 'cac79930-334e-49c5-836b-4f2ee8e0b098', 103, 'DENITRIFICATION RATE', 'EARTH SCIENCE > AGRICULTURE > SOILS > DENITRIFICATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (5111, '7241d799-4f5c-4ae3-a4ec-2e9cdbf656aa', 103, 'ELECTRICAL CONDUCTIVITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > ELECTRICAL CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5112, '8b3939b6-1c11-4a79-878e-0be1b231c528', 103, 'HEAVY METALS', 'EARTH SCIENCE > AGRICULTURE > SOILS > HEAVY METALS', 1);
INSERT INTO {schema}.keywords VALUES (5113, '7112e739-cb5d-427e-95bd-5419360e91d8', 103, 'HYDRAULIC CONDUCTIVITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > HYDRAULIC CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5114, '83da5ac6-5981-4929-9e19-f46522c1babe', 103, 'MACROFAUNA', 'EARTH SCIENCE > AGRICULTURE > SOILS > MACROFAUNA', 1);
INSERT INTO {schema}.keywords VALUES (5115, '79f18259-bd76-4c7b-bd18-cbd2edafd24f', 103, 'MAGNESIUM', 'EARTH SCIENCE > AGRICULTURE > SOILS > MAGNESIUM', 1);
INSERT INTO {schema}.keywords VALUES (5117, 'b3063d3a-af53-44f9-a532-4cea2880c198', 103, 'MICROFLORA', 'EARTH SCIENCE > AGRICULTURE > SOILS > MICROFLORA', 1);
INSERT INTO {schema}.keywords VALUES (5118, '2473e776-4449-4351-9835-1507532ae60e', 103, 'MICRONUTRIENTS/TRACE ELEMENTS', 'EARTH SCIENCE > AGRICULTURE > SOILS > MICRONUTRIENTS/TRACE ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5119, '5ed7811a-2ba1-4985-9f1c-a78c802fa27f', 103, 'NITROGEN', 'EARTH SCIENCE > AGRICULTURE > SOILS > NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (5120, '83cf51f6-8c03-4f6d-b605-fde9818c7805', 103, 'ORGANIC MATTER', 'EARTH SCIENCE > AGRICULTURE > SOILS > ORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (5121, 'fb3ce3be-d830-407f-bd7c-58d66c24b6be', 103, 'PERMAFROST', 'EARTH SCIENCE > AGRICULTURE > SOILS > PERMAFROST', 1);
INSERT INTO {schema}.keywords VALUES (5122, '4962dabc-b426-4c84-8147-12e15645baff', 103, 'PHOSPHORUS', 'EARTH SCIENCE > AGRICULTURE > SOILS > PHOSPHORUS', 1);
INSERT INTO {schema}.keywords VALUES (5123, 'c07fe67b-234e-4293-9f09-abaf9612c0e9', 103, 'POTASSIUM', 'EARTH SCIENCE > AGRICULTURE > SOILS > POTASSIUM', 1);
INSERT INTO {schema}.keywords VALUES (5124, '356a10e1-c81d-44c7-9706-31f7f2642586', 103, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > AGRICULTURE > SOILS > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (5125, 'd0da93ff-af45-4e26-8b94-8b90d0e06438', 103, 'SOIL ABSORPTION', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL ABSORPTION', 1);
INSERT INTO {schema}.keywords VALUES (5126, '62d5fb39-e9ee-47db-a426-1991537f8a4d', 103, 'SOIL BULK DENSITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL BULK DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (5127, '652349bd-f6f9-4c8d-8573-d71e05ad1208', 103, 'SOIL CHEMISTRY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5128, '2f57fd58-d8e4-4e6d-b8c3-2a9ef7e64f54', 103, 'SOIL CLASSIFICATION', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL CLASSIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (5129, '3985ce6b-e0c3-42a8-b40f-9dd948350c6e', 103, 'SOIL COLOR', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL COLOR', 1);
INSERT INTO {schema}.keywords VALUES (5130, 'e0c0af2a-1429-4248-8d5b-ccae510da0c9', 103, 'SOIL COMPACTION', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL COMPACTION', 1);
INSERT INTO {schema}.keywords VALUES (5131, '25c5c222-c053-4081-ac0f-52e6c774198c', 103, 'SOIL CONSISTENCE', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL CONSISTENCE', 1);
INSERT INTO {schema}.keywords VALUES (5132, 'b09b4731-f357-4838-829b-f38c0f5075aa', 103, 'SOIL DEPTH', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5133, '36c862a7-7117-4fd2-8e33-0dda03097178', 103, 'SOIL EROSION', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL EROSION', 1);
INSERT INTO {schema}.keywords VALUES (5134, 'e4781de7-a4a4-4157-a549-4ac238d36512', 103, 'SOIL FERTILITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL FERTILITY', 1);
INSERT INTO {schema}.keywords VALUES (5135, 'd302aeaa-3a86-4ddf-9755-60b7bb4404a5', 103, 'SOIL GAS/AIR', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL GAS/AIR', 1);
INSERT INTO {schema}.keywords VALUES (5136, '68033b72-7f8d-48a4-8f63-638e4e96fd23', 103, 'SOIL HEAT BUDGET', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL HEAT BUDGET', 1);
INSERT INTO {schema}.keywords VALUES (5137, '1fc22c9d-cf29-4bd7-90b1-b0f6f139fd92', 103, 'SOIL HORIZONS/PROFILE', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL HORIZONS/PROFILE', 1);
INSERT INTO {schema}.keywords VALUES (5138, '6edf1b99-fe00-493e-b0d1-ad6b36b8da75', 103, 'SOIL IMPEDANCE', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL IMPEDANCE', 1);
INSERT INTO {schema}.keywords VALUES (5139, '0ab5ead8-6037-42b3-b3c0-0746f3645af6', 103, 'SOIL INFILTRATION', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL INFILTRATION', 1);
INSERT INTO {schema}.keywords VALUES (5140, '3b1d75b6-7559-4921-8edb-63f4dff370cf', 103, 'SOIL MECHANICS', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL MECHANICS', 1);
INSERT INTO {schema}.keywords VALUES (5141, '88e1a654-5cfd-423f-9350-0ef48d85e085', 103, 'SOIL MOISTURE/WATER CONTENT', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL MOISTURE/WATER CONTENT', 1);
INSERT INTO {schema}.keywords VALUES (5142, '2a9bce94-c391-4834-96bb-a9685d3590b1', 103, 'SOIL PH', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL PH', 1);
INSERT INTO {schema}.keywords VALUES (5143, '934bfe13-908b-40d9-b346-a347a8a6855e', 103, 'SOIL PLASTICITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL PLASTICITY', 1);
INSERT INTO {schema}.keywords VALUES (5144, 'c26693ea-ca5a-44e8-9e8e-32427bc62aa0', 103, 'SOIL POROSITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL POROSITY', 1);
INSERT INTO {schema}.keywords VALUES (5145, '5c6df811-bebf-4dae-a70f-f49fece3fa1e', 103, 'SOIL PRODUCTIVITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL PRODUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5146, 'db9b56da-e05f-4d58-b9d5-34edc83ca650', 103, 'SOIL RESPIRATION', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL RESPIRATION', 1);
INSERT INTO {schema}.keywords VALUES (5147, '2b91245e-a779-42fa-89c2-303217463b95', 103, 'SOIL ROOTING DEPTH', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL ROOTING DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5148, '3b54403e-25a1-43cc-97ac-7c14e73bda96', 103, 'SOIL SALINITY/SOIL SODICITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL SALINITY/SOIL SODICITY', 1);
INSERT INTO {schema}.keywords VALUES (5149, 'e4daef1d-e672-41d0-bc6d-80c6b5c0799b', 103, 'SOIL STRUCTURE', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL STRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (5150, '26f5bb2a-b872-41e8-922f-3a9a0e9f9bcd', 103, 'SOIL TEMPERATURE', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5151, 'afd1d3cb-d31d-4069-8cff-b592887aa18c', 103, 'SOIL TEXTURE', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (5152, '223ce1f2-e2f1-4612-8fce-b96b7d34710f', 103, 'SOIL WATER HOLDING CAPACITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > SOIL WATER HOLDING CAPACITY', 1);
INSERT INTO {schema}.keywords VALUES (5153, 'e3d3f76d-0ffe-4616-9988-0520e78cf842', 103, 'SULFUR', 'EARTH SCIENCE > AGRICULTURE > SOILS > SULFUR', 1);
INSERT INTO {schema}.keywords VALUES (5154, '5c349776-dd95-483e-a5da-e8d1b1434985', 103, 'THERMAL CONDUCTIVITY', 'EARTH SCIENCE > AGRICULTURE > SOILS > THERMAL CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5155, 'f795b88f-1aba-4548-97f6-7b587e8ba451', 104, 'AEROSOL BACKSCATTER', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL BACKSCATTER', 1);
INSERT INTO {schema}.keywords VALUES (5156, '40633fe2-5b32-4bdc-a17b-b1cfebc01ae7', 104, 'AEROSOL EXTINCTION', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL EXTINCTION', 1);
INSERT INTO {schema}.keywords VALUES (5157, '449e2e03-8efd-42b6-8152-3602e4bab21d', 104, 'AEROSOL FORWARD SCATTER', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL FORWARD SCATTER', 1);
INSERT INTO {schema}.keywords VALUES (5158, '61c3b720-abc8-4430-866c-f1da35d2cd0b', 104, 'AEROSOL OPTICAL DEPTH/THICKNESS', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL OPTICAL DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5159, '02ea239e-4bca-4fda-ab87-be12c723c30a', 104, 'AEROSOL PARTICLE PROPERTIES', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL PARTICLE PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (5160, '7db9eab3-4c7a-4471-a826-a306f178ad3e', 104, 'AEROSOL RADIANCE', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (5161, '527f637c-aea5-4519-9293-d57e10a76bff', 104, 'CARBONACEOUS AEROSOLS', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > CARBONACEOUS AEROSOLS', 1);
INSERT INTO {schema}.keywords VALUES (5162, '0611b9fd-fd92-4c4d-87bb-bc2f22c548bc', 104, 'CHEMICAL COMPOSITION', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > CHEMICAL COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (5163, '27478148-b4b6-4c89-8829-08d2ee7bfe10', 104, 'CLOUD CONDENSATION NUCLEI', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > CLOUD CONDENSATION NUCLEI', 1);
INSERT INTO {schema}.keywords VALUES (5164, '1b6342c6-315b-4f4f-b4e3-d6902aaa3e85', 104, 'DUST/ASH/SMOKE', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > DUST/ASH/SMOKE', 1);
INSERT INTO {schema}.keywords VALUES (5165, '768cfa32-003d-47bd-ab3a-3e27e4ec2699', 104, 'NITRATE PARTICLES', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > NITRATE PARTICLES', 1);
INSERT INTO {schema}.keywords VALUES (5166, '8929113a-ded5-4c39-b20f-7968ed114317', 104, 'ORGANIC PARTICLES', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > ORGANIC PARTICLES', 1);
INSERT INTO {schema}.keywords VALUES (5167, '548a3f85-bf22-473b-b641-45c32d9c6a0c', 104, 'PARTICULATE MATTER', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > PARTICULATE MATTER', 1);
INSERT INTO {schema}.keywords VALUES (5168, 'ca71b02b-4446-414c-8697-0950d7382cc4', 104, 'SULFATE PARTICLES', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > SULFATE PARTICLES', 1);
INSERT INTO {schema}.keywords VALUES (5169, '080389c4-68d4-41ee-ab89-070794038c8e', 105, 'CARBON MONOXIDE', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > CARBON MONOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (5170, '2a60df4a-a0d7-4e4b-b02a-372a083f0170', 105, 'EMISSIONS', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > EMISSIONS', 1);
INSERT INTO {schema}.keywords VALUES (5171, 'c79453a3-ed2f-4ec4-9298-bf9fd11d08eb', 105, 'LEAD', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > LEAD', 1);
INSERT INTO {schema}.keywords VALUES (5172, 'e5563c99-0fb6-43a9-8e20-6b47b1144394', 105, 'NITROGEN OXIDES', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > NITROGEN OXIDES', 1);
INSERT INTO {schema}.keywords VALUES (5173, 'f9fe1bc0-88c5-4c26-9b4c-a9867d027685', 105, 'PARTICULATES', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > PARTICULATES', 1);
INSERT INTO {schema}.keywords VALUES (5174, 'bad08657-da2b-4e2b-9804-25c5732bc795', 105, 'SMOG', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > SMOG', 1);
INSERT INTO {schema}.keywords VALUES (5175, 'c3090318-c845-4242-bf2f-ff1631b88831', 105, 'SULFUR OXIDES', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > SULFUR OXIDES', 1);
INSERT INTO {schema}.keywords VALUES (5176, '426aee98-764c-4c21-ab65-1e9d4bd6b0d0', 105, 'TROPOSPHERIC OZONE', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > TROPOSPHERIC OZONE', 1);
INSERT INTO {schema}.keywords VALUES (5177, '227cf2d4-968a-4312-89e6-8c6bcf616e5d', 105, 'TURBIDITY', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > TURBIDITY', 1);
INSERT INTO {schema}.keywords VALUES (5178, '9337898d-68dc-43d7-93a9-6afdb4ab1784', 105, 'VISIBILITY', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > VISIBILITY', 1);
INSERT INTO {schema}.keywords VALUES (5179, '1f3c543d-9ca9-4db4-b4a5-d3e2fd71e4a4', 105, 'VOLATILE ORGANIC COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > AIR QUALITY > VOLATILE ORGANIC COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (5180, '5d703cfe-2f7c-4736-acbc-ec4e4f4f8eef', 106, 'BAROMETRIC ALTITUDE', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > BAROMETRIC ALTITUDE', 1);
INSERT INTO {schema}.keywords VALUES (5181, 'd6aec072-daf9-4f96-b667-6c7831cf6bdd', 106, 'GEOPOTENTIAL HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > GEOPOTENTIAL HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5182, 'dacbf270-1734-4503-bab8-a32cdaff3012', 106, 'MESOPAUSE', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > MESOPAUSE', 1);
INSERT INTO {schema}.keywords VALUES (5183, '765e92a7-8c14-47dc-bdd8-d85d132a11ee', 106, 'PLANETARY BOUNDARY LAYER HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > PLANETARY BOUNDARY LAYER HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5184, '2343baae-1c4a-4096-8cac-fea8ed7a984f', 106, 'STATION HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > STATION HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5185, '82191e97-53ba-413d-9a08-acd8b848e0b0', 106, 'STRATOPAUSE', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > STRATOPAUSE', 1);
INSERT INTO {schema}.keywords VALUES (5186, 'c3447c90-7490-4f04-89c1-c5274ba8f8f6', 106, 'TROPOPAUSE', 'EARTH SCIENCE > ATMOSPHERE > ALTITUDE > TROPOPAUSE', 1);
INSERT INTO {schema}.keywords VALUES (5187, '19ab681c-bdd7-4793-bbdb-1ec498575314', 107, 'CARBON AND HYDROCARBON COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (5188, '5e3999ec-d864-43fd-8d84-bd23630c405f', 126, 'CHLOROPHYLL', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > CHLOROPHYLL', 1);
INSERT INTO {schema}.keywords VALUES (5189, 'd46a5046-e1c6-4a09-a2f1-db6a21eda611', 107, 'HALOCARBONS AND HALOGENS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS', 1);
INSERT INTO {schema}.keywords VALUES (5190, 'd8dcfd36-f71c-499f-84f5-43da9fee26c5', 107, 'HYDROGEN COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HYDROGEN COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (5191, '9e5ec924-2fd3-4cbb-a7eb-ffde114d0cb9', 107, 'NITROGEN COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (5192, '4cc9b4fa-5097-447f-914c-eb90820938c6', 107, 'OXYGEN COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > OXYGEN COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (5193, '6433e330-3797-4cf9-a8ba-d26d39624459', 107, 'PHOTOCHEMISTRY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > PHOTOCHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5194, 'b80a242d-d5f5-4a5f-976c-6f6fe2ab6b2c', 107, 'SULFUR COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > SULFUR COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (5195, '2d36c283-2fe3-4a08-aeb3-6a8146e79bb3', 107, 'TRACE ELEMENTS/TRACE METALS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > TRACE ELEMENTS/TRACE METALS', 1);
INSERT INTO {schema}.keywords VALUES (5196, '4dd22dc9-1db4-4187-a2b7-f5b76d666055', 107, 'TRACE GASES/TRACE SPECIES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > TRACE GASES/TRACE SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (5197, '12b1cc7c-cb81-4851-9163-19c04a8ffd1c', 108, 'ATMOSPHERIC CONDUCTIVITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC ELECTRICITY > ATMOSPHERIC CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5198, '41f27172-14f6-4940-9b7b-f3d4db69e0c6', 108, 'ELECTRIC FIELD', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC ELECTRICITY > ELECTRIC FIELD', 1);
INSERT INTO {schema}.keywords VALUES (5199, '637ac172-e624-4ae0-aac4-0d1adcc889a2', 108, 'LIGHTNING', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC ELECTRICITY > LIGHTNING', 1);
INSERT INTO {schema}.keywords VALUES (5200, 'cac28264-0788-49a9-bb6a-c2251b0b325c', 108, 'TOTAL ELECTRON CONTENT', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC ELECTRICITY > TOTAL ELECTRON CONTENT', 1);
INSERT INTO {schema}.keywords VALUES (5201, '178694aa-5f0a-4de5-a193-74e323dc6aa9', 109, 'ANTICYCLONES/CYCLONES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > ANTICYCLONES/CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (5202, '9efbc088-ba8c-4c9c-a458-ad6ad63f4188', 109, 'ATMOSPHERIC PRESSURE MEASUREMENTS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > ATMOSPHERIC PRESSURE MEASUREMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5203, '5d7e487d-0ec4-40ef-9811-401779c31794', 109, 'DIFFERENTIAL PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > DIFFERENTIAL PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5204, '7e6f7c15-32e7-4b6e-bd35-7bff4bc03caf', 109, 'GRAVITY WAVE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > GRAVITY WAVE', 1);
INSERT INTO {schema}.keywords VALUES (5205, 'a5aa7055-642d-4442-9b4b-76a759e15257', 109, 'HYDROSTATIC PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > HYDROSTATIC PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5206, 'c0656cbc-5d94-4945-bbfd-1c8eabb059b2', 109, 'OSCILLATIONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > OSCILLATIONS', 1);
INSERT INTO {schema}.keywords VALUES (5207, 'f51a3caf-c5ec-496a-8dd3-854d9bb994e7', 109, 'PLANETARY BOUNDARY LAYER HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > PLANETARY BOUNDARY LAYER HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5208, '6f262b9b-2cb8-4745-ae41-5fff23c72a1e', 109, 'PLANETARY/ROSSBY WAVES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > PLANETARY/ROSSBY WAVES', 1);
INSERT INTO {schema}.keywords VALUES (5209, '011bed30-f5b6-4b46-a7ce-797851f24f24', 109, 'PRESSURE ANOMALIES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > PRESSURE ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (5210, 'fa98caa0-54dc-465e-9bde-cdf4da905994', 109, 'PRESSURE TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > PRESSURE TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (5211, 'be027470-35ab-4ebb-a213-5f557cca71c8', 109, 'PRESSURE THICKNESS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > PRESSURE THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5212, '07ce145c-9936-4675-b4a7-8710e39aa391', 109, 'SEA LEVEL PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > SEA LEVEL PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5213, '622c44b4-e307-4c11-af4d-8104de7086e5', 109, 'STATIC PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > STATIC PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5214, 'b54de5cd-4475-4c7b-acbc-4eb529b9396e', 109, 'SURFACE PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > SURFACE PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5215, 'b13a29a1-47a0-4d8b-a017-398b364dc202', 109, 'TOPOGRAPHIC WAVES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC PRESSURE > TOPOGRAPHIC WAVES', 1);
INSERT INTO {schema}.keywords VALUES (5216, '061f7fd0-67af-42bf-bc9f-5a007c146f65', 110, 'ABSORPTION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ABSORPTION', 1);
INSERT INTO {schema}.keywords VALUES (5217, 'ec839718-ba64-4bc5-8458-fae7390e11c4', 110, 'ACTINIC FLUX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ACTINIC FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5218, 'bf22e55d-fbff-4eaf-8592-68be24e2bc32', 110, 'AIRGLOW', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > AIRGLOW', 1);
INSERT INTO {schema}.keywords VALUES (5219, '48c16952-b6e0-40cd-b6dd-7cdbf5a443a1', 110, 'ALBEDO', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ALBEDO', 1);
INSERT INTO {schema}.keywords VALUES (5220, '31a14270-6275-4155-961f-b78b60ee05f7', 110, 'ANISOTROPY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ANISOTROPY', 1);
INSERT INTO {schema}.keywords VALUES (5221, '1ed8ac8d-3a66-4b86-be30-a5b79b3806d2', 110, 'ATMOSPHERIC EMITTED RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ATMOSPHERIC EMITTED RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5222, '06a24fd2-38b6-4a4a-a0cf-1abf149283e2', 110, 'ATMOSPHERIC HEATING', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ATMOSPHERIC HEATING', 1);
INSERT INTO {schema}.keywords VALUES (5223, '49c8770a-2eb7-40f1-aab0-9c12d3aed031', 110, 'EMISSIVITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > EMISSIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5224, '46a3c823-727d-4c3c-b09d-e3e3fcaa43a5', 110, 'HEAT FLUX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > HEAT FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5225, '6b3be650-6625-40b5-9b40-9e7c8a9fd336', 110, 'INCOMING SOLAR RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > INCOMING SOLAR RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5226, '68323795-3614-462f-8259-bd5293620799', 110, 'LONGWAVE RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > LONGWAVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5227, '50ee8910-449b-46c8-a59b-1cd76d632b44', 110, 'NET RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > NET RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5228, '13723b5d-1945-4e62-8672-4535ffdddb87', 110, 'OPTICAL DEPTH/THICKNESS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > OPTICAL DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5229, '006b1ea6-222d-4740-b220-03886d49cd81', 110, 'OUTGOING LONGWAVE RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > OUTGOING LONGWAVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5230, 'a87d6473-3a03-4bc6-aa21-6157fae96b8e', 110, 'POLARIZED REFLECTANCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > POLARIZED REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5231, '107582ef-a356-4afa-a9a4-4e1d2200c134', 110, 'RADIATIVE FLUX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > RADIATIVE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5232, '4fad64ce-32fe-413d-8b55-c78000d1980c', 110, 'RADIATIVE FORCING', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > RADIATIVE FORCING', 1);
INSERT INTO {schema}.keywords VALUES (5233, 'bdfd401f-7eed-4a48-bd6f-f0c2a890594a', 110, 'REFLECTANCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5234, 'ec9e0b6a-1315-4569-93bc-0f1190bb8c08', 110, 'SCATTERING', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SCATTERING', 1);
INSERT INTO {schema}.keywords VALUES (5235, 'a8f5c969-34e9-4284-afb5-ff2113f5f881', 110, 'SHORTWAVE RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SHORTWAVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5236, 'de7647c9-b129-4cba-afe4-63fa9998206e', 110, 'SOLAR IRRADIANCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SOLAR IRRADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (5237, 'a0f3474e-9a54-4a82-97c4-43864b48df4c', 110, 'SOLAR RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SOLAR RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5238, 'b7a45c57-b652-469a-a3f2-8d38555bf478', 110, 'SPECTRAL IRRADIANCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SPECTRAL IRRADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (5239, '86c95fdb-17b9-4224-a020-b1aacbea00fd', 110, 'SUNSHINE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SUNSHINE', 1);
INSERT INTO {schema}.keywords VALUES (5240, '714be1d7-2012-4a98-bdd5-02bbcadf69d8', 110, 'TRANSMITTANCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > TRANSMITTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5241, '90e7fd13-2da2-4ba6-9e0c-dbecdf7c2215', 110, 'ULTRAVIOLET RADIATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > ULTRAVIOLET RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5242, 'ff5d5c12-74d9-435d-9164-1c9d69f967d7', 111, 'ATMOSPHERIC STABILITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (5243, '25d73bcf-c8d4-4c0e-ac98-8f3e98677e73', 111, 'ATMOSPHERIC TEMPERATURE INDICES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5244, '5a7bb095-4d12-4232-bc75-b8e82197cb92', 111, 'SURFACE TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5245, '926c1b80-6c11-40eb-ae7f-f5bcfdc43fac', 111, 'UPPER AIR TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5246, '005d192a-95b9-4fc2-afed-f87da3c3dc33', 112, 'WATER VAPOR INDICATORS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (5247, '4f58cf68-0d44-424a-88af-65c3edfd0945', 112, 'WATER VAPOR INDICES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5248, '3c4fe00c-6fb1-403e-a053-3a0174a6dfe6', 112, 'WATER VAPOR PROCESSES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5249, 'acc824e7-8eea-4e7d-aa3d-757cda7e6ec9', 112, 'WATER VAPOR PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (5250, '1488b98d-6497-48b9-88db-6ee82a2e3ed3', 113, 'LOCAL WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS', 1);
INSERT INTO {schema}.keywords VALUES (5251, '10685919-bc01-43e7-901a-b62ac44627f3', 113, 'SURFACE WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS', 1);
INSERT INTO {schema}.keywords VALUES (5252, '592d49c4-e8ae-4ab4-bf24-ae4a896d0637', 113, 'UPPER LEVEL WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS', 1);
INSERT INTO {schema}.keywords VALUES (5253, '492ffe26-8fbe-4d7d-a537-495fb96bdcce', 113, 'WIND DYNAMICS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (5254, '25775905-dac3-4834-b709-f38a0a03b258', 113, 'WIND INDICES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5255, 'dcc6cbbf-23a0-4ae7-bfbd-6207d35c741f', 113, 'WIND PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (5256, 'cbb0d517-462a-46fe-a0e6-32555f7e7f23', 114, 'CLOUD DROPLET DISTRIBUTION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DROPLET DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (5257, '62019831-aaba-4d63-a5cd-73138ccfa5d0', 114, 'CLOUD DYNAMICS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (5258, '0cfcbaa7-727b-4199-8cca-93824b427e9b', 114, 'CLOUD MICROPHYSICS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS', 1);
INSERT INTO {schema}.keywords VALUES (5259, 'c9e429cb-eff0-4dd3-9eca-527e0081f65c', 114, 'CLOUD PROPERTIES', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (5260, '3487d350-a5a5-43d9-a60d-c1407dd2f0ce', 114, 'CLOUD RADIATIVE TRANSFER', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER', 1);
INSERT INTO {schema}.keywords VALUES (5261, '29b61359-ebec-42c2-be05-2d7be2275954', 114, 'CLOUD TYPES', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD TYPES', 1);
INSERT INTO {schema}.keywords VALUES (5262, '9a802ef3-680d-4bc6-a42e-aa84d5eb9908', 114, 'CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED)', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED)', 1);
INSERT INTO {schema}.keywords VALUES (5263, '04bc6942-12e0-413f-94d2-1ba7f5edf595', 114, 'MESOSPHERIC CLOUDS (OBSERVED/ANALYZED)', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > MESOSPHERIC CLOUDS (OBSERVED/ANALYZED)', 1);
INSERT INTO {schema}.keywords VALUES (5264, 'd6ab88c0-5a97-4f5e-8e4c-1c6fc6ed368f', 114, 'STRATOSPHERIC CLOUDS (OBSERVED/ANALYZED)', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > STRATOSPHERIC CLOUDS (OBSERVED/ANALYZED)', 1);
INSERT INTO {schema}.keywords VALUES (5265, '705cd3a0-ea07-40c8-bfa1-9c26f22d13ba', 114, 'TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED)', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED)', 1);
INSERT INTO {schema}.keywords VALUES (5266, '20365b0a-f8df-437a-8b31-25557f7b4d82', 114, 'TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED)', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED)', 1);
INSERT INTO {schema}.keywords VALUES (5267, 'a413f88b-859c-4035-a45b-2faa9934156b', 114, 'TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED)', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED)', 1);
INSERT INTO {schema}.keywords VALUES (5268, '2b3dc817-9238-482a-8c10-d34375f3d27d', 115, 'ACCUMULATIVE CONVECTIVE PRECIPITATION', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > ACCUMULATIVE CONVECTIVE PRECIPITATION', 1);
INSERT INTO {schema}.keywords VALUES (5269, 'c7477201-761f-4cd1-b986-3e99a0be866b', 115, 'ATMOSPHERIC PRECIPITATION INDICES', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > ATMOSPHERIC PRECIPITATION INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5270, '6eaed241-db16-4a1a-a06c-893da5d98b45', 115, 'DROPLET SIZE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > DROPLET SIZE', 1);
INSERT INTO {schema}.keywords VALUES (5271, '56f2cdbd-2a91-4267-97eb-1680e8582322', 115, 'HYDROMETEORS', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > HYDROMETEORS', 1);
INSERT INTO {schema}.keywords VALUES (5272, '7d45f108-dda2-4341-b853-ee3a490aad59', 115, 'LIQUID PRECIPITATION', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION', 1);
INSERT INTO {schema}.keywords VALUES (5273, 'eca0080c-b001-4b6a-b978-f76415e28421', 115, 'LIQUID WATER EQUIVALENT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID WATER EQUIVALENT', 1);
INSERT INTO {schema}.keywords VALUES (5274, 'cad5c02a-e771-434e-bef6-8dced38a68e8', 115, 'PRECIPITATION AMOUNT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (5275, '22a4ddef-90f0-4935-a13d-26b14723a956', 115, 'PRECIPITATION ANOMALIES', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (5276, 'd4449cf4-8d4e-4282-b84d-5098715389dd', 115, 'PRECIPITATION PROFILES', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (5277, 'ac50c468-df2f-429c-8394-9d63efcc6f9d', 115, 'PRECIPITATION RATE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (5278, '30bd3a01-8cb0-4045-a998-582adbf97df9', 115, 'SNOW WATER EQUIVALENT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SNOW WATER EQUIVALENT', 1);
INSERT INTO {schema}.keywords VALUES (5279, '1906bb87-db16-46db-b814-e0b322356125', 115, 'SOLID PRECIPITATION', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION', 1);
INSERT INTO {schema}.keywords VALUES (5280, '9466020a-db25-40ba-a76f-4720800efc92', 115, 'TOTAL SURFACE PRECIPITATION RATE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > TOTAL SURFACE PRECIPITATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (5281, 'e96f2d1a-432e-44e4-bc88-6f8f35ae88fb', 115, 'VIRGA', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > VIRGA', 1);
INSERT INTO {schema}.keywords VALUES (5282, '03bc515c-af45-4a15-b2a2-65270f0e72bd', 116, 'COLD WAVE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > COLD WAVE', 1);
INSERT INTO {schema}.keywords VALUES (5283, '12a896f3-993d-49f6-aafc-17378ffa3998', 116, 'DROUGHTS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > DROUGHTS', 1);
INSERT INTO {schema}.keywords VALUES (5284, 'da436e9b-60e5-4a5f-a50a-08794d62bca8', 116, 'EXTRATROPICAL CYCLONES', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > EXTRATROPICAL CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (5285, 'a5ad4f63-7483-4f07-86c7-57037e5faf6c', 116, 'FOG', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FOG', 1);
INSERT INTO {schema}.keywords VALUES (5286, '4539272a-f041-4fc6-883d-4c4c5bef1683', 116, 'FREEZE/FROST', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST', 1);
INSERT INTO {schema}.keywords VALUES (5287, 'a2ea1792-c011-4c7c-95c7-3bd648b1b57b', 116, 'HAIL STORMS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > HAIL STORMS', 1);
INSERT INTO {schema}.keywords VALUES (5288, 'ca820557-401e-4e5e-ac32-29fdbc0628b3', 116, 'HEAT WAVE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > HEAT WAVE', 1);
INSERT INTO {schema}.keywords VALUES (5289, '5ce75010-ec8a-4af7-9e34-3e49ef2fe10c', 116, 'ICE STORMS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > ICE STORMS', 1);
INSERT INTO {schema}.keywords VALUES (5290, 'f24c4f33-5b89-4e8d-8de7-296078a7f18a', 116, 'LIGHTNING', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > LIGHTNING', 1);
INSERT INTO {schema}.keywords VALUES (5291, 'a6212424-1146-4a79-a14c-8ce88543b08b', 116, 'MONSOONS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > MONSOONS', 1);
INSERT INTO {schema}.keywords VALUES (5292, 'f6b314db-883a-4493-9140-b6afda949710', 116, 'RAIN STORMS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > RAIN STORMS', 1);
INSERT INTO {schema}.keywords VALUES (5293, 'bc9215ae-58ec-481e-ba83-89376a298000', 116, 'SNOW STORMS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SNOW STORMS', 1);
INSERT INTO {schema}.keywords VALUES (5294, 'edfe982b-a5bb-4001-83fa-f46f90f69b79', 116, 'SUBTROPICAL CYCLONES', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SUBTROPICAL CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (5295, '7844ae66-f542-442f-8359-05014bc19831', 116, 'Stability/Severe Weather Indices', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > Stability/Severe Weather Indices', 1);
INSERT INTO {schema}.keywords VALUES (5296, 'a200e677-384a-42d6-8519-1c7735f0adb9', 116, 'TORNADOES', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES', 1);
INSERT INTO {schema}.keywords VALUES (5297, '06180441-d4bb-4fed-b36a-9b3cb2cac0fe', 116, 'TROPICAL CYCLONES', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (5298, 'c40071d2-6478-4edf-80bb-95c3886533b9', 116, 'WIND STORMS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > WIND STORMS', 1);
INSERT INTO {schema}.keywords VALUES (5299, '70c0b882-3d34-4e2d-90bf-339ade328ee0', 117, 'ACORN WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ACORN WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5300, '328d3442-34a0-496b-ae4d-87eb447058b8', 117, 'ARROW WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARROW WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5301, 'bb87baf5-3844-4a56-865f-ea5ed420db06', 117, 'ARTHROPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS', 1);
INSERT INTO {schema}.keywords VALUES (5302, 'b560f23d-f190-4c41-8bd9-4650a83296af', 117, 'BRYOZOANS/MOSS ANIMALS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > BRYOZOANS/MOSS ANIMALS', 1);
INSERT INTO {schema}.keywords VALUES (5303, 'f70d3181-c6b6-40ec-a583-6c9e44e1c4ad', 117, 'BURROWS/SPOON WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > BURROWS/SPOON WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5304, 'b6164a29-8e14-4861-a30c-fefce375e284', 117, 'CNIDARIANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS', 1);
INSERT INTO {schema}.keywords VALUES (5305, 'acce07bc-4e22-48b8-8396-10628c13124f', 117, 'COMB JELLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > COMB JELLIES', 1);
INSERT INTO {schema}.keywords VALUES (5306, '70892c25-4206-4673-9504-2876927d19a3', 117, 'ECHINODERMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ECHINODERMS', 1);
INSERT INTO {schema}.keywords VALUES (5307, '23193921-88ee-4ff2-b9ca-d4688aa4bda7', 117, 'ENTOPROCTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ENTOPROCTS', 1);
INSERT INTO {schema}.keywords VALUES (5308, '8ce4bad9-f050-4b0c-845e-5e7569b6a2d2', 117, 'FLATWORMS/FLUKES/TAPEWORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > FLATWORMS/FLUKES/TAPEWORMS', 1);
INSERT INTO {schema}.keywords VALUES (5309, 'e05fac08-e3de-4f41-a3fa-29d322a99ac2', 117, 'GNATHOSTOMULIDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > GNATHOSTOMULIDS', 1);
INSERT INTO {schema}.keywords VALUES (5310, 'e3425c65-ead7-4bf6-942c-7176a1469b58', 117, 'HORSEHAIR WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > HORSEHAIR WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5311, '28ae9814-61c2-4ca4-8bc5-d093c1ce5e83', 117, 'LAMP SHELLS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > LAMP SHELLS', 1);
INSERT INTO {schema}.keywords VALUES (5312, '470b8420-2a72-4a0c-9c87-e85c57bf01bb', 117, 'LORICIFERANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > LORICIFERANS', 1);
INSERT INTO {schema}.keywords VALUES (5313, 'd85c386f-e4f7-4e1c-a16e-34dbb12bb2be', 117, 'MOLLUSKS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS', 1);
INSERT INTO {schema}.keywords VALUES (5314, '3d179cd8-3d64-47a8-b665-ac1382053aff', 117, 'PEANUT WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > PEANUT WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5315, 'bb62f1cf-a6e5-4d9d-a3ab-c665b93ce072', 117, 'PHORONIDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > PHORONIDS', 1);
INSERT INTO {schema}.keywords VALUES (5316, '9c974992-0ec2-4c55-9ab9-e8158f446fe7', 117, 'PRIAPULANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > PRIAPULANS', 1);
INSERT INTO {schema}.keywords VALUES (5317, '0b5fd1dc-cfff-4bd8-9807-b5dd5ecf83fe', 117, 'RIBBON WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > RIBBON WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5318, '6b3f96de-62f8-482a-87a5-6efcc3414af7', 117, 'ROTIFERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ROTIFERS', 1);
INSERT INTO {schema}.keywords VALUES (5319, '2c1cf609-c70d-4811-8514-3ca45a8bb380', 117, 'ROUNDWORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ROUNDWORMS', 1);
INSERT INTO {schema}.keywords VALUES (5320, 'ab1952ae-de34-4299-ad10-9c9b2baf87f5', 117, 'SEGMENTED WORMS (ANNELIDS)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > SEGMENTED WORMS (ANNELIDS)', 1);
INSERT INTO {schema}.keywords VALUES (5321, 'af9520f0-6011-45e0-a1d8-bd8c3ed042b0', 117, 'SPINY-HEADED WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > SPINY-HEADED WORMS', 1);
INSERT INTO {schema}.keywords VALUES (5322, 'bfbfd84c-6bf0-412f-9e75-1bad5241c339', 117, 'SPONGES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > SPONGES', 1);
INSERT INTO {schema}.keywords VALUES (5323, 'c34af039-4868-41f0-aaf0-39e8e9554e03', 117, 'TUNICATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > TUNICATES', 1);
INSERT INTO {schema}.keywords VALUES (5324, 'fb4834d9-7bfe-4283-86f7-931532baa79c', 117, 'WATER BEARS (TARDIGRADES)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > WATER BEARS (TARDIGRADES)', 1);
INSERT INTO {schema}.keywords VALUES (5325, 'fa4b61fa-32e7-420f-988f-df5527b6f935', 117, 'WHEEL WEAVERS (CYCLIOPHORANS)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > WHEEL WEAVERS (CYCLIOPHORANS)', 1);
INSERT INTO {schema}.keywords VALUES (5326, 'a27837ae-62f7-4931-9da1-0bf63f4755fc', 118, 'AMPHIBIANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > AMPHIBIANS', 1);
INSERT INTO {schema}.keywords VALUES (5327, '1bf8f27a-d6ff-4cb6-acb7-7e5cce11e029', 118, 'BIRDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS', 1);
INSERT INTO {schema}.keywords VALUES (5328, 'ea855d4c-f132-44f9-b31c-447e1101684d', 118, 'FISH', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH', 1);
INSERT INTO {schema}.keywords VALUES (5329, 'f5161094-3593-4bc1-85ea-c8c2ecab1d9a', 118, 'MAMMALS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS', 1);
INSERT INTO {schema}.keywords VALUES (5330, '5d3725b6-743b-4dda-bb54-b64f201ec4d1', 118, 'REPTILES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > REPTILES', 1);
INSERT INTO {schema}.keywords VALUES (5331, '166de4c9-89ad-4248-b771-512beb1705cf', 119, 'CYANOBACTERIA (BLUE-GREEN ALGAE)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > BACTERIA/ARCHAEA > CYANOBACTERIA (BLUE-GREEN ALGAE)', 1);
INSERT INTO {schema}.keywords VALUES (5332, 'e85b6d64-a230-4c1d-99a5-c62be8af18c7', 120, 'LICHENS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > FUNGI > LICHENS', 1);
INSERT INTO {schema}.keywords VALUES (5333, '14fa5360-320c-4d54-9bf6-9871a4b308d7', 120, 'MUSHROOMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > FUNGI > MUSHROOMS', 1);
INSERT INTO {schema}.keywords VALUES (5334, '05763c43-c6ed-4071-b868-2ea6c1335c12', 120, 'SLIME MOLDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > FUNGI > SLIME MOLDS', 1);
INSERT INTO {schema}.keywords VALUES (5335, 'ee2e5028-1963-4de1-a883-b9e546d682a4', 120, 'YEASTS/TRUFFLES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > FUNGI > YEASTS/TRUFFLES', 1);
INSERT INTO {schema}.keywords VALUES (5336, '5eda068f-97ea-474a-8a1b-b193f6901251', 121, 'ANGIOSPERMS (FLOWERING PLANTS)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > ANGIOSPERMS (FLOWERING PLANTS)', 1);
INSERT INTO {schema}.keywords VALUES (5337, '589875d3-4770-4fb3-871c-b37c7aff4b47', 121, 'FERNS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > FERNS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (5338, '566e22da-d72e-4663-89d2-ced5aea948ea', 121, 'GYMNOSPERMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > GYMNOSPERMS', 1);
INSERT INTO {schema}.keywords VALUES (5339, 'e731c2a1-e4b0-42e9-bed9-bd911c9b496c', 121, 'MACROALGAE (SEAWEEDS)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MACROALGAE (SEAWEEDS)', 1);
INSERT INTO {schema}.keywords VALUES (5340, 'd3594523-ba0d-4275-b121-95039f905058', 121, 'MICROALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MICROALGAE', 1);
INSERT INTO {schema}.keywords VALUES (5341, '934bd870-ffa8-41d8-8da9-214b73707168', 121, 'MOSSES/HORNWORTS/LIVERWORTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MOSSES/HORNWORTS/LIVERWORTS', 1);
INSERT INTO {schema}.keywords VALUES (5342, '663a2ea2-e2bf-4209-ae9b-334c8222b106', 122, 'AMOEBOIDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > AMOEBOIDS', 1);
INSERT INTO {schema}.keywords VALUES (5343, '6f2a1cfb-13f4-444f-a6e6-2d8b29797253', 122, 'CILIATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > CILIATES', 1);
INSERT INTO {schema}.keywords VALUES (5344, 'fdb04105-e8ba-4a83-9c35-ed3c931ccc9f', 122, 'DIATOMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > DIATOMS', 1);
INSERT INTO {schema}.keywords VALUES (5345, '2095acb5-14af-40fe-af22-e6af2e3528b5', 122, 'FLAGELLATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > FLAGELLATES', 1);
INSERT INTO {schema}.keywords VALUES (5346, '81655dc5-83d3-4daf-81c8-dc1522e9906e', 122, 'MACROALGAE (SEAWEEDS)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > MACROALGAE (SEAWEEDS)', 1);
INSERT INTO {schema}.keywords VALUES (5347, 'a69dd814-e7c0-437f-ba2a-63500f68c9a3', 122, 'PLANKTON', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > PLANKTON', 1);
INSERT INTO {schema}.keywords VALUES (5348, '98b35c6b-5d40-41d0-b29f-a6b159c03b78', 122, 'SLIME MOLDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > SLIME MOLDS', 1);
INSERT INTO {schema}.keywords VALUES (5349, '32ffe87f-c0f0-4398-9a6a-755d7f87a5ff', 122, 'SPOROZOANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > SPOROZOANS', 1);
INSERT INTO {schema}.keywords VALUES (5350, '8fb66b46-b998-4412-a541-d2acabdf484b', 124, 'COMMUNITY DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (5351, '233a4d81-44f8-4b0e-8ad3-695f641729f8', 124, 'ECOSYSTEM FUNCTIONS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5352, 'dd539b52-6de1-4b1b-a60c-fa5782f4d64b', 124, 'ECOTOXICOLOGY', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOTOXICOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (5353, '62c6d256-e6d4-4204-b7a8-e084dd52d30a', 124, 'FIRE ECOLOGY', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > FIRE ECOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (5354, '58f39353-7e1c-4884-9501-376cd0377fbf', 124, 'SPECIES/POPULATION INTERACTIONS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5355, 'c4a619e9-88ba-4dc6-91a6-5f95284d6f80', 125, 'ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5356, 'c6455081-132d-4661-bb5f-22edf2f90800', 125, 'AQUATIC ECOSYSTEMS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5357, 'ad73e951-fb5b-4a0b-b034-9469a8bfccaa', 125, 'FRESHWATER ECOSYSTEMS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5358, 'f6350232-b1c7-458c-bc43-bda357ebb6db', 125, 'MARINE ECOSYSTEMS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5359, '9361962c-cfc7-4428-8843-b3502718c382', 125, 'TERRESTRIAL ECOSYSTEMS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (5360, 'a28eeef3-b252-4309-957b-860d2e0f97ef', 126, 'AFFORESTATION/REFORESTATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > AFFORESTATION/REFORESTATION', 1);
INSERT INTO {schema}.keywords VALUES (5361, '686feba9-87ba-474c-8280-7f67565cfb2f', 126, 'BIOMASS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > BIOMASS', 1);
INSERT INTO {schema}.keywords VALUES (5362, 'abbba948-9b77-4e19-a855-49a7fbc17696', 126, 'CANOPY CHARACTERISTICS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > CANOPY CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (5363, '2edf648a-6a71-44c3-9c1a-8fcdd2dcc61c', 126, 'CANOPY TRANSMITTANCE', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > CANOPY TRANSMITTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5364, '6f6537f5-773f-4df1-862b-d9ab80eb5e04', 126, 'CARBON', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > CARBON', 1);
INSERT INTO {schema}.keywords VALUES (5365, 'c59b0666-e20f-4134-847b-89719ed5621a', 126, 'CROWN', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > CROWN', 1);
INSERT INTO {schema}.keywords VALUES (5366, 'b7de16ed-c090-449b-81c1-44fe5b1195f0', 126, 'DECIDUOUS VEGETATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > DECIDUOUS VEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (5367, 'df597f06-8575-4726-acac-65b2bd432d59', 126, 'DOMINANT SPECIES', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > DOMINANT SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (5368, '16a7b4d6-e47f-4753-8803-f72edc4e1c5e', 126, 'EVERGREEN VEGETATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > EVERGREEN VEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (5369, 'f717330e-3656-4910-beed-d54cc9a19c2b', 126, 'EXOTIC VEGETATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > EXOTIC VEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (5370, 'a8d3f9a0-be0b-4690-86b9-ac64d951886a', 126, 'FOREST COMPOSITION/VEGETATION STRUCTURE', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > FOREST COMPOSITION/VEGETATION STRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (5371, '40766d01-bda1-420b-9fd1-fba6d6924f3f', 126, 'HERBIVORY', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > HERBIVORY', 1);
INSERT INTO {schema}.keywords VALUES (5372, '536a5a5a-28bb-473a-aa95-6d2dd1e5098d', 126, 'IMPORTANCE VALUE', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > IMPORTANCE VALUE', 1);
INSERT INTO {schema}.keywords VALUES (5373, '0bfb8ae4-c08a-4d69-82d2-1b1b0d4acef6', 126, 'INDIGENOUS VEGETATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > INDIGENOUS VEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (5374, 'bca1b724-3370-4a26-bcbc-3530ce4ddc97', 126, 'LEAF CHARACTERISTICS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > LEAF CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (5375, 'afc54d28-de94-4674-9528-39f00bf74d6d', 126, 'LITTER CHARACTERISTICS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > LITTER CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (5376, 'bf0ddf9c-39ba-4b2d-91ac-63021d644276', 126, 'MACROPHYTES', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > MACROPHYTES', 1);
INSERT INTO {schema}.keywords VALUES (5377, 'ed7c506e-b18e-4a93-ac03-4bdfe119b72f', 126, 'NITROGEN', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (5378, '9bcb805c-718e-42c3-913d-174bdf06d4c1', 126, 'NUTRIENTS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > NUTRIENTS', 1);
INSERT INTO {schema}.keywords VALUES (5379, '47f4e7ac-b4ca-4ef9-824b-a36ea5510526', 126, 'PHOSPHORUS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PHOSPHORUS', 1);
INSERT INTO {schema}.keywords VALUES (5380, 'db69ecb1-0738-4d82-943f-ae92093f500d', 126, 'PHOTOSYNTHETICALLY ACTIVE RADIATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PHOTOSYNTHETICALLY ACTIVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5381, '3e801e91-897e-4528-8f4c-4ec527ad33cc', 126, 'PIGMENTS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PIGMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5382, '0408bac9-c247-4b00-80de-f4665b813658', 126, 'PLANT CHARACTERISTICS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PLANT CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (5383, '3f45aadf-ec7c-43a1-a008-b24ca139837a', 126, 'PLANT PHENOLOGY', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PLANT PHENOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (5384, 'b0ad34ee-4b38-4a8d-a483-b3bfea66fa82', 126, 'POLLEN', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > POLLEN', 1);
INSERT INTO {schema}.keywords VALUES (5385, '86dfb9ca-6587-4a91-b397-f220bb48a1eb', 126, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (5386, 'fe6b37b9-f95a-491e-a58e-22aa66be9a9d', 126, 'REFORESTATION', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > REFORESTATION', 1);
INSERT INTO {schema}.keywords VALUES (5387, '0e06e528-e796-4b7c-9878-dbcb061d878d', 126, 'TREE RINGS', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > TREE RINGS', 1);
INSERT INTO {schema}.keywords VALUES (5388, '5bdb3251-4811-439c-b172-9bbcd98e84b3', 126, 'VEGETATION COVER', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > VEGETATION COVER', 1);
INSERT INTO {schema}.keywords VALUES (5389, 'b7812c71-4b9e-4016-b4ba-dfcdb7e62365', 126, 'VEGETATION INDEX', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > VEGETATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5390, 'de0ace5c-fa2b-47ca-93db-79d8df7ab6f2', 126, 'VEGETATION SPECIES', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > VEGETATION SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (5391, '8c4e2397-aed6-4ce4-9ead-08323e2f90ae', 127, 'CLOUD INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > CLOUD INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (5392, '83e9ddee-5887-4758-a3ba-5cb17a7d4ed5', 127, 'COMPOUND EXTREME EVENTS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > COMPOUND EXTREME EVENTS', 1);
INSERT INTO {schema}.keywords VALUES (5393, 'b29b46ad-f05f-4144-b965-5f606ce96963', 127, 'EXTREME WEATHER', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > EXTREME WEATHER', 1);
INSERT INTO {schema}.keywords VALUES (5394, '12dc1f4f-2116-4b74-a1bd-bc61e8e57a5b', 127, 'FRESH WATER RIVER DISCHARGE', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > FRESH WATER RIVER DISCHARGE', 1);
INSERT INTO {schema}.keywords VALUES (5395, 'b881cf8f-7260-4980-80bc-4b6ae3716c39', 127, 'HUMIDITY INDICES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > HUMIDITY INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5396, 'dbf8a0cf-1e9b-4bc4-95a2-819bb16af00c', 127, 'OCEAN OVERTURNING', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > OCEAN OVERTURNING', 1);
INSERT INTO {schema}.keywords VALUES (5397, '7d3e2368-75ba-43b9-bdce-bba2ff8d3e2c', 127, 'OCEAN UPWELLING INDICES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > OCEAN UPWELLING INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5398, '873ed434-9407-4fd8-9660-41e50b0eb786', 127, 'OCEAN UPWELLING/DOWNWELLING', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > OCEAN UPWELLING/DOWNWELLING', 1);
INSERT INTO {schema}.keywords VALUES (5399, '789939a6-3cd5-46f3-bdfd-5cdd6a012500', 127, 'PRECIPITATION INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (5400, '52347642-9786-4b59-be77-02e9f307118d', 127, 'PRECIPITATION INDICES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5401, '536a86bd-3dd1-4f4a-9b4a-222a12746db5', 127, 'SEA LEVEL RISE', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA LEVEL RISE', 1);
INSERT INTO {schema}.keywords VALUES (5402, 'b83895e9-bac8-49fe-bcf5-8fe4d8fcaa16', 127, 'SEA SURFACE TEMPERATURE INDICES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5403, '1d8525f0-0cfc-4d59-8677-da5c8038deb7', 127, 'SURFACE SALINITY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SURFACE SALINITY', 1);
INSERT INTO {schema}.keywords VALUES (5404, '1c0ebf89-f115-4e0d-9942-8ff8289bd330', 130, 'SEA ICE CONCENTRATION', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SEA ICE CONCENTRATION', 1);
INSERT INTO {schema}.keywords VALUES (5405, 'b887d3e5-4280-43d2-a34e-0f63ac086b6a', 127, 'TELECONNECTIONS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5406, '5d5cf73b-f833-4f8d-84a1-8a3840f3b4af', 130, 'SEA ICE ELEVATION', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SEA ICE ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (5407, '2dcffd8f-2b01-4c68-a4f2-c4940d2709a3', 127, 'TEMPERATURE INDICATORS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS', 1);
INSERT INTO {schema}.keywords VALUES (5408, 'e8580cbb-701a-4ab1-a40f-5fae4ae1ea24', 127, 'TEMPERATURE INDICES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5409, '379dd4c3-04d7-4f76-9bb9-83d0b8e1a2aa', 128, 'BIRTH RATE DECLINE/INCREASE', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > BIRTH RATE DECLINE/INCREASE', 1);
INSERT INTO {schema}.keywords VALUES (5410, '0a07badb-1382-4f63-8344-7ba063b05534', 128, 'BREEDING PRODUCTIVITY', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > BREEDING PRODUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5411, '9a40bc0e-aece-4b4a-a87d-4869c8b903f8', 128, 'CANOPY TEMPERATURE VARIABILITY', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > CANOPY TEMPERATURE VARIABILITY', 1);
INSERT INTO {schema}.keywords VALUES (5412, '853c3456-5397-4e16-ba67-51e4f4205db5', 128, 'HYPOXIC CONDITIONS', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > HYPOXIC CONDITIONS', 1);
INSERT INTO {schema}.keywords VALUES (5413, '6448f172-1560-4ea7-8826-8ac85dc820f3', 128, 'INDICATOR SPECIES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > INDICATOR SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (5414, '93c8b32d-ab89-43e1-b58c-f1823fa7d118', 128, 'INVASIVE SPECIES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > INVASIVE SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (5415, 'cc5ab64b-11d0-4196-b7b3-f9c61e5e3ac6', 128, 'PHENOLOGICAL CHANGES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > PHENOLOGICAL CHANGES', 1);
INSERT INTO {schema}.keywords VALUES (5416, 'f5c63c23-f819-46e8-bc97-1e894424c00c', 128, 'RANGE CHANGES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > RANGE CHANGES', 1);
INSERT INTO {schema}.keywords VALUES (5417, '0de668aa-cc97-482d-a0eb-cddcb1a705b6', 128, 'SPECIES MIGRATION', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > SPECIES MIGRATION', 1);
INSERT INTO {schema}.keywords VALUES (5418, '1d9f0eb8-7233-4969-b40c-979d601ebaa7', 128, 'VECTOR SPECIES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > VECTOR SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (5419, 'fc77777e-614f-41f1-9b97-d5324fa99105', 129, 'ATMOSPHERIC FEEDBACKS', 'EARTH SCIENCE > CLIMATE INDICATORS > CLIMATE FEEDBACKS > ATMOSPHERIC FEEDBACKS', 1);
INSERT INTO {schema}.keywords VALUES (5420, '6a6bed83-f95a-44e6-8ae0-1371b532abc3', 129, 'COUPLED SYSTEM FEEDBACKS', 'EARTH SCIENCE > CLIMATE INDICATORS > CLIMATE FEEDBACKS > COUPLED SYSTEM FEEDBACKS', 1);
INSERT INTO {schema}.keywords VALUES (5421, '3da6855e-9be8-4a79-826e-4ce984ed49a5', 129, 'CRYOSPHERIC FEEDBACKS', 'EARTH SCIENCE > CLIMATE INDICATORS > CLIMATE FEEDBACKS > CRYOSPHERIC FEEDBACKS', 1);
INSERT INTO {schema}.keywords VALUES (5422, '514c891b-60b8-4a6f-adb3-0366c75588e9', 129, 'LAND SURFACE FEEDBACKS', 'EARTH SCIENCE > CLIMATE INDICATORS > CLIMATE FEEDBACKS > LAND SURFACE FEEDBACKS', 1);
INSERT INTO {schema}.keywords VALUES (5423, '80d337f4-8e90-456a-9a5b-33e5f5c907ce', 129, 'OCEANIC FEEDBACKS', 'EARTH SCIENCE > CLIMATE INDICATORS > CLIMATE FEEDBACKS > OCEANIC FEEDBACKS', 1);
INSERT INTO {schema}.keywords VALUES (5424, 'bb8c48bc-a36e-4f7e-afda-3244b058bc9c', 130, 'AVALANCHE', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > AVALANCHE', 1);
INSERT INTO {schema}.keywords VALUES (5425, '82f49e65-c032-4f74-b5c2-a3f8058b7a71', 130, 'DEPTH HOAR', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > DEPTH HOAR', 1);
INSERT INTO {schema}.keywords VALUES (5426, '9fec9f47-c45d-4f15-8be5-d71424f33647', 130, 'FIRN LIMIT', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > FIRN LIMIT', 1);
INSERT INTO {schema}.keywords VALUES (5427, '2d79af4f-d15f-40cc-b0bf-8f5c8eb1fce5', 130, 'GLACIAL MEASUREMENTS', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5428, 'fadd59e2-e1d2-44f6-9e41-0589eb953198', 130, 'ICE DEPTH/THICKNESS', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > ICE DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5429, 'f4c1a555-4758-47ce-baa6-536730333833', 130, 'ICE EDGES', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > ICE EDGES', 1);
INSERT INTO {schema}.keywords VALUES (5430, '50f0cf56-c119-4ac1-9a88-8eb04fa666ad', 130, 'ICE EXTENT', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > ICE EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (5431, '4733ef2c-e512-451b-8079-78ff7278e35c', 130, 'ICE FLOES', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > ICE FLOES', 1);
INSERT INTO {schema}.keywords VALUES (5432, '0ff2a38d-00f6-459d-ac9a-9a983bda602e', 130, 'ICE GROWTH/MELT', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > ICE GROWTH/MELT', 1);
INSERT INTO {schema}.keywords VALUES (5433, 'fde8a54a-8aaa-45fd-bb66-3105e4c57102', 130, 'RIVER ICE DEPTH/EXTENT', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > RIVER ICE DEPTH/EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (5434, 'ee0fce70-2097-4f5b-853a-c34e6cbff929', 130, 'SALINITY', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SALINITY', 1);
INSERT INTO {schema}.keywords VALUES (5435, '8ef6560e-c699-49b4-bcb3-6db68506ca22', 130, 'SNOW COVER', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SNOW COVER', 1);
INSERT INTO {schema}.keywords VALUES (5436, '008708ac-65a4-481a-8e03-640376f42f56', 130, 'SNOW DEPTH', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SNOW DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5437, '29f386e9-84fb-4e5d-9733-20233c63b1be', 130, 'SNOW ENERGY BALANCE', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SNOW ENERGY BALANCE', 1);
INSERT INTO {schema}.keywords VALUES (5438, 'b1be402f-336c-4f1f-8542-9807264a09a7', 130, 'SNOW MELT', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > SNOW MELT', 1);
INSERT INTO {schema}.keywords VALUES (5439, '47200796-7541-4659-acf4-32b5303bcc1f', 131, 'FIJI INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ENVIRONMENTAL VULNERABILITY INDEX (EVI) > FIJI INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5440, '2c1e046e-2feb-4cb7-a6dd-f3753db7b5f5', 131, 'SAMOA INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ENVIRONMENTAL VULNERABILITY INDEX (EVI) > SAMOA INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5441, '585182e9-6e5b-4ad6-96fe-065ffd31f7e8', 131, 'TUVALU INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ENVIRONMENTAL VULNERABILITY INDEX (EVI) > TUVALU INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5442, 'f50672b3-13d8-4206-b6c9-a1f9891ea470', 132, 'DROUGHT INDICES', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > DROUGHT INDICES', 1);
INSERT INTO {schema}.keywords VALUES (5443, 'b51f738c-7061-4ced-b216-53734ce4cb43', 132, 'EROSION', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > EROSION', 1);
INSERT INTO {schema}.keywords VALUES (5444, '7c1977bc-dfe7-4761-9b30-f42ec986d360', 132, 'FIRE WEATHER INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > FIRE WEATHER INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5445, '16329a9b-72ea-4b46-b507-2ce389c63f50', 132, 'FOREST FIRE DANGER INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > FOREST FIRE DANGER INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5446, '36bdce45-37df-4475-9eed-73469a594edb', 132, 'LANDSLIDES', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > LANDSLIDES', 1);
INSERT INTO {schema}.keywords VALUES (5447, 'ed8797be-661a-48c9-a7fe-2600b6c7c067', 132, 'LENGTH OF GROWING SEASON', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > LENGTH OF GROWING SEASON', 1);
INSERT INTO {schema}.keywords VALUES (5448, '32e1b1ec-fa69-47b5-b0d6-d71948e3997a', 132, 'SATELLITE SOIL MOISTURE INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > SATELLITE SOIL MOISTURE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5449, 'cb21c5cb-cc49-4328-a72d-94ccca1fa888', 132, 'SOIL EROSION', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > SOIL EROSION', 1);
INSERT INTO {schema}.keywords VALUES (5450, '27dd85c2-3403-438d-8b0c-8d424df60468', 132, 'SOIL MOISTURE', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > SOIL MOISTURE', 1);
INSERT INTO {schema}.keywords VALUES (5451, 'b29ee2f4-b2ce-4b19-b8e3-2d74d071549b', 132, 'SOIL TEMPERATURE', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > SOIL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5452, 'c7503ec5-4e63-446a-9390-72c8a638a0af', 132, 'SURFACE MOISTURE INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > SURFACE MOISTURE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5453, 'd11df264-e70d-456c-9223-07f34e80b352', 132, 'TREE LINE SHIFT', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > TREE LINE SHIFT', 1);
INSERT INTO {schema}.keywords VALUES (5454, '8d1157c4-d36b-40db-aa82-3603716f9988', 132, 'VEGETATION COVER', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > VEGETATION COVER', 1);
INSERT INTO {schema}.keywords VALUES (5455, '1efdd374-40a1-4118-a1da-61c647017ec9', 133, 'ALUMINUM-26 ANALYSIS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ALUMINUM-26 ANALYSIS', 1);
INSERT INTO {schema}.keywords VALUES (5456, '4bd6aafb-9240-4006-ada3-4b6a0501b612', 133, 'BERYLLIUM-10 ANALYSIS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BERYLLIUM-10 ANALYSIS', 1);
INSERT INTO {schema}.keywords VALUES (5457, '5553fe9d-ab0a-4305-86a6-1f7f697e15e4', 133, 'BIOLOGICAL RECORDS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (5458, '08a4f002-f368-414d-b923-83dd498452d8', 133, 'ICE CORE RECORDS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (5459, '2bedb6b3-6e92-42e2-b382-60e2a6aab8e9', 133, 'LAND RECORDS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (5460, '703d0c14-1978-4e7f-a51a-233c695823b9', 133, 'MASS EXTINCTIONS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > MASS EXTINCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5461, '5237fae3-c98e-4d4a-9013-d7c824b3862b', 133, 'OCEAN/LAKE RECORDS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS', 1);
INSERT INTO {schema}.keywords VALUES (5462, '2f2d4df2-0701-4fe1-9d9b-e7e1c8678a8f', 133, 'OXYGEN ISOTOPE ANALYSIS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OXYGEN ISOTOPE ANALYSIS', 1);
INSERT INTO {schema}.keywords VALUES (5463, 'dc3f297b-8471-4101-b70e-dc5765762061', 133, 'PALEOCLIMATE FORCING', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE FORCING', 1);
INSERT INTO {schema}.keywords VALUES (5464, '6f6423e8-ab4e-4572-8982-d9c40f64e28b', 133, 'PALEOCLIMATE RECONSTRUCTIONS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5465, '478092f3-7cdd-4136-84ec-cebf0d539480', 133, 'PERMAFROST/METHANE RELEASE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PERMAFROST/METHANE RELEASE', 1);
INSERT INTO {schema}.keywords VALUES (5466, '6971fecc-af14-4c97-82db-2b01c98453b9', 133, 'PLATE TECTONICS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PLATE TECTONICS', 1);
INSERT INTO {schema}.keywords VALUES (5467, '1cbefa2a-484e-4742-ad3d-d347d27272bd', 133, 'SPELEOTHEMS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > SPELEOTHEMS', 1);
INSERT INTO {schema}.keywords VALUES (5468, '08bc1b7d-b27b-43e2-a728-4939efb88f08', 133, 'VOLCANIC ACTIVITY', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > VOLCANIC ACTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5469, '3429bc72-0780-44c8-9743-92f84118279d', 134, 'SUNSPOT ACTIVITY', 'EARTH SCIENCE > CLIMATE INDICATORS > SUN-EARTH INTERACTIONS > SUNSPOT ACTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5470, '915399a1-eb5b-475b-ae9a-ff45f1dcddc9', 135, 'FRESHWATER RUNOFF', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS > FRESHWATER RUNOFF', 1);
INSERT INTO {schema}.keywords VALUES (5471, '56e7e412-b354-4ef4-8742-f1f5681c378a', 135, 'MOUNTAIN SNOW LINE SHIFT', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS > MOUNTAIN SNOW LINE SHIFT', 1);
INSERT INTO {schema}.keywords VALUES (5472, 'ed0501c5-310c-42ab-b1eb-66e211f22803', 135, 'PERMAFROST MELT', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS > PERMAFROST MELT', 1);
INSERT INTO {schema}.keywords VALUES (5473, '64baed75-e3c0-4495-9bc9-c5b9373670f6', 135, 'RIVER/LAKE ICE BREAKUP', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS > RIVER/LAKE ICE BREAKUP', 1);
INSERT INTO {schema}.keywords VALUES (5474, '2adde197-3f0f-4eda-ae00-a337dfa853c3', 135, 'RIVER/LAKE ICE FREEZE', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS > RIVER/LAKE ICE FREEZE', 1);
INSERT INTO {schema}.keywords VALUES (5475, '994cc55d-b789-4f03-98dc-4cd0f58ad12a', 135, 'SNOW COVER DEGRADATION', 'EARTH SCIENCE > CLIMATE INDICATORS > TERRESTRIAL HYDROSPHERE INDICATORS > SNOW COVER DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (5476, '2e544263-d92f-46c2-9568-25e36d0b9825', 136, 'ACTIVE LAYER', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > ACTIVE LAYER', 1);
INSERT INTO {schema}.keywords VALUES (5477, '0cd7a96f-46e1-4d86-93d0-9cbb6fda61e3', 136, 'CRYOSOLS', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > CRYOSOLS', 1);
INSERT INTO {schema}.keywords VALUES (5478, '4931dcac-8b89-4bc9-ba59-469cfdcf6f12', 136, 'GROUND ICE', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > GROUND ICE', 1);
INSERT INTO {schema}.keywords VALUES (5479, '097a0fad-d822-49ad-bd12-232e9ea7cb30', 136, 'PERIGLACIAL PROCESSES', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > PERIGLACIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5480, 'c82f3480-545f-4491-83f1-0477369ddcd8', 136, 'PERMAFROST', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > PERMAFROST', 1);
INSERT INTO {schema}.keywords VALUES (5481, 'b1ce822a-139b-4e11-8bbe-453f19501c36', 136, 'ROCK GLACIERS', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > ROCK GLACIERS', 1);
INSERT INTO {schema}.keywords VALUES (5482, '2a109b2f-947a-4c2c-9db9-ae315a53ef93', 136, 'SEASONALLY FROZEN GROUND', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > SEASONALLY FROZEN GROUND', 1);
INSERT INTO {schema}.keywords VALUES (5483, '021714ad-1cae-441c-bb6f-4be866a0f742', 136, 'SOIL TEMPERATURE', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > SOIL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5484, '78e5e44c-7832-456d-a599-893ea87ae695', 136, 'TALIK', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > TALIK', 1);
INSERT INTO {schema}.keywords VALUES (5485, '95fbaefd-1afe-4887-a1ba-fc338a8109bb', 137, 'ABLATION ZONES/ACCUMULATION ZONES', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > ABLATION ZONES/ACCUMULATION ZONES', 1);
INSERT INTO {schema}.keywords VALUES (5486, 'ab4b800d-820f-40cc-bb01-4e8835368d04', 137, 'AGE AT ICE-THICKNESS-NORMALIZED DEPTHS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > AGE AT ICE-THICKNESS-NORMALIZED DEPTHS', 1);
INSERT INTO {schema}.keywords VALUES (5487, '9ce536e1-06c8-4817-af5f-b625cfe571a7', 137, 'AGE OF INTERNAL REFLECTIONS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > AGE OF INTERNAL REFLECTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5488, '68d0f29d-cf46-4f8c-8cad-83817a7093bc', 137, 'BASAL SHEAR STRESS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > BASAL SHEAR STRESS', 1);
INSERT INTO {schema}.keywords VALUES (5489, '70541b66-c911-47fb-a99a-5638a9cb55d4', 137, 'DEPTHS AT SPECIFIC AGES', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > DEPTHS AT SPECIFIC AGES', 1);
INSERT INTO {schema}.keywords VALUES (5490, '6159b9d9-4aa5-4dec-8146-0e47751449ff', 137, 'FIRN', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > FIRN', 1);
INSERT INTO {schema}.keywords VALUES (5491, 'ab319cdf-a34c-446c-9fc0-27605048364e', 137, 'GEOMETRY OF INTERNAL REFLECTIONS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GEOMETRY OF INTERNAL REFLECTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5492, '13bf19c5-087f-4fe0-87ea-ef6f7ecd5444', 137, 'GLACIER ELEVATION/ICE SHEET ELEVATION', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIER ELEVATION/ICE SHEET ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (5493, '399a84d1-ccf5-4167-a699-15eb7d1ad1e6', 137, 'GLACIER FACIES', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIER FACIES', 1);
INSERT INTO {schema}.keywords VALUES (5494, '9f408faa-a427-44e9-a194-b1b9caff1e6d', 137, 'GLACIER MASS BALANCE/ICE SHEET MASS BALANCE', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIER MASS BALANCE/ICE SHEET MASS BALANCE', 1);
INSERT INTO {schema}.keywords VALUES (5495, '73f3c797-2eed-4f0d-accf-7e8a36a3fa93', 137, 'GLACIER MOTION/ICE SHEET MOTION', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIER MOTION/ICE SHEET MOTION', 1);
INSERT INTO {schema}.keywords VALUES (5496, '5034ba1f-7208-40a1-beeb-43aefe1c0c33', 137, 'GLACIER THICKNESS/ICE SHEET THICKNESS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIER THICKNESS/ICE SHEET THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5497, 'bf19f1d1-ae18-4ff2-95f6-dc0ed812c568', 137, 'GLACIER TOPOGRAPHY/ICE SHEET TOPOGRAPHY', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIER TOPOGRAPHY/ICE SHEET TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (5498, '68eed887-8008-4352-b420-949457ab59ab', 137, 'GLACIERS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > GLACIERS', 1);
INSERT INTO {schema}.keywords VALUES (5499, '10b1872b-4a48-4360-a449-388e8988bca9', 137, 'ICE SHEETS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > ICE SHEETS', 1);
INSERT INTO {schema}.keywords VALUES (5500, '4d95ccc8-3ef9-40df-85e7-db36cb815499', 137, 'ICEBERGS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > ICEBERGS', 1);
INSERT INTO {schema}.keywords VALUES (5501, 'a4466cbe-b991-427b-97b8-fdc284b9ef21', 138, 'FREEBOARD', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > FREEBOARD', 1);
INSERT INTO {schema}.keywords VALUES (5502, '5569b7a3-3a4b-4799-8c68-98126757074b', 138, 'HEAT FLUX', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > HEAT FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5503, '1009557b-0d4b-4c13-81a0-fd95c15bf158', 138, 'ICE DEFORMATION', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE DEFORMATION', 1);
INSERT INTO {schema}.keywords VALUES (5504, 'c7708bb6-a0fa-4905-b99d-c468da7d951a', 138, 'ICE DEPTH/THICKNESS', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5505, '5fa04fa9-06c7-41c7-98f9-f92756f080ea', 138, 'ICE EDGES', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE EDGES', 1);
INSERT INTO {schema}.keywords VALUES (5506, '63b37017-9d57-4247-af4e-2df36ee3ed03', 138, 'ICE EXTENT', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (5507, 'af0d756e-784e-4747-97d0-3425baf5d09b', 138, 'ICE FLOES', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE FLOES', 1);
INSERT INTO {schema}.keywords VALUES (5508, 'd9667e73-30db-45f9-861c-e0a5caaf2bf0', 138, 'ICE GROWTH/MELT', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE GROWTH/MELT', 1);
INSERT INTO {schema}.keywords VALUES (5509, 'ce3a1edd-a2fe-4efd-8971-9dd7b97b6d79', 138, 'ICE ROUGHNESS', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE ROUGHNESS', 1);
INSERT INTO {schema}.keywords VALUES (5510, 'f6e7aa9a-ae65-480e-84fa-b3a5d523e822', 138, 'ICE TEMPERATURE', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5511, '6bfd4d52-fad4-470f-9da0-fa7df2a5b4aa', 138, 'ICE TYPES', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICE TYPES', 1);
INSERT INTO {schema}.keywords VALUES (5512, '1efe6ac1-d375-44c3-b8ec-d0ff2987a881', 138, 'ICEBERGS', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ICEBERGS', 1);
INSERT INTO {schema}.keywords VALUES (5513, 'f0d4b06b-c498-4760-bc92-877e28f3a098', 138, 'ISOTOPES', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (5514, '4f0f606c-6bf8-4b8c-9431-d5696fe8a5f2', 138, 'LEADS', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > LEADS', 1);
INSERT INTO {schema}.keywords VALUES (5515, '5d7ea074-225b-4221-b122-e6a085cdce24', 138, 'PACK ICE', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > PACK ICE', 1);
INSERT INTO {schema}.keywords VALUES (5516, '70acf223-7895-4cbe-aca6-815babb2b7ed', 138, 'POLYNYAS', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > POLYNYAS', 1);
INSERT INTO {schema}.keywords VALUES (5517, 'cece77b6-42bf-44f6-9193-050cbc5f4cf7', 138, 'REFLECTANCE', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5518, '6bc39a6d-cc60-467a-9181-d8b4e02a1cb0', 138, 'SALINITY', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SALINITY', 1);
INSERT INTO {schema}.keywords VALUES (5519, '3488309d-ef21-4d60-81a3-78fb99ffa756', 138, 'SEA ICE AGE', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SEA ICE AGE', 1);
INSERT INTO {schema}.keywords VALUES (5520, '8012fda7-3ea4-4ef2-bb4e-0f66d4d9e850', 138, 'SEA ICE CONCENTRATION', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SEA ICE CONCENTRATION', 1);
INSERT INTO {schema}.keywords VALUES (5521, '139b0dae-27bb-42bd-8027-81fb9fd8f85d', 138, 'SEA ICE ELEVATION', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SEA ICE ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (5522, '1455c369-88e2-411b-83f7-c914b20609b1', 138, 'SEA ICE MOTION', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SEA ICE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (5523, 'aa645419-cff3-4f5b-84af-e3de41dd0d16', 138, 'SNOW DEPTH', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SNOW DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5524, '064f9784-697e-414c-b463-29cfd734e689', 138, 'SNOW MELT', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SNOW MELT', 1);
INSERT INTO {schema}.keywords VALUES (5525, '41ebe049-230e-4ff7-acb1-43de68ace83e', 139, 'ALBEDO', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > ALBEDO', 1);
INSERT INTO {schema}.keywords VALUES (5526, 'e1dbe955-7285-4df2-a854-07693fce44ec', 139, 'AVALANCHE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > AVALANCHE', 1);
INSERT INTO {schema}.keywords VALUES (5527, 'c306d542-9be8-449d-ba33-28ad033c77aa', 139, 'DEPTH HOAR', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > DEPTH HOAR', 1);
INSERT INTO {schema}.keywords VALUES (5528, 'dafb67df-dc6d-40a0-8d94-e4621d2538ce', 139, 'FREEZE/THAW', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > FREEZE/THAW', 1);
INSERT INTO {schema}.keywords VALUES (5529, 'ea936862-2c98-41e5-8514-6b7288a5f941', 139, 'FROST', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > FROST', 1);
INSERT INTO {schema}.keywords VALUES (5530, 'e28676de-738d-4112-8897-ee585b7d1d84', 139, 'ICE DEPTH/THICKNESS', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > ICE DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5531, '19409c76-09d4-455c-b1f1-dc2e647f7403', 139, 'ICE EXTENT', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > ICE EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (5532, '19594c37-ef32-4b03-bda6-abf8a321fdb9', 139, 'ICE GROWTH/MELT', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > ICE GROWTH/MELT', 1);
INSERT INTO {schema}.keywords VALUES (5533, '4b85cc37-1577-43f6-8cfa-8da2c49eaece', 139, 'ICE MOTION', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > ICE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (5534, '3896f032-388f-408e-b988-bf7e100704ba', 139, 'ICE VELOCITY', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > ICE VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (5535, '8cb47594-3af6-4f4f-8ba1-4299a6d6887e', 139, 'LAKE ICE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > LAKE ICE', 1);
INSERT INTO {schema}.keywords VALUES (5536, '1f4cdbc4-0f65-4384-83c9-9422c280717d', 139, 'PERMAFROST', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > PERMAFROST', 1);
INSERT INTO {schema}.keywords VALUES (5537, '00a21e9c-0c1d-4931-b9fa-b0204625a98a', 139, 'REFLECTANCE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5538, '52e6600b-7a51-4267-8b62-e79034db3a48', 139, 'RIVER ICE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > RIVER ICE', 1);
INSERT INTO {schema}.keywords VALUES (5539, 'c8ff0035-4776-4eb9-8cc9-a63d380102c8', 139, 'SNOW COVER', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW COVER', 1);
INSERT INTO {schema}.keywords VALUES (5540, 'ba2e2eff-77e0-4071-8884-b2af06e5fc7b', 139, 'SNOW DENSITY', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (5541, '47bc8942-6fdd-4173-bf38-209e933d843f', 139, 'SNOW DEPTH', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5542, 'a3520db9-7bed-4f55-a9f6-028d52af6091', 139, 'SNOW ENERGY BALANCE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW ENERGY BALANCE', 1);
INSERT INTO {schema}.keywords VALUES (5543, '99506fd1-5f84-485d-8e26-03e4f7b55136', 139, 'SNOW FACIES', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW FACIES', 1);
INSERT INTO {schema}.keywords VALUES (5544, '58f98d2a-d7d6-47d4-b826-68fdc57e79bb', 139, 'SNOW MELT', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW MELT', 1);
INSERT INTO {schema}.keywords VALUES (5545, '4dc6b614-36ad-4e3b-ac6f-af6e0aa6378b', 139, 'SNOW MICROSTRUCTURE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW MICROSTRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (5546, '9e15c793-ede5-4089-8fb7-5bbb31ff7913', 139, 'SNOW STRATIGRAPHY', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW STRATIGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (5547, '587e4d68-36f0-45b5-9978-4b3edd58a1c0', 139, 'SNOW WATER EQUIVALENT', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW WATER EQUIVALENT', 1);
INSERT INTO {schema}.keywords VALUES (5548, 'dfe4b154-84e0-4005-81ce-90daf38c06e3', 139, 'SNOW/ICE CHEMISTRY', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW/ICE CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5549, '99bc6084-32bc-405a-b2e9-efd906fa370b', 139, 'SNOW/ICE TEMPERATURE', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW/ICE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5550, '067004b9-1628-4c00-8bfb-28f910b68d59', 139, 'WHITEOUT', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > WHITEOUT', 1);
INSERT INTO {schema}.keywords VALUES (5551, '1ae304de-252c-45da-8dd8-df99a281e4f4', 140, 'ADMINISTRATIVE DIVISIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > BOUNDARIES > ADMINISTRATIVE DIVISIONS', 1);
INSERT INTO {schema}.keywords VALUES (5552, '8064b11d-8f9f-4c89-94fd-8a7cba95bb64', 140, 'BOUNDARY SURVEYS', 'EARTH SCIENCE > HUMAN DIMENSIONS > BOUNDARIES > BOUNDARY SURVEYS', 1);
INSERT INTO {schema}.keywords VALUES (5553, '3381412c-54f0-4911-85ef-81d669c896cf', 140, 'POLITICAL DIVISIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > BOUNDARIES > POLITICAL DIVISIONS', 1);
INSERT INTO {schema}.keywords VALUES (5554, '83741fb9-6f86-4670-abbb-c1f3b14a939d', 141, 'AGRICULTURE PRODUCTION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > AGRICULTURE PRODUCTION', 1);
INSERT INTO {schema}.keywords VALUES (5555, '392d3da2-c03c-4aa5-bf60-417984f824a6', 141, 'AQUACULTURE PRODUCTION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > AQUACULTURE PRODUCTION', 1);
INSERT INTO {schema}.keywords VALUES (5556, 'b73cee46-8e2c-4df9-b1ed-7f0aa98a04ac', 141, 'ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (5557, '49da5018-59ec-4a60-9cb9-614ea6266ced', 141, 'MARICULTURE PRODUCTION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > MARICULTURE PRODUCTION', 1);
INSERT INTO {schema}.keywords VALUES (5558, '82fdb39c-4fe8-4e2b-9dcf-67ceb4c6d8b9', 141, 'TOURISM', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > TOURISM', 1);
INSERT INTO {schema}.keywords VALUES (5559, 'e8c24822-7d2d-48c6-9dca-df3860e9bd63', 142, 'CARBON CAPTURE AND STORAGE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > CARBON CAPTURE AND STORAGE', 1);
INSERT INTO {schema}.keywords VALUES (5560, '0e530a5f-1e75-4602-9659-98ff5c3d7076', 142, 'CARBON FOOTPRINT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > CARBON FOOTPRINT', 1);
INSERT INTO {schema}.keywords VALUES (5561, '079724fa-ff86-4195-aee0-51a4d6dd73bb', 142, 'ENVIRONMENTAL ASSESSMENTS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > ENVIRONMENTAL ASSESSMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5562, '57df059e-578a-4371-9484-7a34d63edfa5', 142, 'ENVIRONMENTAL REGULATIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > ENVIRONMENTAL REGULATIONS', 1);
INSERT INTO {schema}.keywords VALUES (5563, '0ef4a2f0-8a29-4f5e-9396-b4f6a71c8bf6', 142, 'FIRE MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > FIRE MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (5564, '262e3568-c57b-4e28-a142-ad5e7b51dfb7', 142, 'GEOENGINEERING', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > GEOENGINEERING', 1);
INSERT INTO {schema}.keywords VALUES (5565, '2be0af28-a6b8-4fce-82e4-1ad86788a4d5', 142, 'LAND MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > LAND MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (5566, '4dad174d-9419-4634-84f0-7eeb1d517241', 142, 'TREATY AGREEMENTS/RESULTS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > TREATY AGREEMENTS/RESULTS', 1);
INSERT INTO {schema}.keywords VALUES (5567, '14555831-70ae-4650-8983-956d65595575', 142, 'WATER MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > WATER MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (5568, 'dbeff538-6857-4573-8d14-12009e0ee078', 143, 'ACID DEPOSITION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > ACID DEPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (5569, 'd076e628-320a-477b-aad9-07d87ca04993', 143, 'AGRICULTURAL EXPANSION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > AGRICULTURAL EXPANSION', 1);
INSERT INTO {schema}.keywords VALUES (5570, 'de89c42c-206a-4573-a2af-edffe5ddd6bf', 143, 'BIOCHEMICAL RELEASE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > BIOCHEMICAL RELEASE', 1);
INSERT INTO {schema}.keywords VALUES (5571, '9d7eed04-9c49-4024-8d0f-06474cc38bbc', 143, 'BIOMASS BURNING', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > BIOMASS BURNING', 1);
INSERT INTO {schema}.keywords VALUES (5572, 'a5b074da-5e00-4fd9-9c40-cfec771263ee', 143, 'CHEMICAL SPILLS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > CHEMICAL SPILLS', 1);
INSERT INTO {schema}.keywords VALUES (5573, '09cf34f3-5e20-4dc1-9b76-97afd856ebe0', 143, 'CIVIL DISTURBANCE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > CIVIL DISTURBANCE', 1);
INSERT INTO {schema}.keywords VALUES (5574, '40869a25-edea-4438-80f9-47c9e6910b9b', 143, 'CONSERVATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > CONSERVATION', 1);
INSERT INTO {schema}.keywords VALUES (5575, '912245ce-a81e-4d3b-b4fb-f71c8da63357', 143, 'CONTAMINANT LEVELS/SPILLS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > CONTAMINANT LEVELS/SPILLS', 1);
INSERT INTO {schema}.keywords VALUES (5576, '69d84440-b806-4093-a659-f052185e22bd', 143, 'ELECTRIC/MAGNETIC FIELD EXPOSURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > ELECTRIC/MAGNETIC FIELD EXPOSURE', 1);
INSERT INTO {schema}.keywords VALUES (5577, 'edfbff1e-b24b-40b9-be54-e1823b4d7f49', 143, 'FOSSIL FUEL BURNING', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > FOSSIL FUEL BURNING', 1);
INSERT INTO {schema}.keywords VALUES (5578, '083d79ba-b7fa-4a07-9c36-73540666d5c4', 143, 'GAS EXPLOSIONS/LEAKS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > GAS EXPLOSIONS/LEAKS', 1);
INSERT INTO {schema}.keywords VALUES (5579, '6221fa7d-9407-4ffc-ab58-886038209254', 143, 'GAS FLARING', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > GAS FLARING', 1);
INSERT INTO {schema}.keywords VALUES (5580, '0c4ffc6a-694d-4f33-bc18-06fefb68acdd', 143, 'HEAVY METALS CONCENTRATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > HEAVY METALS CONCENTRATION', 1);
INSERT INTO {schema}.keywords VALUES (5581, '07f7ea8e-cf94-4421-923a-539e12dbeb95', 143, 'INDUSTRIAL EMISSIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > INDUSTRIAL EMISSIONS', 1);
INSERT INTO {schema}.keywords VALUES (5582, '207a34e0-48c0-439a-a001-dcf664b61686', 143, 'MINE DRAINAGE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > MINE DRAINAGE', 1);
INSERT INTO {schema}.keywords VALUES (5583, '48671d9e-a627-4034-baec-201bda5d166d', 143, 'NUCLEAR RADIATION EXPOSURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > NUCLEAR RADIATION EXPOSURE', 1);
INSERT INTO {schema}.keywords VALUES (5584, '82c3689a-6bbf-496f-b118-b6ab46a9d2c7', 143, 'OIL SPILLS', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > OIL SPILLS', 1);
INSERT INTO {schema}.keywords VALUES (5585, 'c0fb4215-4f72-445f-af81-b3f44c44cd0e', 143, 'PRESCRIBED BURNS/FIRES', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > PRESCRIBED BURNS/FIRES', 1);
INSERT INTO {schema}.keywords VALUES (5586, '835c5ec2-50e3-4bef-b380-9f74b143dac6', 143, 'SEWAGE DISPOSAL', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL IMPACTS > SEWAGE DISPOSAL', 1);
INSERT INTO {schema}.keywords VALUES (5587, '9a4715a7-1847-4fef-8116-494b36420fb7', 144, 'DEFORESTATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > DEFORESTATION', 1);
INSERT INTO {schema}.keywords VALUES (5588, 'dee57819-62c7-4f89-87e5-90a87a07820a', 144, 'DESERTIFICATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > DESERTIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (5589, 'a66ec515-6a6e-487b-9004-2d19d6ffff04', 144, 'ECOLOGICAL CORRIDORS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > ECOLOGICAL CORRIDORS', 1);
INSERT INTO {schema}.keywords VALUES (5590, '32777aa3-a06a-4719-bbe5-7dcecb1a06f5', 144, 'EUTROPHICATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > EUTROPHICATION', 1);
INSERT INTO {schema}.keywords VALUES (5591, '59b3849e-6704-402f-9a3e-512db10c2f51', 144, 'IRRIGATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > IRRIGATION', 1);
INSERT INTO {schema}.keywords VALUES (5592, 'aa4a9df3-0fed-4512-b158-ed369463e33a', 144, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (5593, '39a032bf-c3bc-481b-9698-8be114fe85cb', 144, 'REFORESTATION/REVEGETATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > REFORESTATION/REVEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (5594, 'e759cacb-33f0-4564-b151-c7cfa5e85ed3', 144, 'URBANIZATION/URBAN SPRAWL', 'EARTH SCIENCE > HUMAN DIMENSIONS > HABITAT CONVERSION/FRAGMENTATION > URBANIZATION/URBAN SPRAWL', 1);
INSERT INTO {schema}.keywords VALUES (5595, 'bf703f22-9775-460d-86bd-149aaef1acde', 145, 'ARCHAEOLOGICAL AREAS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HUMAN SETTLEMENTS > ARCHAEOLOGICAL AREAS', 1);
INSERT INTO {schema}.keywords VALUES (5596, 'b1f63bf1-a547-4189-9c7e-66a8d11facc4', 145, 'COASTAL AREAS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HUMAN SETTLEMENTS > COASTAL AREAS', 1);
INSERT INTO {schema}.keywords VALUES (5597, 'd83b4271-048c-4763-9d5c-b5ec1b1788f4', 145, 'RURAL AREAS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HUMAN SETTLEMENTS > RURAL AREAS', 1);
INSERT INTO {schema}.keywords VALUES (5598, '2b4df9a9-ac03-4bdc-bee4-346045a75e05', 145, 'TRIBAL LANDS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HUMAN SETTLEMENTS > TRIBAL LANDS', 1);
INSERT INTO {schema}.keywords VALUES (5599, 'e4abd82b-b17a-4f16-be79-0093f2a09f7d', 145, 'URBAN AREAS', 'EARTH SCIENCE > HUMAN DIMENSIONS > HUMAN SETTLEMENTS > URBAN AREAS', 1);
INSERT INTO {schema}.keywords VALUES (5600, 'd7742082-5461-4610-9ced-e0ec3bb64697', 146, 'BUILDINGS', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > BUILDINGS', 1);
INSERT INTO {schema}.keywords VALUES (5601, 'db692676-a2f6-4fd9-91b6-92ae4f9c04fd', 146, 'COMMUNICATIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > COMMUNICATIONS', 1);
INSERT INTO {schema}.keywords VALUES (5602, '79b0b1d3-5279-4ce5-a387-6ecb4ee2a335', 146, 'CULTURAL FEATURES', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > CULTURAL FEATURES', 1);
INSERT INTO {schema}.keywords VALUES (5603, '12433114-d15a-46cf-aba9-ce4b569119ce', 146, 'ELECTRICITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > ELECTRICITY', 1);
INSERT INTO {schema}.keywords VALUES (5604, 'eeba88d2-20bf-43b1-bccf-b125485405f4', 146, 'GREEN INFRASTRUCTURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > GREEN INFRASTRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (5605, 'ee49d315-1fe5-42ce-a5f8-232450dfa408', 146, 'PIPELINES', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > PIPELINES', 1);
INSERT INTO {schema}.keywords VALUES (5606, '37a6c8e2-f2ac-48a4-a4fa-d80f700f68db', 146, 'TRANSPORTATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > INFRASTRUCTURE > TRANSPORTATION', 1);
INSERT INTO {schema}.keywords VALUES (5607, 'bb73336e-9113-426b-ac99-2b7c143b22ca', 147, 'BIOLOGICAL HAZARDS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > BIOLOGICAL HAZARDS', 1);
INSERT INTO {schema}.keywords VALUES (5608, '115d340f-cb5e-4436-bfa4-04a740988bf7', 147, 'DROUGHTS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > DROUGHTS', 1);
INSERT INTO {schema}.keywords VALUES (5609, 'b3406120-9faa-4c00-874e-ce8878ae129f', 147, 'EARTHQUAKES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > EARTHQUAKES', 1);
INSERT INTO {schema}.keywords VALUES (5610, '6bb02b3d-be70-47b0-93d7-eb0c926f5979', 147, 'FAMINE', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > FAMINE', 1);
INSERT INTO {schema}.keywords VALUES (5611, 'fd03d204-4391-4e98-8142-8b8efa235231', 147, 'FLOODS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > FLOODS', 1);
INSERT INTO {schema}.keywords VALUES (5612, 'bb9c9be6-78c7-4fbd-9a35-a218276393ec', 147, 'HEAT', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > HEAT', 1);
INSERT INTO {schema}.keywords VALUES (5613, 'ba064d3f-0327-49d2-9984-332de1a97146', 147, 'LAND SUBSIDENCE', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > LAND SUBSIDENCE', 1);
INSERT INTO {schema}.keywords VALUES (5614, 'f81d3752-d97c-4caf-9a79-5709ee693158', 147, 'LANDSLIDES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > LANDSLIDES', 1);
INSERT INTO {schema}.keywords VALUES (5615, 'ad28623e-bb9b-433c-8fc1-2ab06dda58c4', 147, 'SEVERE STORMS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > SEVERE STORMS', 1);
INSERT INTO {schema}.keywords VALUES (5616, 'ff44a7b0-64b6-418a-9d74-1cbc3a4ae951', 147, 'TORNADOES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TORNADOES', 1);
INSERT INTO {schema}.keywords VALUES (5617, '00fc45e0-400d-4024-a82a-4d6544735f64', 147, 'TROPICAL CYCLONES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TROPICAL CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (5618, '768f266e-0807-49c6-a69e-c518de310331', 147, 'TSUNAMIS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TSUNAMIS', 1);
INSERT INTO {schema}.keywords VALUES (5619, '06c1281f-e306-4511-bdab-ed6c0694f0f9', 147, 'VOLCANIC ERUPTIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > VOLCANIC ERUPTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5620, '868b87a1-d8c2-49b3-8bbd-9cbbed115271', 147, 'WILDFIRES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > WILDFIRES', 1);
INSERT INTO {schema}.keywords VALUES (5621, '3fd888c4-2fd2-4ce1-8753-3158e2826ef7', 148, 'MORTALITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > MORTALITY', 1);
INSERT INTO {schema}.keywords VALUES (5622, '9d6eda76-cf5d-4170-92ce-9ac9197832bf', 148, 'NATALITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > NATALITY', 1);
INSERT INTO {schema}.keywords VALUES (5623, 'd2a5c7ec-ccf2-4ab7-8863-9063be91c022', 148, 'POPULATION DENSITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > POPULATION DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (5624, 'ae9f3a07-f23e-4116-b172-677435102b2f', 148, 'POPULATION DISTRIBUTION', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > POPULATION DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (5625, 'd7ad5cff-75df-4bb6-92f0-b5d56da2a588', 148, 'POPULATION ESTIMATES', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > POPULATION ESTIMATES', 1);
INSERT INTO {schema}.keywords VALUES (5626, 'dd0b8bc9-90b3-4e7d-a021-e91dc676d622', 148, 'POPULATION SIZE', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > POPULATION SIZE', 1);
INSERT INTO {schema}.keywords VALUES (5627, '35b7c7cd-49c8-476c-83f2-f2e1f4097307', 148, 'VULNERABLE POPULATIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > VULNERABLE POPULATIONS', 1);
INSERT INTO {schema}.keywords VALUES (5628, '7d59f070-ccac-4a90-815b-edfca521779b', 149, 'DISEASES/EPIDEMICS', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > DISEASES/EPIDEMICS', 1);
INSERT INTO {schema}.keywords VALUES (5629, '5a47842e-785d-4cc4-b1c1-2147a9252c19', 149, 'ENVIRONMENTAL HEALTH FACTORS', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > ENVIRONMENTAL HEALTH FACTORS', 1);
INSERT INTO {schema}.keywords VALUES (5630, '85a73755-cb84-40cb-a23e-2ed3811138f8', 149, 'FOOD SECURITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > FOOD SECURITY', 1);
INSERT INTO {schema}.keywords VALUES (5631, '1d1f1722-27ea-4021-922f-68b90c09bfa1', 149, 'MALNUTRITION', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > MALNUTRITION', 1);
INSERT INTO {schema}.keywords VALUES (5632, '3ad043a9-2ec8-401d-a727-5589a303ea4a', 149, 'MENTAL HEALTH IMPACTS', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > MENTAL HEALTH IMPACTS', 1);
INSERT INTO {schema}.keywords VALUES (5633, '8a49484a-a9c8-411b-b911-7646f5323a7b', 149, 'MORBIDITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > MORBIDITY', 1);
INSERT INTO {schema}.keywords VALUES (5634, '74851074-27ab-425b-9521-8d139b907b0d', 149, 'RADIATION EXPOSURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > RADIATION EXPOSURE', 1);
INSERT INTO {schema}.keywords VALUES (5635, '91df78a1-2e38-41d5-b88e-e235450c89fc', 149, 'WATER TREATMENT DISRUPTION', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > WATER TREATMENT DISRUPTION', 1);
INSERT INTO {schema}.keywords VALUES (5636, 'aef9855c-70e1-4e22-aa25-8ccd23176d3b', 150, 'CONSERVATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > CONSERVATION', 1);
INSERT INTO {schema}.keywords VALUES (5637, 'd11d5e6d-fafb-4012-818c-8bfb984128f1', 150, 'CONSUMER BEHAVIOR', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > CONSUMER BEHAVIOR', 1);
INSERT INTO {schema}.keywords VALUES (5638, '507860e1-7494-438a-8537-b21da89efddf', 150, 'DISASTER RESPONSE', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > DISASTER RESPONSE', 1);
INSERT INTO {schema}.keywords VALUES (5639, '843a6584-e3f2-4a75-a003-cc430fd8c22c', 150, 'HAZARD MITIGATION/PLANNING', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > HAZARD MITIGATION/PLANNING', 1);
INSERT INTO {schema}.keywords VALUES (5640, '859155e1-d2d3-41a3-8d44-91afa87d68b4', 150, 'PRESERVATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > PRESERVATION', 1);
INSERT INTO {schema}.keywords VALUES (5641, '9ee8acad-458e-45c1-a1d5-9b1649c82ea7', 150, 'RECREATIONAL ACTIVITIES/AREAS', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > RECREATIONAL ACTIVITIES/AREAS', 1);
INSERT INTO {schema}.keywords VALUES (5642, 'b2f12641-19c8-4b26-9496-e79da5efcb85', 150, 'RECYCLING', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > RECYCLING', 1);
INSERT INTO {schema}.keywords VALUES (5643, '33f20afe-5ce2-43e9-9676-c5f664fbc324', 150, 'VULNERABILITY LEVELS/INDEX', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIAL BEHAVIOR > VULNERABILITY LEVELS/INDEX', 1);
INSERT INTO {schema}.keywords VALUES (5644, 'c88a747b-2302-49c9-b747-f2faa21e2b6b', 151, 'HOUSEHOLD INCOME', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIOECONOMICS > HOUSEHOLD INCOME', 1);
INSERT INTO {schema}.keywords VALUES (5645, '92d8968b-617e-433d-ab9b-e269497c3f43', 151, 'INDUSTRIALIZATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIOECONOMICS > INDUSTRIALIZATION', 1);
INSERT INTO {schema}.keywords VALUES (5646, 'b37021a3-4d7f-4b94-b614-807d6981d2ad', 151, 'POVERTY LEVELS', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIOECONOMICS > POVERTY LEVELS', 1);
INSERT INTO {schema}.keywords VALUES (5647, '2bf46486-3004-447e-b2c6-82c4aa13fc11', 151, 'PURCHASING POWER', 'EARTH SCIENCE > HUMAN DIMENSIONS > SOCIOECONOMICS > PURCHASING POWER', 1);
INSERT INTO {schema}.keywords VALUES (5648, '73266dd6-217a-432f-9237-176d3e94b39b', 152, 'ENVIRONMENTAL SUSTAINABILITY', 'EARTH SCIENCE > HUMAN DIMENSIONS > SUSTAINABILITY > ENVIRONMENTAL SUSTAINABILITY', 1);
INSERT INTO {schema}.keywords VALUES (5649, '8d11c81c-ff5b-4cc0-9be2-8e73dddcb51b', 152, 'SUSTAINABLE DEVELOPMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > SUSTAINABILITY > SUSTAINABLE DEVELOPMENT', 1);
INSERT INTO {schema}.keywords VALUES (5650, '2f2f5764-d4e6-4bbb-bd6d-dda373018237', 153, 'DEGRADATION', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (5651, 'f6a5cc87-a333-4e99-88d4-bf7b5b1cf484', 153, 'ENTRAINMENT', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > ENTRAINMENT', 1);
INSERT INTO {schema}.keywords VALUES (5652, '1e2b1b67-a401-4fb6-9ee9-b022c1c023dc', 153, 'EROSION', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > EROSION', 1);
INSERT INTO {schema}.keywords VALUES (5653, 'ea4aefeb-64cd-4408-83d8-8e0a672739b9', 153, 'LANDSLIDES', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > LANDSLIDES', 1);
INSERT INTO {schema}.keywords VALUES (5654, 'ca2ffcd6-39e6-4eab-abc2-07eb4a197e3d', 153, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5655, '807aff1a-6fe0-474a-a025-a0d0d8b17dbd', 153, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (5656, 'e4ad5a76-7540-4433-ad82-9fe89259538b', 153, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (5657, 'b41498cd-6b2b-47e3-afe7-0f05b4c0807d', 153, 'SEDIMENTATION', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (5658, '26558c08-beca-4ef0-9ea3-b000504ece60', 153, 'SEDIMENTS', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5659, '42b5ae5b-90d5-44f0-b331-6c22cdd45c3f', 153, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (5660, '69ff701a-674e-4b63-bb93-6ebe6cd95281', 153, 'SUSPENDED SOLIDS', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > SUSPENDED SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (5661, 'b07017e8-d714-45a6-b1fe-8c00230ec209', 153, 'WEATHERING', 'EARTH SCIENCE > LAND SURFACE > EROSION/SEDIMENTATION > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (5662, '10270ee0-8d85-4c75-9fa2-49e7a9755cb3', 154, 'ACTIVE LAYER', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > ACTIVE LAYER', 1);
INSERT INTO {schema}.keywords VALUES (5663, '1469f30b-6eb4-4186-b1ef-7dd25c34c592', 154, 'CRYOSOLS', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > CRYOSOLS', 1);
INSERT INTO {schema}.keywords VALUES (5664, '5b4dde5a-733e-4e55-97c9-2108b337cfeb', 154, 'GROUND ICE', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > GROUND ICE', 1);
INSERT INTO {schema}.keywords VALUES (5665, '5181e50a-b1d2-41b1-bde3-fd9b4da9b1bf', 154, 'PERIGLACIAL PROCESSES', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > PERIGLACIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5666, 'b6723314-3db7-4bdd-85ee-0b8507e6ae1b', 154, 'PERMAFROST', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > PERMAFROST', 1);
INSERT INTO {schema}.keywords VALUES (5667, 'ee2af62b-9f76-440c-aa9b-77940468b8f4', 154, 'ROCK GLACIERS', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > ROCK GLACIERS', 1);
INSERT INTO {schema}.keywords VALUES (5668, '6fdd8021-3f6f-4f54-829c-26f744597309', 154, 'SEASONALLY FROZEN GROUND', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > SEASONALLY FROZEN GROUND', 1);
INSERT INTO {schema}.keywords VALUES (5669, '240ff021-6a9c-4603-983d-f135ee7e49ab', 154, 'SOIL TEMPERATURE', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > SOIL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5670, 'c39710ae-423f-44c8-b969-9af8a1f912cf', 154, 'TALIK', 'EARTH SCIENCE > LAND SURFACE > FROZEN GROUND > TALIK', 1);
INSERT INTO {schema}.keywords VALUES (5671, 'ed75fb8f-cb96-448e-ada5-dc48fbd0ebb1', 155, 'AEOLIAN LANDFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (5672, '3ab3aa92-9cca-4660-a0ed-281fff07eede', 155, 'AEOLIAN PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5673, '0cff6e4b-e42a-4565-89ff-350adf41ed69', 155, 'COASTAL LANDFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (5674, 'e26803a0-82ea-40c4-a41a-9e222c9bd09a', 155, 'COASTAL PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5675, 'bdc0bd86-a3a3-48fa-b1fb-4ca5d13d4dde', 155, 'FLUVIAL LANDFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (5676, '4b982bef-56fe-41e9-a131-af575a8fec6a', 155, 'FLUVIAL PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5677, 'b895f4b5-5273-49ef-883f-b67d9f199505', 155, 'GLACIAL LANDFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (5678, 'b409a30b-0e3f-4592-bec9-7d371797b4a9', 155, 'GLACIAL PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5679, '590aa85e-bbce-40b2-8ffb-53d80a61c51a', 155, 'KARST LANDFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (5680, '9cd875b0-210b-458f-b208-1690f50820d0', 155, 'KARST PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5681, '9673dc0b-89c0-4f0c-b378-f1c8cb267c8f', 155, 'TECTONIC LANDFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (5682, '99b4792a-9ea3-4756-a4dc-b1b30c946b54', 155, 'TECTONIC PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5683, '2e69c08b-ee0f-426c-a8d2-dc50876f76c2', 156, 'LAND PRODUCTIVITY', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER > LAND PRODUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5684, 'c77819e9-f62f-48dc-b924-e7a73b4dcda9', 156, 'LAND RESOURCES', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER > LAND RESOURCES', 1);
INSERT INTO {schema}.keywords VALUES (5685, 'fe2f8240-4d8e-4b1f-b869-29fee59692f7', 156, 'LAND USE CLASSES', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER > LAND USE CLASSES', 1);
INSERT INTO {schema}.keywords VALUES (5686, '75c312bc-79f9-4d74-a7c0-3c67c019196c', 156, 'LAND USE/LAND COVER CLASSIFICATION', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER > LAND USE/LAND COVER CLASSIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (5687, 'e77c0096-05a7-47ff-8629-55d12c46bb6b', 157, 'LANDSCAPE ECOLOGY', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE > LANDSCAPE ECOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (5688, '36a4ac5a-1082-4922-9bca-934c06e54cda', 157, 'LANDSCAPE MANAGEMENT', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE > LANDSCAPE MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (5689, '3b6fe940-7383-4bae-b436-fc487723bbcf', 157, 'LANDSCAPE PATTERNS', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE > LANDSCAPE PATTERNS', 1);
INSERT INTO {schema}.keywords VALUES (5690, '6c44a08d-0a08-47f5-b819-7e561445e613', 157, 'LANDSCAPE PROCESSES', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE > LANDSCAPE PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (5691, 'd57dff3d-5f2f-425c-80bb-2a6fcb42d3fa', 157, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (5692, 'dcb100c9-5b43-422a-a429-25cae9dbb170', 157, 'REFORESTATION', 'EARTH SCIENCE > LAND SURFACE > LANDSCAPE > REFORESTATION', 1);
INSERT INTO {schema}.keywords VALUES (5693, '9409ee0f-2b72-4472-9d61-f8072981a6cb', 158, 'CALCIUM', 'EARTH SCIENCE > LAND SURFACE > SOILS > CALCIUM', 1);
INSERT INTO {schema}.keywords VALUES (5694, 'a7ae5843-479c-4055-b8fc-ba651e485750', 158, 'CARBON', 'EARTH SCIENCE > LAND SURFACE > SOILS > CARBON', 1);
INSERT INTO {schema}.keywords VALUES (5695, '9bad3c7b-daf6-428a-89bd-ce62b074dfcf', 158, 'CATION EXCHANGE CAPACITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > CATION EXCHANGE CAPACITY', 1);
INSERT INTO {schema}.keywords VALUES (5696, '0d0de6a7-c340-4e6b-b01d-ccbb6e7fa913', 158, 'DENITRIFICATION RATE', 'EARTH SCIENCE > LAND SURFACE > SOILS > DENITRIFICATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (5697, '781bf38b-2797-4415-8d5a-67e9f3a2f5fe', 158, 'ELECTRICAL CONDUCTIVITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > ELECTRICAL CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5698, '49ee4fcc-a0ad-4638-aec9-90b4946d8922', 158, 'HEAVY METALS', 'EARTH SCIENCE > LAND SURFACE > SOILS > HEAVY METALS', 1);
INSERT INTO {schema}.keywords VALUES (5699, 'e2a88ac8-7bf3-408c-b2b4-b3217f9e4917', 158, 'HYDRAULIC CONDUCTIVITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > HYDRAULIC CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5700, '5c4b5f03-8e57-49f0-bb03-f8efafb837d3', 158, 'MACROFAUNA', 'EARTH SCIENCE > LAND SURFACE > SOILS > MACROFAUNA', 1);
INSERT INTO {schema}.keywords VALUES (5701, '7b86bc20-ba2b-4cd0-8aa0-ed47663d9222', 158, 'MAGNESIUM', 'EARTH SCIENCE > LAND SURFACE > SOILS > MAGNESIUM', 1);
INSERT INTO {schema}.keywords VALUES (5702, 'e9555194-efd1-4427-b8e3-8fe6c49b8636', 158, 'MICROFAUNA', 'EARTH SCIENCE > LAND SURFACE > SOILS > MICROFAUNA', 1);
INSERT INTO {schema}.keywords VALUES (5703, 'ed1b3fa6-173d-476c-9b35-c57335c0a473', 158, 'MICROFLORA', 'EARTH SCIENCE > LAND SURFACE > SOILS > MICROFLORA', 1);
INSERT INTO {schema}.keywords VALUES (5704, 'ac061db6-21c7-46fc-b5a8-9f61c795fdd6', 158, 'MICRONUTRIENTS/TRACE ELEMENTS', 'EARTH SCIENCE > LAND SURFACE > SOILS > MICRONUTRIENTS/TRACE ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5705, 'e1179e7f-59e5-465a-9879-6bda6985744e', 158, 'NITROGEN', 'EARTH SCIENCE > LAND SURFACE > SOILS > NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (5706, '215f69b9-259a-4b82-9f8f-f96d4f5aaad2', 158, 'ORGANIC MATTER', 'EARTH SCIENCE > LAND SURFACE > SOILS > ORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (5707, '08240c92-00b5-4f25-bf2e-8030531a78d2', 158, 'PERMAFROST', 'EARTH SCIENCE > LAND SURFACE > SOILS > PERMAFROST', 1);
INSERT INTO {schema}.keywords VALUES (5708, '9169ace5-0f04-4fc9-b38d-b89a786b9fe1', 158, 'PHOSPHORUS', 'EARTH SCIENCE > LAND SURFACE > SOILS > PHOSPHORUS', 1);
INSERT INTO {schema}.keywords VALUES (5709, '8af17fd3-7c42-4698-9d60-e154ece5aebe', 158, 'POTASSIUM', 'EARTH SCIENCE > LAND SURFACE > SOILS > POTASSIUM', 1);
INSERT INTO {schema}.keywords VALUES (5710, 'c22818ce-07aa-4f77-8fe2-be1925743bac', 158, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > LAND SURFACE > SOILS > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (5711, 'e497c2e3-cd21-4af9-9a5d-91da4e201631', 158, 'SOIL ABSORPTION', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL ABSORPTION', 1);
INSERT INTO {schema}.keywords VALUES (5712, '2c821621-f035-4c57-8dee-5f24968f959a', 158, 'SOIL BULK DENSITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL BULK DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (5713, 'e273b634-62f5-4601-8b92-6550f6efeab8', 158, 'SOIL CHEMISTRY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5714, '14e51b6e-9d91-4af5-bb93-22842359d492', 158, 'SOIL CLASSIFICATION', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL CLASSIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (5715, '013b44e9-df5c-4ef8-a99f-7351d16bfd14', 158, 'SOIL COLOR', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL COLOR', 1);
INSERT INTO {schema}.keywords VALUES (5716, 'c9f8c1e9-dca8-4c2e-9537-65903d19cfe5', 158, 'SOIL COMPACTION', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL COMPACTION', 1);
INSERT INTO {schema}.keywords VALUES (5717, '6ce3eeff-d222-4356-8cd2-50fbcbcbb295', 158, 'SOIL CONSISTENCE', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL CONSISTENCE', 1);
INSERT INTO {schema}.keywords VALUES (5718, '60e783c1-4b33-4ab3-860b-8bd4ed00dc9f', 158, 'SOIL DEPTH', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5719, '6eef914d-ff9f-44b0-a3a6-3dcf911023d4', 158, 'SOIL EROSION', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL EROSION', 1);
INSERT INTO {schema}.keywords VALUES (5720, 'cdb10789-ef01-46bd-8047-86e550df0df4', 158, 'SOIL FERTILITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL FERTILITY', 1);
INSERT INTO {schema}.keywords VALUES (5721, '76c23076-d9d5-4414-a69f-a830cecdd9ce', 158, 'SOIL GAS/AIR', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL GAS/AIR', 1);
INSERT INTO {schema}.keywords VALUES (5722, 'c6847d01-cbf9-491b-be59-c283d9072d95', 158, 'SOIL HEAT BUDGET', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL HEAT BUDGET', 1);
INSERT INTO {schema}.keywords VALUES (5723, '7a16aa40-c74b-4a69-a230-1edd1b453332', 158, 'SOIL HORIZONS/PROFILE', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL HORIZONS/PROFILE', 1);
INSERT INTO {schema}.keywords VALUES (5724, 'bcc72093-b2d4-47e8-9213-7f48172e0e95', 158, 'SOIL IMPEDANCE', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL IMPEDANCE', 1);
INSERT INTO {schema}.keywords VALUES (5725, '2283a2fe-19ec-4b1d-a553-20ec9713a658', 158, 'SOIL INFILTRATION', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL INFILTRATION', 1);
INSERT INTO {schema}.keywords VALUES (5726, 'e9d5ae5a-0718-44f2-9694-b791b646a825', 158, 'SOIL MECHANICS', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL MECHANICS', 1);
INSERT INTO {schema}.keywords VALUES (5727, 'bbe2ea34-8842-4a9f-9b0b-95dd3c71857f', 158, 'SOIL MOISTURE/WATER CONTENT', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL MOISTURE/WATER CONTENT', 1);
INSERT INTO {schema}.keywords VALUES (5728, '357193c5-154d-487b-a1c3-a1a90d15918c', 158, 'SOIL PH', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL PH', 1);
INSERT INTO {schema}.keywords VALUES (5729, '2da4e52a-b43b-4ff0-9e4d-c98438a38c6d', 158, 'SOIL PLASTICITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL PLASTICITY', 1);
INSERT INTO {schema}.keywords VALUES (5730, '20f932b9-cc40-4462-879f-1c8d8c765152', 158, 'SOIL POROSITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL POROSITY', 1);
INSERT INTO {schema}.keywords VALUES (5731, '1e7afff2-cd50-4d26-968b-bffd2d738edd', 158, 'SOIL PRODUCTIVITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL PRODUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5732, 'e699830a-0abf-45b2-8026-ac80e0269ea7', 158, 'SOIL RESPIRATION', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL RESPIRATION', 1);
INSERT INTO {schema}.keywords VALUES (5733, '1b475201-a032-4a66-a3aa-a35605affaee', 158, 'SOIL ROOTING DEPTH', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL ROOTING DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5734, '9d7b0259-2d88-4e78-b2c2-131a02d05c15', 158, 'SOIL SALINITY/SOIL SODICITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL SALINITY/SOIL SODICITY', 1);
INSERT INTO {schema}.keywords VALUES (5735, 'aa25235a-596f-4504-89e1-4c625275700d', 158, 'SOIL STRUCTURE', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL STRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (5736, '0546b91a-294d-45d9-8b45-76aaad0cc024', 158, 'SOIL TEMPERATURE', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5737, 'fb05c0c0-7fcd-470c-ba2b-755f04f5d811', 158, 'SOIL TEXTURE', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (5738, '7c00e468-6a43-49ef-891e-b0ce29e2ff36', 158, 'SOIL WATER HOLDING CAPACITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > SOIL WATER HOLDING CAPACITY', 1);
INSERT INTO {schema}.keywords VALUES (5739, '742e6889-1ebf-4441-b803-4892c7176822', 158, 'SULFUR', 'EARTH SCIENCE > LAND SURFACE > SOILS > SULFUR', 1);
INSERT INTO {schema}.keywords VALUES (5740, 'c67c1e1c-19f1-49de-8b2b-d5ce6f596323', 158, 'THERMAL CONDUCTIVITY', 'EARTH SCIENCE > LAND SURFACE > SOILS > THERMAL CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5741, '136b1de3-4b2e-49e6-80cd-cf2e9bac2c48', 159, 'ALBEDO', 'EARTH SCIENCE > LAND SURFACE > SURFACE RADIATIVE PROPERTIES > ALBEDO', 1);
INSERT INTO {schema}.keywords VALUES (5742, '00c1d7b9-61d8-40ad-8c33-f27006832866', 159, 'ANISOTROPY', 'EARTH SCIENCE > LAND SURFACE > SURFACE RADIATIVE PROPERTIES > ANISOTROPY', 1);
INSERT INTO {schema}.keywords VALUES (5743, '4ee9d0c5-2e0c-486c-b89b-7b002d18c5f7', 159, 'EMISSIVITY', 'EARTH SCIENCE > LAND SURFACE > SURFACE RADIATIVE PROPERTIES > EMISSIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5744, 'f043c0a8-9cee-4c51-bf64-a4aaa34ab75d', 159, 'REFLECTANCE', 'EARTH SCIENCE > LAND SURFACE > SURFACE RADIATIVE PROPERTIES > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5745, '8931329c-3f6d-4ba6-913c-27afa8d104c1', 160, 'LAND HEAT CAPACITY', 'EARTH SCIENCE > LAND SURFACE > SURFACE THERMAL PROPERTIES > LAND HEAT CAPACITY', 1);
INSERT INTO {schema}.keywords VALUES (5746, 'd559b900-eca6-42a4-9311-0297b2ef98ab', 160, 'LAND SURFACE TEMPERATURE', 'EARTH SCIENCE > LAND SURFACE > SURFACE THERMAL PROPERTIES > LAND SURFACE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5747, '40d6a3e7-89dd-4399-8fa5-bbc7a0917b4e', 160, 'SKIN TEMPERATURE', 'EARTH SCIENCE > LAND SURFACE > SURFACE THERMAL PROPERTIES > SKIN TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5748, '21474df3-f9a6-48ca-be15-bdb3611fe062', 161, 'SURFACE ROUGHNESS', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > SURFACE ROUGHNESS', 1);
INSERT INTO {schema}.keywords VALUES (5749, '74ed1690-968e-444c-8a31-7b8344a2aad3', 161, 'TERRAIN ELEVATION', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > TERRAIN ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (5750, '05bef198-cfff-48be-b0cb-14e296d38dbc', 161, 'TOPOGRAPHIC EFFECTS', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > TOPOGRAPHIC EFFECTS', 1);
INSERT INTO {schema}.keywords VALUES (5751, 'f6c057c9-c789-4cd5-ba22-e9b08aae152b', 162, 'AQUACULTURE', 'EARTH SCIENCE > OCEANS > AQUATIC SCIENCES > AQUACULTURE', 1);
INSERT INTO {schema}.keywords VALUES (5752, 'fa57b0a0-9723-4195-bdd1-4f26aefa0e07', 162, 'FISHERIES', 'EARTH SCIENCE > OCEANS > AQUATIC SCIENCES > FISHERIES', 1);
INSERT INTO {schema}.keywords VALUES (5753, '0b011562-ee55-4ba0-a026-4faa7493ca5b', 163, 'ABYSSAL HILLS/PLAINS', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > ABYSSAL HILLS/PLAINS', 1);
INSERT INTO {schema}.keywords VALUES (5754, '80d79c7e-6c64-4ada-bfcc-4093969758a5', 163, 'BATHYMETRY', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > BATHYMETRY', 1);
INSERT INTO {schema}.keywords VALUES (5755, 'a91a00f7-05ed-4633-9fac-1772a48b6342', 163, 'CONTINENTAL MARGINS', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > CONTINENTAL MARGINS', 1);
INSERT INTO {schema}.keywords VALUES (5756, '58c12630-a889-44c1-a951-56bbbe9758c9', 163, 'FRACTURE ZONES', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > FRACTURE ZONES', 1);
INSERT INTO {schema}.keywords VALUES (5757, '73e02157-9df9-415f-93fc-cb457989ddb1', 163, 'OCEAN PLATEAUS/RIDGES', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > OCEAN PLATEAUS/RIDGES', 1);
INSERT INTO {schema}.keywords VALUES (5758, 'b6b51058-1111-4498-a9ac-e1515270fb27', 163, 'SEAFLOOR TOPOGRAPHY', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > SEAFLOOR TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (5759, '83520258-413c-4842-93c0-58a23dc58638', 163, 'SEAMOUNTS', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > SEAMOUNTS', 1);
INSERT INTO {schema}.keywords VALUES (5760, '18ce5577-26e9-4b76-860b-1ba31cafa9d0', 163, 'SUBMARINE CANYONS', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > SUBMARINE CANYONS', 1);
INSERT INTO {schema}.keywords VALUES (5761, '36040c6a-5e3a-49fe-b519-162fb77a0fd4', 163, 'TRENCHES', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > TRENCHES', 1);
INSERT INTO {schema}.keywords VALUES (5762, 'ca477721-473b-40d7-a72b-4ffa963e48fb', 163, 'WATER DEPTH', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > WATER DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5763, '7e28f2e0-a641-4085-be07-366ed6e701f4', 164, 'BARRIER ISLANDS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > BARRIER ISLANDS', 1);
INSERT INTO {schema}.keywords VALUES (5764, '4ba798ce-ad0b-4809-94fa-ec1b8e294252', 164, 'BEACHES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > BEACHES', 1);
INSERT INTO {schema}.keywords VALUES (5765, '1fbf5df2-ab7c-43fc-9bb2-8eb3f8891f7b', 164, 'COASTAL ELEVATION', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > COASTAL ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (5766, 'ad497e7a-48fa-45e1-90a5-b052508bdb30', 164, 'CORAL REEFS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > CORAL REEFS', 1);
INSERT INTO {schema}.keywords VALUES (5767, 'f9f0f92b-7901-4dda-8d64-be4e845ce29b', 164, 'DELTAS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > DELTAS', 1);
INSERT INTO {schema}.keywords VALUES (5768, '6f7b2753-aed1-4783-a7cc-781d00d13a0f', 164, 'DUNES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > DUNES', 1);
INSERT INTO {schema}.keywords VALUES (5769, 'cd7a7748-7231-4a73-b85c-b5696066230a', 164, 'EROSION', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > EROSION', 1);
INSERT INTO {schema}.keywords VALUES (5770, 'a7dcdedf-bcc5-4032-b70f-7fadf74d6144', 164, 'ESTUARIES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > ESTUARIES', 1);
INSERT INTO {schema}.keywords VALUES (5771, 'a90899c8-fe50-48e0-b92c-bb64f6ae681c', 164, 'FJORDS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > FJORDS', 1);
INSERT INTO {schema}.keywords VALUES (5772, 'f43cd776-c568-4d09-997c-0a8ad1022e06', 164, 'INLETS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > INLETS', 1);
INSERT INTO {schema}.keywords VALUES (5773, '82b62e59-6ea1-48e1-a402-bd386c5046eb', 164, 'INTERTIDAL ZONE', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > INTERTIDAL ZONE', 1);
INSERT INTO {schema}.keywords VALUES (5774, 'c733c179-c12a-47e9-8e9a-817a5212446f', 164, 'LAGOONS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > LAGOONS', 1);
INSERT INTO {schema}.keywords VALUES (5775, '5a090f0c-7466-47fd-b679-5dee947ab05c', 164, 'LOCAL SUBSIDENCE TRENDS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > LOCAL SUBSIDENCE TRENDS', 1);
INSERT INTO {schema}.keywords VALUES (5776, 'ccf07d90-b3a3-43d3-9249-a494bb48d1b6', 164, 'LONGSHORE CURRENTS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > LONGSHORE CURRENTS', 1);
INSERT INTO {schema}.keywords VALUES (5777, '04c4a85f-91ce-4d64-9e19-b3e0897ff187', 164, 'MANGROVES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > MANGROVES', 1);
INSERT INTO {schema}.keywords VALUES (5778, '30056645-a442-4ef6-ac76-c5bc27086d83', 164, 'MARSHES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > MARSHES', 1);
INSERT INTO {schema}.keywords VALUES (5779, '488f4df2-712e-4fac-98d1-46ab134b84ee', 164, 'ROCKY COASTS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > ROCKY COASTS', 1);
INSERT INTO {schema}.keywords VALUES (5780, 'dffe5a35-09af-4413-bdd3-a5aedfeb49cc', 164, 'SALTWATER INTRUSION', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SALTWATER INTRUSION', 1);
INSERT INTO {schema}.keywords VALUES (5781, '0afaaa5e-f88c-4c1f-95c1-1faa0148885a', 164, 'SEA LEVEL RISE', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SEA LEVEL RISE', 1);
INSERT INTO {schema}.keywords VALUES (5782, '1ed24fe1-d0d5-46d1-8d22-8ac25d289c75', 164, 'SEA SURFACE HEIGHT', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SEA SURFACE HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5783, 'c5c34f0a-552e-45a6-91c1-9edb3a8deef9', 164, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (5784, '9457740a-897b-4adc-96fb-f3e3aafa34ea', 164, 'SEDIMENTATION', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (5785, '4c2d2255-680d-47d6-adb2-179093593f8a', 164, 'SHOALS', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SHOALS', 1);
INSERT INTO {schema}.keywords VALUES (5786, '1a740c3e-7032-4f72-93e8-d0ba343d82e0', 164, 'SHORELINE DISPLACEMENT', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SHORELINE DISPLACEMENT', 1);
INSERT INTO {schema}.keywords VALUES (5787, '1d3b4eb7-9931-44bf-8457-26847051b7a8', 164, 'SHORELINES', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > SHORELINES', 1);
INSERT INTO {schema}.keywords VALUES (5788, '9edd23d0-68a9-4bae-8887-705058f48ba7', 164, 'STORM SURGE', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > STORM SURGE', 1);
INSERT INTO {schema}.keywords VALUES (5789, '9ab67e8f-066e-47b8-838d-8cd5e7460119', 164, 'TIDAL HEIGHT', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > TIDAL HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5790, '56e4dd42-e393-4aa2-b4d9-9e96d85c9768', 165, 'MARINE OBSTRUCTIONS', 'EARTH SCIENCE > OCEANS > MARINE ENVIRONMENT MONITORING > MARINE OBSTRUCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (5791, 'e31f905d-bd2a-4fe9-89d8-909e1d2b9b1a', 166, 'MAGNETIC ANOMALIES', 'EARTH SCIENCE > OCEANS > MARINE GEOPHYSICS > MAGNETIC ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (5792, 'ad09b215-e837-4d9f-acbc-2b45e5b81825', 166, 'MARINE GRAVITY FIELD', 'EARTH SCIENCE > OCEANS > MARINE GEOPHYSICS > MARINE GRAVITY FIELD', 1);
INSERT INTO {schema}.keywords VALUES (5793, '7863ce31-0e06-42a5-bcf8-25981c44dec8', 166, 'MARINE MAGNETICS', 'EARTH SCIENCE > OCEANS > MARINE GEOPHYSICS > MARINE MAGNETICS', 1);
INSERT INTO {schema}.keywords VALUES (5794, '78a4dbe2-2d6b-4562-988c-022c3a83f4c1', 166, 'PLATE TECTONICS', 'EARTH SCIENCE > OCEANS > MARINE GEOPHYSICS > PLATE TECTONICS', 1);
INSERT INTO {schema}.keywords VALUES (5795, 'ff0108e2-8415-423c-85ed-07792dbef534', 167, 'BIOGENIC SEDIMENTS', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > BIOGENIC SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5796, '14c8935f-8a46-4111-8f2e-bec8bbae5d13', 167, 'BIOTURBATION', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > BIOTURBATION', 1);
INSERT INTO {schema}.keywords VALUES (5797, '4bfed15d-b8b4-4fb1-940b-ef342c4c2225', 167, 'DIAGENESIS', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > DIAGENESIS', 1);
INSERT INTO {schema}.keywords VALUES (5798, 'd4f4b5d3-27b2-4b7d-bb69-733b67ac687a', 167, 'GEOTECHNICAL PROPERTIES', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > GEOTECHNICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (5799, '3d352f0f-f69f-44c4-b345-aa9230fbd6ca', 167, 'HYDROGENOUS SEDIMENTS', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > HYDROGENOUS SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5800, '676327f4-8354-4033-8081-9cab6651ac98', 167, 'PARTICLE FLUX', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > PARTICLE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5801, 'f8411549-a72d-44cd-9b7b-6953ec22f8da', 167, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5802, '17008d04-394d-4de8-8834-dd0a3cd88093', 167, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (5803, 'bd55adac-4182-4441-91e2-163aa77e1320', 167, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (5804, '282ea985-efd0-4113-860d-b8221f6cc6f2', 167, 'SEDIMENTARY STRUCTURES', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SEDIMENTARY STRUCTURES', 1);
INSERT INTO {schema}.keywords VALUES (5805, 'cddc37fd-8540-4c78-b567-add74e6b789b', 167, 'SEDIMENTARY TEXTURES', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SEDIMENTARY TEXTURES', 1);
INSERT INTO {schema}.keywords VALUES (5806, 'a4eb3bc4-48a5-4ed2-a74b-ca87a58e90f5', 167, 'SEDIMENTATION', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (5807, '41b7293f-7f20-40ab-8bf7-b211c68146b9', 167, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (5808, 'bcf6975f-2a21-4a6c-9286-fb8f85d00901', 167, 'SUSPENDED SOLIDS', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > SUSPENDED SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (5809, '31cf96eb-7fcd-490d-9e10-7f17dc12e1e3', 167, 'TERRIGENOUS SEDIMENTS', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > TERRIGENOUS SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5810, '68e2c729-f729-4936-af2e-0ecf7ee7d231', 167, 'TURBIDITY', 'EARTH SCIENCE > OCEANS > MARINE SEDIMENTS > TURBIDITY', 1);
INSERT INTO {schema}.keywords VALUES (5811, 'bf3d6238-d0d6-4e73-82e6-5e38bc9291bb', 168, 'BENTHIC HEAT FLOW', 'EARTH SCIENCE > OCEANS > MARINE VOLCANISM > BENTHIC HEAT FLOW', 1);
INSERT INTO {schema}.keywords VALUES (5812, 'b677862b-7921-458f-a6db-0eb46469df33', 168, 'HYDROTHERMAL VENTS', 'EARTH SCIENCE > OCEANS > MARINE VOLCANISM > HYDROTHERMAL VENTS', 1);
INSERT INTO {schema}.keywords VALUES (5813, '9bb0de49-1812-400c-a73b-d2686dd9066a', 168, 'ISLAND ARCS', 'EARTH SCIENCE > OCEANS > MARINE VOLCANISM > ISLAND ARCS', 1);
INSERT INTO {schema}.keywords VALUES (5814, 'f345294c-36e6-4c76-b484-2204cc0bc3a2', 168, 'MID-OCEAN RIDGES', 'EARTH SCIENCE > OCEANS > MARINE VOLCANISM > MID-OCEAN RIDGES', 1);
INSERT INTO {schema}.keywords VALUES (5815, 'f32afbca-dac6-41b1-a198-791c1fb57951', 168, 'RIFT VALLEYS', 'EARTH SCIENCE > OCEANS > MARINE VOLCANISM > RIFT VALLEYS', 1);
INSERT INTO {schema}.keywords VALUES (5816, '025c1e31-1a97-4a30-a887-0b9a5127fd4d', 169, 'ACOUSTIC ATTENUATION/TRANSMISSION', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > ACOUSTIC ATTENUATION/TRANSMISSION', 1);
INSERT INTO {schema}.keywords VALUES (5817, '7bb3c4cd-cbb4-4c82-997b-d11ecc1cdb9f', 169, 'ACOUSTIC FREQUENCY', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > ACOUSTIC FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (5818, '6a583047-6023-4b6a-ab25-b72529721a8c', 169, 'ACOUSTIC REFLECTIVITY', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > ACOUSTIC REFLECTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5819, 'b4a924bb-0d42-4169-bad7-3856f69f0c4a', 169, 'ACOUSTIC SCATTERING', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > ACOUSTIC SCATTERING', 1);
INSERT INTO {schema}.keywords VALUES (5820, '1295cf9a-c345-40eb-9b79-82bddc6acf50', 169, 'ACOUSTIC TOMOGRAPHY', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > ACOUSTIC TOMOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (5821, 'e4aae1a4-b4d5-4b13-9cc0-c0df6234ce3b', 169, 'ACOUSTIC VELOCITY', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > ACOUSTIC VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (5822, 'a74abbc1-dd75-4f22-bbec-7d45091a4593', 169, 'AMBIENT NOISE', 'EARTH SCIENCE > OCEANS > OCEAN ACOUSTICS > AMBIENT NOISE', 1);
INSERT INTO {schema}.keywords VALUES (5823, '4eab7956-e59e-4615-8d5c-39a16faa1f27', 170, 'ALKALINITY', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > ALKALINITY', 1);
INSERT INTO {schema}.keywords VALUES (5824, '64d17528-29b4-4e2e-843a-7f7035bb5717', 170, 'AMMONIA', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > AMMONIA', 1);
INSERT INTO {schema}.keywords VALUES (5825, 'f1e6caa5-2c97-407d-a0db-7bf01794d8e3', 170, 'BIOGEOCHEMICAL CYCLES', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > BIOGEOCHEMICAL CYCLES', 1);
INSERT INTO {schema}.keywords VALUES (5826, '97636cf7-189f-4953-9807-64fbcc60f72c', 170, 'BIOMEDICAL CHEMICALS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > BIOMEDICAL CHEMICALS', 1);
INSERT INTO {schema}.keywords VALUES (5827, '26afa886-4866-4536-be3a-6f9db9aacd97', 170, 'CARBON DIOXIDE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > CARBON DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (5828, '68f7ba1b-a2f9-41b6-9bc1-fd187942fbed', 170, 'CARBONATE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > CARBONATE', 1);
INSERT INTO {schema}.keywords VALUES (5829, '5c52009f-2c44-4db1-b62b-135c6181bad2', 170, 'CARBON', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > CARBON', 1);
INSERT INTO {schema}.keywords VALUES (5830, '7989eae1-8ea3-4039-af0c-9130de145449', 170, 'CHLOROPHYLL', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > CHLOROPHYLL', 1);
INSERT INTO {schema}.keywords VALUES (5831, '38219b66-2acd-4f77-a0fc-8241172c9001', 170, 'DISSOLVED GASES', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > DISSOLVED GASES', 1);
INSERT INTO {schema}.keywords VALUES (5832, 'a3c25ed5-d3e4-4b86-bd9a-6f78d5d2bc07', 170, 'DISSOLVED SOLIDS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > DISSOLVED SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (5833, '6d8eb011-ffb5-4e18-ac59-2d8f84353734', 170, 'HYDROCARBONS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > HYDROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (5834, 'b846063c-e218-4fc6-9866-0cdca24e9023', 170, 'HYPOXIA', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > HYPOXIA', 1);
INSERT INTO {schema}.keywords VALUES (5835, 'd9b4f30d-bddd-4888-b66b-07d2dc09708b', 170, 'INORGANIC CARBON', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > INORGANIC CARBON', 1);
INSERT INTO {schema}.keywords VALUES (5836, 'b9cfc6af-a424-42b9-8e89-6b332262e841', 170, 'INORGANIC MATTER', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > INORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (5837, '1dfb36a3-f985-4514-a1d0-cc73ca572922', 170, 'MARINE GEOCHEMISTRY', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > MARINE GEOCHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (5838, '4fde380a-38c5-4d46-bc80-4f2515a43983', 170, 'NITRATE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NITRATE', 1);
INSERT INTO {schema}.keywords VALUES (5839, '61740c18-f010-4384-8516-1eb33d75352e', 170, 'NITRIC ACID', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NITRIC ACID', 1);
INSERT INTO {schema}.keywords VALUES (5840, '941410da-0b7f-4ec6-a718-212194ced13f', 170, 'NITRITE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NITRITE', 1);
INSERT INTO {schema}.keywords VALUES (5841, '54054bc3-5faa-4b0d-b5dd-cf04595369b5', 170, 'NITROGEN DIOXIDE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NITROGEN DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (5842, 'db5357c9-cc9d-4693-86fe-6bb88555d434', 170, 'NITROGEN', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (5843, 'd1c2bba5-799d-412b-80e0-fa04058416e3', 170, 'NITROUS OXIDE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NITROUS OXIDE', 1);
INSERT INTO {schema}.keywords VALUES (5844, '8dd7c9f0-51d0-4037-b1d0-a2517c1770ad', 170, 'NUTRIENTS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > NUTRIENTS', 1);
INSERT INTO {schema}.keywords VALUES (5845, '080db90f-79ff-4900-941d-9c02fe2df862', 170, 'OCEAN TRACERS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > OCEAN TRACERS', 1);
INSERT INTO {schema}.keywords VALUES (5846, 'd3055f47-258e-4556-a885-54cd1fff4680', 170, 'ORGANIC CARBON', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > ORGANIC CARBON', 1);
INSERT INTO {schema}.keywords VALUES (5847, 'b2bdeb71-81b5-43e6-a8b1-b09c215c8d1a', 170, 'ORGANIC MATTER', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > ORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (5848, '90aa8838-79bd-4b28-b518-8217e863c385', 170, 'OXYGEN', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > OXYGEN', 1);
INSERT INTO {schema}.keywords VALUES (5849, '0b513d8c-bfd3-44ee-976e-42757b8375a2', 170, 'PHOSPHATE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > PHOSPHATE', 1);
INSERT INTO {schema}.keywords VALUES (5850, '4433600b-f323-458a-b295-352f939aab6b', 170, 'PH', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > PH', 1);
INSERT INTO {schema}.keywords VALUES (5851, 'ed925b43-db83-4cbb-8347-3dc0081bb8f4', 170, 'PIGMENTS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > PIGMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5852, '6641ff15-36c8-4dbc-bf9c-176a08688173', 170, 'RADIOCARBON', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > RADIOCARBON', 1);
INSERT INTO {schema}.keywords VALUES (5853, 'e9ed684e-5252-4091-a794-aaf6e5f249ed', 170, 'RADIONUCLIDES', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > RADIONUCLIDES', 1);
INSERT INTO {schema}.keywords VALUES (5854, 'c91c8879-1b29-48e3-b4cd-a238af66cdaf', 170, 'SILICATE', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > SILICATE', 1);
INSERT INTO {schema}.keywords VALUES (5855, '38dadd6d-6adb-44e2-b28a-fd18d797d052', 170, 'STABLE ISOTOPES', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > STABLE ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (5856, '718fb499-8c55-4fa6-9a07-ac9155d4bc9d', 170, 'SUSPENDED SOLIDS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > SUSPENDED SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (5857, '6c320188-da7b-4d52-8e99-57d7ac401841', 170, 'TRACE ELEMENTS', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > TRACE ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (5858, '0cb7f2c6-5e99-4781-8d4f-19ecbad2e2e0', 171, 'ADVECTION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > ADVECTION', 1);
INSERT INTO {schema}.keywords VALUES (5859, '81f51367-8467-4183-baea-6b526780fcc7', 171, 'BUOY POSITION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > BUOY POSITION', 1);
INSERT INTO {schema}.keywords VALUES (5860, '10a9c153-f37d-48fe-920d-c790d946ab07', 171, 'CONVECTION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > CONVECTION', 1);
INSERT INTO {schema}.keywords VALUES (5861, '6fe4680b-96e8-4304-ab32-c17a0769932c', 171, 'DIFFUSION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > DIFFUSION', 1);
INSERT INTO {schema}.keywords VALUES (5862, '13927300-c59c-491a-91f3-f1540bcb2d8d', 171, 'EDDIES', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > EDDIES', 1);
INSERT INTO {schema}.keywords VALUES (5863, 'bdd42024-d1a4-4fb2-a16a-06ac0cc1dedc', 171, 'FRESH WATER FLUX', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > FRESH WATER FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5864, '22b339b5-1af5-46e3-8191-d93729001eeb', 171, 'FRONTS', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > FRONTS', 1);
INSERT INTO {schema}.keywords VALUES (5865, 'fc0a6bb2-27f0-48e8-89f1-ebfc7ccd4823', 171, 'GYRES', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > GYRES', 1);
INSERT INTO {schema}.keywords VALUES (5866, '510c5f78-e19e-4ce4-b59a-8937aeb84631', 171, 'OCEAN CURRENTS', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > OCEAN CURRENTS', 1);
INSERT INTO {schema}.keywords VALUES (5867, '48ec6449-373c-41f6-8a61-8f1e9ed95737', 171, 'OCEAN MIXED LAYER', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > OCEAN MIXED LAYER', 1);
INSERT INTO {schema}.keywords VALUES (5868, 'aa1bc71c-daeb-401e-9e29-ebde975482cf', 171, 'THERMOHALINE CIRCULATION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > THERMOHALINE CIRCULATION', 1);
INSERT INTO {schema}.keywords VALUES (5869, 'b9f343a1-0b8d-4e88-91bc-21f5d551963f', 171, 'TURBULENCE', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > TURBULENCE', 1);
INSERT INTO {schema}.keywords VALUES (5870, '75ab3537-34b1-4025-b758-7296626079ba', 171, 'UPWELLING/DOWNWELLING', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > UPWELLING/DOWNWELLING', 1);
INSERT INTO {schema}.keywords VALUES (5871, '55715ed3-471e-46a8-97b6-b463708a2cbe', 171, 'VORTICITY', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > VORTICITY', 1);
INSERT INTO {schema}.keywords VALUES (5872, '113edd07-7b1a-4082-b054-b58d3f23b93a', 171, 'WATER MASSES', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > WATER MASSES', 1);
INSERT INTO {schema}.keywords VALUES (5873, '03fbea0a-74b9-4c78-8752-a588cff27f17', 171, 'WIND-DRIVEN CIRCULATION', 'EARTH SCIENCE > OCEANS > OCEAN CIRCULATION > WIND-DRIVEN CIRCULATION', 1);
INSERT INTO {schema}.keywords VALUES (5874, '5f6358aa-872c-4c1c-9388-4714138f034a', 172, 'ADVECTION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > ADVECTION', 1);
INSERT INTO {schema}.keywords VALUES (5875, 'a9b6a001-42b2-48db-b132-62e69f03b8cb', 172, 'BOWEN RATIO', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > BOWEN RATIO', 1);
INSERT INTO {schema}.keywords VALUES (5876, '93c1a177-70e3-4c33-a183-baff7f401697', 172, 'CONDENSATION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > CONDENSATION', 1);
INSERT INTO {schema}.keywords VALUES (5877, '2ef42281-1e38-4391-b578-ba6a6158f0c2', 172, 'CONDUCTION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > CONDUCTION', 1);
INSERT INTO {schema}.keywords VALUES (5878, '69d394f7-a792-4a17-8d7f-e60cd60dcda0', 172, 'CONVECTION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > CONVECTION', 1);
INSERT INTO {schema}.keywords VALUES (5879, '064d919e-3262-44c3-a636-8094bc963001', 172, 'DIFFUSION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > DIFFUSION', 1);
INSERT INTO {schema}.keywords VALUES (5880, '881eea51-e32c-4174-a73f-d56c94122c2e', 172, 'EVAPORATION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > EVAPORATION', 1);
INSERT INTO {schema}.keywords VALUES (5881, 'ee2cb9eb-f960-4e23-9e7c-be64d44a64e7', 172, 'HEAT FLUX', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > HEAT FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5882, 'ed2e9f34-2358-4a2a-a83e-febba8989c5c', 172, 'HEATING RATE', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > HEATING RATE', 1);
INSERT INTO {schema}.keywords VALUES (5883, 'bc891281-b24c-4310-b39b-81715d7dad08', 172, 'LONGWAVE RADIATION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > LONGWAVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5884, 'd1426df9-7653-442b-8e38-fa28757ec748', 172, 'REFLECTANCE', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5885, '8d69bce7-efce-4efb-9870-6a6d3a2684fd', 172, 'SHORTWAVE RADIATION', 'EARTH SCIENCE > OCEANS > OCEAN HEAT BUDGET > SHORTWAVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5886, 'e501d002-d11e-4569-8c0d-e40ae5b45f65', 173, 'ABSORPTION', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > ABSORPTION', 1);
INSERT INTO {schema}.keywords VALUES (5887, '4e8943e7-daf9-41f2-8a5e-b415b82e6381', 173, 'APHOTIC/PHOTIC ZONE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > APHOTIC/PHOTIC ZONE', 1);
INSERT INTO {schema}.keywords VALUES (5888, '71c78d69-9cfe-48e9-8dd2-9c75acf22283', 173, 'ATTENUATION/TRANSMISSION', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > ATTENUATION/TRANSMISSION', 1);
INSERT INTO {schema}.keywords VALUES (5889, '90f97e5b-f883-4a34-a3bc-7dea8d96eb7d', 173, 'BIOLUMINESCENCE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > BIOLUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (5890, '5f2ec7b9-3e8c-4d12-bba6-0f84c08729e0', 173, 'EXTINCTION COEFFICIENTS', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > EXTINCTION COEFFICIENTS', 1);
INSERT INTO {schema}.keywords VALUES (5891, 'a60ae1b6-abfc-4905-8c09-772da7bb1a10', 173, 'FLUORESCENCE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > FLUORESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (5892, '87b074b4-9b73-4e69-b8c0-0f112b1cfa6d', 173, 'GELBSTOFF', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > GELBSTOFF', 1);
INSERT INTO {schema}.keywords VALUES (5893, '40aacf7a-aba0-4ba2-bf85-ea7c39c3322c', 173, 'IRRADIANCE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > IRRADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (5894, '78f5a84f-1b5b-44a9-97e7-4a1996cd2e36', 173, 'OCEAN COLOR', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > OCEAN COLOR', 1);
INSERT INTO {schema}.keywords VALUES (5895, '001f18d3-7e61-430b-9883-1960c6256fe5', 173, 'OPTICAL DEPTH', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > OPTICAL DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5896, 'b7410899-350a-4443-9430-c7fe1fa3a499', 173, 'PHOTOSYNTHETICALLY ACTIVE RADIATION', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > PHOTOSYNTHETICALLY ACTIVE RADIATION', 1);
INSERT INTO {schema}.keywords VALUES (5897, '68dacfbb-4f23-4325-b80f-4b09d41bd505', 173, 'RADIANCE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (5898, '4f7ad022-70ea-4254-b0ae-7a231fc2e46a', 173, 'REFLECTANCE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5899, '20b41061-e6dc-47ef-b73b-00dc08a59618', 173, 'SCATTERING', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > SCATTERING', 1);
INSERT INTO {schema}.keywords VALUES (5900, '954c2f25-3ec8-4774-ba34-fa4289f33f0e', 173, 'SECCHI DEPTH', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > SECCHI DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5901, 'f0d83687-bc0a-4491-bb3e-697f1018da13', 173, 'TURBIDITY', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > TURBIDITY', 1);
INSERT INTO {schema}.keywords VALUES (5902, 'ad41b62a-141b-4207-887c-334367860cf4', 173, 'WATER-LEAVING RADIANCE', 'EARTH SCIENCE > OCEANS > OCEAN OPTICS > WATER-LEAVING RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (5903, 'e5bca08d-ecb3-4b85-8acd-fed782875aa2', 174, 'SEA LEVEL PRESSURE', 'EARTH SCIENCE > OCEANS > OCEAN PRESSURE > SEA LEVEL PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5904, 'dd025312-0d27-44e0-ae05-7cfcc1aa17f0', 174, 'WATER PRESSURE', 'EARTH SCIENCE > OCEANS > OCEAN PRESSURE > WATER PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (5905, '64074461-95d0-4538-869a-0114e39216aa', 175, 'OCEAN MIXED LAYER', 'EARTH SCIENCE > OCEANS > OCEAN TEMPERATURE > OCEAN MIXED LAYER', 1);
INSERT INTO {schema}.keywords VALUES (5906, 'e02b0b50-a0f2-4c47-841b-9689fdb99121', 175, 'POTENTIAL TEMPERATURE', 'EARTH SCIENCE > OCEANS > OCEAN TEMPERATURE > POTENTIAL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5907, 'bd24a9a9-7d52-4c29-b2a0-6cefd216ae78', 175, 'SEA SURFACE TEMPERATURE', 'EARTH SCIENCE > OCEANS > OCEAN TEMPERATURE > SEA SURFACE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5908, '68772b70-e493-48d5-b063-00b9d2dd4078', 175, 'THERMOCLINE', 'EARTH SCIENCE > OCEANS > OCEAN TEMPERATURE > THERMOCLINE', 1);
INSERT INTO {schema}.keywords VALUES (5909, '46206e8c-8def-406f-9e62-da4e74633a58', 175, 'WATER TEMPERATURE', 'EARTH SCIENCE > OCEANS > OCEAN TEMPERATURE > WATER TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5910, 'dc9fcd27-58ac-4705-a522-6475d59cfb81', 176, 'GRAVITY WAVES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > GRAVITY WAVES', 1);
INSERT INTO {schema}.keywords VALUES (5911, '41764af0-1264-4adb-881d-44991489344c', 176, 'ROSSBY/PLANETARY WAVES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > ROSSBY/PLANETARY WAVES', 1);
INSERT INTO {schema}.keywords VALUES (5912, '11aca777-8a01-42ce-b076-b3059c3d8cae', 176, 'SEA STATE', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > SEA STATE', 1);
INSERT INTO {schema}.keywords VALUES (5913, '2b4963ba-1a7a-419d-97ef-eacaa14688e0', 176, 'SEICHES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > SEICHES', 1);
INSERT INTO {schema}.keywords VALUES (5914, '1ac6850e-9266-4e90-ba83-b6a6cc4ae365', 176, 'SIGNIFICANT WAVE HEIGHT', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > SIGNIFICANT WAVE HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5915, '0bf50cd4-8a97-468c-8e73-047e3e09a03d', 176, 'STORM SURGE', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > STORM SURGE', 1);
INSERT INTO {schema}.keywords VALUES (5916, 'a90526a9-5476-45bc-9a15-73ac2dfc62ab', 176, 'SURF BEAT', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > SURF BEAT', 1);
INSERT INTO {schema}.keywords VALUES (5917, '4e4d3c18-cdd4-474a-a936-6e127ec526f7', 176, 'SWELLS', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > SWELLS', 1);
INSERT INTO {schema}.keywords VALUES (5918, '3dd99ea6-51bd-4b78-bf2e-d5aeca7f5bc8', 176, 'TOPOGRAPHIC WAVES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > TOPOGRAPHIC WAVES', 1);
INSERT INTO {schema}.keywords VALUES (5919, '7a79a3f3-1817-4c9f-8485-550a022b5a8d', 176, 'TSUNAMIS', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > TSUNAMIS', 1);
INSERT INTO {schema}.keywords VALUES (5920, '09b326df-79b3-41b8-8998-e06344b0fe0d', 176, 'WAVE FETCH', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE FETCH', 1);
INSERT INTO {schema}.keywords VALUES (5921, '0d91f6d9-44c4-4418-90b0-00feb09c6fc0', 176, 'WAVE FREQUENCY', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (5922, '0fc68280-1361-43e1-bc5a-40c49e9679b7', 176, 'WAVE HEIGHT', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5923, '5daa972e-b47c-4050-97f1-1e628401fb97', 176, 'WAVE LENGTH', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE LENGTH', 1);
INSERT INTO {schema}.keywords VALUES (5924, '5377fb64-b10a-4284-9b7b-be77b4c16fe5', 176, 'WAVE OVERTOPPING', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE OVERTOPPING', 1);
INSERT INTO {schema}.keywords VALUES (5925, '99ea6719-b751-4a4f-95d4-aaa02e961bc1', 176, 'WAVE PERIOD', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE PERIOD', 1);
INSERT INTO {schema}.keywords VALUES (5926, '9a4816c1-dba8-4ae4-9c3b-7f98a4ac245b', 176, 'WAVE RUNUP', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE RUNUP', 1);
INSERT INTO {schema}.keywords VALUES (5927, '4dd520ea-30fc-416d-b98c-340fd23431d3', 176, 'WAVE SETUP', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE SETUP', 1);
INSERT INTO {schema}.keywords VALUES (5928, 'e79ff727-c598-4a1c-8b4f-b6019fcf386b', 176, 'WAVE SPECTRA', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE SPECTRA', 1);
INSERT INTO {schema}.keywords VALUES (5929, 'e52114b2-adbc-4e3e-9c87-1a7f245fe5ef', 176, 'WAVE SPEED/DIRECTION', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE SPEED/DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (5930, 'a4f0e0d2-4bcb-4675-b874-e6e0f3a8c462', 176, 'WAVE TYPES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WAVE TYPES', 1);
INSERT INTO {schema}.keywords VALUES (5931, '0c9adb35-b203-42d7-8ccf-b7f2079db7ce', 176, 'WIND WAVES', 'EARTH SCIENCE > OCEANS > OCEAN WAVES > WIND WAVES', 1);
INSERT INTO {schema}.keywords VALUES (5932, 'b59e188c-49b8-41b3-94c4-0bc1dbb554fe', 177, 'CONVERGENCE/DIVERGENCE', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > CONVERGENCE/DIVERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (5933, 'fbc53539-ce4e-4e3e-bbd2-8270386616b4', 177, 'SURFACE WINDS', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > SURFACE WINDS', 1);
INSERT INTO {schema}.keywords VALUES (5934, '13aeaea0-ab45-4148-abcf-c6becf7a8934', 177, 'TURBULENCE', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > TURBULENCE', 1);
INSERT INTO {schema}.keywords VALUES (5935, 'ab1e152c-eab9-400a-a90f-15cb64ed2a75', 177, 'VERTICAL WIND MOTION', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > VERTICAL WIND MOTION', 1);
INSERT INTO {schema}.keywords VALUES (5936, '253ccaf2-dd4c-4fc1-923d-1aea542a51b0', 177, 'VORTICITY', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > VORTICITY', 1);
INSERT INTO {schema}.keywords VALUES (5937, 'd571e1f5-7449-4052-943b-94d76f762677', 177, 'WIND CHILL', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > WIND CHILL', 1);
INSERT INTO {schema}.keywords VALUES (5938, '855c22f5-d1e0-4ccf-81bd-c8120e7c4055', 177, 'WIND SHEAR', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > WIND SHEAR', 1);
INSERT INTO {schema}.keywords VALUES (5939, '91d73256-925d-4d04-9b55-aaf088080cac', 177, 'WIND STRESS', 'EARTH SCIENCE > OCEANS > OCEAN WINDS > WIND STRESS', 1);
INSERT INTO {schema}.keywords VALUES (5940, '7041e51c-e2de-405a-b154-6016f624f54f', 178, 'CONDUCTIVITY', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (5941, '007ab607-2ee1-484d-85fb-0bfb89f18c9b', 178, 'DENSITY', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (5942, '41926d67-161a-4add-bb12-66038c919efb', 178, 'DESALINIZATION', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > DESALINIZATION', 1);
INSERT INTO {schema}.keywords VALUES (5943, '04305c55-14f0-42a3-a099-79eb326946d7', 178, 'HALOCLINE', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > HALOCLINE', 1);
INSERT INTO {schema}.keywords VALUES (5944, 'fe4a246b-4614-422b-8ca5-0481ee417318', 178, 'POTENTIAL DENSITY', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > POTENTIAL DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (5945, '2ad73f85-8bad-4e5a-a902-e83eee910b5e', 178, 'PYCNOCLINE', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > PYCNOCLINE', 1);
INSERT INTO {schema}.keywords VALUES (5946, '7e95b5fc-1d58-431a-af36-948b29fa870d', 178, 'SALINITY', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > SALINITY', 1);
INSERT INTO {schema}.keywords VALUES (5947, '15f87fbc-b972-403f-97c0-15f387a13efe', 178, 'SALT TRANSPORT', 'EARTH SCIENCE > OCEANS > SALINITY/DENSITY > SALT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (5948, 'ae1c9b54-caf2-4726-b180-5c6544f09111', 179, 'HEAT FLUX', 'EARTH SCIENCE > OCEANS > SEA ICE > HEAT FLUX', 1);
INSERT INTO {schema}.keywords VALUES (5949, '3cdebef6-902d-4c1a-9d7e-7609f8ee6ef6', 179, 'ICE DEFORMATION', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE DEFORMATION', 1);
INSERT INTO {schema}.keywords VALUES (5950, 'a735d8ca-182c-4307-9305-186a065e84a4', 179, 'ICE DEPTH/THICKNESS', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (5951, 'f0cd20bd-41e8-4ca0-9ae3-7c602c251858', 179, 'ICE EDGES', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE EDGES', 1);
INSERT INTO {schema}.keywords VALUES (5952, '87feb47e-aee3-42f1-8c39-5109d9d5422e', 179, 'ICE EXTENT', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (5953, 'aa15804c-5f7f-40cc-b949-aa3e4418fc27', 179, 'ICE FLOES', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE FLOES', 1);
INSERT INTO {schema}.keywords VALUES (5954, '89fc22ca-326e-468c-ad3d-171c4ad34977', 179, 'ICE GROWTH/MELT', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE GROWTH/MELT', 1);
INSERT INTO {schema}.keywords VALUES (5955, 'a6c3e78f-f408-4b72-941a-f40e3d83dd60', 179, 'ICE ROUGHNESS', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE ROUGHNESS', 1);
INSERT INTO {schema}.keywords VALUES (5956, '2a664e2d-4e50-463a-af9f-b14b86eb42a7', 179, 'ICE TEMPERATURE', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (5957, 'f5d7cafc-13bf-4ec8-bc6e-a6d850fae5c8', 179, 'ICE TYPES', 'EARTH SCIENCE > OCEANS > SEA ICE > ICE TYPES', 1);
INSERT INTO {schema}.keywords VALUES (5958, '1151dc7e-7441-4a21-95b6-1d03a1053f60', 179, 'ICEBERGS', 'EARTH SCIENCE > OCEANS > SEA ICE > ICEBERGS', 1);
INSERT INTO {schema}.keywords VALUES (5959, '9d99408d-0d8b-4642-a2cb-edee8319fe1d', 179, 'ISOTOPES', 'EARTH SCIENCE > OCEANS > SEA ICE > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (5960, 'f523f73f-efcc-4193-b9e3-1161ed7f4881', 179, 'LEADS', 'EARTH SCIENCE > OCEANS > SEA ICE > LEADS', 1);
INSERT INTO {schema}.keywords VALUES (5961, 'ea85ea0b-1b7d-464a-9f8c-1f80383ffc51', 179, 'PACK ICE', 'EARTH SCIENCE > OCEANS > SEA ICE > PACK ICE', 1);
INSERT INTO {schema}.keywords VALUES (5962, '10a128a6-12d4-4bce-b25d-2ffc464182f4', 179, 'POLYNYAS', 'EARTH SCIENCE > OCEANS > SEA ICE > POLYNYAS', 1);
INSERT INTO {schema}.keywords VALUES (5963, '8ed9f39d-986e-4b36-83f9-f29f6a4df89b', 179, 'REFLECTANCE', 'EARTH SCIENCE > OCEANS > SEA ICE > REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (5964, '04fa9023-ab68-4dd0-a82e-abe685105a53', 179, 'SALINITY', 'EARTH SCIENCE > OCEANS > SEA ICE > SALINITY', 1);
INSERT INTO {schema}.keywords VALUES (5965, 'b6085d71-a7ee-4b65-9c9c-ff374bdc3974', 179, 'SEA ICE AGE', 'EARTH SCIENCE > OCEANS > SEA ICE > SEA ICE AGE', 1);
INSERT INTO {schema}.keywords VALUES (5966, 'bb27bbb7-7bc4-4e38-833a-30e0a7861ccc', 179, 'SEA ICE CONCENTRATION', 'EARTH SCIENCE > OCEANS > SEA ICE > SEA ICE CONCENTRATION', 1);
INSERT INTO {schema}.keywords VALUES (5967, '6e2f1371-05b1-41db-a6d9-bccd7cc2b3da', 179, 'SEA ICE ELEVATION', 'EARTH SCIENCE > OCEANS > SEA ICE > SEA ICE ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (5968, 'a47ab696-7ed9-4374-8965-c8996e61463d', 179, 'SEA ICE MOTION', 'EARTH SCIENCE > OCEANS > SEA ICE > SEA ICE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (5969, '5575125b-7f15-4d46-ba47-f86de96a1a25', 179, 'SNOW DEPTH', 'EARTH SCIENCE > OCEANS > SEA ICE > SNOW DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (5970, '32259124-81f7-4845-b2fb-6435d7bb5804', 179, 'SNOW MELT', 'EARTH SCIENCE > OCEANS > SEA ICE > SNOW MELT', 1);
INSERT INTO {schema}.keywords VALUES (5971, '5c0b448c-7eb4-4e8c-8403-260cbb6114bb', 180, 'SEA SURFACE HEIGHT', 'EARTH SCIENCE > OCEANS > SEA SURFACE TOPOGRAPHY > SEA SURFACE HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5972, '52a32bd3-d701-49e1-a827-67b3d96d8e56', 180, 'SEA SURFACE SLOPE', 'EARTH SCIENCE > OCEANS > SEA SURFACE TOPOGRAPHY > SEA SURFACE SLOPE', 1);
INSERT INTO {schema}.keywords VALUES (5973, '062be713-9c35-458e-86e2-26cea9415f5d', 181, 'STORM SURGE', 'EARTH SCIENCE > OCEANS > TIDES > STORM SURGE', 1);
INSERT INTO {schema}.keywords VALUES (5974, 'f4f40ec7-e698-4e11-b406-a0fa7f4b530c', 181, 'TIDAL COMPONENTS', 'EARTH SCIENCE > OCEANS > TIDES > TIDAL COMPONENTS', 1);
INSERT INTO {schema}.keywords VALUES (5975, '54ab2e0e-8e36-48e8-b020-ea9a5b453373', 181, 'TIDAL CURRENTS', 'EARTH SCIENCE > OCEANS > TIDES > TIDAL CURRENTS', 1);
INSERT INTO {schema}.keywords VALUES (5976, '9afcf69c-f56f-45a9-afd9-6f929850326b', 181, 'TIDAL HEIGHT', 'EARTH SCIENCE > OCEANS > TIDES > TIDAL HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (5977, 'a5a6266a-9457-4acf-b140-fcdc8bc00a00', 181, 'TIDAL RANGE', 'EARTH SCIENCE > OCEANS > TIDES > TIDAL RANGE', 1);
INSERT INTO {schema}.keywords VALUES (5978, 'f1ee3e81-09b9-48d4-81d9-5faeb90430cc', 182, 'OCEAN CONTAMINANTS', 'EARTH SCIENCE > OCEANS > WATER QUALITY > OCEAN CONTAMINANTS', 1);
INSERT INTO {schema}.keywords VALUES (5979, '7b9fb947-97cd-4354-a799-f14a81564132', 183, 'CALCIUM', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > CALCIUM', 1);
INSERT INTO {schema}.keywords VALUES (5980, '37dac8df-b04b-4561-91fb-886e1bded2c1', 183, 'CARBON DIOXIDE', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > CARBON DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (5981, '01a4a324-cad3-441d-b0f1-02dc9742784a', 183, 'ELECTRICAL PROPERTIES', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > ELECTRICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (5982, '3643618f-3af3-4c69-8beb-2ad14141a176', 183, 'ICE CORE AIR BUBBLES', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > ICE CORE AIR BUBBLES', 1);
INSERT INTO {schema}.keywords VALUES (5983, '591d2038-5c5e-47bf-a551-1b28f33d1f05', 183, 'IONS', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > IONS', 1);
INSERT INTO {schema}.keywords VALUES (5984, 'cf32d0f2-31f5-450d-9f1d-8aa38fd526dc', 183, 'IRON', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > IRON', 1);
INSERT INTO {schema}.keywords VALUES (5985, '096f466a-a86a-42ac-93f7-05a799910817', 183, 'ISOTOPES', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (5986, 'daab3b2a-1fe7-4ad9-8340-1a7cfa54a2ac', 183, 'METHANE', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > METHANE', 1);
INSERT INTO {schema}.keywords VALUES (5987, 'ddbd1be1-2a1b-4aea-a085-6a63208a75c0', 183, 'NITROUS OXIDE', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > NITROUS OXIDE', 1);
INSERT INTO {schema}.keywords VALUES (5988, '63c7d604-707e-4c38-8baf-19a620e61917', 183, 'PARTICULATE MATTER', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > PARTICULATE MATTER', 1);
INSERT INTO {schema}.keywords VALUES (5989, 'aeaa43ab-5ccf-4df7-b8ad-b9f9f4249551', 183, 'POTASSIUM', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > POTASSIUM', 1);
INSERT INTO {schema}.keywords VALUES (5990, 'c692e8e4-b920-4eb5-86c3-b5f6121fec4b', 183, 'SODIUM', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > SODIUM', 1);
INSERT INTO {schema}.keywords VALUES (5991, '4487cb97-df49-421f-8c00-5c5f12dd8af1', 183, 'VELOCITY', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (5992, '2f4ccb5c-7b99-442c-9054-964070d95f7b', 183, 'VOLCANIC DEPOSITS', 'EARTH SCIENCE > PALEOCLIMATE > ICE CORE RECORDS > VOLCANIC DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (5993, '5a63fa7f-2971-4874-a920-394df07d218e', 184, 'BOREHOLES', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > BOREHOLES', 1);
INSERT INTO {schema}.keywords VALUES (5994, '1651d2e2-4483-42fc-aef2-fd49e650eff1', 184, 'CAVE DEPOSITS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > CAVE DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (5995, '8c615709-df55-4b09-a5a9-1fabb133fe1a', 184, 'GLACIATION', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > GLACIATION', 1);
INSERT INTO {schema}.keywords VALUES (5996, '61f57065-8f47-45c7-8319-f6115153a6ad', 184, 'ISOTOPES', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (5997, '733234ec-053b-4595-811a-b221e6afb35e', 184, 'LOESS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > LOESS', 1);
INSERT INTO {schema}.keywords VALUES (5998, 'd412deec-d4ef-4c97-ac1c-f92ddb6964c6', 184, 'MACROFOSSILS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > MACROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (5999, '98e15316-0055-4392-8825-c38f447d6582', 184, 'MICROFOSSILS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > MICROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6000, 'f2ceb98b-4b5d-4ee6-b033-e987d2f820f1', 184, 'PALEOMAGNETIC DATA', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > PALEOMAGNETIC DATA', 1);
INSERT INTO {schema}.keywords VALUES (6001, 'b54e01eb-02d9-413a-baf1-40a6e59d9eae', 184, 'PALEOSOLS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > PALEOSOLS', 1);
INSERT INTO {schema}.keywords VALUES (6002, 'e4871f3e-bc88-4380-b7b7-3a18afccc2bd', 184, 'PALEOVEGETATION', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > PALEOVEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (6003, '14c8721e-4d05-4aaa-90be-8607ae2f84b1', 184, 'POLLEN', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > POLLEN', 1);
INSERT INTO {schema}.keywords VALUES (6004, 'bf0db125-0182-42e7-81c9-6ed55a05ddd0', 184, 'RADIOCARBON', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > RADIOCARBON', 1);
INSERT INTO {schema}.keywords VALUES (6005, '858d3f93-f2eb-4d2a-87c5-68018f206a47', 184, 'SEDIMENTS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6006, 'ac45c059-9555-45ee-ad20-d58514578f1e', 184, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (6007, '84510f18-a4e6-434c-a54c-44cc995e1af2', 184, 'TREE RINGS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > TREE RINGS', 1);
INSERT INTO {schema}.keywords VALUES (6008, '9761565c-2126-49cd-b4c4-cd3bcb5dbbde', 184, 'VOLCANIC DEPOSITS', 'EARTH SCIENCE > PALEOCLIMATE > LAND RECORDS > VOLCANIC DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6009, 'e001c431-c204-419e-af64-cc8978132abf', 185, 'BOREHOLES', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > BOREHOLES', 1);
INSERT INTO {schema}.keywords VALUES (6010, '296b7bc4-c031-48ea-bb6d-99f7c971c953', 185, 'CORAL DEPOSITS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > CORAL DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6011, '56589fec-7573-42df-b853-2754cdc9e1b7', 185, 'ISOTOPES', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6012, '77cbdebf-eddf-42b5-8603-e939eccd1780', 185, 'LAKE LEVELS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > LAKE LEVELS', 1);
INSERT INTO {schema}.keywords VALUES (6013, 'f986b716-d26c-4c98-8166-b415229186ff', 185, 'MACROFOSSILS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > MACROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6014, '6e872413-f416-43dd-a960-942ef892ae59', 185, 'MICROFOSSILS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > MICROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6015, 'a65ec029-86a7-4c3b-b2b3-ee26353aaf36', 185, 'OXYGEN ISOTOPES', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > OXYGEN ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6016, 'd42bf3e3-3eda-471a-adb5-ddf1240cd474', 185, 'PALEOMAGNETIC DATA', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > PALEOMAGNETIC DATA', 1);
INSERT INTO {schema}.keywords VALUES (6017, 'adcd37fe-9f4a-4d8d-8f79-489775707ea2', 185, 'POLLEN', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > POLLEN', 1);
INSERT INTO {schema}.keywords VALUES (6018, '23822618-39a2-4b2b-9162-37bb0651c118', 185, 'RADIOCARBON', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > RADIOCARBON', 1);
INSERT INTO {schema}.keywords VALUES (6019, 'd324729f-cc0d-4943-8d1a-d38335120c00', 185, 'SEDIMENTS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6020, '4722fc1e-f93f-4aa1-854a-2b8a82920008', 185, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (6021, '4ad60c3b-f72e-4f54-9d3e-0048373c166d', 185, 'VARVE DEPOSITS', 'EARTH SCIENCE > PALEOCLIMATE > OCEAN/LAKE RECORDS > VARVE DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6022, 'cb49a2e7-bd89-4d3a-974a-8776a763a4ae', 186, 'AIR TEMPERATURE RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > AIR TEMPERATURE RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6023, '2bdfbf06-c583-4e51-a595-dbc6143d95e0', 186, 'ATMOSPHERIC CIRCULATION RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > ATMOSPHERIC CIRCULATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6024, 'cc063daf-1db5-4597-9de2-0501a5593947', 186, 'DROUGHT/PRECIPITATION RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > DROUGHT/PRECIPITATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6025, 'cf0e53d3-c8ae-4baa-8a31-672a2252f285', 186, 'GROUND WATER RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > GROUND WATER RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6026, 'fed291ec-8f7d-4131-a5cd-dc04706f61b0', 186, 'LAKE LEVEL RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > LAKE LEVEL RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6027, '80a6803a-5bf3-4439-b13f-0909e0ea40f9', 186, 'OCEAN SALINITY RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > OCEAN SALINITY RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6028, 'e240565d-d265-474b-a25b-34059526ae44', 186, 'SEA LEVEL RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > SEA LEVEL RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6029, 'e7b30694-5d05-404b-9748-b8f6adc3491d', 186, 'SEA SURFACE TEMPERATURE RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > SEA SURFACE TEMPERATURE RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6030, '4f07a511-1c78-4b2b-8c6a-f4aeedb0f5b6', 186, 'SOLAR FORCING/INSOLATION RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > SOLAR FORCING/INSOLATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6031, '7859191e-732b-47cf-b1a3-fc7a934509ce', 186, 'STREAMFLOW RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > STREAMFLOW RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6032, '91600c9b-397e-4855-b21e-b9e97e6d5261', 186, 'VEGETATION RECONSTRUCTION', 'EARTH SCIENCE > PALEOCLIMATE > PALEOCLIMATE RECONSTRUCTIONS > VEGETATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6033, '96bbae63-81c1-43b4-90f0-52731e2b52ca', 187, 'HYDROGEN GAS', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > HYDROGEN GAS', 1);
INSERT INTO {schema}.keywords VALUES (6034, '72eb280a-d5d0-4c5e-b789-8f1a8cf8bdac', 187, 'NATURAL GAS', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > NATURAL GAS', 1);
INSERT INTO {schema}.keywords VALUES (6035, '44d0ad8f-fe22-4d17-bc47-c0b728a82baf', 187, 'PETROLEUM', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > PETROLEUM', 1);
INSERT INTO {schema}.keywords VALUES (6036, '4add3005-9151-4b8d-a0bc-14c3908ef3a9', 187, 'RECLAMATION/REVEGETATION/RESTORATION', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > RECLAMATION/REVEGETATION/RESTORATION', 1);
INSERT INTO {schema}.keywords VALUES (6037, 'b472632f-8e67-4892-9896-1c14c5089682', 188, 'BIOGEOCHEMICAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > BIOGEOCHEMICAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6038, 'e6fb1b81-8ffc-486f-b1a1-2f292af8cee6', 188, 'GEOCHEMICAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6039, '048df94e-841d-4f4d-a5c5-6683d1d07aa6', 188, 'GEOCHEMICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (6040, '5cef2f41-a17a-4eff-8ce4-328593e1b703', 188, 'MARINE GEOCHEMICAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > MARINE GEOCHEMICAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6041, '14b19e68-0fb3-43b1-a102-537c4e33c338', 189, 'COORDINATE REFERENCE SYSTEM', 'EARTH SCIENCE > SOLID EARTH > GEODETICS > COORDINATE REFERENCE SYSTEM', 1);
INSERT INTO {schema}.keywords VALUES (6042, 'bc640e63-70c1-4228-b2dc-6aa1ac6edfa6', 189, 'ELLIPSOID CHARACTERISTICS', 'EARTH SCIENCE > SOLID EARTH > GEODETICS > ELLIPSOID CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (6043, '6bbbf7b0-434b-4dbc-9fe8-e5e31fe99614', 189, 'GEOID CHARACTERISTICS', 'EARTH SCIENCE > SOLID EARTH > GEODETICS > GEOID CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (6044, '3202dab6-144a-4bfb-9bda-9d07e5ee7ec2', 190, 'ELECTRICAL FIELD', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > ELECTRICAL FIELD', 1);
INSERT INTO {schema}.keywords VALUES (6045, '02290e22-24ae-40f6-96f1-0c6c76a145af', 190, 'GEOMAGNETIC FORECASTS', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC FORECASTS', 1);
INSERT INTO {schema}.keywords VALUES (6046, 'ae35f430-6534-49de-8b4c-edfc1e98870a', 190, 'GEOMAGNETIC INDICES', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC INDICES', 1);
INSERT INTO {schema}.keywords VALUES (6047, '204b482b-449b-42c9-a5bb-f6da42bee3a4', 190, 'MAGNETIC FIELD', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > MAGNETIC FIELD', 1);
INSERT INTO {schema}.keywords VALUES (6048, '720969dd-e966-41aa-af94-ee41cdf60390', 190, 'PALEOMAGNETISM', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > PALEOMAGNETISM', 1);
INSERT INTO {schema}.keywords VALUES (6049, 'fd631e31-fe6f-462e-a3f6-c07b4b736ac7', 190, 'REFERENCE FIELDS', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > REFERENCE FIELDS', 1);
INSERT INTO {schema}.keywords VALUES (6050, '26637389-f4f6-47a0-9c3d-17e93ab99dea', 191, 'AEOLIAN LANDFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6051, 'f15b2ad3-f658-420b-99b4-41588646d9b7', 191, 'AEOLIAN PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6052, 'c58320e6-3f1d-4c36-9bee-6bad73404c21', 191, 'COASTAL LANDFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6053, '672d6958-4bbc-4b33-adc8-927e4348908b', 191, 'COASTAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6054, 'cb5193ab-2d7a-4b35-b7ec-f16ce78ae270', 191, 'FLUVIAL LANDFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6055, '6f47ae88-f28f-43e3-be6a-34f86b15fe19', 191, 'FLUVIAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6056, '601d36fc-8171-475c-a1c5-84802aecb77e', 195, 'EARTHQUAKES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES', 1);
INSERT INTO {schema}.keywords VALUES (6057, '3c78951a-0293-4fb0-baff-ec7372fe784d', 191, 'GLACIAL LANDFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6058, 'd7b62912-5970-46b1-be45-6a603c9a6979', 191, 'GLACIAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6059, 'ac2d1035-1896-42c1-861b-042a917b6889', 191, 'KARST LANDFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6060, '63846997-4a3f-41e1-9241-6d5053360d7a', 191, 'KARST PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6061, '46172bbe-8bf0-49a0-848f-129c089aeb8e', 191, 'TECTONIC LANDFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6062, 'f0bd7eeb-9004-4e40-a649-f6010d8a4303', 191, 'TECTONIC PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6063, '33d1810f-40c6-4b37-ac90-7435ef5fa507', 192, 'GEOTHERMAL ENERGY', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL ENERGY', 1);
INSERT INTO {schema}.keywords VALUES (6064, 'cacfd8f0-b83a-46b7-b324-52ce1b55baa9', 192, 'GEOTHERMAL TEMPERATURE', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6065, '8b39b880-f385-4dab-a563-24064b43be7e', 193, 'CONTROL SURVEYS', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > CONTROL SURVEYS', 1);
INSERT INTO {schema}.keywords VALUES (6066, '122f7d15-7e5c-4249-992c-c753c80cf05b', 193, 'CRUSTAL MOTION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > CRUSTAL MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6067, '56b4cbe5-e5f7-4e61-8c48-bbb858b505e6', 193, 'GRAVITATIONAL FIELD', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > GRAVITATIONAL FIELD', 1);
INSERT INTO {schema}.keywords VALUES (6068, 'fb7eeee0-9ad1-40f8-baa2-df7dc3acb6d3', 193, 'GRAVITY ANOMALIES', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > GRAVITY ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (6069, '69af3046-08e0-4c24-981d-803c0412ce58', 193, 'GRAVITY', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (6070, 'c44b078d-ec95-47d5-9a43-ba8475e568d2', 193, 'POLAR MOTION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > POLAR MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6071, '05225982-60ab-4772-a0b7-f67c3b853ab9', 193, 'ROTATIONAL MOTION/VARIATIONS', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > ROTATIONAL MOTION/VARIATIONS', 1);
INSERT INTO {schema}.keywords VALUES (6072, '71278ba7-9a13-43ba-9ec3-62ae2b39de88', 193, 'SATELLITE ORBITS/REVOLUTION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > SATELLITE ORBITS/REVOLUTION', 1);
INSERT INTO {schema}.keywords VALUES (6073, 'd4ac49a1-9ba5-4a90-a033-2ef317028352', 194, 'AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (6074, '4beaeec9-0750-44e6-8fb4-8d0085efc82e', 194, 'BEDROCK LITHOLOGY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > BEDROCK LITHOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (6075, 'da22144c-634d-4007-aba9-e636a9f2fa3f', 194, 'ELEMENTS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6076, 'a654a922-8b69-46f2-be40-d4d830ce999c', 194, 'GAS HYDRATES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES', 1);
INSERT INTO {schema}.keywords VALUES (6077, 'e8d97ffd-2fd2-4989-88a7-9772fc9b7cd8', 194, 'IGNEOUS ROCKS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS', 1);
INSERT INTO {schema}.keywords VALUES (6078, '7b76bca5-32ee-4285-8550-0de120b01a13', 194, 'METALS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS', 1);
INSERT INTO {schema}.keywords VALUES (6079, 'd220bbb1-410e-4b77-9663-78cb68c6b134', 194, 'METAMORPHIC ROCKS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS', 1);
INSERT INTO {schema}.keywords VALUES (6080, '96be1efc-d5e2-423d-8ade-00b3d454244d', 194, 'METEORITES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES', 1);
INSERT INTO {schema}.keywords VALUES (6081, '3ef98fe3-3471-414b-8b8c-e88d43c6aeaf', 195, 'NEOTECTONICS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > NEOTECTONICS', 1);
INSERT INTO {schema}.keywords VALUES (6082, '387a51ad-382f-4297-be72-fdd4bb0fe3f9', 194, 'MINERALS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS', 1);
INSERT INTO {schema}.keywords VALUES (6083, 'd64a9627-3cf8-41d3-aaf7-8c2c46fb4a13', 194, 'NON-METALLIC MINERALS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS', 1);
INSERT INTO {schema}.keywords VALUES (6084, '85353d7b-05d8-4c32-a5b2-065f1f22f026', 194, 'SEDIMENTARY ROCKS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS', 1);
INSERT INTO {schema}.keywords VALUES (6085, '6600ace1-fc1e-4b5a-9f82-0afa19acf037', 194, 'SEDIMENTS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6086, '57503db6-7cff-4e92-bcac-1ba2c3c0cb48', 195, 'CORE PROCESSES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > CORE PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6087, '71e9bc66-6f8c-41ec-8b22-2fe390223639', 195, 'PLATE TECTONICS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS', 1);
INSERT INTO {schema}.keywords VALUES (6088, '1faaede0-2cd6-4447-b28b-0a28d9e2d067', 195, 'VOLCANIC ACTIVITY', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (6089, 'fd8d9257-795c-4406-b205-cf20059d8e77', 196, 'GAMMA RAY FLUX', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > GAMMA RAY > GAMMA RAY FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6090, '73629546-592e-41ed-bfde-feb4c94415fb', 197, 'BRIGHTNESS TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > BRIGHTNESS TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6091, 'd76e6734-956b-419d-9d7a-52b8e645b6ac', 197, 'INFRARED FLUX', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > INFRARED FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6092, 'd1407646-e34a-4a43-ae1d-afc4c229d6de', 197, 'INFRARED IMAGERY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > INFRARED IMAGERY', 1);
INSERT INTO {schema}.keywords VALUES (6093, '69f475b6-42af-4822-ae57-6c8fd8ebad4a', 197, 'INFRARED RADIANCE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > INFRARED RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (6094, 'ff985037-2f20-4b08-bb22-3ed701ed2f4d', 197, 'REFLECTED INFRARED', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > REFLECTED INFRARED', 1);
INSERT INTO {schema}.keywords VALUES (6095, '32212cbf-e2ba-44c9-930c-8b454ea88bee', 197, 'SENSOR COUNTS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > SENSOR COUNTS', 1);
INSERT INTO {schema}.keywords VALUES (6096, '68c2baba-b9b9-41d4-89bf-07488728bc4f', 197, 'THERMAL INFRARED', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > INFRARED WAVELENGTHS > THERMAL INFRARED', 1);
INSERT INTO {schema}.keywords VALUES (6097, 'ca776e14-fc3d-4044-9d1a-fd7c07569399', 198, 'LIDAR BACKSCATTER', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > LIDAR > LIDAR BACKSCATTER', 1);
INSERT INTO {schema}.keywords VALUES (6098, '19c3f401-1328-495c-9705-74b0175fee56', 198, 'LIDAR DEPOLARIZATION RATIO', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > LIDAR > LIDAR DEPOLARIZATION RATIO', 1);
INSERT INTO {schema}.keywords VALUES (6099, '570397b4-3b45-4e12-85c3-ef26779a2c96', 199, 'ANTENNA TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > MICROWAVE > ANTENNA TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6100, 'd8525750-2ca4-4b1f-a717-08fda61fd547', 199, 'BRIGHTNESS TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > MICROWAVE > BRIGHTNESS TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6101, 'af234b68-d1ad-40ea-aa1b-6bc2c8e5b467', 199, 'MICROWAVE IMAGERY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > MICROWAVE > MICROWAVE IMAGERY', 1);
INSERT INTO {schema}.keywords VALUES (6102, 'd9654ddc-1dc0-4f9d-9b95-61ab0c3d6f87', 199, 'MICROWAVE RADIANCE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > MICROWAVE > MICROWAVE RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (6103, '5f6e0ca7-5d60-4973-890b-08ad82654331', 199, 'SENSOR COUNTS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > MICROWAVE > SENSOR COUNTS', 1);
INSERT INTO {schema}.keywords VALUES (6104, '7ebe88d4-fa73-4dd1-8cbd-6b1c266dff52', 200, 'AIRSPEED/GROUND SPEED', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > AIRSPEED/GROUND SPEED', 1);
INSERT INTO {schema}.keywords VALUES (6105, 'edbca82e-9396-4842-ad91-18c0000b2741', 200, 'ATTITUDE CHARACTERISTICS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > ATTITUDE CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (6106, '762f9d7f-5f2d-423d-81c4-288350f64b9d', 200, 'DATA SYNCHRONIZATION TIME', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > DATA SYNCHRONIZATION TIME', 1);
INSERT INTO {schema}.keywords VALUES (6107, '6b68bae6-e5cb-44ff-ad40-a8100a88e5b1', 200, 'FLIGHT DATA LOGS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > FLIGHT DATA LOGS', 1);
INSERT INTO {schema}.keywords VALUES (6108, '53ab7819-1837-4919-b4a8-85bcc8b7731c', 200, 'LINE OF SIGHT VELOCITY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > LINE OF SIGHT VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (6109, '4809f1e1-1b36-46a7-a7ae-ce55523424e6', 200, 'ORBITAL CHARACTERISTICS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > ORBITAL CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (6110, 'd622004f-e155-4af3-87c5-61b3a4b87692', 200, 'VIEWING GEOMETRY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > PLATFORM CHARACTERISTICS > VIEWING GEOMETRY', 1);
INSERT INTO {schema}.keywords VALUES (6111, '5d6377ee-def2-4457-b780-6bcb202d7e3e', 201, 'DOPPLER VELOCITY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > DOPPLER VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (6112, 'bb20786b-2499-40b0-a9a5-2cc64421a6d2', 201, 'MEAN RADIAL VELOCITY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > MEAN RADIAL VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (6113, '625da982-3648-43fc-a640-1b230509944e', 201, 'RADAR BACKSCATTER', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > RADAR BACKSCATTER', 1);
INSERT INTO {schema}.keywords VALUES (6114, '9613f08d-da11-4ed0-989e-c0c830870044', 201, 'RADAR CROSS-SECTION', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > RADAR CROSS-SECTION', 1);
INSERT INTO {schema}.keywords VALUES (6115, '53f69037-ff05-4b09-a95d-e65ff42da595', 201, 'RADAR IMAGERY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > RADAR IMAGERY', 1);
INSERT INTO {schema}.keywords VALUES (6116, '46975e66-863a-49c9-b673-b2e099a04c85', 201, 'RADAR REFLECTIVITY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > RADAR REFLECTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (6117, '6eca12d1-bafd-448c-bdce-a4438efb359e', 201, 'RETURN POWER', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > RETURN POWER', 1);
INSERT INTO {schema}.keywords VALUES (6118, 'e2c01004-be17-4be4-bfcd-7b5c7fc958d6', 201, 'SENSOR COUNTS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > SENSOR COUNTS', 1);
INSERT INTO {schema}.keywords VALUES (6119, '11e14ac8-e9f3-4737-b83d-98668ad975ed', 201, 'SIGMA NAUGHT', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > SIGMA NAUGHT', 1);
INSERT INTO {schema}.keywords VALUES (6120, '41a7f02b-5ab6-4c1e-8583-abb870507ea1', 201, 'SPECTRUM WIDTH', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADAR > SPECTRUM WIDTH', 1);
INSERT INTO {schema}.keywords VALUES (6121, 'b3578efe-fc86-4fb0-92b5-42c08bae5e3c', 202, 'RADIO WAVE FLUX', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > RADIO WAVE > RADIO WAVE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6122, '68ac1c78-6b8b-4e45-b588-38ff94ceb3a4', 203, 'DOME TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > DOME TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6123, '914a7dba-82ae-4419-97cf-397007ad9c30', 203, 'ELECTRICAL PROPERTIES', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > ELECTRICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (6124, '7a0ab5f9-2317-4217-a081-8d4a46eb5334', 203, 'GEOLOCATION', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > GEOLOCATION', 1);
INSERT INTO {schema}.keywords VALUES (6125, 'a4a3d233-581b-4171-bf16-41a1528a7dda', 203, 'PHASE AND AMPLITUDE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > PHASE AND AMPLITUDE', 1);
INSERT INTO {schema}.keywords VALUES (6126, '4a42042b-7427-4cf2-9475-7d1788e3ac54', 203, 'SINK TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > SINK TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6127, '7d3d6c15-b328-43a4-92eb-7d3c430647c4', 203, 'THERMAL PROPERTIES', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > THERMAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (6128, '733092b1-4256-433a-85fe-78c912f21f80', 203, 'TOTAL PRESSURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > TOTAL PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (6129, '3ef1cc7b-2864-46e3-b399-fcc1fbcf0d9b', 203, 'TOTAL TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > TOTAL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6130, '36085074-ba97-450b-847b-046509b0e09a', 203, 'ULTRAVIOLET SENSOR TEMPERATURE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > ULTRAVIOLET SENSOR TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6131, '14edbe59-89a4-45ce-ac61-0143fb311da6', 203, 'VIEWING GEOMETRY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > SENSOR CHARACTERISTICS > VIEWING GEOMETRY', 1);
INSERT INTO {schema}.keywords VALUES (6132, '03d45804-cc21-449d-81f4-4bb778f97ac6', 204, 'SENSOR COUNTS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > ULTRAVIOLET WAVELENGTHS > SENSOR COUNTS', 1);
INSERT INTO {schema}.keywords VALUES (6133, '01e4b433-34ae-4ffb-a73b-dff7ae4c789a', 204, 'ULTRAVIOLET FLUX', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > ULTRAVIOLET WAVELENGTHS > ULTRAVIOLET FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6134, 'ca87e2c2-9087-42f7-a88a-93ace50ebe39', 204, 'ULTRAVIOLET RADIANCE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > ULTRAVIOLET WAVELENGTHS > ULTRAVIOLET RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (6554, '9818a5f0-bec9-47c0-b2ee-7e84c55466ed', 5337, 'FERNS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > FERNS AND ALLIES > FERNS', 1);
INSERT INTO {schema}.keywords VALUES (6135, 'a3792ab1-61af-48be-acf2-116c291a3765', 205, 'SENSOR COUNTS', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > VISIBLE WAVELENGTHS > SENSOR COUNTS', 1);
INSERT INTO {schema}.keywords VALUES (6136, '7971f416-cf75-47f4-9108-6184baab58e5', 205, 'VISIBLE FLUX', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > VISIBLE WAVELENGTHS > VISIBLE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6137, '03f0c0a3-04a7-4ef8-8ec0-3c2266510815', 205, 'VISIBLE IMAGERY', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > VISIBLE WAVELENGTHS > VISIBLE IMAGERY', 1);
INSERT INTO {schema}.keywords VALUES (6138, 'b590bfda-a053-4439-8f86-a2811e67ce46', 205, 'VISIBLE RADIANCE', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > VISIBLE WAVELENGTHS > VISIBLE RADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (6139, 'e32b5dca-c243-40d8-9e06-d146a40a71df', 206, 'X-RAY FLUX', 'EARTH SCIENCE > SPECTRAL/ENGINEERING > X-RAY > X-RAY FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6140, '792cf9f0-6d24-4de8-902c-b74e42c74fd3', 207, 'AURORAE', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > AURORAE', 1);
INSERT INTO {schema}.keywords VALUES (6141, '9abe9fdb-59f3-4bd6-b24f-b9b7e46eae7c', 207, 'ELECTRIC FIELDS/ELECTRIC CURRENTS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > ELECTRIC FIELDS/ELECTRIC CURRENTS', 1);
INSERT INTO {schema}.keywords VALUES (6142, '882d9a10-713c-4b58-8c7b-d9af086115a3', 207, 'GEOMAGNETIC FORECASTS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > GEOMAGNETIC FORECASTS', 1);
INSERT INTO {schema}.keywords VALUES (6143, '990016e0-f247-4c36-8a17-f50e792a964a', 207, 'GEOMAGNETIC INDICES', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > GEOMAGNETIC INDICES', 1);
INSERT INTO {schema}.keywords VALUES (6144, 'ba75172a-6965-40cf-bf3f-6c0af2f97dad', 207, 'ION CHEMISTRY/IONIZATION', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > ION CHEMISTRY/IONIZATION', 1);
INSERT INTO {schema}.keywords VALUES (6145, '8cbdfa00-852c-452d-8013-86145ad318c8', 207, 'MAGNETIC FIELDS/MAGNETIC CURRENTS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > MAGNETIC FIELDS/MAGNETIC CURRENTS', 1);
INSERT INTO {schema}.keywords VALUES (6146, 'e453077b-b6f3-44f0-9f3d-4408bf9a69e5', 207, 'MAGNETIC STORMS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > MAGNETIC STORMS', 1);
INSERT INTO {schema}.keywords VALUES (6147, '5f8a9188-d588-4782-a34b-07fa68380c41', 207, 'PLASMA WAVES', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > PLASMA WAVES', 1);
INSERT INTO {schema}.keywords VALUES (6148, '5d290bd8-049b-4002-86c8-8acba563d0e1', 207, 'SOLAR WIND', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > IONOSPHERE/MAGNETOSPHERE DYNAMICS > SOLAR WIND', 1);
INSERT INTO {schema}.keywords VALUES (6149, '6a5a2ccf-3ba6-4519-bc9b-7617ef3b9087', 208, 'CORONA HOLES', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > CORONA HOLES', 1);
INSERT INTO {schema}.keywords VALUES (6150, '6d486f25-7477-4da9-96ae-0091596ed4d2', 208, 'CORONAL MASS EJECTIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > CORONAL MASS EJECTIONS', 1);
INSERT INTO {schema}.keywords VALUES (6151, '1ef327e1-6139-49ff-87c3-f959ea75a511', 208, 'CORONA', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > CORONA', 1);
INSERT INTO {schema}.keywords VALUES (6152, 'e06822d8-b640-4d75-ac37-33ab3cc5e765', 208, 'COSMIC RAYS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > COSMIC RAYS', 1);
INSERT INTO {schema}.keywords VALUES (6153, '0d32a340-ee64-4795-9254-09dcaf55bf4c', 208, 'SOLAR ACTIVE REGIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR ACTIVE REGIONS', 1);
INSERT INTO {schema}.keywords VALUES (6154, 'fa9f54b2-a101-4faf-b1dc-b6dff141c08c', 208, 'SOLAR FLARES', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR FLARES', 1);
INSERT INTO {schema}.keywords VALUES (6155, 'e2fc7768-955b-4e76-935e-d33805fcc914', 208, 'SOLAR IMAGERY', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR IMAGERY', 1);
INSERT INTO {schema}.keywords VALUES (6156, '33f0ec3e-cd6d-498c-9468-749741fc12e2', 208, 'SOLAR IRRADIANCE', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR IRRADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (6157, '88bd8ce6-334d-4a42-8d51-5ed074ef5a89', 208, 'SOLAR OSCILLATIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR OSCILLATIONS', 1);
INSERT INTO {schema}.keywords VALUES (6158, '7b52f7f5-4102-4829-8ea3-c0dcdd36bdca', 208, 'SOLAR PROMINENCES/SOLAR FILAMENTS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR PROMINENCES/SOLAR FILAMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6159, '25aa0f7b-89a5-46d7-b3d3-622b60032661', 208, 'SOLAR RADIO WAVE EMISSIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR RADIO WAVE EMISSIONS', 1);
INSERT INTO {schema}.keywords VALUES (6160, 'ace2d2e5-0b9a-472e-b27b-c687b9108076', 208, 'SOLAR SYNOPTIC MAPS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR SYNOPTIC MAPS', 1);
INSERT INTO {schema}.keywords VALUES (6161, 'a4390c3d-cffa-43ee-8e91-49c6d49ac371', 208, 'SOLAR ULTRAVIOLET EMISSIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR ULTRAVIOLET EMISSIONS', 1);
INSERT INTO {schema}.keywords VALUES (6162, 'e4fcb001-f517-4295-89dd-73292e0bf3ee', 208, 'SOLAR VELOCITY FIELDS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR VELOCITY FIELDS', 1);
INSERT INTO {schema}.keywords VALUES (6163, 'a15e514b-4b44-4587-a857-34ab7e2d357e', 208, 'SOLAR X-RAY EMISSIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SOLAR X-RAY EMISSIONS', 1);
INSERT INTO {schema}.keywords VALUES (6164, '429d42ef-9b58-4068-b389-0a9e60e55486', 208, 'SUNSPOTS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ACTIVITY > SUNSPOTS', 1);
INSERT INTO {schema}.keywords VALUES (6165, '2217b742-b21a-4230-ba34-1af30132135d', 209, 'ALPHA PARTICLE FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > ALPHA PARTICLE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6166, '5223ebeb-a22d-4bb9-b2b2-ed949a10ac29', 209, 'ELECTRON FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > ELECTRON FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6167, '67773da0-f5f1-4047-871a-1fb5a5c1621a', 209, 'HEAVY NUCLEI FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > HEAVY NUCLEI FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6168, 'd9ce8e7e-44ff-4555-a910-86b87daca0c2', 209, 'ION FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > ION FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6169, '8f801f54-9ca9-4ba6-be35-fd87968f24e7', 209, 'NEUTRAL PARTICLE FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > NEUTRAL PARTICLE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6170, 'a2443978-118d-4f7c-843d-dcd0059fe949', 209, 'PROTON FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > PROTON FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6171, '0168947c-5f28-46d8-b643-cb31af02a6de', 209, 'SUB-ATOMIC PARTICLE FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > SUB-ATOMIC PARTICLE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6172, '8686285f-9949-4a22-ad80-a1bf4d43e122', 209, 'X-RAY FLUX', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE FLUX > X-RAY FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6173, '36bab763-b5d7-450a-8328-1c1f935184f4', 210, 'ENERGY DEPOSITION', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > ENERGY DEPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (6174, 'bc02662f-d4a1-43c6-833f-836107ae6737', 210, 'PARTICLE COMPOSITION', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > PARTICLE COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (6175, 'fd42b8e3-b76c-4888-aeb7-e6486beb4b69', 210, 'PARTICLE DENSITY', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > PARTICLE DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6176, 'c39210ba-7659-424b-a2f0-5777a1519115', 210, 'PARTICLE DISTRIBUTION FUNCTIONS', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > PARTICLE DISTRIBUTION FUNCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (6177, '68f1ff0e-2e23-4025-ba71-7f6177352311', 210, 'PARTICLE SPEED', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > PARTICLE SPEED', 1);
INSERT INTO {schema}.keywords VALUES (6178, '630c1f3f-73b9-4f80-bc47-4cbf1fa43788', 210, 'PARTICLE TEMPERATURE', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > PARTICLE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6179, '0b2ca4d1-a225-4243-90eb-1b482fb094a5', 210, 'TOTAL ELECTRON CONTENT', 'EARTH SCIENCE > SUN-EARTH INTERACTIONS > SOLAR ENERGETIC PARTICLE PROPERTIES > TOTAL ELECTRON CONTENT', 1);
INSERT INTO {schema}.keywords VALUES (6180, 'a994a6f6-cfcd-45d2-95a4-0f8455a9454d', 211, 'ABLATION ZONES/ACCUMULATION ZONES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > ABLATION ZONES/ACCUMULATION ZONES', 1);
INSERT INTO {schema}.keywords VALUES (6181, 'ff79c018-8d61-4811-91bc-c4ddea29677c', 211, 'FIRN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > FIRN', 1);
INSERT INTO {schema}.keywords VALUES (6182, '4d1cc756-c12a-472a-9eae-de96e0a7ba74', 211, 'GLACIER ELEVATION/ICE SHEET ELEVATION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIER ELEVATION/ICE SHEET ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (6183, '7b657679-78bf-4580-987d-0d1b98dcd0d2', 211, 'GLACIER FACIES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIER FACIES', 1);
INSERT INTO {schema}.keywords VALUES (6184, '5ac9ae0b-901a-468e-8a42-5d6f3865a584', 211, 'GLACIER MASS BALANCE/ICE SHEET MASS BALANCE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIER MASS BALANCE/ICE SHEET MASS BALANCE', 1);
INSERT INTO {schema}.keywords VALUES (6185, 'a870d769-b815-435a-b7cc-cba5e6c27bb3', 211, 'GLACIER MOTION/ICE SHEET MOTION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIER MOTION/ICE SHEET MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6186, '87b27ecd-c10b-4d41-8c49-b84f185c5bd4', 211, 'GLACIER THICKNESS/ICE SHEET THICKNESS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIER THICKNESS/ICE SHEET THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (6187, '72fdd0c7-f998-47ab-aeee-2956b9015ccb', 211, 'GLACIER TOPOGRAPHY/ICE SHEET TOPOGRAPHY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIER TOPOGRAPHY/ICE SHEET TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (6188, '4a426aab-4a95-4bf4-8449-19a72a251541', 211, 'GLACIERS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > GLACIERS', 1);
INSERT INTO {schema}.keywords VALUES (6189, 'b2800856-f1e3-41aa-bdc4-75e9cd626d3f', 211, 'ICE SHEETS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > ICE SHEETS', 1);
INSERT INTO {schema}.keywords VALUES (6190, 'f1c79b5f-fcc2-42e7-818b-7534f79081ff', 211, 'ICEBERGS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > ICEBERGS', 1);
INSERT INTO {schema}.keywords VALUES (6191, 'ae94befb-d08e-4350-8ebe-c0ba7ded8320', 212, 'GROUND WATER FEATURES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER FEATURES', 1);
INSERT INTO {schema}.keywords VALUES (6192, '6e4b29b7-a0c9-4e8e-b778-23b50cf8efb8', 212, 'GROUND WATER PROCESSES/MEASUREMENTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6193, '8435030e-8d16-409f-a812-ace5d8ffc122', 212, 'GROUNDWATER CHEMISTRY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUNDWATER CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (6194, '2ddd003d-c19f-4336-9837-316cce5efe0b', 213, 'ALBEDO', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > ALBEDO', 1);
INSERT INTO {schema}.keywords VALUES (6195, '2565d1be-7468-4969-9367-e21719c006a1', 213, 'AVALANCHE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > AVALANCHE', 1);
INSERT INTO {schema}.keywords VALUES (6196, '67648fff-9415-4a36-a1f6-ef028dd1d9b5', 213, 'DEPTH HOAR', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > DEPTH HOAR', 1);
INSERT INTO {schema}.keywords VALUES (6197, '4453ac7c-1869-4aef-8b06-dbdc9e63e245', 213, 'FREEZE/THAW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > FREEZE/THAW', 1);
INSERT INTO {schema}.keywords VALUES (6198, 'f3743f11-06bb-4337-969a-d5616b96038f', 213, 'FROST', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > FROST', 1);
INSERT INTO {schema}.keywords VALUES (6199, 'fa751659-7032-447c-a581-f4e9de854070', 213, 'ICE DEPTH/THICKNESS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > ICE DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (6200, '0fcce7dc-496f-4078-96f0-2035a73563fb', 213, 'ICE EXTENT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > ICE EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (6201, '7c23be3f-89fc-4a85-83fc-128b0837ee83', 213, 'ICE GROWTH/MELT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > ICE GROWTH/MELT', 1);
INSERT INTO {schema}.keywords VALUES (6202, '10068260-94c0-4e58-83ac-f9c5d6bd5748', 213, 'ICE MOTION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > ICE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6203, 'cee7ed2f-3ed1-44ad-b48b-513a68bb3244', 213, 'ICE VELOCITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > ICE VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (6204, 'a99c2917-8f91-4ec8-ad4f-7ee6200ab35d', 213, 'LAKE ICE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > LAKE ICE', 1);
INSERT INTO {schema}.keywords VALUES (6205, '6a7eed90-327a-4609-b952-c9617445a1d1', 213, 'PERMAFROST', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > PERMAFROST', 1);
INSERT INTO {schema}.keywords VALUES (6206, 'ad8499b4-28cb-46ed-b0fe-867ed90fce05', 213, 'RIVER ICE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > RIVER ICE', 1);
INSERT INTO {schema}.keywords VALUES (6207, '6a08f79f-a621-4f8c-b5d5-e1335f9cbcec', 213, 'SNOW COVER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW COVER', 1);
INSERT INTO {schema}.keywords VALUES (6208, 'fde70d8c-d64c-4784-971d-589eedfc42d1', 213, 'SNOW DENSITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6209, '9512b90f-f495-41bb-9600-ff25e4cfc571', 213, 'SNOW DEPTH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (6210, '8b99fd5b-4be4-4d4b-bdf2-ef92df294738', 213, 'SNOW ENERGY BALANCE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW ENERGY BALANCE', 1);
INSERT INTO {schema}.keywords VALUES (6211, '1f10a307-df15-43e2-b3fa-5fe6df619f98', 213, 'SNOW FACIES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW FACIES', 1);
INSERT INTO {schema}.keywords VALUES (6212, 'dd6de9e1-61e7-41bf-a2dc-9d2afc690bb3', 213, 'SNOW MELT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW MELT', 1);
INSERT INTO {schema}.keywords VALUES (6213, 'c5aaee13-289b-40b7-867d-83bd72c02b2d', 213, 'SNOW STRATIGRAPHY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW STRATIGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (6214, '47d8d3db-9aea-49f3-8edd-5216736a85ef', 213, 'SNOW WATER EQUIVALENT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW WATER EQUIVALENT', 1);
INSERT INTO {schema}.keywords VALUES (6215, '9a3b0d9b-4409-439f-b23d-c07590ff919e', 213, 'SNOW/ICE CHEMISTRY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW/ICE CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (6216, '1341f3e1-9279-4ae6-9a93-6a612957efd1', 213, 'SNOW/ICE TEMPERATURE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > SNOW/ICE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6217, '06741402-492e-4cda-926b-8897b15450e7', 213, 'WHITEOUT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SNOW/ICE > WHITEOUT', 1);
INSERT INTO {schema}.keywords VALUES (6218, '1baa552d-c563-43fb-b618-54651f8b07e6', 214, 'SURFACE WATER CHEMISTRY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (6219, '959f1861-a776-41b1-ba6b-d23c71d4d1eb', 214, 'SURFACE WATER FEATURES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER FEATURES', 1);
INSERT INTO {schema}.keywords VALUES (6220, '9d86cd70-062a-4c39-b3f3-226abebc07f7', 214, 'SURFACE WATER PROCESSES/MEASUREMENTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6221, 'c84b61fe-720a-4240-b6c8-8dcc9ae24a36', 214, 'WATERSHED CHARACTERISTICS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > WATERSHED CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (6222, '42c6d91b-afef-4638-95c5-0d130828b2e7', 215, 'CONTAMINANTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS', 1);
INSERT INTO {schema}.keywords VALUES (6223, '7b98fcc5-4465-45c8-a647-557432276844', 215, 'GASES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > GASES', 1);
INSERT INTO {schema}.keywords VALUES (6224, '4d5f7ae1-3368-468b-825b-e72c1df24508', 215, 'ISOTOPES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6225, '1459a39c-4781-4481-8bd9-510762865efd', 215, 'NUTRIENTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS', 1);
INSERT INTO {schema}.keywords VALUES (6226, 'fad79bec-0672-4c71-8910-174c8985a1b9', 215, 'SOLIDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (6227, 'f7e97dc3-1181-41b5-8b90-946eb2504110', 215, 'WATER CHARACTERISTICS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS', 1);
INSERT INTO {schema}.keywords VALUES (6228, 'f2130ca3-3587-4312-b6d4-138456b5ea78', 215, 'WATER QUALITY INDEXES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER QUALITY INDEXES', 1);
INSERT INTO {schema}.keywords VALUES (6229, '6e7306a1-79a5-482e-b646-74b75a1eaa48', 5158, 'ANGSTROM EXPONENT', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > AEROSOL OPTICAL DEPTH/THICKNESS > ANGSTROM EXPONENT', 1);
INSERT INTO {schema}.keywords VALUES (6230, 'a63f4fe6-51dc-4719-95e3-a09d111774c9', 5162, 'NON-REFRACTORY AEROSOL ORGANIC MASS', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > CHEMICAL COMPOSITION > NON-REFRACTORY AEROSOL ORGANIC MASS', 1);
INSERT INTO {schema}.keywords VALUES (6231, 'bc6f9a64-0d00-4f39-9f1c-a4c25b373897', 5162, 'WATER-SOLUBLE AEROSOL ORGANIC MASS', 'EARTH SCIENCE > ATMOSPHERE > AEROSOLS > CHEMICAL COMPOSITION > WATER-SOLUBLE AEROSOL ORGANIC MASS', 1);
INSERT INTO {schema}.keywords VALUES (6232, 'c3b81888-8a39-4b3f-8033-4c077797bcba', 5187, 'CARBON DIOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > CARBON DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6233, '88a1b416-1589-45a4-9923-452975ec35c7', 5187, 'CARBON MONOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > CARBON MONOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6234, 'cdab2cca-6767-427e-b464-09fe26ec59db', 5187, 'CHLORINATED HYDROCARBONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > CHLORINATED HYDROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (6235, 'bc05d7d2-3c96-4bb6-b759-d45e3c673b86', 5187, 'FORMALDEHYDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > FORMALDEHYDE', 1);
INSERT INTO {schema}.keywords VALUES (6236, 'af157837-bdbd-4a9a-b24e-6a79adfef57f', 5187, 'HYDROGEN CYANIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > HYDROGEN CYANIDE', 1);
INSERT INTO {schema}.keywords VALUES (6237, 'c6b2279c-804f-42bf-aa8a-0c81f9ecf6cd', 5187, 'HYPOCHLOROUS MONOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > HYPOCHLOROUS MONOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6238, '7c892333-f4c4-4f81-b825-d6a86e107e9f', 5187, 'METHANE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > METHANE', 1);
INSERT INTO {schema}.keywords VALUES (6239, '35721fc2-a968-487f-ad85-6307a18e4af6', 5187, 'METHYL CYANIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > METHYL CYANIDE', 1);
INSERT INTO {schema}.keywords VALUES (6240, '06d230f1-08f8-48cc-9bbd-5f2358a84d13', 5187, 'NON-METHANE HYDROCARBONS/VOLATILE ORGANIC COMPOUNDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > CARBON AND HYDROCARBON COMPOUNDS > NON-METHANE HYDROCARBONS/VOLATILE ORGANIC COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (6241, '39c478bd-620e-455c-904d-4621965e376c', 5189, 'BROMINE MONOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > BROMINE MONOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6242, '1ecb1e7c-50fc-4951-b610-5140475d87ed', 5189, 'CARBON TETRACHLORIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > CARBON TETRACHLORIDE', 1);
INSERT INTO {schema}.keywords VALUES (6243, 'a56d397b-bff5-4a14-b54c-366470e023c7', 5189, 'CHLORINE DIOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > CHLORINE DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6244, '6f96d1bd-f6ba-437a-9079-c575c4822248', 5189, 'CHLORINE MONOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > CHLORINE MONOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6245, 'a9104127-6846-4123-8ab0-b65c61a0018d', 5189, 'CHLORINE NITRATE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > CHLORINE NITRATE', 1);
INSERT INTO {schema}.keywords VALUES (6246, 'e78ae4ce-807a-4417-ad6e-a458c6da6638', 5189, 'CHLOROFLUOROCARBONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > CHLOROFLUOROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (6247, '13588158-07b6-4294-a00c-fa095b6ad4fd', 5189, 'HALOCARBONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HALOCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (6248, '33e3c858-25ee-4a5e-a938-93779679ed06', 5189, 'HALONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HALONS', 1);
INSERT INTO {schema}.keywords VALUES (6249, 'f6b97280-74d0-4233-bd17-f9f3d9dd21c2', 5189, 'HYDROCHLOROFLUOROCARBONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HYDROCHLOROFLUOROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (6250, 'ed5106fd-a73f-4203-87a3-9c9e7e85dcfc', 5189, 'HYDROFLUOROCARBONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HYDROFLUOROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (6251, '146a0a0b-1b42-41a6-b1f7-a27615b006a0', 5189, 'HYDROGEN CHLORIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HYDROGEN CHLORIDE', 1);
INSERT INTO {schema}.keywords VALUES (6252, 'ff9f8056-84d6-4fbc-abe0-9b6e82ed3f5e', 5189, 'HYDROGEN FLUORIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HYDROGEN FLUORIDE', 1);
INSERT INTO {schema}.keywords VALUES (6253, '27d63fe6-9970-46fd-9b22-a58e52efc57b', 5189, 'HYPOCHLOROUS ACID', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > HYPOCHLOROUS ACID', 1);
INSERT INTO {schema}.keywords VALUES (6254, '228c14d1-e9bf-4c25-a67b-92c99bc2a8b7', 5189, 'METHANOL', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > METHANOL', 1);
INSERT INTO {schema}.keywords VALUES (6255, '9b6ca807-7719-48aa-864d-ebb45a519ff8', 5189, 'METHYL BROMIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > METHYL BROMIDE', 1);
INSERT INTO {schema}.keywords VALUES (6256, '676248f0-75cd-466d-93f1-351440027c82', 5189, 'METHYL CHLORIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HALOCARBONS AND HALOGENS > METHYL CHLORIDE', 1);
INSERT INTO {schema}.keywords VALUES (6257, 'd8494f01-bcec-4232-ad78-fbd92c242e62', 5190, 'HYDROPEROXY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HYDROGEN COMPOUNDS > HYDROPEROXY', 1);
INSERT INTO {schema}.keywords VALUES (6258, '5b49fd6d-3759-4b61-8b04-8309f38b2f90', 5190, 'HYDROXYL', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HYDROGEN COMPOUNDS > HYDROXYL', 1);
INSERT INTO {schema}.keywords VALUES (6259, 'e073c9d4-5a61-436c-8890-2695c4e825eb', 5190, 'MOLECULAR HYDROGEN', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > HYDROGEN COMPOUNDS > MOLECULAR HYDROGEN', 1);
INSERT INTO {schema}.keywords VALUES (6260, '6a745a5e-829c-43f5-8d5a-6fb549e7b81b', 5191, 'AMMONIA', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > AMMONIA', 1);
INSERT INTO {schema}.keywords VALUES (6261, '6c5a6bbe-a12f-4030-9220-2013db36cf47', 5191, 'CLOUD-SCREENED TOTAL COLUMN NITROGEN DIOXIDE (NO2)', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > CLOUD-SCREENED TOTAL COLUMN NITROGEN DIOXIDE (NO2)', 1);
INSERT INTO {schema}.keywords VALUES (6262, 'd92ae6cc-989b-45b8-92d3-68008356c2b0', 5191, 'CLOUD-SCREENED TROPOSHERIC COLUMN NO2', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > CLOUD-SCREENED TROPOSHERIC COLUMN NO2', 1);
INSERT INTO {schema}.keywords VALUES (6641, 'af953f41-ab6c-4569-9762-c46ad07118da', 5358, 'DEMERSAL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > DEMERSAL', 1);
INSERT INTO {schema}.keywords VALUES (6263, '9ca9519d-c62b-42ea-8c91-cad06cfc59cb', 5191, 'DINITROGEN PENTOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > DINITROGEN PENTOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6264, '3c3b37d4-b934-4057-b8e4-438523ae88e3', 5191, 'MOLECULAR NITROGEN', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > MOLECULAR NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (6265, 'b7bbed0f-24a1-44d8-a10d-92541cd2c05b', 5191, 'NITRIC ACID', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > NITRIC ACID', 1);
INSERT INTO {schema}.keywords VALUES (6266, '82a60ed8-5414-4ce0-858c-c50b27b12bc8', 5191, 'NITRIC OXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > NITRIC OXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6267, 'f8e65155-27c1-483e-a9b8-85399897c3ae', 5191, 'NITROGEN DIOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > NITROGEN DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6268, 'e82ebd1c-8241-4ca0-95a9-a6e1432519cd', 5191, 'NITROGEN OXIDES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > NITROGEN OXIDES', 1);
INSERT INTO {schema}.keywords VALUES (6269, 'cf08917f-4cef-456f-99b0-57dc468da877', 5191, 'NITROUS OXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > NITROUS OXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6270, 'd44d3115-91d1-4655-9e6e-babfe39e1632', 5191, 'Peroxyacyl Nitrate', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > NITROGEN COMPOUNDS > Peroxyacyl Nitrate', 1);
INSERT INTO {schema}.keywords VALUES (6271, '61f4f3d0-7895-4cce-94e3-d249001d5ee8', 5192, 'MOLECULAR OXYGEN', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > OXYGEN COMPOUNDS > MOLECULAR OXYGEN', 1);
INSERT INTO {schema}.keywords VALUES (6272, 'dd316647-9043-40c3-9329-f22f9215fefa', 5192, 'OZONE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > OXYGEN COMPOUNDS > OZONE', 1);
INSERT INTO {schema}.keywords VALUES (6273, '0fd2b083-e65c-443b-9794-2c355ebac06b', 5193, 'PHOTOLYSIS RATES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > PHOTOCHEMISTRY > PHOTOLYSIS RATES', 1);
INSERT INTO {schema}.keywords VALUES (6274, 'bde65cfd-faec-4656-bc27-22dfe30912b7', 5194, 'CARBONYL SULFIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > SULFUR COMPOUNDS > CARBONYL SULFIDE', 1);
INSERT INTO {schema}.keywords VALUES (6275, '5d282de9-162a-4aeb-a48d-4569fbbd5205', 5194, 'DIMETHYL SULFIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > SULFUR COMPOUNDS > DIMETHYL SULFIDE', 1);
INSERT INTO {schema}.keywords VALUES (6276, '2ab4134d-1ac7-4421-a7a6-659a542aff4c', 5194, 'SULFATE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > SULFUR COMPOUNDS > SULFATE', 1);
INSERT INTO {schema}.keywords VALUES (6277, 'f5717312-c3ca-4492-a166-9f17c6d9b273', 5194, 'SULFUR DIOXIDE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > SULFUR COMPOUNDS > SULFUR DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6278, 'cc676fb2-cf17-413d-bb00-0b95d231f157', 5194, 'SULFUR OXIDES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC CHEMISTRY > SULFUR COMPOUNDS > SULFUR OXIDES', 1);
INSERT INTO {schema}.keywords VALUES (6279, 'e1af236f-ee88-4b10-8feb-70d9e09f90be', 5236, 'SHORTWAVE DOWNWARD IRRADIANCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC RADIATION > SOLAR IRRADIANCE > SHORTWAVE DOWNWARD IRRADIANCE', 1);
INSERT INTO {schema}.keywords VALUES (6280, '1d527151-57b2-49ed-9937-c1756a704ce9', 5243, 'COMMON SENSE CLIMATE INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > COMMON SENSE CLIMATE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6281, '2590519a-c2bb-448a-b2f3-d10aaa7e057c', 5243, 'COOLING DEGREE DAYS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > COOLING DEGREE DAYS', 1);
INSERT INTO {schema}.keywords VALUES (6282, '2329bf96-d927-4993-95f9-93551d787ad7', 5243, 'FREEZING INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > FREEZING INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6283, 'a43f9a02-769d-4343-8790-fa29a0507f44', 5243, 'GROWING DEGREE DAYS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > GROWING DEGREE DAYS', 1);
INSERT INTO {schema}.keywords VALUES (6284, '289ca013-0526-49e0-8b87-51513702e8f4', 5243, 'HEAT INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > HEAT INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6285, '349b4322-26ff-4b3c-90fb-b3b1afd20755', 5243, 'HEATING DEGREE DAYS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > HEATING DEGREE DAYS', 1);
INSERT INTO {schema}.keywords VALUES (6286, '37ae8d4e-fe97-43d3-b8ee-a597e4ebfe87', 5243, 'RESIDENTIAL ENERGY DEMAND TEMPERATURE INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > RESIDENTIAL ENERGY DEMAND TEMPERATURE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6287, '1c441454-851f-48e0-abb3-053ae44c0d4e', 5243, 'TEMPERATURE CONCENTRATION INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > TEMPERATURE CONCENTRATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6288, '746c49af-3e36-4f0a-b488-e024314d6cfa', 5243, 'THAWING INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > THAWING INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6289, 'd50d0685-f42f-4693-9458-eddb9ccf5704', 5243, 'WIND CHILL INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > ATMOSPHERIC TEMPERATURE INDICES > WIND CHILL INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6290, 'f634ab55-de40-4d0b-93bc-691bf5408ccb', 5244, 'AIR TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > AIR TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6291, 'e9c3b6ca-a534-4f3e-82de-b8b921e8f312', 5244, 'BOUNDARY LAYER TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > BOUNDARY LAYER TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6292, '6e923275-f9e3-4faf-8a7f-2c96f3d5a280', 5244, 'DEICED TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > DEICED TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6293, '0c28d9e4-c848-4628-9c00-45a540707b59', 5244, 'DEW POINT TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > DEW POINT TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6294, '5164162a-60eb-4c94-a0f0-2caaa3bb1754', 5244, 'MAXIMUM/MINIMUM TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > MAXIMUM/MINIMUM TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6295, '7a0bd777-be0d-43c8-80eb-5ac58f4832de', 5244, 'POTENTIAL TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > POTENTIAL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6296, '25fcdcb7-efd2-4d2f-ba57-92bbcc7ba69a', 5244, 'SKIN TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > SKIN TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6297, 'a1588b7d-7307-4543-9908-76d7877c4010', 5244, 'STATIC TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > STATIC TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6298, '7ca345d4-8e15-49ae-98a7-1c387f61ea85', 5244, 'TEMPERATURE ANOMALIES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > TEMPERATURE ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (6299, '449ad1fb-8010-43c7-b994-178a049d4cff', 5244, 'TEMPERATURE TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > TEMPERATURE TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (6300, 'fd19a3f1-8eeb-49ab-bcaf-e7b4b267d415', 5244, 'VIRTUAL TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > VIRTUAL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6301, '7f94b0e5-edc6-4724-bd84-404896e09afe', 5245, 'BOUNDARY LAYER TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > BOUNDARY LAYER TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6302, 'b3e6afd7-35a6-4cdb-a066-654a17168253', 5245, 'DEICED TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > DEICED TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6303, '76103e17-59c2-4458-972d-9ff9801e5d32', 5245, 'DEW POINT TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > DEW POINT TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6304, '1e76ccc7-2729-4de1-8c01-f295476ebb35', 5245, 'TEMPERATURE ANOMALIES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > TEMPERATURE ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (6305, '72304037-ce59-451a-beeb-4258f3db296a', 5245, 'VERTICAL PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > VERTICAL PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (6306, '3afb06fa-96b7-4bf4-a6b7-b5fa626afc04', 5245, 'VIRTUAL TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > VIRTUAL TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6307, '731beb11-9418-40ec-8f2c-c4b320e8231a', 5246, 'DEW POINT TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > DEW POINT TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6308, '427e5121-a142-41cb-a8e9-a70b7f98eb6a', 5246, 'HUMIDITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > HUMIDITY', 1);
INSERT INTO {schema}.keywords VALUES (6309, '871f5bee-ea8d-44c0-8740-9b0153fa6ea4', 5246, 'LAYERED PRECIPITABLE WATER', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > LAYERED PRECIPITABLE WATER', 1);
INSERT INTO {schema}.keywords VALUES (6310, '1a2332d9-fd69-4002-89a5-203d748a4e21', 5246, 'SATURATION VAPOR PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > SATURATION VAPOR PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (6311, 'df1a03f5-1cb3-4c63-870a-5a09debdf065', 5246, 'STABLE ISOTOPES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > STABLE ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6312, 'c3a4eb4a-4619-43cd-b890-b567d01324ea', 5246, 'TOTAL PRECIPITABLE WATER', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > TOTAL PRECIPITABLE WATER', 1);
INSERT INTO {schema}.keywords VALUES (6313, '433ea253-243d-42e4-bc61-f85eb7a73879', 5246, 'VAPOR PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > VAPOR PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (6314, '15029eb0-6342-4066-8ac9-c50f7dbfb392', 5246, 'WATER VAPOR', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > WATER VAPOR', 1);
INSERT INTO {schema}.keywords VALUES (6315, '07826fba-f581-4119-803e-14f3bfc2d14c', 5247, 'HUMIDITY INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICES > HUMIDITY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6316, '425486f4-7b04-4b77-af40-563fe6ed4167', 5247, 'WATER VAPOR TRANSPORT INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICES > WATER VAPOR TRANSPORT INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6317, 'd7fbbafe-fc73-4b63-9837-3d53d2370d9d', 5248, 'CONDENSATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > CONDENSATION', 1);
INSERT INTO {schema}.keywords VALUES (6318, 'b68ab978-6db6-49ee-84e2-5f37b461a998', 5248, 'EVAPORATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > EVAPORATION', 1);
INSERT INTO {schema}.keywords VALUES (6319, '26fc4850-7ba9-44d8-a156-5c623e17b72f', 5248, 'EVAPOTRANSPIRATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > EVAPOTRANSPIRATION', 1);
INSERT INTO {schema}.keywords VALUES (6320, 'd438f0a2-5a88-4d56-8bec-7c5e35249544', 5248, 'SUBLIMATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > SUBLIMATION', 1);
INSERT INTO {schema}.keywords VALUES (6321, '293cdec2-44b7-488c-ae04-0722f0a9e8b9', 5248, 'SUPERSATURATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > SUPERSATURATION', 1);
INSERT INTO {schema}.keywords VALUES (6322, '5d8b1280-62a6-48f5-a9f6-ed18023e3481', 5248, 'WATER VAPOR CONVERGENCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > WATER VAPOR CONVERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (6323, '957240ee-7ad8-4c62-9fd7-364371d247d7', 5248, 'WATER VAPOR DIVERGENCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > WATER VAPOR DIVERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (6324, '32a88fee-dfa9-4ef8-ab6d-cbc18426da53', 5248, 'WATER VAPOR FLUX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > WATER VAPOR FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6325, '5cd8b242-ac18-4d9f-85d5-eb551792d7e9', 5248, 'WATER VAPOR TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > WATER VAPOR TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (6326, '1b9a1873-c02f-4b6c-906e-5da8833354d4', 5249, 'VERTICALLY RESOLVED BACKSCATTER LIGHT', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROFILES > VERTICALLY RESOLVED BACKSCATTER LIGHT', 1);
INSERT INTO {schema}.keywords VALUES (6327, '04c30b59-88ea-4311-8353-8896d4eba83f', 5249, 'WATER VAPOR CONCENTRATION PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROFILES > WATER VAPOR CONCENTRATION PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (6328, '9fccc013-4a58-438a-b1e4-cd625aeb8204', 5249, 'WATER VAPOR MIXING RATIO PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROFILES > WATER VAPOR MIXING RATIO PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (6329, '72c180e6-b3f3-4f9a-8d04-23f0b10735af', 5250, 'DUST DEVILS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > DUST DEVILS', 1);
INSERT INTO {schema}.keywords VALUES (6330, '31fe9edf-ec85-446f-a476-4bd24ee59ae2', 5250, 'LAND BREEZES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > LAND BREEZES', 1);
INSERT INTO {schema}.keywords VALUES (6331, 'b73a2e6a-7a8b-443e-98f4-5a77f3a9691c', 5250, 'MICROBURSTS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > MICROBURSTS', 1);
INSERT INTO {schema}.keywords VALUES (6332, 'a1df1d50-dd2b-4944-bda5-0cf1127e2f49', 5250, 'OROGRAPHIC WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS', 1);
INSERT INTO {schema}.keywords VALUES (6333, '9cb8f1a4-5d2b-40d1-a7c3-c608bbe20a0b', 5250, 'SEA BREEZES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > SEA BREEZES', 1);
INSERT INTO {schema}.keywords VALUES (6334, '185b86e2-af35-42b2-b20d-f9ca6fdab493', 5251, 'STORM RELATIVE WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS > STORM RELATIVE WINDS', 1);
INSERT INTO {schema}.keywords VALUES (6335, '1e9bb112-5dc0-47a5-8c8a-b9cb07ece7c5', 5251, 'U/V WIND COMPONENTS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS > U/V WIND COMPONENTS', 1);
INSERT INTO {schema}.keywords VALUES (6336, 'c455fcc4-e27d-44bc-96c6-f7a7b31911ff', 5251, 'WIND DIRECTION TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS > WIND DIRECTION TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (6337, 'e987550e-d443-48eb-93eb-0bc47a62d4b4', 5251, 'WIND DIRECTION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS > WIND DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (6338, '69526601-5607-46e0-954a-251249de80fe', 5251, 'WIND SPEED TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS > WIND SPEED TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (6339, 'a92f49f3-e2ee-4ef4-b064-39311ffb95d3', 5251, 'WIND SPEED', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > SURFACE WINDS > WIND SPEED', 1);
INSERT INTO {schema}.keywords VALUES (6340, '8bb1dca3-9793-4120-b0ea-f27a5b81f259', 5252, 'BOUNDARY LAYER WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > BOUNDARY LAYER WINDS', 1);
INSERT INTO {schema}.keywords VALUES (6341, '385af5fe-ad73-4e04-9d51-675599fb0576', 5252, 'FLIGHT LEVEL WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > FLIGHT LEVEL WINDS', 1);
INSERT INTO {schema}.keywords VALUES (6342, 'b30a6184-0d59-41de-92f0-8876582ef045', 5252, 'STORM RELATIVE WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > STORM RELATIVE WINDS', 1);
INSERT INTO {schema}.keywords VALUES (6343, 'baa4b68a-96f9-4ab3-9a9f-3df1ee1d8ff0', 5252, 'U/V WIND COMPONENTS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > U/V WIND COMPONENTS', 1);
INSERT INTO {schema}.keywords VALUES (6344, '2a43bf40-7f23-4616-be1b-66940b7b7f4f', 5252, 'WIND DIRECTION TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > WIND DIRECTION TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (6345, '272ffe8a-2949-4b58-bb81-52cb1c879f4a', 5252, 'WIND DIRECTION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > WIND DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (6346, '1fe29b31-b9ff-4a6c-b474-09bd9502b5c5', 5252, 'WIND SPEED TENDENCY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > WIND SPEED TENDENCY', 1);
INSERT INTO {schema}.keywords VALUES (6347, '661591b3-6685-4de7-a2a4-9ce8ae505044', 5252, 'WIND SPEED', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > UPPER LEVEL WINDS > WIND SPEED', 1);
INSERT INTO {schema}.keywords VALUES (6348, 'ce546f0d-d2e1-43ed-b8e0-a9079c690c56', 5253, 'ADVECTION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > ADVECTION', 1);
INSERT INTO {schema}.keywords VALUES (6349, 'ebce0874-7635-4094-8ef4-968851873771', 5253, 'CONVECTION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > CONVECTION', 1);
INSERT INTO {schema}.keywords VALUES (6350, 'a2cc8e02-3207-4c40-af41-9656404bac0a', 5253, 'CONVERGENCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > CONVERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (6351, '5c58acfc-04ed-4cbf-8674-13c41b3e950d', 5253, 'DIVERGENCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > DIVERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (6352, '8a12ec59-c8c8-4512-b123-16bca93771b0', 5253, 'HORIZONTAL WIND VELOCITY/SPEED', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > HORIZONTAL WIND VELOCITY/SPEED', 1);
INSERT INTO {schema}.keywords VALUES (6353, '84780569-bef5-41fd-901f-828418e390dd', 5253, 'OROGRAPHIC LIFTING', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > OROGRAPHIC LIFTING', 1);
INSERT INTO {schema}.keywords VALUES (6354, 'eaeb5cdd-365f-4368-8e20-6defe111b3b4', 5253, 'STREAMFUNCTIONS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > STREAMFUNCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (6355, '226d05da-dd0b-4314-919a-0b259ce724b5', 5253, 'TURBULENCE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > TURBULENCE', 1);
INSERT INTO {schema}.keywords VALUES (6356, '841a7ac7-5981-4e93-895f-1b57c3d892a0', 5253, 'VERTICAL WIND VELOCITY/SPEED', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > VERTICAL WIND VELOCITY/SPEED', 1);
INSERT INTO {schema}.keywords VALUES (6357, '858a80ff-5aa4-4590-b2e2-e88a802a6ee4', 5253, 'VORTICITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > VORTICITY', 1);
INSERT INTO {schema}.keywords VALUES (6358, '05cf5b56-0f86-4819-b713-1272b97b06c5', 5253, 'WIND SHEAR', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > WIND SHEAR', 1);
INSERT INTO {schema}.keywords VALUES (6359, 'ef034881-8bf4-403f-a4ee-c68771769c93', 5253, 'WIND STRESS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > WIND STRESS', 1);
INSERT INTO {schema}.keywords VALUES (6360, '8251fedc-3910-4f18-9594-df2fbb9bb1d9', 5254, 'GOES WIND INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND INDICES > GOES WIND INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6361, '17e33fba-625b-40eb-b51d-902a89ca5747', 5254, 'QUASI-BIENNIAL OSCILLATION (QBO) ZONAL WIND INDEX', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND INDICES > QUASI-BIENNIAL OSCILLATION (QBO) ZONAL WIND INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6362, 'cd6f51f9-6ab4-4df4-a4d2-347e38fe80b6', 5255, 'LINE OF SIGHT WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND PROFILES > LINE OF SIGHT WINDS', 1);
INSERT INTO {schema}.keywords VALUES (6363, '4478e3ea-ac49-4ea3-bcb8-e6b4e2190266', 5255, 'VELOCITY AZIMUTH DISPLAY VERTICAL WIND PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND PROFILES > VELOCITY AZIMUTH DISPLAY VERTICAL WIND PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (6364, '5be35f50-a1ea-40c5-8e0d-579dad1b9143', 5255, 'WIND DIRECTION PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND PROFILES > WIND DIRECTION PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (6365, '1c93710e-cfaa-47c1-ba97-b2deb85620ca', 5255, 'WIND VELOCITY/SPEED PROFILES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND PROFILES > WIND VELOCITY/SPEED PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (6366, '49fd6f11-5682-4d27-8fc6-66bf3faadf39', 5257, 'HEAT FLUX', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > HEAT FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6367, '925f563d-908a-4671-b750-23d0f3e42310', 5257, 'MOISTURE FLUX', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > MOISTURE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6368, '5bac3ef6-5e30-4f14-a5dc-8065c7fcba55', 5257, 'RADIATIONAL COOLING', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > RADIATIONAL COOLING', 1);
INSERT INTO {schema}.keywords VALUES (6369, 'c7259da4-18dd-4196-91ff-a68087978349', 5257, 'RADIATIONAL DIVERGENCE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > RADIATIONAL DIVERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (6370, 'cfa49843-2d36-4709-8969-b176432adf78', 5257, 'THETA-E ENTRAINMENT', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > THETA-E ENTRAINMENT', 1);
INSERT INTO {schema}.keywords VALUES (6371, 'ba4a9964-8323-45df-a372-b4e2f3eef9e5', 5257, 'VORTEX STREET', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > VORTEX STREET', 1);
INSERT INTO {schema}.keywords VALUES (6372, 'a997c21b-ca61-4e78-8828-aa3e144976c3', 5257, 'WATER VAPOR TRANSPORT', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > WATER VAPOR TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (6373, 'ebbf8642-3da1-4401-a779-3e56550a029d', 5258, 'CLOUD CONDENSATION NUCLEI', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > CLOUD CONDENSATION NUCLEI', 1);
INSERT INTO {schema}.keywords VALUES (6374, '47812ef8-b64b-4988-9ae4-31f3581ae9a5', 5258, 'CLOUD DROPLET CONCENTRATION/SIZE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > CLOUD DROPLET CONCENTRATION/SIZE', 1);
INSERT INTO {schema}.keywords VALUES (6375, '05ac9d3e-bc44-41fa-ace0-c41bf3ebee97', 5258, 'CLOUD LIQUID WATER/ICE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > CLOUD LIQUID WATER/ICE', 1);
INSERT INTO {schema}.keywords VALUES (6376, '804fb334-1c74-4070-bd5f-848014a6e220', 5258, 'CLOUD MASS FLUX', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > CLOUD MASS FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6377, '4bc483b1-dd64-4e97-bfd3-c0e755df6308', 5258, 'CLOUD OPTICAL DEPTH/THICKNESS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > CLOUD OPTICAL DEPTH/THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (6378, 'b709d6fc-f0cf-47de-bdbb-1cd875b5f3ab', 5258, 'CLOUD PRECIPITABLE WATER', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > CLOUD PRECIPITABLE WATER', 1);
INSERT INTO {schema}.keywords VALUES (6379, '76bcb8e0-1c07-4783-9d15-3a22203f7849', 5258, 'COLLISION RATE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > COLLISION RATE', 1);
INSERT INTO {schema}.keywords VALUES (6380, '63effad4-4323-486d-a81b-e0bf3264e5c9', 5258, 'DROPLET GROWTH', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > DROPLET GROWTH', 1);
INSERT INTO {schema}.keywords VALUES (6381, '00d6fb2f-16d5-4949-afec-a1adbd600a58', 5258, 'PARTICLE SIZE DISTRIBUTION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > PARTICLE SIZE DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (6382, '8d66dbbe-886e-449d-bfd2-93fc8d357ccd', 5258, 'SEDIMENTATION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (6383, '4c737490-1486-418f-81f4-c50c47da117d', 5259, 'CLOUD ASYMMETRY', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD ASYMMETRY', 1);
INSERT INTO {schema}.keywords VALUES (6384, '1f0765e3-4ea3-42be-8ed5-3e26bdebb219', 5259, 'CLOUD BASE HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD BASE HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (6385, '17f212af-e782-4196-b467-060699ecf4ca', 5259, 'CLOUD BASE PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD BASE PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (6386, '5f5f4f7a-ea5f-40fe-ba73-8d5f7241e5fa', 5259, 'CLOUD BASE TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD BASE TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6387, '88dc0be1-7427-4a82-9fee-3b2bf84d002a', 5259, 'CLOUD CEILING', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD CEILING', 1);
INSERT INTO {schema}.keywords VALUES (6388, 'b296b688-0ff0-4212-9b30-30e9fe413709', 5259, 'CLOUD FRACTION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD FRACTION', 1);
INSERT INTO {schema}.keywords VALUES (6389, 'acb52274-6c0d-4241-a979-3fa3efca6702', 5259, 'CLOUD FREQUENCY', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (6390, '57292a97-19be-4fae-b2f7-9fa0a3629b53', 5259, 'CLOUD HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (6391, '2ca13dfa-c2b3-47de-8175-f0723151ef28', 5259, 'CLOUD MIDLAYER TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD MIDLAYER TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6392, '0893cf38-fe6e-4ebc-95f4-db7d24c874db', 5259, 'CLOUD TOP HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD TOP HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (6393, '1a217e7e-74fa-438e-b4bd-5ad574d92e9d', 5259, 'CLOUD TOP PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD TOP PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (6394, '4dc3fcab-a947-47b9-b9a1-acb2a23ee478', 5259, 'CLOUD TOP TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD TOP TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6395, 'f2902c27-0872-4ea4-98b9-706855bcd7a3', 5259, 'CLOUD VERTICAL DISTRIBUTION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD PROPERTIES > CLOUD VERTICAL DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (6396, 'd2e93932-0231-4b23-af2f-217c6315a95e', 5260, 'ABSORPTION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > ABSORPTION', 1);
INSERT INTO {schema}.keywords VALUES (6397, '576b5025-dc0e-4021-b8ff-6a7699a79b0c', 5260, 'CLOUD EMISSIVITY', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > CLOUD EMISSIVITY', 1);
INSERT INTO {schema}.keywords VALUES (6398, '345ab082-59ac-4649-9a2a-a3bef0d26a06', 5260, 'CLOUD RADIATIVE FORCING', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > CLOUD RADIATIVE FORCING', 1);
INSERT INTO {schema}.keywords VALUES (6399, '8a6572c3-676a-41dd-851f-836ac9f1f1d9', 5260, 'CLOUD REFLECTANCE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > CLOUD REFLECTANCE', 1);
INSERT INTO {schema}.keywords VALUES (6400, '4d5273ad-febb-47f6-bdb7-ededf9f9eb1e', 5260, 'DROPLET GROWTH', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > DROPLET GROWTH', 1);
INSERT INTO {schema}.keywords VALUES (6401, '4b12439a-45fc-42fa-ae19-535826f6247b', 5260, 'EMISSION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > EMISSION', 1);
INSERT INTO {schema}.keywords VALUES (6402, 'c830ad5e-ac31-41cf-b8e2-277fe457d76d', 5260, 'SCATTERING', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD RADIATIVE TRANSFER > SCATTERING', 1);
INSERT INTO {schema}.keywords VALUES (6403, '4074eb32-a3de-494f-a722-2deeaab76b33', 5262, 'CLOUD CLUSTERS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CLOUD CLUSTERS', 1);
INSERT INTO {schema}.keywords VALUES (6404, '7c4d5f8f-4809-4859-b379-3b8c379bc83c', 5262, 'CUMULONIMBUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULONIMBUS', 1);
INSERT INTO {schema}.keywords VALUES (6405, 'e1dff4d5-2e5b-46e7-9804-9de29fdb36d9', 5262, 'CUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (6406, '879cccd4-d375-40f6-8bee-6f58efd2dd61', 5262, 'DEEP CONVECTIVE CLOUD SYSTEMS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > DEEP CONVECTIVE CLOUD SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (6407, 'd13661da-d022-439a-bb27-dc2273f9dc88', 5262, 'MESOSCALE CONVECTIVE COMPLEX', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > MESOSCALE CONVECTIVE COMPLEX', 1);
INSERT INTO {schema}.keywords VALUES (6408, 'c3ee0a52-266b-45e4-adad-d0675699676b', 5262, 'PERCENT CONVECTIVE CLOUDS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > PERCENT CONVECTIVE CLOUDS', 1);
INSERT INTO {schema}.keywords VALUES (6409, 'ca7f5dbd-199e-4cc8-bc7b-550753ecbc93', 5262, 'PRECIPITATING CONVECTIVE CLOUD SYSTEMS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > PRECIPITATING CONVECTIVE CLOUD SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (6410, 'c6024258-d344-4cd2-932b-31e5c81a9c4b', 5262, 'SQUALL LINE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > SQUALL LINE', 1);
INSERT INTO {schema}.keywords VALUES (6411, 'fe2e0b6f-3d7d-489a-b093-86ed0d233385', 5262, 'TROPICAL OCEANIC CLOUD SYSTEMS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > TROPICAL OCEANIC CLOUD SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (6412, '939c0a66-0340-425b-999a-44a09046ec93', 5263, 'NOCTILUCENT CLOUDS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > MESOSPHERIC CLOUDS (OBSERVED/ANALYZED) > NOCTILUCENT CLOUDS', 1);
INSERT INTO {schema}.keywords VALUES (6413, '0a7f50ce-4968-46c8-86a6-23ea13c1830c', 5263, 'POLAR MESOSPHERIC CLOUDS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > MESOSPHERIC CLOUDS (OBSERVED/ANALYZED) > POLAR MESOSPHERIC CLOUDS', 1);
INSERT INTO {schema}.keywords VALUES (6414, '9d3d400c-ded2-4b3c-8d0c-5a76e25be033', 5264, 'POLAR STRATOSPHERIC CLOUDS/NACREOUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > STRATOSPHERIC CLOUDS (OBSERVED/ANALYZED) > POLAR STRATOSPHERIC CLOUDS/NACREOUS', 1);
INSERT INTO {schema}.keywords VALUES (6415, 'e59c154f-cdc9-4400-a0d2-af60df9e1b56', 5265, 'CIRROCUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > CIRROCUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (6416, 'bf271f69-3294-44d6-bfa8-a8f54468ca30', 5265, 'CIRROSTRATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > CIRROSTRATUS', 1);
INSERT INTO {schema}.keywords VALUES (6417, '8ce319a5-9b49-49e3-8981-3ce512c7efb0', 5265, 'CIRRUS/SYSTEMS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > CIRRUS/SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (6418, 'cf75769c-2430-4280-b9c2-ba384849a548', 5265, 'CONTRAILS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > CONTRAILS', 1);
INSERT INTO {schema}.keywords VALUES (6419, '31c8b1d1-1e46-4c40-a23f-0db327121eb7', 5265, 'PILEUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > PILEUS', 1);
INSERT INTO {schema}.keywords VALUES (6420, '94668478-3b79-4819-847e-b154bf241aa3', 5266, 'FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG', 1);
INSERT INTO {schema}.keywords VALUES (6421, 'a3d37438-644d-448e-95ea-991d79b3a0f3', 5266, 'NIMBOSTRATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > NIMBOSTRATUS', 1);
INSERT INTO {schema}.keywords VALUES (6422, '3375096a-7782-42e8-97d2-0febf63893e0', 5266, 'STRATOCUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (6423, '8945d3c7-1c39-4a8b-b954-2a84da8ecc88', 5266, 'STRATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATUS', 1);
INSERT INTO {schema}.keywords VALUES (6424, '01021105-60ed-479a-a35b-faa73e286264', 5267, 'ALTOCUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOCUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (6425, 'f58d0203-0070-422c-ab52-6ca8ffbb6362', 5267, 'ALTOSTRATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOSTRATUS', 1);
INSERT INTO {schema}.keywords VALUES (6426, 'c6e7ddb6-1f7c-4364-8fb4-aabd1f4dcab4', 5269, 'CENTRAL INDIAN PRECIPITATION INDEX', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > ATMOSPHERIC PRECIPITATION INDICES > CENTRAL INDIAN PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6427, '284738a2-4fcb-4eee-9ee7-5eac2378f46d', 5269, 'ENSO PRECIPITATION INDEX', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > ATMOSPHERIC PRECIPITATION INDICES > ENSO PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6428, '3b024dec-76c2-4995-a9ad-7e2bf4feda72', 5269, 'STANDARDIZED PRECIPITATION INDEX', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > ATMOSPHERIC PRECIPITATION INDICES > STANDARDIZED PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6429, 'dc9c73a3-689c-44b5-b8fe-a5229168193e', 5269, 'WEIGHTED ANOMALY STANDARDIZED PRECIPITATION INDEX', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > ATMOSPHERIC PRECIPITATION INDICES > WEIGHTED ANOMALY STANDARDIZED PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6430, '0ffab597-284f-4d1a-b026-a78a6604cec5', 5272, 'DRIZZLE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION > DRIZZLE', 1);
INSERT INTO {schema}.keywords VALUES (6431, '09d991ca-020a-4d20-910a-747ea683e1f8', 5272, 'LIQUID SURFACE PRECIPITATION RATE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION > LIQUID SURFACE PRECIPITATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (6432, '09a57dc7-3911-4a65-9f12-b819652b8671', 5272, 'RAIN', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION > RAIN', 1);
INSERT INTO {schema}.keywords VALUES (6433, 'feef8827-92a6-4d1d-b6a5-ecda38a32656', 5274, '12 HOUR PRECIPITATION AMOUNT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT > 12 HOUR PRECIPITATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (6434, '12250935-8f40-4279-aada-2f22cbef1459', 5274, '24 HOUR PRECIPITATION AMOUNT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT > 24 HOUR PRECIPITATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (6435, '039bbfd2-7653-4ba8-9003-b46d367c6038', 5274, '3 AND 6 HOUR PRECIPITATION AMOUNT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT > 3 AND 6 HOUR PRECIPITATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (6436, '2f0f103a-4fe9-429f-a783-ba1d6e6a446a', 5274, 'HOURLY PRECIPITATION AMOUNT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT > HOURLY PRECIPITATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (6437, '9985d211-1056-4a7a-a1c8-550923ea5a81', 5276, 'LATENT HEAT FLUX', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION PROFILES > LATENT HEAT FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6438, 'ce105b93-42b1-4692-a8ef-dc10792f26bf', 5276, 'MELTING LAYER HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION PROFILES > MELTING LAYER HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (6439, 'e3973025-f274-44f1-9ff5-0d2fd7e006c2', 5276, 'RAIN TYPE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION PROFILES > RAIN TYPE', 1);
INSERT INTO {schema}.keywords VALUES (6440, '6c8581e8-d49c-423e-9b38-3be406b64efa', 5279, 'CONVECTIVE SURFACE PRECIPITATION RATE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > CONVECTIVE SURFACE PRECIPITATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (6441, '7118d286-6629-48e5-931f-052cd347395e', 5279, 'HAIL', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > HAIL', 1);
INSERT INTO {schema}.keywords VALUES (6442, 'cac27b59-7810-4132-87b4-53108663584e', 5279, 'ICE PELLETS', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > ICE PELLETS', 1);
INSERT INTO {schema}.keywords VALUES (6443, 'b51b3708-a662-4cf1-bf13-e67f36b001c4', 5279, 'SNOW', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > SNOW', 1);
INSERT INTO {schema}.keywords VALUES (6444, '10277cb5-5a11-47a2-8578-3ac1c7152cd2', 5284, 'EXTRATROPICAL CYCLONE FREQUENCY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > EXTRATROPICAL CYCLONES > EXTRATROPICAL CYCLONE FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (6445, '2357d9ae-3376-4c4e-8533-6193bf177345', 5284, 'EXTRATROPICAL CYCLONE MOTION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > EXTRATROPICAL CYCLONES > EXTRATROPICAL CYCLONE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6446, '7de1c2c0-89c2-4841-b0b8-158224c8ad22', 5284, 'EXTRATROPICAL CYCLONE TRACK', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > EXTRATROPICAL CYCLONES > EXTRATROPICAL CYCLONE TRACK', 1);
INSERT INTO {schema}.keywords VALUES (6447, '2cc64007-a443-45d8-bf9d-c9fae69f4554', 5286, 'FIRST FREEZE/FROST DATE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > FIRST FREEZE/FROST DATE', 1);
INSERT INTO {schema}.keywords VALUES (6448, '53b7e7d6-2aeb-4636-bae1-c7cd92d3d541', 5286, 'FIRST FREEZE/FROST PROBABILITY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > FIRST FREEZE/FROST PROBABILITY', 1);
INSERT INTO {schema}.keywords VALUES (6449, '581d6ad6-2132-45cf-b6be-72341024587b', 5286, 'FIRST MODERATE FREEZE/FROST DATE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > FIRST MODERATE FREEZE/FROST DATE', 1);
INSERT INTO {schema}.keywords VALUES (6450, '5a0347ba-2684-4c4a-adc0-ddb63cbbde6b', 5286, 'FREEZE FREE PERIOD LENGTH', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > FREEZE FREE PERIOD LENGTH', 1);
INSERT INTO {schema}.keywords VALUES (6451, 'fc768468-62d4-40fa-8880-a773a855a496', 5286, 'LAST FREEZE/FROST DATE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > LAST FREEZE/FROST DATE', 1);
INSERT INTO {schema}.keywords VALUES (6452, '22b3623a-66c6-4616-8a6a-139ce119f672', 5286, 'LAST FREEZE/FROST PROBABILITY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > LAST FREEZE/FROST PROBABILITY', 1);
INSERT INTO {schema}.keywords VALUES (6453, 'a8cc5031-9c46-4a73-a999-68cdaec453a5', 5286, 'LAST MODERATE FREEZE/FROST DATE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > FREEZE/FROST > LAST MODERATE FREEZE/FROST DATE', 1);
INSERT INTO {schema}.keywords VALUES (6454, '0df15471-3175-44c0-aa8b-5178dfeb27a0', 5289, 'TOTAL FREEZING RAIN ACCUMULATION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > ICE STORMS > TOTAL FREEZING RAIN ACCUMULATION', 1);
INSERT INTO {schema}.keywords VALUES (6455, '3d4f9f5a-912b-4dc1-b1c5-cd0fd9bbd3d3', 5293, 'BLIZZARDS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SNOW STORMS > BLIZZARDS', 1);
INSERT INTO {schema}.keywords VALUES (6456, '12b7f57f-c295-4adf-97f5-43356f1270bf', 5293, 'LAKE EFFECT SNOW', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SNOW STORMS > LAKE EFFECT SNOW', 1);
INSERT INTO {schema}.keywords VALUES (6457, '99ad9306-0a99-402a-961f-acb9255cb113', 5294, 'SUBTROPICAL DEPRESSION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SUBTROPICAL CYCLONES > SUBTROPICAL DEPRESSION', 1);
INSERT INTO {schema}.keywords VALUES (6458, 'ca133c4d-9751-4b92-a1ec-013ef625ad7b', 5294, 'SUBTROPICAL STORM', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SUBTROPICAL CYCLONES > SUBTROPICAL STORM', 1);
INSERT INTO {schema}.keywords VALUES (6459, '00748b19-30cc-4d12-a7a3-0aa8b3be5a94', 5295, 'CONVECTIVE AVAILABLE POTENTIAL ENERGY (CAPE)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > Stability/Severe Weather Indices > CONVECTIVE AVAILABLE POTENTIAL ENERGY (CAPE)', 1);
INSERT INTO {schema}.keywords VALUES (6460, '1d8a8e42-0fc0-4ce1-a058-9fa961c9d4ac', 5295, 'K-index (KI)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > Stability/Severe Weather Indices > K-index (KI)', 1);
INSERT INTO {schema}.keywords VALUES (6461, 'f07365c3-a36e-4a28-8364-be3941fae000', 5295, 'LIFTED INDEX (LI)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > Stability/Severe Weather Indices > LIFTED INDEX (LI)', 1);
INSERT INTO {schema}.keywords VALUES (6462, 'bd0c62a2-5336-4b41-81e1-089ce118651a', 5295, 'SHOWALTER STABILITY INDEX (SI)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > Stability/Severe Weather Indices > SHOWALTER STABILITY INDEX (SI)', 1);
INSERT INTO {schema}.keywords VALUES (6463, '77bcf3f2-8d61-4b18-9e2a-439310197c83', 5295, 'TOTAL TOTALS INDEX (TT)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > Stability/Severe Weather Indices > TOTAL TOTALS INDEX (TT)', 1);
INSERT INTO {schema}.keywords VALUES (6464, '8fd6e7bc-df59-4637-b1e7-d6715fb3e8af', 5296, 'DESTRUCTION POTENTIAL INDEX', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > DESTRUCTION POTENTIAL INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6465, 'd866f0ba-c70a-4377-9f91-58ab402f6f8b', 5296, 'ENHANCED FUJITA SCALE RATING', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > ENHANCED FUJITA SCALE RATING', 1);
INSERT INTO {schema}.keywords VALUES (6466, 'd9969cf1-6a1f-4f37-91bf-c746aeba81c4', 5296, 'STORM SYSTEM MOTION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > STORM SYSTEM MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6467, 'd912e61f-6c95-449d-9bee-2eac2f599b8f', 5296, 'TORNADO CLIMATOLOGY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > TORNADO CLIMATOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (6468, '9a310897-86d4-4a31-9fe3-4b4ad45b3575', 5296, 'TORNADO DENSITY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > TORNADO DENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6469, 'de691f09-0ef3-4795-bac0-1ed15c3e7f8b', 5296, 'TORNADO FREQUENCY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > TORNADO FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (6470, 'b253d76b-d48a-4d7a-abbe-7d02f783176e', 5296, 'TORNADO PATH LENGTH', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > TORNADO PATH LENGTH', 1);
INSERT INTO {schema}.keywords VALUES (6471, '069ff99d-1455-4285-83d9-4f57fb0cb635', 5296, 'TORNADO PATH WIDTH', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > TORNADO PATH WIDTH', 1);
INSERT INTO {schema}.keywords VALUES (6472, 'c3354d3b-44a4-4b1a-b1dd-1243bd1640be', 5296, 'TORNADO VORTEX SIGNATURE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > TORNADO VORTEX SIGNATURE', 1);
INSERT INTO {schema}.keywords VALUES (6473, '2992d7d3-5ae6-4844-b0fa-4ad348e3a8c2', 5296, 'WATER SPOUT', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TORNADOES > WATER SPOUT', 1);
INSERT INTO {schema}.keywords VALUES (6474, '2ead8ea2-0357-4c95-9483-da8149855fd4', 5297, 'ACCUMULATED CYCLONE ENERGY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > ACCUMULATED CYCLONE ENERGY', 1);
INSERT INTO {schema}.keywords VALUES (6475, '923ab959-48ee-4db1-827a-3d672099e273', 5297, 'LANDFALL INTENSITY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > LANDFALL INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6476, 'ba286b68-a400-4c29-bd24-b8ca99967968', 5297, 'MAXIMUM 1-MINUTE SUSTAINED WIND', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM 1-MINUTE SUSTAINED WIND', 1);
INSERT INTO {schema}.keywords VALUES (6477, '106461af-377c-4dc0-bbd7-9769eba05321', 5297, 'MAXIMUM SURFACE WIND', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM SURFACE WIND', 1);
INSERT INTO {schema}.keywords VALUES (6478, '4b0e986f-5dce-48ca-8bad-794c97482553', 5297, 'MAXIMUM WIND GUST', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM WIND GUST', 1);
INSERT INTO {schema}.keywords VALUES (6479, '38cefcb2-f5d6-4917-a87b-7cfba482e30d', 5297, 'MINIMUM CENTRAL PRESSURE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MINIMUM CENTRAL PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (6480, 'c17617a1-5d2b-426f-bfe0-d8c4d4b5cfad', 5297, 'PEAK INTENSITY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > PEAK INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6481, '27847732-2a5a-4094-9ba5-3c56ae897f87', 5297, 'SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 1)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 1)', 1);
INSERT INTO {schema}.keywords VALUES (6482, 'e282c375-ed1a-465b-b960-aa49118307ea', 5297, 'SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 2)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 2)', 1);
INSERT INTO {schema}.keywords VALUES (6483, '530dfe77-5740-49e8-b994-9a6f82cf4adb', 5297, 'SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 3)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 3)', 1);
INSERT INTO {schema}.keywords VALUES (6484, 'e691d1ab-6d20-4ad6-bea6-46587e94c4ff', 5297, 'SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 4)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 4)', 1);
INSERT INTO {schema}.keywords VALUES (6485, '978dd843-3a96-4d52-a7d6-31642503c267', 5297, 'SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 5)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 5)', 1);
INSERT INTO {schema}.keywords VALUES (6486, 'eec57358-8166-443e-b595-cb831911cd42', 5297, 'TROPICAL CYCLONE FORCE WIND EXTENT', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE FORCE WIND EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (6487, '9b5474eb-2dc8-4a8e-90b4-872f9fda80d9', 5301, 'MYRIAPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > MYRIAPODS', 1);
INSERT INTO {schema}.keywords VALUES (6488, 'cda34c9c-e59a-4dfb-9d2d-b8317e4b7f27', 5297, 'TROPICAL CYCLONE MOTION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6489, '104ed5fa-f65a-442e-992c-88a4fe74a66c', 5297, 'TROPICAL CYCLONE RADIUS', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE RADIUS', 1);
INSERT INTO {schema}.keywords VALUES (6490, '10a9bb22-9119-4409-84c1-7c97ef31b1a1', 5297, 'TROPICAL CYCLONE TRACK', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE TRACK', 1);
INSERT INTO {schema}.keywords VALUES (6491, '74aac882-80ae-4ecd-9585-c541cd7a10fc', 5297, 'TROPICAL DEPRESSION FREQUENCY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL DEPRESSION FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (6492, '03e9cfd2-631c-42e6-b25c-b75f57e4ebb8', 5297, 'TROPICAL DEPRESSION MOTION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL DEPRESSION MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6493, '75c369df-2b9f-4328-8b1f-325d83ffb4cf', 5297, 'TROPICAL DEPRESSION TRACK', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL DEPRESSION TRACK', 1);
INSERT INTO {schema}.keywords VALUES (6494, '23c94a4c-db57-4d57-b24f-4dba24aa3cc6', 5297, 'TROPICAL STORM FORCE WIND EXTENT', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL STORM FORCE WIND EXTENT', 1);
INSERT INTO {schema}.keywords VALUES (6495, 'de9ffa22-76e3-469c-926b-2dee007702d0', 5297, 'TROPICAL STORM FREQUENCY', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL STORM FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (6496, 'ce15b57a-9b1b-4bb7-805e-b13defd9a851', 5297, 'TROPICAL STORM MOTION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL STORM MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6497, '2a4bc557-ee60-4446-920a-25632f5b8b4d', 5297, 'TROPICAL STORM TRACK', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL STORM TRACK', 1);
INSERT INTO {schema}.keywords VALUES (6498, '4e845edf-3635-4665-9d9d-d7186c151cda', 5298, 'DERECHO', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > WIND STORMS > DERECHO', 1);
INSERT INTO {schema}.keywords VALUES (6499, '530ca9b8-50f3-4bd6-82d4-c49fa688a977', 5298, 'GALE', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > WIND STORMS > GALE', 1);
INSERT INTO {schema}.keywords VALUES (6500, '9da19ae9-799f-4885-8fb8-564ca803639a', 5298, 'MICROBURST', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > WIND STORMS > MICROBURST', 1);
INSERT INTO {schema}.keywords VALUES (6501, '27275638-546e-4181-b15c-ddc3524de3d5', 5298, 'SQUALL', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > WIND STORMS > SQUALL', 1);
INSERT INTO {schema}.keywords VALUES (6502, 'b32ca9df-f981-4696-bf97-c190175e47b7', 5301, 'CHELICERATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CHELICERATES', 1);
INSERT INTO {schema}.keywords VALUES (6503, 'f2044dcf-40da-4fcc-97ab-914343d885a5', 5301, 'CRUSTACEANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS', 1);
INSERT INTO {schema}.keywords VALUES (6504, '38e40180-1a2a-40a9-a030-04775dabbabb', 5301, 'HEXAPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > HEXAPODS', 1);
INSERT INTO {schema}.keywords VALUES (6505, 'ad557b31-fc70-4519-a8e4-3a5daf05f774', 5304, 'ANTHOZOANS/HEXACORALS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/HEXACORALS', 1);
INSERT INTO {schema}.keywords VALUES (6506, 'cbdf4f94-efc6-4965-a329-5df989a9a211', 5304, 'ANTHOZOANS/OCTOCORALS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/OCTOCORALS', 1);
INSERT INTO {schema}.keywords VALUES (6507, 'c2c891c2-aa15-40b8-bfae-f02f42d0c739', 5304, 'HYDROZOANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > HYDROZOANS', 1);
INSERT INTO {schema}.keywords VALUES (6508, 'cb628a66-a10b-4ef1-9261-7ce63a9439dc', 5304, 'JELLYFISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > JELLYFISHES', 1);
INSERT INTO {schema}.keywords VALUES (6509, '4c653917-a5d8-4572-a509-572e9fd2c63d', 5306, 'BRITTLE/BASKET STARS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ECHINODERMS > BRITTLE/BASKET STARS', 1);
INSERT INTO {schema}.keywords VALUES (6510, 'ec994afa-ecd4-4d25-9e8b-335cd982755c', 5306, 'SEA STARS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ECHINODERMS > SEA STARS', 1);
INSERT INTO {schema}.keywords VALUES (6511, '6972b6bd-2f7e-460d-b12a-914b7d1e029c', 5306, 'SEA URCHINS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ECHINODERMS > SEA URCHINS', 1);
INSERT INTO {schema}.keywords VALUES (6512, '2b24db47-ecf4-4559-aaff-aef150188b03', 5313, 'APLACOPHORANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > APLACOPHORANS', 1);
INSERT INTO {schema}.keywords VALUES (6513, '7da8400b-e2cf-4ab1-b2f0-5bc4b21c23b3', 5313, 'BIVALVES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > BIVALVES', 1);
INSERT INTO {schema}.keywords VALUES (6514, '955fae6f-6aae-460a-a952-1c0c30f5151e', 5313, 'CEPHALOPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > CEPHALOPODS', 1);
INSERT INTO {schema}.keywords VALUES (6515, 'e65cfeec-0da2-40d8-b80d-1c74d1a498fc', 5313, 'CHITONS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > CHITONS', 1);
INSERT INTO {schema}.keywords VALUES (6516, 'd2db293d-2ed7-4831-9794-a2cf903e4d4d', 5313, 'GASTROPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > GASTROPODS', 1);
INSERT INTO {schema}.keywords VALUES (6517, 'ea2c5c8f-6b57-4fcc-8c01-53343c706cef', 5320, 'BRISTLE WORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > SEGMENTED WORMS (ANNELIDS) > BRISTLE WORMS', 1);
INSERT INTO {schema}.keywords VALUES (6518, '517e2978-223e-42a2-b889-9c60f7099859', 5320, 'EARTHWORMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > SEGMENTED WORMS (ANNELIDS) > EARTHWORMS', 1);
INSERT INTO {schema}.keywords VALUES (6519, 'b845369b-bf6b-47a6-b56a-a11438604a39', 5320, 'LEECHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > SEGMENTED WORMS (ANNELIDS) > LEECHES', 1);
INSERT INTO {schema}.keywords VALUES (6520, '8b1af14c-25f1-42bb-bba9-24ee5cee4e43', 5323, 'LARVACEANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > TUNICATES > LARVACEANS', 1);
INSERT INTO {schema}.keywords VALUES (6521, 'b63e1a64-661a-4228-8453-248076f612b7', 5323, 'SALPS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > TUNICATES > SALPS', 1);
INSERT INTO {schema}.keywords VALUES (6522, '9987f02e-2f2f-48ed-95ac-02514f02d7b0', 5323, 'SEA SQUIRTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > TUNICATES > SEA SQUIRTS', 1);
INSERT INTO {schema}.keywords VALUES (6523, 'db49ac33-d70a-488c-a1f2-9aa3706ba707', 5326, 'FROGS/TOADS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > AMPHIBIANS > FROGS/TOADS', 1);
INSERT INTO {schema}.keywords VALUES (6524, '1ac84a15-6f6b-48e0-b7ba-796813e5ff2c', 5326, 'SALAMANDERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > AMPHIBIANS > SALAMANDERS', 1);
INSERT INTO {schema}.keywords VALUES (6525, 'b4e28ec2-c2a0-4eb4-9544-8eb227903d47', 5327, 'ALBATROSSES/PETRELS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > ALBATROSSES/PETRELS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (6526, '39e33722-56b0-4928-a032-d4832f7136cc', 5327, 'CRANES AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > CRANES AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (6527, 'c310aa65-810b-4e36-9689-d37b1154fa1b', 5327, 'DUCKS/GEESE/SWANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > DUCKS/GEESE/SWANS', 1);
INSERT INTO {schema}.keywords VALUES (6528, '3f51c987-e49b-4988-a05c-d2d9da82dd22', 5327, 'EAGLES/FALCONS/HAWKS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > EAGLES/FALCONS/HAWKS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (6529, '050ce2a5-f895-4600-a0a1-eb0e3adb09e1', 5327, 'GREBES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > GREBES', 1);
INSERT INTO {schema}.keywords VALUES (6530, 'af67dee1-7c50-4e73-8db8-b1f421df67fb', 5327, 'HERONS/EGRETS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > HERONS/EGRETS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (6531, '70464ef6-7702-4b8d-bacc-50f44b0d6100', 5327, 'IBISES/SPOONBILLS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > IBISES/SPOONBILLS', 1);
INSERT INTO {schema}.keywords VALUES (6532, '4342be4c-fd26-4c02-b09f-e35ea4f34575', 5327, 'LOONS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > LOONS', 1);
INSERT INTO {schema}.keywords VALUES (6533, '3a591a70-def2-4625-bf26-1151724dbcb4', 5327, 'PELICANS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > PELICANS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (6534, 'a463163e-8e86-4086-8b10-8fd6a95fca4a', 5327, 'PENGUINS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > PENGUINS', 1);
INSERT INTO {schema}.keywords VALUES (6535, 'c8186508-c5dd-4282-86d2-b217643a87d8', 5327, 'PERCHING BIRDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > PERCHING BIRDS', 1);
INSERT INTO {schema}.keywords VALUES (6536, '519a7291-55a2-44a4-8f01-ca7742ff69cc', 5327, 'SANDPIPERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > SANDPIPERS', 1);
INSERT INTO {schema}.keywords VALUES (6537, 'e8f25820-dd06-4d8d-9548-dcc30a871982', 5327, 'WADERS/GULLS/AUKS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > BIRDS > WADERS/GULLS/AUKS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (6538, 'e5404ad9-95bf-4851-9dbb-fecf7dc1e905', 5328, 'LAMPREYS/HAGFISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > LAMPREYS/HAGFISHES', 1);
INSERT INTO {schema}.keywords VALUES (6539, 'c69cde73-7bd9-489b-a20b-bd23cfb82d92', 5328, 'RAY-FINNED FISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES', 1);
INSERT INTO {schema}.keywords VALUES (6540, 'ed019e00-9b0a-4bdc-89aa-606cc929bd9f', 5328, 'SHARKS/RAYS/CHIMAERAS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > SHARKS/RAYS/CHIMAERAS', 1);
INSERT INTO {schema}.keywords VALUES (6541, '9db9cb8c-7d18-4922-990c-b610d22356eb', 5329, 'BATS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > BATS', 1);
INSERT INTO {schema}.keywords VALUES (6542, '7a00c50c-827c-4012-9afe-20972e6a00c6', 5329, 'CARNIVORES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CARNIVORES', 1);
INSERT INTO {schema}.keywords VALUES (6543, '7f066677-c0f8-4bb1-91de-13954494a927', 5329, 'CETACEANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CETACEANS', 1);
INSERT INTO {schema}.keywords VALUES (6544, 'af5fb4da-260e-4e4e-a332-36dfd5084e5d', 5329, 'DUGONGS/MANATEES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > DUGONGS/MANATEES', 1);
INSERT INTO {schema}.keywords VALUES (6545, 'de9598de-24cc-4f87-b3df-d9f3d4717d33', 5329, 'ELEPHANTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > ELEPHANTS', 1);
INSERT INTO {schema}.keywords VALUES (6546, '7b0bc104-eed1-4bc1-b12b-3cf9add700da', 5329, 'EVEN-TOED UNGULATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > EVEN-TOED UNGULATES', 1);
INSERT INTO {schema}.keywords VALUES (6547, 'fae29067-5d65-455a-a515-b1ac52881285', 5329, 'RODENTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > RODENTS', 1);
INSERT INTO {schema}.keywords VALUES (6548, '3f1803fa-3ada-4762-96e4-28966dfdcc83', 5330, 'ALLIGATORS/CROCODILES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > REPTILES > ALLIGATORS/CROCODILES', 1);
INSERT INTO {schema}.keywords VALUES (6549, '7dce336b-8596-45f0-bc76-f82b26e1405f', 5330, 'LIZARDS/SNAKES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > REPTILES > LIZARDS/SNAKES', 1);
INSERT INTO {schema}.keywords VALUES (6550, '2037d286-6285-49df-aeb4-6e429b18d595', 5330, 'TURTLES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > REPTILES > TURTLES', 1);
INSERT INTO {schema}.keywords VALUES (6551, 'f4211da2-9eaa-4bb3-86b1-c4595e9f2971', 5336, 'DICOTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > ANGIOSPERMS (FLOWERING PLANTS) > DICOTS', 1);
INSERT INTO {schema}.keywords VALUES (6552, 'b2957a8b-4c60-42aa-ac1c-56a88421702b', 5336, 'MONOCOTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > ANGIOSPERMS (FLOWERING PLANTS) > MONOCOTS', 1);
INSERT INTO {schema}.keywords VALUES (6553, 'c5ae3a71-d144-4b91-9cf0-e3cb27ce718f', 5337, 'CLUB MOSSES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > FERNS AND ALLIES > CLUB MOSSES', 1);
INSERT INTO {schema}.keywords VALUES (6555, '5f5bbb69-57ea-4d8e-bd89-20478bc765d1', 5337, 'HORSETAILS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > FERNS AND ALLIES > HORSETAILS', 1);
INSERT INTO {schema}.keywords VALUES (6556, 'e76b3409-8be4-422b-8002-85bbfa846994', 5337, 'WHISK FERNS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > FERNS AND ALLIES > WHISK FERNS', 1);
INSERT INTO {schema}.keywords VALUES (6557, 'b26769a1-f023-4ab1-bc21-78ef2a5fd185', 5338, 'CONIFERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > GYMNOSPERMS > CONIFERS', 1);
INSERT INTO {schema}.keywords VALUES (6558, '2e7a8b01-ee3b-44e2-95ef-cf4603b05204', 5338, 'CYCADS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > GYMNOSPERMS > CYCADS', 1);
INSERT INTO {schema}.keywords VALUES (6559, 'fdccf097-a2e1-4494-ad47-1c96a4d0d99a', 5338, 'GINKGO', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > GYMNOSPERMS > GINKGO', 1);
INSERT INTO {schema}.keywords VALUES (6560, 'f0077bce-436c-432c-8d28-eb8d9cf2849b', 5338, 'GNETOPS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > GYMNOSPERMS > GNETOPS', 1);
INSERT INTO {schema}.keywords VALUES (6561, '36e07e20-ce85-4418-83fd-6d718e55f370', 5339, 'BROWN ALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MACROALGAE (SEAWEEDS) > BROWN ALGAE', 1);
INSERT INTO {schema}.keywords VALUES (6562, '4fb63f34-f934-4a20-9d6e-ee57424f2391', 5339, 'GREEN ALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MACROALGAE (SEAWEEDS) > GREEN ALGAE', 1);
INSERT INTO {schema}.keywords VALUES (6563, '63015ca3-455b-4d91-b047-ff83a95d6bbe', 5339, 'RED ALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MACROALGAE (SEAWEEDS) > RED ALGAE', 1);
INSERT INTO {schema}.keywords VALUES (6564, '502c9a41-ab95-4ae7-8e92-d1024b094f36', 5340, 'CRYPTOMONADS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MICROALGAE > CRYPTOMONADS', 1);
INSERT INTO {schema}.keywords VALUES (6565, 'a14cfe48-9554-4e7c-9a2b-bf72834eafba', 5340, 'DIATOMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MICROALGAE > DIATOMS', 1);
INSERT INTO {schema}.keywords VALUES (6566, 'b29cf79c-92a9-4160-aa8a-6917da79e298', 5340, 'DINOFLAGELLATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MICROALGAE > DINOFLAGELLATES', 1);
INSERT INTO {schema}.keywords VALUES (6567, '0a454dc9-de56-4682-8688-36ffd547d42f', 5340, 'HAPTOPHYTES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MICROALGAE > HAPTOPHYTES', 1);
INSERT INTO {schema}.keywords VALUES (6568, '949f8a84-185a-42a0-89dc-48534b46f309', 5342, 'AMOEBAS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > AMOEBOIDS > AMOEBAS', 1);
INSERT INTO {schema}.keywords VALUES (6569, 'd9750f06-3784-4058-941f-40289c8d9d8b', 5342, 'FORAMINIFERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > AMOEBOIDS > FORAMINIFERS', 1);
INSERT INTO {schema}.keywords VALUES (6570, '9becd489-f8fb-4dbb-b920-6c8399100515', 5342, 'RADIOLARIANS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > AMOEBOIDS > RADIOLARIANS', 1);
INSERT INTO {schema}.keywords VALUES (6571, '802614f5-e178-4e5d-be64-a7e09ea736cb', 5345, 'CRYPTOMONADS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > FLAGELLATES > CRYPTOMONADS', 1);
INSERT INTO {schema}.keywords VALUES (6572, 'a0176a92-3eff-4278-b8db-02148c990302', 5345, 'DINOFLAGELLATES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > FLAGELLATES > DINOFLAGELLATES', 1);
INSERT INTO {schema}.keywords VALUES (6573, 'dc7d2770-86a3-463c-a92b-c61516ffb32a', 5345, 'HAPTOPHYTES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > FLAGELLATES > HAPTOPHYTES', 1);
INSERT INTO {schema}.keywords VALUES (6574, 'e2d18940-adf6-4bdd-ab4f-fe86e68278f4', 5346, 'BROWN ALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > MACROALGAE (SEAWEEDS) > BROWN ALGAE', 1);
INSERT INTO {schema}.keywords VALUES (6575, '76557903-2ed7-4f0e-b8fc-df02798d724e', 5346, 'GREEN ALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > MACROALGAE (SEAWEEDS) > GREEN ALGAE', 1);
INSERT INTO {schema}.keywords VALUES (6576, 'b9e718df-0a3a-46b6-a34f-4960e9449660', 5346, 'RED ALGAE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > MACROALGAE (SEAWEEDS) > RED ALGAE', 1);
INSERT INTO {schema}.keywords VALUES (6577, '28dc7895-3365-4bab-9946-3b247f4137b0', 5347, 'PHYTOPLANKTON', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > PLANKTON > PHYTOPLANKTON', 1);
INSERT INTO {schema}.keywords VALUES (6578, '4e366444-01ea-4517-9d93-56f55ddf41b7', 5350, 'BIODIVERSITY FUNCTIONS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > BIODIVERSITY FUNCTIONS', 1);
INSERT INTO {schema}.keywords VALUES (6579, 'f42c849c-7113-4c69-a01e-52ebc5e7b44d', 5350, 'COMMUNITY STRUCTURE', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > COMMUNITY STRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (6580, 'c09be13f-5dc2-4460-9055-1a7232aa41ae', 5350, 'GRAZING DYNAMICS/PLANT ECOLOGY', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > GRAZING DYNAMICS/PLANT ECOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (6581, 'd3c5e3e3-97bf-4e74-9f8d-523dce5f9270', 5350, 'INDICATOR SPECIES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > INDICATOR SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (6582, '7bfdbe8d-3945-4678-a90b-d2251f973955', 5350, 'INVASIVE SPECIES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > INVASIVE SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (6583, 'ad7abcce-b88e-46c7-be44-496d60c88f25', 5350, 'PLANT SUCCESSION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > PLANT SUCCESSION', 1);
INSERT INTO {schema}.keywords VALUES (6584, '1a2a8cf8-6d7d-4ad6-b40c-4d9f7fed493f', 5350, 'SPECIES DOMINANCE INDICES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > SPECIES DOMINANCE INDICES', 1);
INSERT INTO {schema}.keywords VALUES (6585, 'b98b8823-3e95-4383-bbb0-414ee8832112', 5350, 'SPECIES RECRUITMENT', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > COMMUNITY DYNAMICS > SPECIES RECRUITMENT', 1);
INSERT INTO {schema}.keywords VALUES (6586, '9015e65f-bbae-4855-a4b6-1bfa601752bd', 5351, 'BIOGEOCHEMICAL CYCLES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > BIOGEOCHEMICAL CYCLES', 1);
INSERT INTO {schema}.keywords VALUES (6587, 'a0eb9268-0333-4442-9bc6-efbe338d9836', 5351, 'BIOMASS DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > BIOMASS DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (6588, '7f8a1613-67b0-4d6a-a9ad-89097c27a052', 5351, 'CHEMOSYNTHESIS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > CHEMOSYNTHESIS', 1);
INSERT INTO {schema}.keywords VALUES (6589, 'd6464d91-2373-456f-85a7-a5019bdb1076', 5351, 'CONSUMPTION RATES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > CONSUMPTION RATES', 1);
INSERT INTO {schema}.keywords VALUES (6590, '560eac7e-d172-4a31-a659-a3e99d5f61ac', 5351, 'DECOMPOSITION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > DECOMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (6591, '16e5beb3-e3ae-49a4-8fac-302fbbcdd39c', 5351, 'EXCRETION RATES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > EXCRETION RATES', 1);
INSERT INTO {schema}.keywords VALUES (6592, '4a55497b-8e07-431a-9af9-fece001f1dd7', 5351, 'FOOD-WEB DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > FOOD-WEB DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (6593, '7a33a978-8ef6-4313-b489-c06cfc6d9cec', 5351, 'NUTRIENT CYCLING', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > NUTRIENT CYCLING', 1);
INSERT INTO {schema}.keywords VALUES (6594, '5fb90409-f9b5-46bc-8a6a-7c42e250c7c3', 5351, 'OXYGEN DEMAND', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > OXYGEN DEMAND', 1);
INSERT INTO {schema}.keywords VALUES (6595, '07b53dde-6fea-4662-9d03-ccfd617ca710', 5351, 'PHOTOSYNTHESIS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > PHOTOSYNTHESIS', 1);
INSERT INTO {schema}.keywords VALUES (6596, 'ecd03762-df34-49b7-91f2-d8a51acd270e', 5351, 'PRIMARY PRODUCTION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > PRIMARY PRODUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6597, '29a64468-46a8-4dbc-955d-80b7b4cf9aaf', 5351, 'RESPIRATION RATE', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > RESPIRATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (6598, '200e9b2d-0201-4f52-9a5e-6dc6c4668ec9', 5351, 'SECONDARY PRODUCTION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > SECONDARY PRODUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6599, 'bd46a0bf-5c06-48af-a6c9-022417b1fffd', 5351, 'TROPHIC DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOSYSTEM FUNCTIONS > TROPHIC DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (6600, '8e89d525-161c-4e02-8ef8-4868e0cf8c57', 5352, 'BIOAVAILABILITY', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOTOXICOLOGY > BIOAVAILABILITY', 1);
INSERT INTO {schema}.keywords VALUES (6601, 'a54dbc4f-c136-4648-9797-db00e62fe22b', 5352, 'SPECIES BIOACCUMULATION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOTOXICOLOGY > SPECIES BIOACCUMULATION', 1);
INSERT INTO {schema}.keywords VALUES (6602, '5518feb6-93a8-46fd-9e9a-25be3a832d6d', 5352, 'TOXICITY LEVELS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > ECOTOXICOLOGY > TOXICITY LEVELS', 1);
INSERT INTO {schema}.keywords VALUES (6603, '2a0a6319-80c4-49fd-8a40-553175aa8637', 5353, 'FIRE DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > FIRE ECOLOGY > FIRE DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (6604, '2bfd42f1-0453-4c33-a21e-74df3ad64813', 5353, 'FIRE MODELS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > FIRE ECOLOGY > FIRE MODELS', 1);
INSERT INTO {schema}.keywords VALUES (6605, 'e6f1ee58-fb71-42dd-b071-c1637da7e51f', 5353, 'FIRE OCCURRENCE', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > FIRE ECOLOGY > FIRE OCCURRENCE', 1);
INSERT INTO {schema}.keywords VALUES (6606, '5efc3bc4-6403-4e33-ba23-5418fbc026b1', 5354, 'BIOLUMINESCENCE', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > BIOLUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (6607, 'f75f9011-903e-4757-9fcf-fefac2599b59', 5354, 'DIURNAL MOVEMENTS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > DIURNAL MOVEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6608, 'f930dcf2-ddb4-4242-9079-9c8d5ceeaa35', 5354, 'ENDANGERED SPECIES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > ENDANGERED SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (6609, 'cf3d1728-7606-4561-a0dd-116b4dbec21f', 5354, 'EVOLUTIONARY ADAPTATION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > EVOLUTIONARY ADAPTATION', 1);
INSERT INTO {schema}.keywords VALUES (6610, 'ddeb06af-5c36-428d-801e-e9f9a60ce429', 5354, 'EXOTIC SPECIES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > EXOTIC SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (6611, 'f27f7bf4-53fd-41bb-8e7e-b771f48f3bcc', 5354, 'EXTINCTION RATE', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > EXTINCTION RATE', 1);
INSERT INTO {schema}.keywords VALUES (6612, 'bcb43cdf-294e-463c-a114-a55bd54f0b48', 5354, 'GRAZING DYNAMICS/PLANT HERBIVORY', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > GRAZING DYNAMICS/PLANT HERBIVORY', 1);
INSERT INTO {schema}.keywords VALUES (6613, 'dfc20833-d79a-4976-91fd-db9f3efc7822', 5354, 'HIBERNATION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > HIBERNATION', 1);
INSERT INTO {schema}.keywords VALUES (6614, 'cd9f44da-b3b4-4f9c-a21f-89b59a29b235', 5354, 'INDIGENOUS/NATIVE SPECIES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > INDIGENOUS/NATIVE SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (6615, 'a4ed794f-d7b6-4e53-b565-3b86fe584ba3', 5354, 'MIGRATORY RATES/ROUTES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > MIGRATORY RATES/ROUTES', 1);
INSERT INTO {schema}.keywords VALUES (6616, '87601d17-faca-42c2-a431-61cf67933095', 5354, 'MUTATION RATES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > MUTATION RATES', 1);
INSERT INTO {schema}.keywords VALUES (6617, '003466f4-9ee7-4d3b-81ff-2013add292e2', 5354, 'MUTUALISM', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > MUTUALISM', 1);
INSERT INTO {schema}.keywords VALUES (6618, '80ae5fdc-c312-4fa1-bf7d-60346529976d', 5354, 'NATURAL SELECTION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > NATURAL SELECTION', 1);
INSERT INTO {schema}.keywords VALUES (6619, '51f3e55c-b694-4028-86fe-604a52dc794f', 5354, 'PARASITISM', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > PARASITISM', 1);
INSERT INTO {schema}.keywords VALUES (6620, '45950ee6-adc2-4f39-96a7-c00bacd1ba9e', 5354, 'POLLINATOR SPECIES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > POLLINATOR SPECIES', 1);
INSERT INTO {schema}.keywords VALUES (6621, 'ad3a5f4f-4624-4a08-b875-6723c2615e90', 5354, 'POPULATION DYNAMICS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > POPULATION DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (6622, 'f173021d-afc4-4a8f-8432-30c0cf832e3b', 5354, 'POST-BREEDING PERIODS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > POST-BREEDING PERIODS', 1);
INSERT INTO {schema}.keywords VALUES (6623, '615e826e-a5da-4e94-b7df-ad3515c06135', 5354, 'RANGE CHANGES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > RANGE CHANGES', 1);
INSERT INTO {schema}.keywords VALUES (6624, 'abc96dce-cbae-43a4-b7c2-2ff02276b030', 5354, 'SCAVENGING', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > SCAVENGING', 1);
INSERT INTO {schema}.keywords VALUES (6625, '60bd0b0a-2d6f-4f3c-bf42-2c081ef48b72', 5354, 'SPECIES COMPETITION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > SPECIES COMPETITION', 1);
INSERT INTO {schema}.keywords VALUES (6626, 'fd06e0a2-f689-4b33-8a85-f38bf4966808', 5354, 'SPECIES LIFE HISTORY', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > SPECIES LIFE HISTORY', 1);
INSERT INTO {schema}.keywords VALUES (6627, 'b69d76ba-ad69-4418-8e5b-ebb659604dda', 5354, 'SPECIES PREDATION', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > SPECIES PREDATION', 1);
INSERT INTO {schema}.keywords VALUES (6628, 'fa68e752-f3a7-4361-a000-47c908545e49', 5354, 'SURVIVAL RATES', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > SURVIVAL RATES', 1);
INSERT INTO {schema}.keywords VALUES (6629, 'e008a809-42eb-4694-aac2-db7b6027ee77', 5354, 'SYMBIOSIS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > SYMBIOSIS', 1);
INSERT INTO {schema}.keywords VALUES (6630, '744c38f8-feeb-4e01-a909-33d75fefba82', 5354, 'USE/FEEDING HABITATS', 'EARTH SCIENCE > BIOSPHERE > ECOLOGICAL DYNAMICS > SPECIES/POPULATION INTERACTIONS > USE/FEEDING HABITATS', 1);
INSERT INTO {schema}.keywords VALUES (6631, '38fb609b-2a10-4d4f-b2e8-7e51161ec974', 5355, 'AGRICULTURAL LANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > AGRICULTURAL LANDS', 1);
INSERT INTO {schema}.keywords VALUES (6632, '8f109871-e6ff-4cef-a5f8-5a3ad981923e', 5355, 'RESOURCE DEVELOPMENT SITE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > RESOURCE DEVELOPMENT SITE', 1);
INSERT INTO {schema}.keywords VALUES (6633, '3e59af3d-500b-4c66-a9a1-76db5cf4a00b', 5355, 'URBAN LANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > URBAN LANDS', 1);
INSERT INTO {schema}.keywords VALUES (6634, 'ca8d77f2-9257-4298-9244-e81cd890f000', 5356, 'PLANKTON', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > PLANKTON', 1);
INSERT INTO {schema}.keywords VALUES (6635, 'b72c49a1-8276-4753-8c88-894bc7bbf60d', 5356, 'WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (6636, '57a3a5a7-66b9-4a4a-82da-7b09d82c684a', 5357, 'LAKE/POND', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > LAKE/POND', 1);
INSERT INTO {schema}.keywords VALUES (6637, '43d51c24-0523-4b65-919f-17618c7d72b4', 5357, 'RIVERS/STREAM', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > RIVERS/STREAM', 1);
INSERT INTO {schema}.keywords VALUES (6638, '1c286cb7-2668-4db3-a5ac-cb8b710bebc2', 5358, 'ABYSSAL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ABYSSAL', 1);
INSERT INTO {schema}.keywords VALUES (6639, '09a78997-581b-4d1b-ae71-b2b3f96ef719', 5358, 'BENTHIC', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > BENTHIC', 1);
INSERT INTO {schema}.keywords VALUES (6640, '47be68db-d10d-43e7-b150-61cfd3f06126', 5358, 'COASTAL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL', 1);
INSERT INTO {schema}.keywords VALUES (6642, '5a1ebca4-057d-43b9-af6a-04f57b93f8bb', 5358, 'ESTUARY', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ESTUARY', 1);
INSERT INTO {schema}.keywords VALUES (6643, '3d7ecc4f-e79e-40d1-8796-63059888bf5f', 5358, 'PELAGIC', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > PELAGIC', 1);
INSERT INTO {schema}.keywords VALUES (6644, '367718c8-cc3b-4c94-a270-0a278afabb43', 5358, 'REEF', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > REEF', 1);
INSERT INTO {schema}.keywords VALUES (6645, '76589134-8d93-4e45-8476-f04497181d14', 5359, 'ALPINE/TUNDRA', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > ALPINE/TUNDRA', 1);
INSERT INTO {schema}.keywords VALUES (6646, '91f6a2e5-5862-46a9-ba6a-d76e06d9997c', 5359, 'CAVE/SUBTERRANEAN', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > CAVE/SUBTERRANEAN', 1);
INSERT INTO {schema}.keywords VALUES (6647, '5d5426f6-e7ce-41c1-a3d3-b93adf748f0f', 5359, 'DESERTS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > DESERTS', 1);
INSERT INTO {schema}.keywords VALUES (6648, '46e4aaa4-349c-4049-a910-035391360010', 5359, 'FORESTS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS', 1);
INSERT INTO {schema}.keywords VALUES (6649, '142ea0c1-b77f-44da-8c64-ac7ee13fd5f6', 5359, 'GRASSLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > GRASSLANDS', 1);
INSERT INTO {schema}.keywords VALUES (6650, 'fa3c6df8-a1e1-41d5-9de1-49b92e1ea455', 5359, 'ISLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > ISLANDS', 1);
INSERT INTO {schema}.keywords VALUES (6651, 'de702fdd-3702-4164-a396-08082b0558c0', 5359, 'KARST LANDSCAPE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > KARST LANDSCAPE', 1);
INSERT INTO {schema}.keywords VALUES (6652, '99e09719-f1f8-439e-be4c-759242612a84', 5359, 'MONTANE HABITATS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > MONTANE HABITATS', 1);
INSERT INTO {schema}.keywords VALUES (6653, 'f8d55ee4-1efb-4d83-b07f-1029ab0fa9e1', 5359, 'SAVANNAS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > SAVANNAS', 1);
INSERT INTO {schema}.keywords VALUES (6654, 'e018b139-7e05-4155-8e2e-8d5603b5fe47', 5359, 'SHRUBLAND/SCRUB', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > SHRUBLAND/SCRUB', 1);
INSERT INTO {schema}.keywords VALUES (6655, '7da95c01-4b39-437e-a8d4-fd572e43f693', 5359, 'WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (6656, 'f829171e-8b22-4f93-8f71-7932dfd7a70b', 5374, 'LEAF AREA INDEX (LAI)', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > LEAF CHARACTERISTICS > LEAF AREA INDEX (LAI)', 1);
INSERT INTO {schema}.keywords VALUES (6657, '6079e5e4-4dee-4b32-aaa8-ae3231bcbadb', 5380, 'FRACTION OF ABSORBED PHOTOSYNTHETICALLY ACTIVE RADIATION (FAPAR)', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PHOTOSYNTHETICALLY ACTIVE RADIATION > FRACTION OF ABSORBED PHOTOSYNTHETICALLY ACTIVE RADIATION (FAPAR)', 1);
INSERT INTO {schema}.keywords VALUES (6658, 'ff141ffe-05ea-4901-a243-e6186826b05c', 5382, 'VEGETATION WATER CONTENT', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > PLANT CHARACTERISTICS > VEGETATION WATER CONTENT', 1);
INSERT INTO {schema}.keywords VALUES (6659, 'b1d65d88-7bd0-491d-91ca-4102b89dc3e7', 5389, 'LEAF AREA INDEX (LAI)', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > VEGETATION INDEX > LEAF AREA INDEX (LAI)', 1);
INSERT INTO {schema}.keywords VALUES (6660, '2297a00a-80f5-466e-b28e-b9ca42562d3f', 5389, 'NORMALIZED DIFFERENCE VEGETATION INDEX (NDVI)', 'EARTH SCIENCE > BIOSPHERE > VEGETATION > VEGETATION INDEX > NORMALIZED DIFFERENCE VEGETATION INDEX (NDVI)', 1);
INSERT INTO {schema}.keywords VALUES (6661, '2111d240-315c-411b-8114-7ef9e89317e5', 5391, 'INCREASED/DECREASED CLOUD FRACTION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > CLOUD INDICATORS > INCREASED/DECREASED CLOUD FRACTION', 1);
INSERT INTO {schema}.keywords VALUES (6662, 'e4c806af-ab57-4fda-b7e9-29e3c65f6ec5', 5393, 'EXTREME DROUGHT', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > EXTREME WEATHER > EXTREME DROUGHT', 1);
INSERT INTO {schema}.keywords VALUES (6663, 'fc5a1b7a-5ee8-4d67-80f5-a57e3f1734ab', 5393, 'EXTREME PRECIPITATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > EXTREME WEATHER > EXTREME PRECIPITATION', 1);
INSERT INTO {schema}.keywords VALUES (6664, '079e6699-efbf-4358-9047-b668b459fc22', 5393, 'HEAT/COLD WAVE FREQUENCY/INTENSITY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > EXTREME WEATHER > HEAT/COLD WAVE FREQUENCY/INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6665, '7f95ceda-09fd-4ee3-9f30-bf38bf831e12', 5393, 'MONSOON ONSET/INTENSITY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > EXTREME WEATHER > MONSOON ONSET/INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6666, 'a85b812e-e4d2-4dce-bf67-d89a3e1a9122', 5393, 'TROPICAL OR EXTRATROPICAL CYCLONE FREQUENCY/INTENSITY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > EXTREME WEATHER > TROPICAL OR EXTRATROPICAL CYCLONE FREQUENCY/INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (6667, 'cdd7a31f-3244-494d-bc44-7b5f1ebb4bd7', 5395, 'HUMIDITY INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > HUMIDITY INDICES > HUMIDITY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6668, '5bdc74e2-ea3a-4d1d-b64e-9eaf3a879545', 5395, 'TEMPERATURE-HUMIDITY INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > HUMIDITY INDICES > TEMPERATURE-HUMIDITY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6669, 'b9349099-8d45-4260-ab30-c891c3553a25', 5395, 'WATER VAPOR TRANSPORT INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > HUMIDITY INDICES > WATER VAPOR TRANSPORT INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6670, '74ad118c-2f18-40fb-a26e-092390f52c20', 5397, 'OCEAN COASTAL UPWELLING INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > OCEAN UPWELLING INDICES > OCEAN COASTAL UPWELLING INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6671, '279961c4-dac3-4188-917f-fa11982f957e', 5399, 'PRECIPITATION TRENDS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICATORS > PRECIPITATION TRENDS', 1);
INSERT INTO {schema}.keywords VALUES (6672, 'c7c88080-660c-4913-8140-5f3bc91e295e', 5399, 'PRECIPITATION VARIABILITY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICATORS > PRECIPITATION VARIABILITY', 1);
INSERT INTO {schema}.keywords VALUES (6673, 'e13b084e-d044-49c9-8791-f057f777fca3', 5399, 'SAHEL STANDARDIZED RAINFALL', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICATORS > SAHEL STANDARDIZED RAINFALL', 1);
INSERT INTO {schema}.keywords VALUES (6674, 'd14d762c-4117-438a-9093-a098a0d0e4e6', 5400, 'ENSO PRECIPITATION INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICES > ENSO PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6675, 'b8f0571c-4c19-4025-936c-936e9ac72e21', 5400, 'NORTHEAST BRAZIL RAINFALL ANOMALY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICES > NORTHEAST BRAZIL RAINFALL ANOMALY', 1);
INSERT INTO {schema}.keywords VALUES (6676, '7427fb2d-43b5-478a-960d-2ff9aa398462', 5400, 'STANDARDIZED PRECIPITATION INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICES > STANDARDIZED PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6677, 'aefbd3c5-6594-455b-a99d-7397a694bf8e', 5400, 'WEIGHTED ANOMALY STANDARDIZED PRECIPITATION INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > PRECIPITATION INDICES > WEIGHTED ANOMALY STANDARDIZED PRECIPITATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6678, 'eec5b471-bcc5-4d9b-8274-f3990e79ed84', 5401, 'EROSION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA LEVEL RISE > EROSION', 1);
INSERT INTO {schema}.keywords VALUES (6679, '9db10fb2-0ceb-412e-9936-a286c579fa9f', 5401, 'INUNDATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA LEVEL RISE > INUNDATION', 1);
INSERT INTO {schema}.keywords VALUES (6680, 'ca418285-d1f2-4348-82e4-7fc59f8b60c8', 5402, 'ATLANTIC TRIPOLE SST', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > ATLANTIC TRIPOLE SST', 1);
INSERT INTO {schema}.keywords VALUES (6681, '5f2273b8-be30-45d5-a5d7-9bd947779c2e', 5402, 'CARIBBEAN INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > CARIBBEAN INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6682, 'ad5bde75-1f54-4f7e-a958-3adaf9f40639', 5402, 'CENTRAL TROPICAL PACIFIC SST', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > CENTRAL TROPICAL PACIFIC SST', 1);
INSERT INTO {schema}.keywords VALUES (6683, '01b96758-13f3-4cea-8447-decae36b1bde', 5402, 'EAST CENTRAL TROPICAL PACIFIC SST', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > EAST CENTRAL TROPICAL PACIFIC SST', 1);
INSERT INTO {schema}.keywords VALUES (6684, '4b862c68-9cd9-4fee-942a-7cec0e6b05c2', 5402, 'EXTREME EASTERN TROPICAL PACIFIC SST', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > EXTREME EASTERN TROPICAL PACIFIC SST', 1);
INSERT INTO {schema}.keywords VALUES (6685, '9c98dcbd-1dc8-4e0a-8ad1-0d11e88360eb', 5402, 'KAPLAN SST INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > KAPLAN SST INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6686, 'c58dc7fb-65d5-4309-8abe-160e8e845382', 5402, 'NINO 3 INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > NINO 3 INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6687, 'd52674c3-0c78-4f35-9675-c2a8b3869b16', 5402, 'NORTH TROPICAL ATLANTIC INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > NORTH TROPICAL ATLANTIC INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6688, '70ed535b-a591-411d-80ca-9eafe10b3be8', 5402, 'OCEANIC NINO INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > OCEANIC NINO INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6689, 'db1000b8-3b19-46fa-9d79-379379d654ac', 5402, 'PACIFIC WARM POOL', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > PACIFIC WARM POOL', 1);
INSERT INTO {schema}.keywords VALUES (6690, '58d71334-7fb5-4e05-85fd-9d2485854abe', 5402, 'TRANS-NINO INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TRANS-NINO INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6691, '2cde80e8-3eb1-40e7-9305-e765dc8df5e2', 5402, 'TROPICAL NORTH ATLANTIC INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TROPICAL NORTH ATLANTIC INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6692, 'ed2f3a3f-c841-41cf-9394-3a3254d13fc2', 5402, 'TROPICAL PACIFIC SST EOF', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TROPICAL PACIFIC SST EOF', 1);
INSERT INTO {schema}.keywords VALUES (6693, '887e3bcc-ffd4-4f10-a91c-849783aac709', 5402, 'TROPICAL SOUTH ATLANTIC INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TROPICAL SOUTH ATLANTIC INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6694, '309d2897-c74b-4de6-96fc-751a6935d549', 5402, 'WESTERN HEMISPHERE WARM POOL', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > WESTERN HEMISPHERE WARM POOL', 1);
INSERT INTO {schema}.keywords VALUES (6695, '511e6c26-8806-4d88-9763-a136a6957042', 5405, 'ANTARCTIC OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ANTARCTIC OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6696, '98e5a7e4-b946-474a-8214-c1b7b3e5f976', 5405, 'ARCTIC OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ARCTIC OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6697, 'f141c968-94d4-4c42-8877-bbe34bb84b26', 5405, 'ATLANTIC MERIDIONAL MODE', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ATLANTIC MERIDIONAL MODE', 1);
INSERT INTO {schema}.keywords VALUES (6698, 'dcdb6cf1-48a7-488e-aeb8-e6c0b36752d4', 5405, 'ATLANTIC MULTIDECADAL OSCILLATION LONG VERSION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ATLANTIC MULTIDECADAL OSCILLATION LONG VERSION', 1);
INSERT INTO {schema}.keywords VALUES (6699, 'a69f9faf-f730-4eba-9e38-0f72b0544bbe', 5405, 'BIVARIATE ENSO TIMESERIES INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > BIVARIATE ENSO TIMESERIES INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6700, '2aeb8e10-b7f8-429e-b9f6-968ece330741', 5405, 'BLOCKING INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > BLOCKING INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6701, '47fb8f57-2ddd-4289-b8a5-af7ffa0ee031', 5405, 'EAST ATLANTIC JET PATTERN', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EAST ATLANTIC JET PATTERN', 1);
INSERT INTO {schema}.keywords VALUES (6702, '64d4ff80-59bb-4565-8759-e5223939abfd', 5405, 'EAST ATLANTIC PATTERN', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EAST ATLANTIC PATTERN', 1);
INSERT INTO {schema}.keywords VALUES (6703, 'c58e035f-87c6-4aa5-8729-5a9c6270e73b', 5405, 'EASTERN ATLANTIC WESTERN RUSSIA PATTERN', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EASTERN ATLANTIC WESTERN RUSSIA PATTERN', 1);
INSERT INTO {schema}.keywords VALUES (6704, '0384fecd-9303-47f3-84e3-f01f58013fc3', 5405, 'EASTERN PACIFIC OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EASTERN PACIFIC OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6705, '095a05c0-6220-4abd-9c1b-c4504a092d7d', 5405, 'EL NINO SOUTHERN OSCILLATION (ENSO)', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EL NINO SOUTHERN OSCILLATION (ENSO)', 1);
INSERT INTO {schema}.keywords VALUES (6706, '21389c4a-0d32-484a-95b9-db319a18f6ca', 5405, 'EQUATORIAL PACIFIC MERIDIONAL WIND ANOMALY INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EQUATORIAL PACIFIC MERIDIONAL WIND ANOMALY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6707, '57a381ef-56f6-48af-8974-822f5859979d', 5405, 'EQUATORIAL PACIFIC ZONAL WIND ANOMALY INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EQUATORIAL PACIFIC ZONAL WIND ANOMALY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6708, '523c148f-bb4f-47d0-b176-0949ed59288a', 5405, 'GLOBALLY INTEGRATED ANGULAR MOMENTUM', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > GLOBALLY INTEGRATED ANGULAR MOMENTUM', 1);
INSERT INTO {schema}.keywords VALUES (6709, '25d4368e-3b66-40d5-bac1-2343b127fa32', 5405, 'MADDEN-JULIAN OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > MADDEN-JULIAN OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6710, 'caddaef6-1a60-490a-938e-9107885f286f', 5405, 'MULTIVARIATE ENSO INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > MULTIVARIATE ENSO INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6711, 'c5e1c055-768e-4aa3-a0a1-3adfda8ecdca', 5405, 'NORTH ATLANTIC OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTH ATLANTIC OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6712, '2295728d-0ee0-4c6f-9bb4-261b4b22322e', 5405, 'NORTH PACIFIC OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTH PACIFIC OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6713, 'c6abcc08-7d59-4852-8c1a-82f464900333', 5405, 'NORTH PACIFIC PATTERN', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTH PACIFIC PATTERN', 1);
INSERT INTO {schema}.keywords VALUES (6714, '77b2422e-ce52-465f-8841-5d04ebe536dc', 5405, 'NORTHERN OSCILLATION INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTHERN OSCILLATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6715, '2de06b90-4abe-4c71-a537-978679bf8aea', 5405, 'PACIFIC DECADAL OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > PACIFIC DECADAL OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6716, '0e53e397-7836-45ec-bc62-0d54f9f176e5', 5405, 'PACIFIC/NORTH AMERICAN (PNA) PATTERN', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > PACIFIC/NORTH AMERICAN (PNA) PATTERN', 1);
INSERT INTO {schema}.keywords VALUES (6717, '233903dd-daec-474f-ac2e-cdcad84a85b5', 5405, 'Pacific Transition Index', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > Pacific Transition Index', 1);
INSERT INTO {schema}.keywords VALUES (6718, 'ea64fa04-2822-4cc5-9014-f18ce1a1ef23', 5405, 'QUASI-BIENNIAL OSCILLATION', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > QUASI-BIENNIAL OSCILLATION', 1);
INSERT INTO {schema}.keywords VALUES (6719, 'eaa0bc43-e283-4bf1-ba20-ca32850a66ef', 5405, 'SOUTHERN OSCILLATION INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > SOUTHERN OSCILLATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6720, '83b711e1-3fb5-4ef3-bafb-783e8239a4b5', 5405, 'TROPICAL/NORTHERN HEMISPHERE PATTERN', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > TROPICAL/NORTHERN HEMISPHERE PATTERN', 1);
INSERT INTO {schema}.keywords VALUES (6721, 'bdb6eafa-f4e1-4536-b513-4c787f829722', 5405, 'WEST PACIFIC INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > WEST PACIFIC INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6722, '3d997f01-8987-4fb1-a32e-d88d51f0a2c4', 5407, 'HIGHER MAXIMUM DAYTIME TEMPERATURES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS > HIGHER MAXIMUM DAYTIME TEMPERATURES', 1);
INSERT INTO {schema}.keywords VALUES (6723, '93741006-ff2a-4ec2-bbd4-ff55301fabe0', 5407, 'HIGHER MINIMUM NIGHTTIME TEMPERATURES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS > HIGHER MINIMUM NIGHTTIME TEMPERATURES', 1);
INSERT INTO {schema}.keywords VALUES (6724, '0eb1af15-7bd4-40c6-b8a4-666cbb61ff8c', 5407, 'STRATOSPHERIC TEMPERATURE ANOMALIES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS > STRATOSPHERIC TEMPERATURE ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (6725, 'ae247e59-db82-45ac-a9de-a9773ae4db40', 5407, 'TEMPERATURE TRENDS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS > TEMPERATURE TRENDS', 1);
INSERT INTO {schema}.keywords VALUES (6726, '7013bdc9-519d-42b6-827c-4b8013fbb726', 5407, 'TEMPERATURE VARIABILITY', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS > TEMPERATURE VARIABILITY', 1);
INSERT INTO {schema}.keywords VALUES (6727, 'f0e47cca-fa6e-44d0-b900-43920a3d0b91', 5407, 'TROPOSPHERIC TEMPERATURE ANOMALIES', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICATORS > TROPOSPHERIC TEMPERATURE ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (6728, 'c7fa79e4-67a1-45da-b393-a1b89d54a1a5', 5408, 'COMMON SENSE CLIMATE INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > COMMON SENSE CLIMATE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6729, 'db0d03d7-1d08-42fb-b212-0da35b88e656', 5408, 'COOLING DEGREE DAYS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > COOLING DEGREE DAYS', 1);
INSERT INTO {schema}.keywords VALUES (6730, 'bc6d73a9-4943-4a3e-9f9d-9406fa54b0bc', 5408, 'FREEZING INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > FREEZING INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6731, '6d808909-ce04-4401-a883-aff4d723d025', 5408, 'GROWING DEGREE DAYS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > GROWING DEGREE DAYS', 1);
INSERT INTO {schema}.keywords VALUES (6732, 'fe2bc223-e503-4ca1-924c-d3fd5876721c', 5408, 'HEATING DEGREE DAYS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > HEATING DEGREE DAYS', 1);
INSERT INTO {schema}.keywords VALUES (6733, 'f19ff7fb-fd8b-433c-88e2-afc5dd3ee7b2', 5408, 'RESIDENTIAL ENERGY DEMAND TEMPERATURE INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > RESIDENTIAL ENERGY DEMAND TEMPERATURE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6734, 'd73be111-7aae-4a96-89c2-7b64c064893c', 5408, 'TEMPERATURE CONCENTRATION INDEX (TCI)', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > TEMPERATURE CONCENTRATION INDEX (TCI)', 1);
INSERT INTO {schema}.keywords VALUES (6735, '1e540a87-ffd9-4277-b8f2-683a58145b87', 5408, 'THAWING INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TEMPERATURE INDICES > THAWING INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6736, 'f73cf4ee-2ae0-47b0-a294-5f8a8f694215', 5415, 'ANIMAL PHENOLOGICAL CHANGES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > PHENOLOGICAL CHANGES > ANIMAL PHENOLOGICAL CHANGES', 1);
INSERT INTO {schema}.keywords VALUES (6737, 'c6f81edb-b683-4356-93e6-5852766a5ee8', 5415, 'PLANT PHENOLOGICAL CHANGES', 'EARTH SCIENCE > CLIMATE INDICATORS > BIOSPHERIC INDICATORS > PHENOLOGICAL CHANGES > PLANT PHENOLOGICAL CHANGES', 1);
INSERT INTO {schema}.keywords VALUES (6738, '83bd640d-cd05-49a8-9ec7-aab60820b126', 5427, 'GLACIER ELEVATION/ICE SHEET ELEVATION', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS > GLACIER ELEVATION/ICE SHEET ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (6739, '613c1fba-8710-47fb-a8e1-e4cd50bb97e1', 5427, 'GLACIER FACIES', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS > GLACIER FACIES', 1);
INSERT INTO {schema}.keywords VALUES (6740, '6095d796-68e0-4c7d-aa4f-f2e5bd8c4916', 5427, 'GLACIER MASS BALANCE/ICE SHEET MASS BALANCE', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS > GLACIER MASS BALANCE/ICE SHEET MASS BALANCE', 1);
INSERT INTO {schema}.keywords VALUES (6741, '4c9afaf7-4aec-440d-8084-6a482de09e7a', 5427, 'GLACIER MOTION/ICE SHEET MOTION', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS > GLACIER MOTION/ICE SHEET MOTION', 1);
INSERT INTO {schema}.keywords VALUES (6742, '6a8a6fdb-c431-4d32-8cea-5849e2ee1f33', 5427, 'GLACIER/ICE SHEET THICKNESS', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS > GLACIER/ICE SHEET THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (6743, 'c3e4d439-bbb0-48c9-89eb-57d3a330627a', 5427, 'GLACIER/ICE SHEET TOPOGRAPHY', 'EARTH SCIENCE > CLIMATE INDICATORS > CRYOSPHERIC INDICATORS > GLACIAL MEASUREMENTS > GLACIER/ICE SHEET TOPOGRAPHY', 1);
INSERT INTO {schema}.keywords VALUES (6744, '7e26f9e3-4c20-453d-bbc6-1970eca1ffb8', 5442, 'PALMER DROUGHT CROP MOISTURE INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > DROUGHT INDICES > PALMER DROUGHT CROP MOISTURE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6745, 'a43850a1-7b00-4993-80ff-753c2b5c4015', 5442, 'PALMER DROUGHT SEVERITY INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > DROUGHT INDICES > PALMER DROUGHT SEVERITY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6746, '0365f0af-7843-4ba3-af8c-82d032c14f7e', 5442, 'PALMER HYDROLOGICAL DROUGHT INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > DROUGHT INDICES > PALMER HYDROLOGICAL DROUGHT INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6747, '0565650b-dce1-4ae8-8a7a-7ce25ac198c3', 5442, 'PALMER Z INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > DROUGHT INDICES > PALMER Z INDEX', 1);
INSERT INTO {schema}.keywords VALUES (6748, 'f5824b8f-c3e7-4e56-96e8-cf4b5adefbf8', 5447, 'CROP HARVEST DATES', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > LENGTH OF GROWING SEASON > CROP HARVEST DATES', 1);
INSERT INTO {schema}.keywords VALUES (6749, '226d4804-1a09-4d9b-a5c1-346f52a2e709', 5447, 'FREEZE/FROST DATE', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > LENGTH OF GROWING SEASON > FREEZE/FROST DATE', 1);
INSERT INTO {schema}.keywords VALUES (6750, 'efc141a6-7d8e-45d5-b335-2fc122c62d78', 5447, 'FREEZE/FROST PROBABILITY', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > LENGTH OF GROWING SEASON > FREEZE/FROST PROBABILITY', 1);
INSERT INTO {schema}.keywords VALUES (6751, '738185b7-54d6-41a2-b31f-b8a4ee1dabe7', 5447, 'LENGTH OF FREEZE FREE PERIOD', 'EARTH SCIENCE > CLIMATE INDICATORS > LAND SURFACE/AGRICULTURE INDICATORS > LENGTH OF GROWING SEASON > LENGTH OF FREEZE FREE PERIOD', 1);
INSERT INTO {schema}.keywords VALUES (6752, '625ac4b3-a126-4c98-a061-3a780b942280', 5457, 'BIOMARKER', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > BIOMARKER', 1);
INSERT INTO {schema}.keywords VALUES (6753, 'afeb9962-d3e8-4260-ab2b-e62e11099e31', 5457, 'CORAL DEPOSITS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > CORAL DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6754, 'cffe377f-d840-4bcf-9223-8379b72defe7', 5457, 'FAUNA', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > FAUNA', 1);
INSERT INTO {schema}.keywords VALUES (6755, '14c78811-5296-4095-9c44-26362914e798', 5457, 'MACROFOSSILS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > MACROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6756, '0aa423e0-bc21-4d74-894d-a0dfcf17fae5', 5457, 'MICROFOSSILS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > MICROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6757, 'fbd867cf-f7e8-4dbc-9fd2-2ccc0728350f', 5457, 'PALEOVEGETATION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > PALEOVEGETATION', 1);
INSERT INTO {schema}.keywords VALUES (6758, '59719c53-a2b7-4200-9b3c-dfa5d39607f7', 5457, 'POLLEN', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > POLLEN', 1);
INSERT INTO {schema}.keywords VALUES (6759, '7bc06198-5546-40f5-97ac-b7b5b5503cfc', 5457, 'POPULATION ABUNDANCE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > POPULATION ABUNDANCE', 1);
INSERT INTO {schema}.keywords VALUES (6760, '6444fc67-8cad-41c0-9ded-e93f604ba8b0', 5457, 'TREE RINGS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > TREE RINGS', 1);
INSERT INTO {schema}.keywords VALUES (6761, 'b53939ae-1264-409d-8434-3bb3d22b2848', 5458, 'CARBON DIOXIDE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > CARBON DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6762, 'a2987914-ed66-4b7c-964d-8eccf0174e57', 5458, 'ELECTRICAL PROPERTIES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > ELECTRICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (6763, '42664b0d-26c2-44ad-b0a9-673ed2902f00', 5458, 'ICE CORE AIR BUBBLES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > ICE CORE AIR BUBBLES', 1);
INSERT INTO {schema}.keywords VALUES (6764, '302d7079-299a-4269-bd7e-d95009c9b46e', 5458, 'IONS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > IONS', 1);
INSERT INTO {schema}.keywords VALUES (6765, 'a0358b3e-0926-4b17-8b32-c1b15a73cba5', 5458, 'ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6766, '0948a59e-cc72-4e5d-b97d-4ea0335b0906', 5458, 'METHANE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > METHANE', 1);
INSERT INTO {schema}.keywords VALUES (6767, 'bc90bc40-2a21-4a6f-9fb9-bf3ae5845157', 5458, 'NITROUS OXIDE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > NITROUS OXIDE', 1);
INSERT INTO {schema}.keywords VALUES (6768, '15fdef7c-7fb7-4a1d-a24b-01164a8ba11a', 5458, 'PARTICULATE MATTER', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > PARTICULATE MATTER', 1);
INSERT INTO {schema}.keywords VALUES (6769, 'c736e45d-63f2-428b-abae-48f79d007703', 5458, 'VOLCANIC DEPOSITS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > VOLCANIC DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6770, 'f1f84fc8-d242-4f97-bb7d-77b68631273e', 5459, 'BOREHOLES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > BOREHOLES', 1);
INSERT INTO {schema}.keywords VALUES (6771, '482453d7-ffa4-4ae9-8158-9fa73bcf39ef', 5459, 'CAVE DEPOSITS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > CAVE DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6772, 'd2dc2330-0433-43f2-9154-dc399d24406c', 5459, 'FIRE HISTORY', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > FIRE HISTORY', 1);
INSERT INTO {schema}.keywords VALUES (6773, '2f257f83-bddd-41ce-ac78-5dac857b1be3', 5459, 'GLACIAL RETREAT', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > GLACIAL RETREAT', 1);
INSERT INTO {schema}.keywords VALUES (6774, '3dfa8dcf-0df2-4654-ae3e-c97586265c3e', 5459, 'GLACIATION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > GLACIATION', 1);
INSERT INTO {schema}.keywords VALUES (6775, '7557eddd-db2a-4f39-b1e2-91162f4fc92e', 5459, 'ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6776, 'e0d88b2a-8563-443b-8756-73d744a41ee7', 5459, 'LOESS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > LOESS', 1);
INSERT INTO {schema}.keywords VALUES (6777, '219ba382-6c90-43d2-a6cf-2ddcc358f70e', 5459, 'PALEOMAGNETIC DATA', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > PALEOMAGNETIC DATA', 1);
INSERT INTO {schema}.keywords VALUES (6778, '4fe601b0-314f-4f63-8ec1-3b96cc7263b8', 5459, 'PALEOSOLS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > PALEOSOLS', 1);
INSERT INTO {schema}.keywords VALUES (6779, '8f4e90e0-aea0-40cd-b781-a6a69a6e6cb3', 5459, 'RADIOCARBON', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > RADIOCARBON', 1);
INSERT INTO {schema}.keywords VALUES (6780, '0960827a-ecdb-40a0-babc-fbd6df27bb53', 5459, 'SEDIMENTS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6781, 'd845886d-0c44-4505-b5b9-d3fcd819208e', 5459, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (6782, '52325c6e-1084-43c1-83b2-278bbe0201c6', 5459, 'VOLCANIC DEPOSITS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > VOLCANIC DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6783, '8f8c1808-ac5f-43e5-8397-dbb3d171144c', 5461, 'BOREHOLES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > BOREHOLES', 1);
INSERT INTO {schema}.keywords VALUES (6784, '47d6c670-db83-4975-b684-1be787811ac8', 5461, 'CORAL DEPOSITS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > CORAL DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6785, 'dc02e5fb-9ff3-483d-8c33-18db25a07eea', 5461, 'ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6786, '2c99427c-1a6a-4326-b072-0c12c87bd944', 5461, 'LAKE LEVELS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > LAKE LEVELS', 1);
INSERT INTO {schema}.keywords VALUES (6787, '11e12021-f63e-4081-ae78-1bb19fe7b4bf', 5461, 'MACROFOSSILS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > MACROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6788, '6d00c961-de64-40ed-becd-3a95cae182e3', 5461, 'MICROFOSSILS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > MICROFOSSILS', 1);
INSERT INTO {schema}.keywords VALUES (6789, '9713a1d5-8b03-4d38-b3b6-34578a1d5f39', 5461, 'OXYGEN ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > OXYGEN ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (6790, '7ee90f7c-bdc6-403a-b447-2100d573cad6', 5461, 'PALEOMAGNETIC DATA', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > PALEOMAGNETIC DATA', 1);
INSERT INTO {schema}.keywords VALUES (6791, 'fe06f678-7155-4f93-9e28-4c083d60cccc', 5461, 'POLLEN', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > POLLEN', 1);
INSERT INTO {schema}.keywords VALUES (6792, 'a389bcd6-929d-43ac-9af1-5a20a4ddcbe2', 5461, 'RADIOCARBON', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > RADIOCARBON', 1);
INSERT INTO {schema}.keywords VALUES (6793, 'b3764016-0b5d-48fb-be3e-4f1082cf13e7', 5461, 'SEDIMENTS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6794, '417a6538-f89e-4f73-a89a-c2e5d2cd7667', 5461, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (6795, '9db3b1cb-0d3d-4486-bf56-1e96b8691b01', 5461, 'VARVE DEPOSITS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > VARVE DEPOSITS', 1);
INSERT INTO {schema}.keywords VALUES (6796, 'e0867ff5-2eb4-4959-b874-ac37c1b407e0', 5463, 'CARBON DIOXIDE FORCING', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE FORCING > CARBON DIOXIDE FORCING', 1);
INSERT INTO {schema}.keywords VALUES (6797, '7cc62051-537c-4399-b9b9-b59c1a3e0773', 5463, 'ORBITAL CHANGE FORCING', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE FORCING > ORBITAL CHANGE FORCING', 1);
INSERT INTO {schema}.keywords VALUES (6798, '250ce118-46e7-4dec-9e44-8054c9318cff', 5463, 'SOLAR FORCING', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE FORCING > SOLAR FORCING', 1);
INSERT INTO {schema}.keywords VALUES (6799, '78c47e38-e842-4e31-81b2-44f44c52c692', 5463, 'VOLCANIC FORCING', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE FORCING > VOLCANIC FORCING', 1);
INSERT INTO {schema}.keywords VALUES (6800, '89e5b8c9-ef72-4e21-83c8-a7552f6871a4', 5464, 'AIR TEMPERATURE RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > AIR TEMPERATURE RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6801, '555b048d-8904-4a62-a85a-3af1aa14674e', 5464, 'ATMOSPHERIC CIRCULATION RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > ATMOSPHERIC CIRCULATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6802, '06bcba40-6046-4c0e-aa38-8f83410b93f0', 5464, 'DROUGHT/PRECIPITATION RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > DROUGHT/PRECIPITATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6803, '9f687ff2-52c0-496b-9a81-503a8c207823', 5464, 'GROUND WATER RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > GROUND WATER RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6804, 'ec4c1ae2-53f4-40ca-b0c3-e145f00e2583', 5464, 'LAKE LEVEL RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > LAKE LEVEL RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6805, '1ba98ab7-dee3-4b15-aea1-179ecd8f6e7d', 5464, 'OCEAN SALINITY RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > OCEAN SALINITY RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6806, 'b51093c5-5997-410c-899d-98d15ab5f5cc', 5464, 'SEA LEVEL RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > SEA LEVEL RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6807, 'facdb262-04eb-47f9-b46e-ba7a379722ec', 5464, 'SEA SURFACE TEMPERATURE RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > SEA SURFACE TEMPERATURE RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6808, '3b4ea1db-bb93-4eb8-ac08-4880a3a5e6d2', 5464, 'SEDIMENTS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6809, 'fec6c2e4-ca15-426a-b344-36bba69e5c1f', 5464, 'SOLAR FORCING/INSOLATION RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > SOLAR FORCING/INSOLATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6810, 'cde7aacb-0204-4a84-afcb-279cc3d0870c', 5464, 'STREAMFLOW RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > STREAMFLOW RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6811, 'c1c1890d-a6b0-4482-836b-a4b8ed0beee8', 5464, 'VEGETATION RECONSTRUCTION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > VEGETATION RECONSTRUCTION', 1);
INSERT INTO {schema}.keywords VALUES (6812, '22c14e35-48a4-40b5-a503-add48c2d4cd4', 5469, 'LENGTH OF THE SOLAR CYCLE', 'EARTH SCIENCE > CLIMATE INDICATORS > SUN-EARTH INTERACTIONS > SUNSPOT ACTIVITY > LENGTH OF THE SOLAR CYCLE', 1);
INSERT INTO {schema}.keywords VALUES (6813, '3b230650-68ff-4e7a-9273-6e0b1083bdfa', 5469, 'SOLAR FLUX', 'EARTH SCIENCE > CLIMATE INDICATORS > SUN-EARTH INTERACTIONS > SUNSPOT ACTIVITY > SOLAR FLUX', 1);
INSERT INTO {schema}.keywords VALUES (6814, 'd8606e80-3d34-4540-a355-5f99737f7ab7', 5480, 'PERMAFROST TEMPERATURE', 'EARTH SCIENCE > CRYOSPHERE > FROZEN GROUND > PERMAFROST > PERMAFROST TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (6815, 'a30b2871-4cdc-418a-b00c-969b50008726', 5490, 'SNOW GRAIN SIZE', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > FIRN > SNOW GRAIN SIZE', 1);
INSERT INTO {schema}.keywords VALUES (6816, '6d6a2b61-5d2c-4ec1-a164-34000f481588', 5499, 'ICE SHEET MEASUREMENTS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > ICE SHEETS > ICE SHEET MEASUREMENTS', 1);
INSERT INTO {schema}.keywords VALUES (6817, '94402f47-38ea-4798-98da-ea17599e092f', 5499, 'SURFACE MORPHOLOGY', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > ICE SHEETS > SURFACE MORPHOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (6818, 'a3f36d7c-4eed-4d7a-8902-a5fcdc1b6261', 5520, 'ICE FRACTION', 'EARTH SCIENCE > CRYOSPHERE > SEA ICE > SEA ICE CONCENTRATION > ICE FRACTION', 1);
INSERT INTO {schema}.keywords VALUES (6819, '2dce1d90-f958-4e96-b8d8-c8b0bc69d16e', 5537, 'BIDIRECTIONAL REFLECTANCE DISTRIBUTION FUNCTION', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > REFLECTANCE > BIDIRECTIONAL REFLECTANCE DISTRIBUTION FUNCTION', 1);
INSERT INTO {schema}.keywords VALUES (6820, 'a72b96ad-3755-4205-b353-66592c7bff54', 5545, 'SPECIFIC SURFACE AREA', 'EARTH SCIENCE > CRYOSPHERE > SNOW/ICE > SNOW MICROSTRUCTURE > SPECIFIC SURFACE AREA', 1);
INSERT INTO {schema}.keywords VALUES (6821, '245c630a-8022-46ed-9a79-8f6cf99b0822', 5553, 'COUNTRY BOUNDARIES', 'EARTH SCIENCE > HUMAN DIMENSIONS > BOUNDARIES > POLITICAL DIVISIONS > COUNTRY BOUNDARIES', 1);
INSERT INTO {schema}.keywords VALUES (6822, 'ef04f170-4797-4db1-aff7-ad493b6a7cda', 5553, 'STATE BOUNDARIES', 'EARTH SCIENCE > HUMAN DIMENSIONS > BOUNDARIES > POLITICAL DIVISIONS > STATE BOUNDARIES', 1);
INSERT INTO {schema}.keywords VALUES (6823, '941c691a-3bff-4c58-854a-16c5529524e9', 5554, 'MONOCULTURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > AGRICULTURE PRODUCTION > MONOCULTURE', 1);
INSERT INTO {schema}.keywords VALUES (6824, '99ed30c9-332c-4acf-8620-eab3c67bcc90', 5556, 'BIOMASS ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > BIOMASS ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6825, 'c90081fb-f6c2-4f7c-a124-0cd432e92200', 5556, 'COAL PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > COAL PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6826, '05410006-351a-4877-96e8-f0a821161ecf', 5556, 'GEOTHERMAL ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > GEOTHERMAL ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6827, '7eba0eef-3a30-4282-a162-1f483370ddc4', 5556, 'HYDROELECTRIC ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > HYDROELECTRIC ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6828, 'c346378a-09ee-428c-89c1-c94354cdc74f', 5556, 'HYDROGEN PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > HYDROGEN PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6829, 'd3b2e908-b732-480c-a9cb-2e981da52094', 5556, 'METHANE PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > METHANE PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6830, '83bddfa5-d9ba-40f1-9a2f-1bee33559176', 5556, 'NATURAL GAS PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > NATURAL GAS PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6831, '582af998-1f5c-48a7-8cdd-70fe06bb9f17', 5556, 'NUCLEAR ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > NUCLEAR ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6832, 'e5d17711-c9c1-42f6-96e4-c618c0df37cb', 5556, 'OIL PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > OIL PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6833, 'e4774745-c565-4b9e-a642-6fa4a0b3b79b', 5556, 'PETROLEUM PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > PETROLEUM PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6834, '8b4f34c1-7aed-4833-811a-401382abd17c', 5556, 'SOLAR ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > SOLAR ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6835, '1eb6eeff-77f8-40b6-8e4a-2e4438f00b10', 5556, 'TIDAL ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > TIDAL ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6836, '62c1fec5-3512-4136-a060-ec2338a48296', 5556, 'WAVE ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > WAVE ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6837, 'b3a95e10-1c1d-41cf-8802-8bb1d3a41353', 5556, 'WIND ENERGY PRODUCTION/USE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > ENERGY PRODUCTION/USE > WIND ENERGY PRODUCTION/USE', 1);
INSERT INTO {schema}.keywords VALUES (6838, 'e6cf64ce-389f-479c-835a-eecd612d4d88', 5558, 'ECOTOURISM', 'EARTH SCIENCE > HUMAN DIMENSIONS > ECONOMIC RESOURCES > TOURISM > ECOTOURISM', 1);
INSERT INTO {schema}.keywords VALUES (6839, '1595c0a9-63a8-433c-8515-044a977d73a7', 5564, 'CARBON DIOXIDE REMOVAL', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > GEOENGINEERING > CARBON DIOXIDE REMOVAL', 1);
INSERT INTO {schema}.keywords VALUES (6840, '0f583845-c39e-471d-a590-8212a4358e1e', 5564, 'SOLAR RADIATION MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > GEOENGINEERING > SOLAR RADIATION MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (6841, '0ceb5ef1-5a07-4f93-8e86-d3cc2baf5768', 5565, 'LAND TENURE', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > LAND MANAGEMENT > LAND TENURE', 1);
INSERT INTO {schema}.keywords VALUES (6842, '1fd206a9-83a7-4f43-902d-003811080fed', 5565, 'LAND USE CLASSES', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > LAND MANAGEMENT > LAND USE CLASSES', 1);
INSERT INTO {schema}.keywords VALUES (6843, '5066def0-b14b-4a2c-b40f-dc9953860366', 5565, 'LAND USE/LAND COVER CLASSIFICATION', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > LAND MANAGEMENT > LAND USE/LAND COVER CLASSIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (6844, '96810430-e7e1-45eb-a4eb-8a7e17fe5076', 5567, 'GROUNDWATER MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > WATER MANAGEMENT > GROUNDWATER MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (6845, '873e35f5-908b-4418-861e-eab5d13a19a4', 5567, 'STORMWATER MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > WATER MANAGEMENT > STORMWATER MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (6846, 'cbf64c32-99fa-4312-91a0-4fc85a6890bb', 5567, 'WASTEWATER MANAGEMENT', 'EARTH SCIENCE > HUMAN DIMENSIONS > ENVIRONMENTAL GOVERNANCE/MANAGEMENT > WATER MANAGEMENT > WASTEWATER MANAGEMENT', 1);
INSERT INTO {schema}.keywords VALUES (6847, '0720043d-4d31-45ae-a37c-9ba5959bf97d', 5617, 'CYCLONES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TROPICAL CYCLONES > CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (6848, '6314f68a-1f00-4e6d-9f06-b3e2ce4348e8', 5617, 'HURRICANES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TROPICAL CYCLONES > HURRICANES', 1);
INSERT INTO {schema}.keywords VALUES (6849, '4bee2d4d-d15d-4300-8804-626eff7ac0f3', 5617, 'SEVERE CYCLONIC STORMS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TROPICAL CYCLONES > SEVERE CYCLONIC STORMS', 1);
INSERT INTO {schema}.keywords VALUES (6850, '6f7996f7-5905-42e7-b9fd-c24c6328b5d9', 5617, 'SEVERE TROPICAL CYCLONES', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TROPICAL CYCLONES > SEVERE TROPICAL CYCLONES', 1);
INSERT INTO {schema}.keywords VALUES (6851, 'bd5c19e4-b25a-48b2-ad9d-4596a0ba67de', 5617, 'TYPHOONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > TROPICAL CYCLONES > TYPHOONS', 1);
INSERT INTO {schema}.keywords VALUES (6852, '436b098d-e4d9-4fbd-9ede-05675e111eee', 5620, 'BURNED AREA', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > WILDFIRES > BURNED AREA', 1);
INSERT INTO {schema}.keywords VALUES (6853, '5e693789-87a8-4f94-9b5d-a50cecf55e24', 5620, 'WILDFIRE SUPPRESSION', 'EARTH SCIENCE > HUMAN DIMENSIONS > NATURAL HAZARDS > WILDFIRES > WILDFIRE SUPPRESSION', 1);
INSERT INTO {schema}.keywords VALUES (6854, '611f0108-5706-43ca-bc39-38e528f6024b', 5621, 'INFANT MORTALITY RATES', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > MORTALITY > INFANT MORTALITY RATES', 1);
INSERT INTO {schema}.keywords VALUES (6855, '918c4136-bb4c-422b-9c15-8273307546d1', 5621, 'MORTALITY RATES', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > MORTALITY > MORTALITY RATES', 1);
INSERT INTO {schema}.keywords VALUES (6856, 'd0931461-2e93-418c-b470-a218cadcf498', 5622, 'NATALITY RATES', 'EARTH SCIENCE > HUMAN DIMENSIONS > POPULATION > NATALITY > NATALITY RATES', 1);
INSERT INTO {schema}.keywords VALUES (6857, 'b8a877b7-d867-4305-9053-3777e5dd330a', 5628, 'EPIDEMIOLOGY', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > DISEASES/EPIDEMICS > EPIDEMIOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (6858, '007eeff3-1c96-4b54-aa35-2de5ebb9971a', 5628, 'FOODBORNE DISEASES', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > DISEASES/EPIDEMICS > FOODBORNE DISEASES', 1);
INSERT INTO {schema}.keywords VALUES (6859, '9d92320e-b9b9-4ae8-8394-252eeda7ceb1', 5628, 'VECTOR-BORNE DISEASES', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > DISEASES/EPIDEMICS > VECTOR-BORNE DISEASES', 1);
INSERT INTO {schema}.keywords VALUES (6860, '68447296-6019-453b-9684-3cd3ff1530c9', 5628, 'WATERBORNE DISEASES', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > DISEASES/EPIDEMICS > WATERBORNE DISEASES', 1);
INSERT INTO {schema}.keywords VALUES (6861, '6984e0a6-cb78-4f60-a31d-3ff8415e3829', 5629, 'AEROALLERGENS', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > ENVIRONMENTAL HEALTH FACTORS > AEROALLERGENS', 1);
INSERT INTO {schema}.keywords VALUES (6862, '681812bd-c115-42b2-b717-f89715e89406', 5629, 'PARTICULATE MATTER CONCENTRATIONS', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > ENVIRONMENTAL HEALTH FACTORS > PARTICULATE MATTER CONCENTRATIONS', 1);
INSERT INTO {schema}.keywords VALUES (6863, '5ce8b673-cdb9-4000-ad00-774d1c67c1b1', 5629, 'URBAN HEAT ISLAND', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > ENVIRONMENTAL HEALTH FACTORS > URBAN HEAT ISLAND', 1);
INSERT INTO {schema}.keywords VALUES (6864, '4dcd46e9-4830-4de0-b75a-820729a6d787', 5631, 'MALNUTRITION RATES', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > MALNUTRITION > MALNUTRITION RATES', 1);
INSERT INTO {schema}.keywords VALUES (6865, '4b95ab99-4784-44aa-99f0-ecc677dbda65', 5633, 'MORBIDITY RATES', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > MORBIDITY > MORBIDITY RATES', 1);
INSERT INTO {schema}.keywords VALUES (6866, '416221ec-04e1-4913-aacb-9045551949c4', 5671, 'DUNES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES', 1);
INSERT INTO {schema}.keywords VALUES (6867, '1376f8a1-84f2-4797-a978-69ec520e2423', 5671, 'RIPPLES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > RIPPLES', 1);
INSERT INTO {schema}.keywords VALUES (6868, 'eb039da2-8af7-4d31-9ec9-0700251cfd5d', 5672, 'ABRASION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (6869, '03ea18fe-793d-48e0-aa44-e211376c73d8', 5672, 'DEFLATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > DEFLATION', 1);
INSERT INTO {schema}.keywords VALUES (6870, '32f6083c-f6a2-40cf-8cf4-782b02b9df9e', 5672, 'DEGRADATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (6871, 'cfaf76ef-89e2-4dc8-a4eb-b3308ef8c52c', 5672, 'SALTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SALTATION', 1);
INSERT INTO {schema}.keywords VALUES (6872, '0b5e5a9b-5552-4e41-b1a1-9c01c52dff4b', 5672, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (6873, '5fff607c-5df4-4f06-a541-896f7cbc1e4c', 5672, 'SEDIMENTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (6874, '82eac236-38ba-469d-837a-950ffa7e8316', 5672, 'WEATHERING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (6875, '128db882-0522-4a5e-ac69-81d05986a645', 5673, 'BARRIER ISLANDS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > BARRIER ISLANDS', 1);
INSERT INTO {schema}.keywords VALUES (6876, '68b4238d-c10f-4f59-9c23-820563107d12', 5673, 'BEACHES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > BEACHES', 1);
INSERT INTO {schema}.keywords VALUES (6877, 'c6244bfb-300f-4818-bf45-cf1a15e7e073', 5673, 'CORAL REEFS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS', 1);
INSERT INTO {schema}.keywords VALUES (6878, '11175bd5-ee63-4b13-aa03-bc5500a458c2', 5673, 'CUSPATE FORELANDS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CUSPATE FORELANDS', 1);
INSERT INTO {schema}.keywords VALUES (6879, '93647a7c-a881-4066-a696-c19053c7c30b', 5673, 'DELTAS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DELTAS', 1);
INSERT INTO {schema}.keywords VALUES (6880, '362993fc-743e-42bc-a011-459baea8f427', 5673, 'DUNES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES', 1);
INSERT INTO {schema}.keywords VALUES (6881, '8d634619-aed2-4326-a73d-cec49ff74398', 5673, 'ESTUARIES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > ESTUARIES', 1);
INSERT INTO {schema}.keywords VALUES (6882, '7299f45f-eafb-4ed9-ae12-5e01c97c1530', 5673, 'FJORDS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > FJORDS', 1);
INSERT INTO {schema}.keywords VALUES (6883, '153080e1-2ab1-438a-8f1e-0cb6d5fe1242', 5673, 'HEADLANDS/BAYS/CAPE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > HEADLANDS/BAYS/CAPE', 1);
INSERT INTO {schema}.keywords VALUES (6884, '49db8758-1282-45a0-ad3f-0f1e9d8abc44', 5673, 'INLETS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > INLETS', 1);
INSERT INTO {schema}.keywords VALUES (6885, 'e069e3fc-0c75-40ee-92d7-595991f8fdb4', 5673, 'ISTHMUS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > ISTHMUS', 1);
INSERT INTO {schema}.keywords VALUES (6886, 'd9483208-ff59-4293-9867-3f4895e58c9f', 5673, 'LAGOONS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > LAGOONS', 1);
INSERT INTO {schema}.keywords VALUES (6887, '1e7daefd-fa73-4561-90cc-478ca37bcb9a', 5673, 'RIA', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > RIA', 1);
INSERT INTO {schema}.keywords VALUES (6888, 'd541e4e1-2542-4716-b943-e080b0865e74', 5673, 'SALT MARSH', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SALT MARSH', 1);
INSERT INTO {schema}.keywords VALUES (6889, '575d5577-3107-4192-83a3-5a28ceea7a5d', 5673, 'SEA ARCHES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SEA ARCHES', 1);
INSERT INTO {schema}.keywords VALUES (6890, 'c702cd1d-48dd-4652-9ec6-cff6ff52b430', 5673, 'SEA CAVES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SEA CAVES', 1);
INSERT INTO {schema}.keywords VALUES (6891, 'a82477e6-b563-4135-90e8-c6977c7381be', 5673, 'SEA CLIFFS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SEA CLIFFS', 1);
INSERT INTO {schema}.keywords VALUES (6892, 'cae5bafd-10a7-4bcf-af1a-3e187ee5e955', 5673, 'SHOALS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SHOALS', 1);
INSERT INTO {schema}.keywords VALUES (6893, '4e5cf935-cf17-4947-bd1f-6816a855953a', 5673, 'SHORELINES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SHORELINES', 1);
INSERT INTO {schema}.keywords VALUES (6894, '1815faf3-2411-4d2a-a3d5-1e5b0c50782b', 5673, 'SOUNDS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (6895, '4f25c039-56b9-47a9-9232-d80860da5990', 5673, 'SPITS AND BARS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SPITS AND BARS', 1);
INSERT INTO {schema}.keywords VALUES (6896, '320e14a6-4882-4533-b1cf-55d49c8a6b37', 5673, 'TOMBOLOS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > TOMBOLOS', 1);
INSERT INTO {schema}.keywords VALUES (6897, '0c523ed2-d02e-4b02-bf21-2da4e171c959', 5673, 'WAVE-CUT NOTCH/PLATFORMS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > WAVE-CUT NOTCH/PLATFORMS', 1);
INSERT INTO {schema}.keywords VALUES (6898, '9ca8db82-9230-42e0-ad91-9068bc144855', 5674, 'ABRASION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (6899, 'ee016b0b-353b-4811-bfc2-5d32aed59f29', 5674, 'ACCRETION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > ACCRETION', 1);
INSERT INTO {schema}.keywords VALUES (6900, '4dee8110-972f-4665-bd28-a9e64de21a16', 5674, 'ATTRITION/WEATHERING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > ATTRITION/WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (6901, '1e73dd30-abb5-4723-be3e-71706d2b1ea1', 5674, 'CHEMICAL SOLUTION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > CHEMICAL SOLUTION', 1);
INSERT INTO {schema}.keywords VALUES (6902, '8b99d6c3-1751-43e6-81d1-92a7618cadb3', 5674, 'DEPOSITION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > DEPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (6903, 'a2401a77-908f-4c03-abcc-d27d99586967', 5674, 'FLOODING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > FLOODING', 1);
INSERT INTO {schema}.keywords VALUES (6904, 'ebb8ef06-0f73-48eb-bc22-47f36a729bc6', 5674, 'HYDRAULIC ACTION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > HYDRAULIC ACTION', 1);
INSERT INTO {schema}.keywords VALUES (6905, 'c344fddc-ffa8-4093-bcf5-bcfe7806c737', 5674, 'SALTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SALTATION', 1);
INSERT INTO {schema}.keywords VALUES (6906, '2aad0e7e-1c96-4d87-adeb-4894225e2922', 5674, 'SEA LEVEL CHANGES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEA LEVEL CHANGES', 1);
INSERT INTO {schema}.keywords VALUES (6907, '5e101ced-5d9f-4733-8768-38db92d83660', 5674, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (6908, '866aa07b-132c-4b93-9ced-d74b56b3016f', 5674, 'SEDIMENTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (6909, '43b2798d-32ac-497f-8881-98d52422e3ac', 5674, 'SUBMERGENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SUBMERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (6910, 'af017320-085a-4e6c-81c2-38056cb55c7b', 5674, 'SUBSIDENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SUBSIDENCE', 1);
INSERT INTO {schema}.keywords VALUES (6911, '62ecfc64-48d0-4373-9c44-599471703cf4', 5674, 'SUSPENSION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SUSPENSION', 1);
INSERT INTO {schema}.keywords VALUES (6912, '406bfa8b-8522-4776-936a-1fda8b0cfe97', 5674, 'WAVE BREAKING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE BREAKING', 1);
INSERT INTO {schema}.keywords VALUES (6913, 'ab0138b8-6939-4ac1-aa5f-36073d52360b', 5674, 'WAVE DIFFRACTION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE DIFFRACTION', 1);
INSERT INTO {schema}.keywords VALUES (6914, '097a7f54-df6e-4aeb-8d15-65d4bd24da64', 5674, 'WAVE EROSION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE EROSION', 1);
INSERT INTO {schema}.keywords VALUES (6915, 'df4a0112-3aba-41ca-816a-86129cacb6a5', 5674, 'WAVE REFRACTION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE REFRACTION', 1);
INSERT INTO {schema}.keywords VALUES (6916, '15d5b23c-f739-43b5-bf14-3063c0a59f2d', 5674, 'WAVE SHOALING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE SHOALING', 1);
INSERT INTO {schema}.keywords VALUES (6917, '3207af29-bd29-4f85-9a08-2614579dd27f', 5675, 'AIT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > AIT', 1);
INSERT INTO {schema}.keywords VALUES (6918, 'ff850d62-675c-4386-a375-fe4af92ec3ff', 5675, 'BAR', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > BAR', 1);
INSERT INTO {schema}.keywords VALUES (6919, 'a6fdb3c7-a0ea-4f7c-82e5-d72db09b6444', 5675, 'BAYOU', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > BAYOU', 1);
INSERT INTO {schema}.keywords VALUES (6920, 'a78c946a-9529-4643-b002-1aa2ac9cfed6', 5675, 'CANYON', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > CANYON', 1);
INSERT INTO {schema}.keywords VALUES (6921, 'e18c970a-d0c6-4430-b419-64cf718bc456', 5675, 'CONFLUENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > CONFLUENCE', 1);
INSERT INTO {schema}.keywords VALUES (6922, '47ea7cc6-2816-4d64-ad41-6ac1d11c2a33', 5675, 'CUTBANK', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > CUTBANK', 1);
INSERT INTO {schema}.keywords VALUES (6923, 'daa297ec-4397-4caa-b563-634a71f62b8a', 5675, 'DELTAS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > DELTAS', 1);
INSERT INTO {schema}.keywords VALUES (6924, '1afe698e-d920-4756-8de4-482d2ef15a24', 5675, 'ENDORHEIC BASIN', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > ENDORHEIC BASIN', 1);
INSERT INTO {schema}.keywords VALUES (6925, 'ba37314d-ec38-4e67-bf30-7e1fdc6bfbad', 5675, 'FLOOD PLAIN', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > FLOOD PLAIN', 1);
INSERT INTO {schema}.keywords VALUES (6926, 'b9b85df8-3b95-4baf-bd32-8bacd35dc9b5', 5675, 'GULLY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > GULLY', 1);
INSERT INTO {schema}.keywords VALUES (6927, '9d078d5c-62cb-46b5-a6f5-43678643a0ce', 5675, 'ISLAND', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > ISLAND', 1);
INSERT INTO {schema}.keywords VALUES (6928, '8ca51b5e-0b7a-4b7a-b7e2-6e163e195e26', 5675, 'LACUSTRINE PLAIN', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > LACUSTRINE PLAIN', 1);
INSERT INTO {schema}.keywords VALUES (6929, '4c09d43f-68d5-469d-aaed-f9ef8968ef2e', 5675, 'MARSH', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > MARSH', 1);
INSERT INTO {schema}.keywords VALUES (6930, 'b976b8e5-01b9-4bb3-ba4c-308f8fa0fb97', 5675, 'MEANDER', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > MEANDER', 1);
INSERT INTO {schema}.keywords VALUES (6931, 'c5a9eb49-93c4-4fb5-9a02-5fa06ea8800f', 5675, 'OX-BOW LAKE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > OX-BOW LAKE', 1);
INSERT INTO {schema}.keywords VALUES (6932, '71b4e773-40a4-47db-8449-7c13f4cc49d9', 5675, 'PINGO', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > PINGO', 1);
INSERT INTO {schema}.keywords VALUES (6933, '00e49fcb-d846-4b4e-8f45-b022c1713920', 5675, 'POINT BAR', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > POINT BAR', 1);
INSERT INTO {schema}.keywords VALUES (6934, '89228e69-5a64-4662-839f-cb3d2209fa41', 5675, 'POND', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > POND', 1);
INSERT INTO {schema}.keywords VALUES (6935, 'af058c0e-d40b-4e59-9f92-67b59fd1e2bd', 5675, 'RIFFLE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > RIFFLE', 1);
INSERT INTO {schema}.keywords VALUES (6936, '87624706-e11f-4043-ac54-479ed94b8dac', 5675, 'RIVER', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > RIVER', 1);
INSERT INTO {schema}.keywords VALUES (6937, '620a9e6c-5851-48b7-93c5-a1706546f5d1', 5675, 'SPRING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > SPRING', 1);
INSERT INTO {schema}.keywords VALUES (6938, 'd1964724-2481-417a-be5a-e0dedb111ab4', 5675, 'STREAM TERRACE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > STREAM TERRACE', 1);
INSERT INTO {schema}.keywords VALUES (6939, '01a84bc1-a571-4d23-b57f-1b04fd9542a6', 5675, 'STREAM', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > STREAM', 1);
INSERT INTO {schema}.keywords VALUES (6940, '8f6adff6-672d-4066-8c85-25418a7d0e00', 5675, 'SWAMP', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > SWAMP', 1);
INSERT INTO {schema}.keywords VALUES (6941, 'f4f9c238-2d7e-4529-944b-52389c13932c', 5675, 'VALLEY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (6942, '97c6eb84-90a8-4b47-9a22-99c7c1369989', 5675, 'WATERFALL', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > WATERFALL', 1);
INSERT INTO {schema}.keywords VALUES (6943, 'feceb3aa-d3b4-49e0-ad85-3275acd604fb', 5675, 'WATERSHED/DRAINAGE BASIN', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > WATERSHED/DRAINAGE BASIN', 1);
INSERT INTO {schema}.keywords VALUES (6944, '6ae0d1f7-cc99-4da7-8446-e2dca16f546b', 5676, 'ABRASION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (6945, 'b655ca30-361c-4434-a784-68b8ab99668d', 5676, 'ATTRITION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > ATTRITION', 1);
INSERT INTO {schema}.keywords VALUES (6946, 'ae368822-4979-4feb-967b-ee7764639646', 5676, 'DEGRADATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (6947, '0bb77741-598a-4f8c-8ce9-5aa0d61a0906', 5676, 'DOWNCUTTING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > DOWNCUTTING', 1);
INSERT INTO {schema}.keywords VALUES (6948, '3288c7e0-20fa-4e05-80fa-cdb14c436c7e', 5676, 'ENTRAINMENT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > ENTRAINMENT', 1);
INSERT INTO {schema}.keywords VALUES (6949, 'b13bf33a-2a06-489f-80ca-0c77b08588ec', 5676, 'HYDRAULIC ACTION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > HYDRAULIC ACTION', 1);
INSERT INTO {schema}.keywords VALUES (6950, 'c09cb9dc-2916-40f0-9f2f-4bbb39d2e7c9', 5676, 'LANDSLIDES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > LANDSLIDES', 1);
INSERT INTO {schema}.keywords VALUES (6951, 'e8ba38ce-fc48-44b7-8b78-03b69e068d46', 5676, 'SALTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SALTATION', 1);
INSERT INTO {schema}.keywords VALUES (6952, '4a031bdf-a6c6-40b8-9c92-34cd83a5739e', 5676, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (6953, 'b1de8d2f-cfe6-4358-a4cd-5b7e19d0e585', 5676, 'SEDIMENTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (6954, '26352dff-a48b-4b4a-a442-3b5039cf55c0', 5676, 'SUSPENSION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SUSPENSION', 1);
INSERT INTO {schema}.keywords VALUES (6955, '5d05853c-b709-484f-a406-03f64e643ea4', 5676, 'WEATHERING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (6956, 'd37d51e0-1bef-473a-9221-6713166762f9', 5677, 'ARETES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ARETES', 1);
INSERT INTO {schema}.keywords VALUES (6957, 'b3032f74-fcdf-41d7-8899-2f2b140209c9', 5677, 'CIRQUES/COMBES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CIRQUES/COMBES', 1);
INSERT INTO {schema}.keywords VALUES (6958, 'b1d30791-5871-474f-aedf-2d4aa51e2b92', 5677, 'CREVASSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (6959, '614309a2-4332-4695-aa77-d11794fe4733', 5677, 'DRUMLINS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > DRUMLINS', 1);
INSERT INTO {schema}.keywords VALUES (6960, '158a8764-a6e4-4d28-a1b9-b2ab91e09995', 5677, 'ESKERS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ESKERS', 1);
INSERT INTO {schema}.keywords VALUES (6961, '666d9a2b-aaa8-4789-a9d9-a6774e650fe4', 5677, 'FJORDS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > FJORDS', 1);
INSERT INTO {schema}.keywords VALUES (6962, '8c878cc0-d601-4371-af35-9db2c67d8de6', 5677, 'GLACIAL HORNS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIAL HORNS', 1);
INSERT INTO {schema}.keywords VALUES (6963, 'c8ad9c7e-384d-42c9-a75c-813a67e4dbfa', 5677, 'GLACIER STRIATIONS/GROOVES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIER STRIATIONS/GROOVES', 1);
INSERT INTO {schema}.keywords VALUES (6964, '7335b131-0e86-41b3-a0bc-b28120a0a78a', 5677, 'GLACIER/HANGING/U-SHAPED VALLEYS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIER/HANGING/U-SHAPED VALLEYS', 1);
INSERT INTO {schema}.keywords VALUES (6965, '0a009cb2-9883-48d3-8b91-21efb75b4347', 5677, 'GLACIER/ICE CAVES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIER/ICE CAVES', 1);
INSERT INTO {schema}.keywords VALUES (6966, '86c6042a-b7ca-4d97-b9d7-db22b1560810', 5677, 'ICE-DAMMED LAKES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ICE-DAMMED LAKES', 1);
INSERT INTO {schema}.keywords VALUES (6967, '6a8d6d83-1a3b-452c-90b8-f37b28bd7eb6', 5677, 'KAME DELTA', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > KAME DELTA', 1);
INSERT INTO {schema}.keywords VALUES (6968, 'a3407182-6908-4206-b2fd-4c39da4072ce', 5677, 'KAMES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > KAMES', 1);
INSERT INTO {schema}.keywords VALUES (6969, '0557b602-cf85-4b04-82a7-ca76f364e5f4', 5677, 'KETTLE HOLES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > KETTLE HOLES', 1);
INSERT INTO {schema}.keywords VALUES (6970, '2575cfaf-1a09-48b6-acb9-fda23b6f4719', 5677, 'MORAINES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES', 1);
INSERT INTO {schema}.keywords VALUES (6971, '12e5921b-0d9b-4656-8d5c-d73abcf90a81', 5677, 'NUNATAKS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > NUNATAKS', 1);
INSERT INTO {schema}.keywords VALUES (6972, '2e62a5dd-5ea5-4cd6-8051-b5e162ef4e01', 5677, 'OUTWASH FANS/PLAINS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > OUTWASH FANS/PLAINS', 1);
INSERT INTO {schema}.keywords VALUES (6973, 'e96cea31-2bee-4d9d-bf4a-d0f469aa3bd4', 5677, 'ROCHE MOUTONNEES/SHEEPBACK', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ROCHE MOUTONNEES/SHEEPBACK', 1);
INSERT INTO {schema}.keywords VALUES (6974, 'fcbf8f96-ac53-41b6-9c98-a87425a4ec82', 5677, 'ROCK GLACIERS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ROCK GLACIERS', 1);
INSERT INTO {schema}.keywords VALUES (6975, 'bffac466-83aa-4060-a378-6d2d6e49f2a1', 5677, 'TILL PLAINS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > TILL PLAINS', 1);
INSERT INTO {schema}.keywords VALUES (6976, 'ad793d5e-b75d-4d3e-a542-ad4b4075b141', 5678, 'ABLATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > ABLATION', 1);
INSERT INTO {schema}.keywords VALUES (6977, 'c4c96fc4-c75b-4e98-852d-b28fdf6b77a4', 5678, 'ABRASION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (6978, 'df77e4c7-0b22-4f14-afa5-11b1d335a315', 5678, 'CRUST REBOUND', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > CRUST REBOUND', 1);
INSERT INTO {schema}.keywords VALUES (6979, 'eb31cb40-97cf-4445-8abd-d375391edf6f', 5678, 'DEGRADATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (6980, '45ee1fde-6b00-4aca-ac1b-6c13e2361467', 5678, 'DUMPING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > DUMPING', 1);
INSERT INTO {schema}.keywords VALUES (6981, '10ec2826-c4ac-4373-ad05-9bb4eb35b360', 5678, 'ENTRAINMENT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > ENTRAINMENT', 1);
INSERT INTO {schema}.keywords VALUES (6982, 'e2ea5b37-7004-4943-ad69-ca39a57569a4', 5678, 'FIRN FORMATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > FIRN FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (6983, '24b052b6-5996-496d-9e91-1fdbda5897da', 5678, 'FREEZE/THAW', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > FREEZE/THAW', 1);
INSERT INTO {schema}.keywords VALUES (6984, 'aa74db50-4ae7-463b-903a-2a256f967ca8', 5678, 'GLACIAL DISPLACEMENT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL DISPLACEMENT', 1);
INSERT INTO {schema}.keywords VALUES (6985, 'b313436f-d925-48b7-a339-e6a08475b6e1', 5678, 'GLACIAL DRIFT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL DRIFT', 1);
INSERT INTO {schema}.keywords VALUES (6986, '6743ea28-0a6e-4d47-ac71-0c9cdf24ac25', 5678, 'GLACIAL GROWTH', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL GROWTH', 1);
INSERT INTO {schema}.keywords VALUES (6987, '12bb9ec2-a706-436d-aa29-253495276052', 5678, 'GLACIAL STRIATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL STRIATION', 1);
INSERT INTO {schema}.keywords VALUES (6988, 'f8b73efd-d313-41d8-995a-49b80bc8f248', 5678, 'GLACIER CRUST SUBSIDENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIER CRUST SUBSIDENCE', 1);
INSERT INTO {schema}.keywords VALUES (6989, '2f8b965f-0a0e-427f-a696-ac6b4323744e', 5678, 'PERIGLACIAL PROCESSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > PERIGLACIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (6990, '53e26c7c-5e85-4dd0-a999-8de519bf9976', 5678, 'PLUCKING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > PLUCKING', 1);
INSERT INTO {schema}.keywords VALUES (6991, '92e348f3-9e6c-4e9e-a1bc-ee72d04755d6', 5678, 'SCOURING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SCOURING', 1);
INSERT INTO {schema}.keywords VALUES (6992, '8c6d4f39-6ae0-4c8d-ad48-2f82bb4e1541', 5678, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (6993, 'b609e525-db71-4634-b569-f8aab5ad544e', 5678, 'SEDIMENTATION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (6994, '07825acf-619a-4689-b1ed-09c15166624c', 5678, 'WEATHERING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (6995, 'cdeff06c-28ec-4a4c-b522-4a46f1f9a239', 5679, 'CAVES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > CAVES', 1);
INSERT INTO {schema}.keywords VALUES (6996, 'ee347068-e1ff-4271-8726-8343f4f15614', 5679, 'COCKPIT/TOWER KARST', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > COCKPIT/TOWER KARST', 1);
INSERT INTO {schema}.keywords VALUES (6997, 'c9323363-ea07-479d-8b64-e3dbf298a7c5', 5679, 'KARST VALLEY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > KARST VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (6998, 'b9e8b2e3-ea76-4ce9-8a25-64ba0cdef913', 5679, 'SINKHOLES (DOLINES)', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > SINKHOLES (DOLINES)', 1);
INSERT INTO {schema}.keywords VALUES (6999, 'd42a8f13-c438-4794-9f37-bd7870ec731d', 5679, 'UVALA', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > UVALA', 1);
INSERT INTO {schema}.keywords VALUES (7000, '50fd29da-a846-4dd6-98e8-e826b75eeda7', 5680, 'CAC03', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > CAC03', 1);
INSERT INTO {schema}.keywords VALUES (7001, 'c2920f06-fd42-47da-9989-3104f8fb7282', 5680, 'DISSOLVED CO2', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > DISSOLVED CO2', 1);
INSERT INTO {schema}.keywords VALUES (7002, 'e657b41f-4aa0-4816-b3c8-5b477812a0bc', 5680, 'KARST HYDROLOGY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > KARST HYDROLOGY', 1);
INSERT INTO {schema}.keywords VALUES (7003, '0317caf8-af0a-4abe-89fb-fd1d9c33b9e7', 5680, 'POROSITY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > POROSITY', 1);
INSERT INTO {schema}.keywords VALUES (7004, 'd727d3c7-3a02-48c6-ab63-a4b3d3364783', 5680, 'WEATHERING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7005, '1a0e7a60-9c22-40c5-8424-55119b4db743', 5681, 'CALDRA', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > CALDRA', 1);
INSERT INTO {schema}.keywords VALUES (7006, 'a9f7bee8-fb32-40b1-9936-ecf6f6597b6b', 5681, 'CINDER CONE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > CINDER CONE', 1);
INSERT INTO {schema}.keywords VALUES (7007, '181fb5a4-125b-445d-b65f-adf9a919c800', 5681, 'FAULTS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > FAULTS', 1);
INSERT INTO {schema}.keywords VALUES (7008, '12d2d3ab-2f04-436f-abd4-e28517e6f86c', 5681, 'FOLDS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > FOLDS', 1);
INSERT INTO {schema}.keywords VALUES (7009, '1a888a27-8715-46c8-9e11-a6bffba00078', 5681, 'GEYSER', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > GEYSER', 1);
INSERT INTO {schema}.keywords VALUES (7010, 'f1fa2b28-dc04-4373-a6b6-bbcedfaabfb5', 5681, 'GRABEN', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > GRABEN', 1);
INSERT INTO {schema}.keywords VALUES (7011, '8493f8c2-63c3-4e1c-b813-1f0f3893a30a', 5681, 'HORST', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > HORST', 1);
INSERT INTO {schema}.keywords VALUES (7012, '78200b25-8c91-4f1b-82cc-ed79764cd647', 5681, 'LAVA DOME', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > LAVA DOME', 1);
INSERT INTO {schema}.keywords VALUES (7013, 'edb9d13d-27a1-4e9a-a32e-4e49b5e76836', 5681, 'LAVA PLAIN', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > LAVA PLAIN', 1);
INSERT INTO {schema}.keywords VALUES (7014, 'b7ff366c-4322-47bf-b12e-c3fbfb05cf54', 5681, 'MAAR', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > MAAR', 1);
INSERT INTO {schema}.keywords VALUES (7015, '8b7f66ea-d481-4641-9dbf-da90ca3ad9c9', 5681, 'MOUNTAINS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > MOUNTAINS', 1);
INSERT INTO {schema}.keywords VALUES (7016, '694e18ec-ceaf-4070-9763-f3ee6dbd6b5b', 5681, 'PLATEAU', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > PLATEAU', 1);
INSERT INTO {schema}.keywords VALUES (7017, '97298feb-6991-4d68-8337-177460e436ad', 5681, 'RIDGE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > RIDGE', 1);
INSERT INTO {schema}.keywords VALUES (7018, 'ca874a66-f3a8-4099-978c-4684944dc348', 5681, 'RIFT VALLEY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > RIFT VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (7019, 'f8a9104b-fe7b-4a60-94fc-6b5ef504db55', 5681, 'TUYA', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > TUYA', 1);
INSERT INTO {schema}.keywords VALUES (7020, '7c2e1960-ae20-46a9-acf1-a3e71542fbb4', 5681, 'VOLCANO', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > VOLCANO', 1);
INSERT INTO {schema}.keywords VALUES (7021, 'bb554660-d608-467c-b265-b9b68eecfb37', 5682, 'EPEIROGENIC MOVEMENT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > EPEIROGENIC MOVEMENT', 1);
INSERT INTO {schema}.keywords VALUES (7022, '4f0f52fb-b272-49c6-9425-690d9285c380', 5682, 'ISOSTATIC UPLIFT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > ISOSTATIC UPLIFT', 1);
INSERT INTO {schema}.keywords VALUES (7023, 'f486acc8-0d0c-4322-bf5c-177bc632bd76', 5682, 'OROGENIC MOVEMENT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > OROGENIC MOVEMENT', 1);
INSERT INTO {schema}.keywords VALUES (7024, '1b370af4-1887-4e7a-82a6-9acb9ce5dd5f', 5682, 'RIFTING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > RIFTING', 1);
INSERT INTO {schema}.keywords VALUES (7025, '0d43cb88-dd6d-40ac-b241-b628a39ed2af', 5682, 'SUBDUCTION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > SUBDUCTION', 1);
INSERT INTO {schema}.keywords VALUES (7026, '7d5472ba-ae65-45df-a19a-c762055eaead', 5682, 'TECTONIC UPLIFT', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > TECTONIC UPLIFT', 1);
INSERT INTO {schema}.keywords VALUES (7027, 'e63844c1-015c-4776-b01c-e3e7d5dd3d0c', 5686, 'VEGETATION INDEX', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER > LAND USE/LAND COVER CLASSIFICATION > VEGETATION INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7028, '05e52e24-b9ac-42cf-bdf9-1dcad56900e8', 5749, 'BED ELEVATION', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > TERRAIN ELEVATION > BED ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (7029, '120f9132-a756-4f6f-a74c-78e94dfcd2a1', 5749, 'CONTOUR MAPS', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > TERRAIN ELEVATION > CONTOUR MAPS', 1);
INSERT INTO {schema}.keywords VALUES (7030, '395372ad-2883-4b6a-a481-6383a310ca47', 5749, 'DIGITAL ELEVATION/TERRAIN MODEL (DEM)', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > TERRAIN ELEVATION > DIGITAL ELEVATION/TERRAIN MODEL (DEM)', 1);
INSERT INTO {schema}.keywords VALUES (7031, 'f7d2e34a-c5c2-4c21-9132-2472620dbda1', 5749, 'TOPOGRAPHICAL RELIEF MAPS', 'EARTH SCIENCE > LAND SURFACE > TOPOGRAPHY > TERRAIN ELEVATION > TOPOGRAPHICAL RELIEF MAPS', 1);
INSERT INTO {schema}.keywords VALUES (7032, 'd80c015f-a383-4883-8309-6aab1c39f5b6', 5754, 'COASTAL BATHYMETRY', 'EARTH SCIENCE > OCEANS > BATHYMETRY/SEAFLOOR TOPOGRAPHY > BATHYMETRY > COASTAL BATHYMETRY', 1);
INSERT INTO {schema}.keywords VALUES (7033, 'f5df87b6-ed50-4da0-9ba5-7ce4c907bdb3', 5766, 'CORAL BLEACHING', 'EARTH SCIENCE > OCEANS > COASTAL PROCESSES > CORAL REEFS > CORAL BLEACHING', 1);
INSERT INTO {schema}.keywords VALUES (7034, '37669b8c-1940-4330-b4e9-ee49ad3673b5', 5851, 'CHLOROPHYLL', 'EARTH SCIENCE > OCEANS > OCEAN CHEMISTRY > PIGMENTS > CHLOROPHYLL', 1);
INSERT INTO {schema}.keywords VALUES (7035, '833b6958-fc93-473c-aadb-bb65da7578e5', 6033, 'HYDROGEN GAS VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > HYDROGEN GAS > HYDROGEN GAS VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7036, '58769369-608c-4482-924b-207454a5fb1c', 6034, 'NATURAL GAS VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > NATURAL GAS > NATURAL GAS VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7037, '37f3fdb8-a82f-4bff-bda4-cca12a683d6f', 6035, 'MICROFOSSIL', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > PETROLEUM > MICROFOSSIL', 1);
INSERT INTO {schema}.keywords VALUES (7038, 'f9e3595d-29b6-462a-8eb6-a06e5a02b081', 6035, 'PETROLEUM VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > EARTH GASES/LIQUIDS > PETROLEUM > PETROLEUM VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7039, '14d972b3-a587-4994-a021-f1e620b02341', 6037, 'CHEMICAL DECOMPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > BIOGEOCHEMICAL PROCESSES > CHEMICAL DECOMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7040, '8c6adb44-54c5-42f1-ae19-602e248ff9d9', 6037, 'HYDROLYSIS', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > BIOGEOCHEMICAL PROCESSES > HYDROLYSIS', 1);
INSERT INTO {schema}.keywords VALUES (7041, 'd73ed320-cd5b-4994-a26a-dac5a2fc394f', 6037, 'NITRIFICATION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > BIOGEOCHEMICAL PROCESSES > NITRIFICATION', 1);
INSERT INTO {schema}.keywords VALUES (7042, '3e934184-42bd-45ff-b9c1-5c5321fd066f', 6038, 'BIODEGRATION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > BIODEGRATION', 1);
INSERT INTO {schema}.keywords VALUES (7043, 'b2a9741a-f978-46ac-83ad-e92ff07a637c', 6038, 'CARBONATE FORMATION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > CARBONATE FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7044, '84b29fbe-8200-4d21-a1a3-fe84fa4cb132', 6038, 'CHEMICAL FIXATION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > CHEMICAL FIXATION', 1);
INSERT INTO {schema}.keywords VALUES (7045, '7e140a1e-385d-4dd3-8b08-6239b082e35e', 6038, 'CHEMICAL WEATHERING', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > CHEMICAL WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7046, '7b60ab41-92e7-4550-821b-0ab7ebd3d7c8', 6038, 'DECOMPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > DECOMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7047, '2b1f870b-c679-4b6d-b02e-3eb005f0648d', 6038, 'HYDRATION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > HYDRATION', 1);
INSERT INTO {schema}.keywords VALUES (7048, 'ccbf4ef8-955b-4337-a45b-95affc360173', 6038, 'ION EXCHANGE', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > ION EXCHANGE', 1);
INSERT INTO {schema}.keywords VALUES (7049, '524cbe78-9c1f-4ef3-8aa9-0481476c253e', 6038, 'MINERAL DISSOLUTION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > MINERAL DISSOLUTION', 1);
INSERT INTO {schema}.keywords VALUES (7050, '9c2f3bee-4629-4607-9962-12fe919594a0', 6038, 'OXIDATION/REDUCTION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROCESSES > OXIDATION/REDUCTION', 1);
INSERT INTO {schema}.keywords VALUES (7051, '12ed4fa0-27cc-4e05-a2b7-bbf2fde871f6', 6039, 'CHEMICAL CONCENTRATIONS', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES > CHEMICAL CONCENTRATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7052, '849edfe2-9ed7-4211-8f57-9c8ccff0a4ea', 6039, 'ISOTOPE MEASUREMENTS', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES > ISOTOPE MEASUREMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7053, 'f7998303-d145-452d-bcff-770f62038909', 6039, 'ISOTOPE RATIOS', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES > ISOTOPE RATIOS', 1);
INSERT INTO {schema}.keywords VALUES (7054, '441ce068-91f2-4412-8893-c0096d8f9079', 6039, 'ISOTOPES', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES > ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (7055, '211d289d-fae7-4815-9f3d-28a5afc7b3a9', 6039, 'ISOTOPIC AGE', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES > ISOTOPIC AGE', 1);
INSERT INTO {schema}.keywords VALUES (7056, '2dc96cc9-a128-4dc8-b8c8-1d799201b5c6', 6039, 'ROCK-EVAL PRYOLYSIS', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > GEOCHEMICAL PROPERTIES > ROCK-EVAL PRYOLYSIS', 1);
INSERT INTO {schema}.keywords VALUES (7057, '4efb531e-3c6c-4469-9215-d55a8a6ce9da', 6040, 'CHEMICAL DECOMPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > MARINE GEOCHEMICAL PROCESSES > CHEMICAL DECOMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7058, '6628bfb9-c0e1-4281-9b1a-d213a9d5b2d8', 6040, 'DISSOLUTION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > MARINE GEOCHEMICAL PROCESSES > DISSOLUTION', 1);
INSERT INTO {schema}.keywords VALUES (7059, 'f956cc7c-da39-4eac-98ab-ba6207181b7d', 6040, 'MINERAL DISSOLUTION', 'EARTH SCIENCE > SOLID EARTH > GEOCHEMISTRY > MARINE GEOCHEMICAL PROCESSES > MINERAL DISSOLUTION', 1);
INSERT INTO {schema}.keywords VALUES (7060, 'bb5ca226-fdb1-4fab-9988-7486c643635b', 6041, 'COUNTRY/REGIONAL COORDINATE REFERENCE SYSTEM', 'EARTH SCIENCE > SOLID EARTH > GEODETICS > COORDINATE REFERENCE SYSTEM > COUNTRY/REGIONAL COORDINATE REFERENCE SYSTEM', 1);
INSERT INTO {schema}.keywords VALUES (7061, 'e0a2edbb-8a94-4f47-918a-fe9f93aba5f4', 6041, 'GLOBAL COORDINATE REFERENCE SYSTEM', 'EARTH SCIENCE > SOLID EARTH > GEODETICS > COORDINATE REFERENCE SYSTEM > GLOBAL COORDINATE REFERENCE SYSTEM', 1);
INSERT INTO {schema}.keywords VALUES (7062, 'd55d29e8-9015-4c23-b137-528eb298aa49', 6044, 'ELECTRICAL ANOMALIES', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > ELECTRICAL FIELD > ELECTRICAL ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (7063, '84d77f98-d5a2-4da8-9ba6-0b15e082d050', 6044, 'ELECTRICAL INTENSITY', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > ELECTRICAL FIELD > ELECTRICAL INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (7064, '2d3d9a57-44e8-43c0-98b4-b4891c994862', 6045, 'GEOMAGNETIC ACTIVITY', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC FORECASTS > GEOMAGNETIC ACTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (7065, '4b7decec-e378-4824-aecf-9fe509392efd', 6045, 'GEOMAGNETIC STORM CATEGORY', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC FORECASTS > GEOMAGNETIC STORM CATEGORY', 1);
INSERT INTO {schema}.keywords VALUES (7066, '9a46a62c-952d-4253-8249-7375c14068a2', 6045, 'TOTAL INTENSITY', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC FORECASTS > TOTAL INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (7067, '5fd5ccc2-5edb-4823-940d-03a290a5c5fc', 6046, 'AA INDEX', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC INDICES > AA INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7068, '31f77d6b-72f7-45e6-93be-8ac5fd5dc373', 6046, 'AE INDEX', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC INDICES > AE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7069, 'b3283844-d867-4c2f-9917-a72bc06fd9ef', 6046, 'AM INDEX', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC INDICES > AM INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7070, 'cdb4b514-75c4-4a1f-a4ad-1855fbd396ab', 6046, 'DST INDEX', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC INDICES > DST INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7071, '40386eea-beb0-4b83-906b-75c6bfa24b73', 6046, 'KP INDEX', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > GEOMAGNETIC INDICES > KP INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7072, 'ee421700-0fe2-420c-9a07-91e8ae9fb524', 6047, 'GEOMAGNETIC INDUCTION', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > MAGNETIC FIELD > GEOMAGNETIC INDUCTION', 1);
INSERT INTO {schema}.keywords VALUES (7073, '65ae8ab2-489b-44bf-bf5b-43cf957b70c0', 6047, 'MAGNETIC ANOMALIES', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > MAGNETIC FIELD > MAGNETIC ANOMALIES', 1);
INSERT INTO {schema}.keywords VALUES (7074, 'f311eac7-5c85-4a8f-90c2-abcff3eec92d', 6047, 'MAGNETIC DECLINATION', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > MAGNETIC FIELD > MAGNETIC DECLINATION', 1);
INSERT INTO {schema}.keywords VALUES (7075, 'f0b7311e-df08-45fa-8dd5-33b6f74a66d9', 6047, 'MAGNETIC INCLINATION', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > MAGNETIC FIELD > MAGNETIC INCLINATION', 1);
INSERT INTO {schema}.keywords VALUES (7076, 'd817911a-685b-4c9f-bdc7-2411b8c0a7af', 6047, 'MAGNETIC INTENSITY', 'EARTH SCIENCE > SOLID EARTH > GEOMAGNETISM > MAGNETIC FIELD > MAGNETIC INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (7077, 'e43473a1-4392-48e3-9e56-8a4dcad8d7a2', 6050, 'DUNES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES', 1);
INSERT INTO {schema}.keywords VALUES (7078, 'cae41424-161f-4378-a1a4-62cd76c61143', 6050, 'RIPPLES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > RIPPLES', 1);
INSERT INTO {schema}.keywords VALUES (7079, 'f6e19e2e-555a-4d40-9833-c7513d92c813', 6051, 'ABRASION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (7080, 'd415cb15-7586-464c-8707-9a5623a61cee', 6051, 'DEFLATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > DEFLATION', 1);
INSERT INTO {schema}.keywords VALUES (7081, 'baf70c0f-fd59-4d4b-ae03-b664e0352ff7', 6051, 'DEGRADATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (7082, '78778362-5d08-4cd7-9131-159cad561e54', 6051, 'SALTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SALTATION', 1);
INSERT INTO {schema}.keywords VALUES (7083, 'fe2d9f93-ee9c-4d1e-af28-0c15ee762019', 6051, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (7084, '22ba30ec-a4e2-4547-bad7-4d5f9917625d', 6051, 'SEDIMENTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (7085, '7a67a5af-42be-4aa7-8cb1-e1fc0de074cc', 6051, 'WEATHERING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7086, '6e3135e9-6be6-4995-a5df-022f6a0cf45b', 6052, 'BARRIER ISLANDS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > BARRIER ISLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7087, '6a5d3e4d-86d1-4863-bfe6-f8e2899fab0e', 6052, 'BEACHES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > BEACHES', 1);
INSERT INTO {schema}.keywords VALUES (7088, 'dff4d4af-e1e0-4991-884b-a1c088a802b2', 6052, 'CORAL REEFS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS', 1);
INSERT INTO {schema}.keywords VALUES (7089, '0c51bdb0-54b0-4d0d-afd0-35ef7458ccb7', 6052, 'CUSPATE FORELANDS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CUSPATE FORELANDS', 1);
INSERT INTO {schema}.keywords VALUES (7090, 'b37b1bdf-6392-4a80-891a-14f177ba2ca2', 6052, 'DELTAS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DELTAS', 1);
INSERT INTO {schema}.keywords VALUES (7091, '0c279e58-9ad3-4748-816a-de8cabeaf0c4', 6052, 'DUNES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES', 1);
INSERT INTO {schema}.keywords VALUES (7092, '127fdf1d-9985-4a27-9b6c-ad54380fd299', 6052, 'ESTUARIES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > ESTUARIES', 1);
INSERT INTO {schema}.keywords VALUES (7093, 'c9291bc7-784d-486a-95fa-f08fa1edcad9', 6052, 'FJORDS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > FJORDS', 1);
INSERT INTO {schema}.keywords VALUES (7094, '860e25fa-e63a-4fd0-bde9-4f596b4a5929', 6052, 'HEADLANDS/BAYS/CAPE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > HEADLANDS/BAYS/CAPE', 1);
INSERT INTO {schema}.keywords VALUES (7095, '356a245d-418a-4560-9eb1-d12f8f155f66', 6052, 'INLETS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > INLETS', 1);
INSERT INTO {schema}.keywords VALUES (7096, 'ca9d9064-91c8-4c49-b388-e5f7290a3234', 6052, 'ISTHMUS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > ISTHMUS', 1);
INSERT INTO {schema}.keywords VALUES (7097, '081d131a-6bef-47dc-adb3-f96da9123f93', 6052, 'LAGOONS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > LAGOONS', 1);
INSERT INTO {schema}.keywords VALUES (7098, '8d4c5e9c-bdab-48c9-89da-1eb4b9a528ab', 6052, 'RIA', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > RIA', 1);
INSERT INTO {schema}.keywords VALUES (7099, '85f409fd-9d81-4cac-84ed-fb0bb4599924', 6052, 'SALT MARSH', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SALT MARSH', 1);
INSERT INTO {schema}.keywords VALUES (7100, '4321cb64-0997-438f-92fb-45169503c01f', 6052, 'SEA ARCHES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SEA ARCHES', 1);
INSERT INTO {schema}.keywords VALUES (7101, '521f883e-18be-4f28-b5fe-c1f887b4233a', 6052, 'SEA CAVES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SEA CAVES', 1);
INSERT INTO {schema}.keywords VALUES (7102, '01400b09-68a3-4e3e-b076-1687e30bed56', 6052, 'SEA CLIFFS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SEA CLIFFS', 1);
INSERT INTO {schema}.keywords VALUES (7103, '94b575b8-eac4-433d-aa74-d781b650f452', 6052, 'SHOALS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SHOALS', 1);
INSERT INTO {schema}.keywords VALUES (7104, '57e6b119-567b-44d0-9d93-278ed5c21c47', 6052, 'SHORELINES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SHORELINES', 1);
INSERT INTO {schema}.keywords VALUES (7105, 'c5b85924-9e3f-4106-b389-1ab4486bd233', 6052, 'SOUNDS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (7106, '62ef0883-8311-4485-947a-2691b456b667', 6052, 'SPITS AND BARS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > SPITS AND BARS', 1);
INSERT INTO {schema}.keywords VALUES (7107, '30f556c4-7531-4758-9e51-8adc6b2e0e8a', 6052, 'TOMBOLOS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > TOMBOLOS', 1);
INSERT INTO {schema}.keywords VALUES (7108, 'ee1d9786-33e9-46dc-b859-25d18e9c8a88', 6052, 'WAVE-CUT NOTCH/PLATFORMS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > WAVE-CUT NOTCH/PLATFORMS', 1);
INSERT INTO {schema}.keywords VALUES (7109, 'fd29bf77-df38-4b80-8148-8184fa41d843', 6053, 'ABRASION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (7110, '8b232049-ce98-4a34-8f00-2366335508e4', 6053, 'ACCRETION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > ACCRETION', 1);
INSERT INTO {schema}.keywords VALUES (7111, '36b178ad-4f20-41ce-89d1-4ee8567a3cf2', 6053, 'ATTRITION/WEATHERING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > ATTRITION/WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7112, 'bb891ee1-6c7b-4ec0-b2fa-6fb67a2df2a3', 6053, 'CHEMICAL SOLUTION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > CHEMICAL SOLUTION', 1);
INSERT INTO {schema}.keywords VALUES (7113, '6a11e5e5-e6a3-42dd-b793-141ce99932e1', 6053, 'DEPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > DEPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7114, 'fb5c09ec-c924-4deb-8294-8a27697a4550', 6053, 'FLOODING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > FLOODING', 1);
INSERT INTO {schema}.keywords VALUES (7115, '8fde8c6c-97d4-41a6-9e20-f862faafcd88', 6053, 'HYDRAULIC ACTION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > HYDRAULIC ACTION', 1);
INSERT INTO {schema}.keywords VALUES (7116, '872459ca-da1e-448f-9bf4-383b628f4609', 6053, 'SALTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SALTATION', 1);
INSERT INTO {schema}.keywords VALUES (7117, '6c958ab4-ab98-438e-86d4-1e6a6d0580da', 6053, 'SEA LEVEL CHANGE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEA LEVEL CHANGE', 1);
INSERT INTO {schema}.keywords VALUES (7118, '1088e9e2-dadd-4d20-a2db-ef7df32c6d42', 6053, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (7119, '2cca0a13-3c6f-4617-aca9-bff7f8142c52', 6053, 'SEDIMENTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (7120, '87186c13-548e-4ea8-ba79-38cff394eb59', 6053, 'SUBMERGENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SUBMERGENCE', 1);
INSERT INTO {schema}.keywords VALUES (7121, 'b3657e71-acd1-4be4-9c70-a54e074a40a4', 6053, 'SUBSIDENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SUBSIDENCE', 1);
INSERT INTO {schema}.keywords VALUES (7122, '15c6332d-f6f2-45a4-9485-bb55471c0090', 6053, 'SUSPENSION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SUSPENSION', 1);
INSERT INTO {schema}.keywords VALUES (7123, 'a8c37cb5-9426-41fd-b192-53b4c3ae1ba3', 6053, 'WAVE BREAKING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE BREAKING', 1);
INSERT INTO {schema}.keywords VALUES (7124, '5cbfc557-f3a6-4558-9954-ce37f0510952', 6053, 'WAVE DIFFRACTION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE DIFFRACTION', 1);
INSERT INTO {schema}.keywords VALUES (7125, '86405d6d-eb37-4aa5-a525-bf6a23fd131d', 6053, 'WAVE EROSION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE EROSION', 1);
INSERT INTO {schema}.keywords VALUES (7126, 'b43d2d47-c86e-41b6-81bd-be803db536da', 6053, 'WAVE REFRACTION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE REFRACTION', 1);
INSERT INTO {schema}.keywords VALUES (7127, 'f8accc20-818e-47a1-962d-80b7ec7f6d92', 6053, 'WAVE SHOALING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE SHOALING', 1);
INSERT INTO {schema}.keywords VALUES (7128, 'd8b04023-b9c4-42bc-a986-ab6c4f32ba28', 6054, 'AIT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > AIT', 1);
INSERT INTO {schema}.keywords VALUES (7129, '6c061296-2c92-4aa4-b9d1-6ecf0efde876', 6054, 'BAR', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > BAR', 1);
INSERT INTO {schema}.keywords VALUES (7130, '244bd4be-a3d2-4c02-b576-ae9f2f9e544f', 6054, 'BAYOU', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > BAYOU', 1);
INSERT INTO {schema}.keywords VALUES (7131, 'e25ce36c-eacd-447a-9d73-ccc8a7e3a328', 6054, 'CANYON', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > CANYON', 1);
INSERT INTO {schema}.keywords VALUES (7132, 'cbd9ee43-24f8-45ab-a39b-2ff34be81c51', 6054, 'CONFLUENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > CONFLUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7133, '8dcff6c3-a6b3-479e-96e2-63191d10ac2d', 6054, 'CUTBANK', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > CUTBANK', 1);
INSERT INTO {schema}.keywords VALUES (7134, 'ad535c83-3b93-4632-8aaa-7dfba8bb125a', 6054, 'DELTAS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > DELTAS', 1);
INSERT INTO {schema}.keywords VALUES (7135, '4a2a2f6d-9735-4bee-9d1a-21dcd0352c6b', 6054, 'ENDORHERIC BASIN', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > ENDORHERIC BASIN', 1);
INSERT INTO {schema}.keywords VALUES (7136, 'd71f94cb-e773-487a-a8ff-9c5f11c1dbc4', 6054, 'FLOOD PLAIN', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > FLOOD PLAIN', 1);
INSERT INTO {schema}.keywords VALUES (7137, '2f8ad9b0-adb8-4022-8c95-bca68e7a87a5', 6054, 'GULLY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > GULLY', 1);
INSERT INTO {schema}.keywords VALUES (7138, '74caea9b-6023-438b-af3d-bb9d948036f1', 6054, 'ISLAND', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > ISLAND', 1);
INSERT INTO {schema}.keywords VALUES (7139, '588d868d-05a4-4dac-9fb3-770b54ce39e5', 6054, 'LACUSTRINE PLAIN', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > LACUSTRINE PLAIN', 1);
INSERT INTO {schema}.keywords VALUES (7140, '88adcca6-2bc8-443a-9f25-c9aded577615', 6054, 'MARSH', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > MARSH', 1);
INSERT INTO {schema}.keywords VALUES (7141, 'c6f77e54-069e-454f-8260-e150bc29547a', 6054, 'MEANDER', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > MEANDER', 1);
INSERT INTO {schema}.keywords VALUES (7142, '12233807-f6cd-410d-b607-ecbfbd545464', 6054, 'OX-BOW LAKE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > OX-BOW LAKE', 1);
INSERT INTO {schema}.keywords VALUES (7143, '4a0c46ff-2d07-442d-b141-6156d9ea4a2e', 6054, 'PINGO', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > PINGO', 1);
INSERT INTO {schema}.keywords VALUES (7144, 'dd0de414-6663-4280-94cf-bda7fea736cc', 6054, 'POINT BAR', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > POINT BAR', 1);
INSERT INTO {schema}.keywords VALUES (7145, '5f292d99-b14a-4f18-bbe0-8025d04cae50', 6054, 'POND', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > POND', 1);
INSERT INTO {schema}.keywords VALUES (7146, '5df6e78f-6dd4-4fc8-a88e-9e575dbca2eb', 6054, 'RIFFLE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > RIFFLE', 1);
INSERT INTO {schema}.keywords VALUES (7147, 'bb6b3b76-c496-464b-bd20-1b22296aae15', 6054, 'RIVER', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > RIVER', 1);
INSERT INTO {schema}.keywords VALUES (7148, 'b498a5cb-f77d-4485-8174-81dec28cee0e', 6054, 'SPRING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > SPRING', 1);
INSERT INTO {schema}.keywords VALUES (7149, '74ce5e8a-038a-471e-a27a-be5b1f17b72f', 6054, 'STREAM TERRACE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > STREAM TERRACE', 1);
INSERT INTO {schema}.keywords VALUES (7150, '1d2d0777-b47e-45ee-ac85-2d7b9f6e4ffd', 6054, 'STREAM', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > STREAM', 1);
INSERT INTO {schema}.keywords VALUES (7151, '4811065d-7aed-45e0-ac31-6417123be10e', 6054, 'SWAMP', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > SWAMP', 1);
INSERT INTO {schema}.keywords VALUES (7152, '87b01c3a-f64f-4764-8cb8-c40ebcd5a989', 6054, 'VALLEY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (7153, '948dea97-9843-4895-b59b-cb55f07a41b4', 6054, 'WATERFALL', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > WATERFALL', 1);
INSERT INTO {schema}.keywords VALUES (7154, '97a71326-75ac-422f-941e-c0c2897dd46b', 6054, 'WATERSHED/DRAINAGE BASINS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > WATERSHED/DRAINAGE BASINS', 1);
INSERT INTO {schema}.keywords VALUES (7155, 'efacd4f6-59ea-4019-8265-8cc81ecc99c0', 6055, 'ABRASION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (7156, '9eedd20e-fce3-4fb2-9871-c0a327565ad9', 6055, 'ATTRITION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > ATTRITION', 1);
INSERT INTO {schema}.keywords VALUES (7157, '800606ea-9890-4475-af7b-100f529858d1', 6055, 'DEGRADATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (7158, 'aff6bb19-84d0-40ed-8b81-a2210c468283', 6055, 'DOWNCUTTING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > DOWNCUTTING', 1);
INSERT INTO {schema}.keywords VALUES (7159, 'e89704aa-91a0-4888-bb33-a9073eff7119', 6055, 'ENTRAINMENT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > ENTRAINMENT', 1);
INSERT INTO {schema}.keywords VALUES (7160, '267eca20-09a7-46ad-89f4-111ccb3fd16d', 6055, 'HYDRAULIC ACTION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > HYDRAULIC ACTION', 1);
INSERT INTO {schema}.keywords VALUES (7161, '54e5d072-5a2c-471b-bca0-7e4ca32a2001', 6055, 'LANDSLIDE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > LANDSLIDE', 1);
INSERT INTO {schema}.keywords VALUES (7162, '93596daf-d2d3-4bb8-9626-9db100c402de', 6055, 'SALTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SALTATION', 1);
INSERT INTO {schema}.keywords VALUES (7163, '0c33b48d-1dd1-4309-bcd4-1ce3d0e24b46', 6055, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (7164, '984e15c6-7eac-45b8-b098-ad82eab6be6e', 6055, 'SEDIMENTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (7165, '8009663e-73c7-403e-b849-f40d2c3e3de8', 6055, 'SUSPENSION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SUSPENSION', 1);
INSERT INTO {schema}.keywords VALUES (7166, '6f47d087-21dc-41bc-955e-6eb2db8890cd', 6055, 'WEATHERING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7167, '8e73bff6-c2f9-46a6-963b-8ef09dd7f5f3', 6057, 'ARETES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ARETES', 1);
INSERT INTO {schema}.keywords VALUES (7168, 'ae3b0c3d-35a1-4c94-ba72-ffe1a641902e', 6057, 'CIRQUES/COMBES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CIRQUES/COMBES', 1);
INSERT INTO {schema}.keywords VALUES (7169, 'e0d85cf0-b477-47df-a067-18e28a3e228f', 6057, 'CREVASSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7170, '4be9b544-68fa-45ea-89f1-a44a9f5929e5', 6057, 'DRUMLINS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > DRUMLINS', 1);
INSERT INTO {schema}.keywords VALUES (7171, '5e012809-98cf-468f-bdf7-7cea8569d3ab', 6057, 'ESKERS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ESKERS', 1);
INSERT INTO {schema}.keywords VALUES (7172, '6aed82cb-be90-4e58-ae33-14943ea555be', 6057, 'FJORDS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > FJORDS', 1);
INSERT INTO {schema}.keywords VALUES (7173, '5477fad4-789b-436d-a01e-610aa8efa592', 6057, 'GLACIAL HORNS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIAL HORNS', 1);
INSERT INTO {schema}.keywords VALUES (7174, 'b2d3b8a4-4861-4c21-b875-97084b6e75aa', 6057, 'GLACIER STRIATIONS/GROOVES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIER STRIATIONS/GROOVES', 1);
INSERT INTO {schema}.keywords VALUES (7175, 'd23f75ed-29ea-4aa2-8785-fd3a3726bc33', 6057, 'GLACIER/HANGING/U-SHAPED VALLEYS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIER/HANGING/U-SHAPED VALLEYS', 1);
INSERT INTO {schema}.keywords VALUES (7176, '93b60653-f7bb-46f3-8f65-69221267018c', 6057, 'GLACIER/ICE CAVES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > GLACIER/ICE CAVES', 1);
INSERT INTO {schema}.keywords VALUES (7177, 'ee565a8c-72b9-44a4-b25d-efefd1a28d8d', 6057, 'ICE-DAMMED LAKES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ICE-DAMMED LAKES', 1);
INSERT INTO {schema}.keywords VALUES (7178, '3f86db44-f853-4eb3-b4e3-4aaee481043a', 6057, 'KAME DELTA', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > KAME DELTA', 1);
INSERT INTO {schema}.keywords VALUES (7179, '89541868-0ea0-47c6-b81e-a0c4981f2d62', 6057, 'KAMES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > KAMES', 1);
INSERT INTO {schema}.keywords VALUES (7180, '6d3722bb-29c0-4fb6-90c3-3f3a144b9941', 6057, 'KETTLE HOLES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > KETTLE HOLES', 1);
INSERT INTO {schema}.keywords VALUES (7181, '4f590d94-110c-4762-9171-aba6d24af6a0', 6057, 'MORAINES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES', 1);
INSERT INTO {schema}.keywords VALUES (7182, '3b8bdda1-2415-47ea-b4cf-c802fa44c496', 6057, 'NUNATAKS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > NUNATAKS', 1);
INSERT INTO {schema}.keywords VALUES (7183, 'a8bfc8ad-42f2-43cc-b161-20058037bb95', 6057, 'OUTWASH FANS/PLAINS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > OUTWASH FANS/PLAINS', 1);
INSERT INTO {schema}.keywords VALUES (7184, '691cb42a-9de2-4f49-b1b4-9a4be80abd2b', 6057, 'ROCHE MOUNTONNEES/SHEEPBACK', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ROCHE MOUNTONNEES/SHEEPBACK', 1);
INSERT INTO {schema}.keywords VALUES (7185, '2d98cbaf-8c82-46e6-9962-a5e63918fe66', 6057, 'ROCK GLACIERS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > ROCK GLACIERS', 1);
INSERT INTO {schema}.keywords VALUES (7186, '2bea72da-2cf3-403c-adb9-9d963eb71536', 6057, 'TILL PLAINS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > TILL PLAINS', 1);
INSERT INTO {schema}.keywords VALUES (7187, '99db4dca-4d07-48fd-8ba3-393532d04aa6', 6058, 'ABLATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > ABLATION', 1);
INSERT INTO {schema}.keywords VALUES (7188, '8f57f4b0-5177-4362-81e8-ced75d37d1aa', 6058, 'ABRASION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > ABRASION', 1);
INSERT INTO {schema}.keywords VALUES (7189, 'c06e70c0-616c-44f2-a884-ad0252e29e37', 6058, 'CRUST REBOUND', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > CRUST REBOUND', 1);
INSERT INTO {schema}.keywords VALUES (7190, 'e60bfab8-01a8-4d0b-ae95-5d9014c71717', 6058, 'DEGRADATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (7191, 'b6d56c3f-daa4-4c2f-9c56-4cecdf3d9fcd', 6058, 'DUMPING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > DUMPING', 1);
INSERT INTO {schema}.keywords VALUES (7192, '1dc7ed2f-2834-4044-8caa-117ce12389af', 6058, 'ENTRAINMENT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > ENTRAINMENT', 1);
INSERT INTO {schema}.keywords VALUES (7193, '5b66d75f-331f-49d0-ad97-12f6535ce93a', 6058, 'FIRN FORMATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > FIRN FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7194, 'f7849055-fa5c-437c-a8c6-08c7db3a3b0a', 6058, 'FREEZE/THAW', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > FREEZE/THAW', 1);
INSERT INTO {schema}.keywords VALUES (7195, '5ddbaf71-b279-42cf-b250-faaefb627f66', 6058, 'GLACIAL DISPLACEMENT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL DISPLACEMENT', 1);
INSERT INTO {schema}.keywords VALUES (7196, '5cd3ad48-ade6-4306-a7de-4e68ecdf6bc7', 6058, 'GLACIAL DRIFT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL DRIFT', 1);
INSERT INTO {schema}.keywords VALUES (7197, '4be0198b-b88c-44db-b887-6cc7f5cd68f8', 6058, 'GLACIAL GROWTH', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL GROWTH', 1);
INSERT INTO {schema}.keywords VALUES (7198, '114e9f84-8bc5-4863-abd2-55b80ed2af11', 6058, 'GLACIAL STRIATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIAL STRIATION', 1);
INSERT INTO {schema}.keywords VALUES (7199, 'b87c5264-13c6-4716-acf3-51b2576dc1e9', 6058, 'GLACIER CRUST SUBSIDENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > GLACIER CRUST SUBSIDENCE', 1);
INSERT INTO {schema}.keywords VALUES (7200, 'fa0f38f3-2faa-4cd7-a848-22f3d96ab210', 6058, 'PERIGLACIAL PROCESSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > PERIGLACIAL PROCESSES', 1);
INSERT INTO {schema}.keywords VALUES (7201, 'c4619d3d-f852-4899-9e33-9fd6d4096351', 6058, 'PLUCKING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > PLUCKING', 1);
INSERT INTO {schema}.keywords VALUES (7202, '7ca88385-d0cf-439c-9a12-86b926b71582', 6058, 'SCOURING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SCOURING', 1);
INSERT INTO {schema}.keywords VALUES (7203, '791b7271-3a30-46ee-98e0-bc8239389950', 6058, 'SEDIMENT TRANSPORT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENT TRANSPORT', 1);
INSERT INTO {schema}.keywords VALUES (7204, 'd8f33f0a-137c-49ac-aebf-f8a8b0540a09', 6058, 'SEDIMENTATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENTATION', 1);
INSERT INTO {schema}.keywords VALUES (7205, '580ef100-0fb8-456c-a9ca-565d11392a26', 6058, 'WEATHERING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7206, '631c5fb8-5e44-48f8-b937-a5f393d0832d', 6059, 'CAVES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > CAVES', 1);
INSERT INTO {schema}.keywords VALUES (7207, 'a20151df-e7cf-43e0-9745-ffc965f97ef7', 6059, 'COCKPIT/TOWER KARST', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > COCKPIT/TOWER KARST', 1);
INSERT INTO {schema}.keywords VALUES (7208, 'c319a44c-b21a-491f-9cf0-65868507576c', 6059, 'KARST VALLEY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > KARST VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (7209, '7f298307-73f6-4f10-96a2-db381f357cb6', 6059, 'SINKHOLES (DOLINES)', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > SINKHOLES (DOLINES)', 1);
INSERT INTO {schema}.keywords VALUES (7210, '40d9bf88-e7e2-4137-81fc-4721d67ce520', 6059, 'UVALA', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST LANDFORMS > UVALA', 1);
INSERT INTO {schema}.keywords VALUES (7211, '9902dc89-61fb-4a1e-becf-c8138122d2c4', 6060, 'CACO3', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > CACO3', 1);
INSERT INTO {schema}.keywords VALUES (7212, '613abf26-7625-4134-8961-7a59fe82efc9', 6060, 'DISSOLVED CO2', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > DISSOLVED CO2', 1);
INSERT INTO {schema}.keywords VALUES (7213, '05172a3b-cdc0-4e97-af29-e38cd4f271c6', 6060, 'KARST HYDROLOGY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > KARST HYDROLOGY', 1);
INSERT INTO {schema}.keywords VALUES (7214, '07f6c977-077b-47f2-962c-00dadcd9f555', 6060, 'POROSITY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > POROSITY', 1);
INSERT INTO {schema}.keywords VALUES (7215, '60dc0787-9e7e-4e0d-8023-d916da5d0836', 6060, 'WEATHERING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > WEATHERING', 1);
INSERT INTO {schema}.keywords VALUES (7216, '5d9d1d85-b402-4f84-ab5c-03a49fc68c25', 6061, 'CALDERA', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > CALDERA', 1);
INSERT INTO {schema}.keywords VALUES (7217, '7c394040-91f1-4438-a50a-3118254f5989', 6061, 'CINDER CONE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > CINDER CONE', 1);
INSERT INTO {schema}.keywords VALUES (7218, '6107d1c4-5aea-4bfa-861d-d77083a4476e', 6061, 'FAULTS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > FAULTS', 1);
INSERT INTO {schema}.keywords VALUES (7219, 'a2a3893c-de51-4ca7-a952-e9a43dd961a1', 6061, 'FOLDS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > FOLDS', 1);
INSERT INTO {schema}.keywords VALUES (7220, 'ea580c65-2f66-4745-bbb6-dde61279ecfa', 6061, 'GEYSER', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > GEYSER', 1);
INSERT INTO {schema}.keywords VALUES (7221, '524f075d-e875-4c9d-9e46-91f2a0b12168', 6061, 'GRABEN', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > GRABEN', 1);
INSERT INTO {schema}.keywords VALUES (7222, 'bf3fbdaa-cefb-4a54-8a4e-ee0a862795fb', 6061, 'HORST', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > HORST', 1);
INSERT INTO {schema}.keywords VALUES (7223, '33a0cd6c-a8e4-4187-a2f3-7eb4bf62808d', 6061, 'LAVA DOME', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > LAVA DOME', 1);
INSERT INTO {schema}.keywords VALUES (7224, 'dc18db4d-2184-453e-ba0a-86c83a9bede0', 6061, 'LAVA PLAIN', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > LAVA PLAIN', 1);
INSERT INTO {schema}.keywords VALUES (7225, 'c1f717e9-da1a-4e85-ba2b-01986d53674d', 6061, 'MAAR', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > MAAR', 1);
INSERT INTO {schema}.keywords VALUES (7226, 'c34ea556-10bd-4665-9f22-68b5d05c9aea', 6061, 'MOUNTAINS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > MOUNTAINS', 1);
INSERT INTO {schema}.keywords VALUES (7227, '0baf564f-f942-4aeb-9b75-30b838f28f3f', 6061, 'PLATEAU', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > PLATEAU', 1);
INSERT INTO {schema}.keywords VALUES (7228, 'ca091be1-4762-49ec-859b-a1a2fcb8e038', 6061, 'RIDGE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > RIDGE', 1);
INSERT INTO {schema}.keywords VALUES (7229, '0bd4d492-4911-4a6a-afaa-34899a80294b', 6061, 'RIFT VALLEY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > RIFT VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (7230, 'a355aafc-f0ce-4774-afc3-82b41df5f022', 6061, 'TUYA', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > TUYA', 1);
INSERT INTO {schema}.keywords VALUES (7231, 'cefe2205-809c-4386-915e-a8737ae8e68e', 6061, 'VOLCANO', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC LANDFORMS > VOLCANO', 1);
INSERT INTO {schema}.keywords VALUES (7232, 'ebcd5f14-9468-493b-b0e6-de5afda2621a', 6062, 'EPEIROGENIC MOVEMENT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > EPEIROGENIC MOVEMENT', 1);
INSERT INTO {schema}.keywords VALUES (7233, 'ca464924-4299-46ea-8cae-fd9bad49c1b1', 6062, 'ISOSTATIC UPLIFT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > ISOSTATIC UPLIFT', 1);
INSERT INTO {schema}.keywords VALUES (7234, '46d188a9-1099-4d72-b466-6e839297320e', 6062, 'OROGENIC MOVEMENT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > OROGENIC MOVEMENT', 1);
INSERT INTO {schema}.keywords VALUES (7235, '9c207e15-9947-4849-bdf4-c1893a7f800a', 6062, 'RIFTING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > RIFTING', 1);
INSERT INTO {schema}.keywords VALUES (7236, '44dd98d0-a0d0-46b2-bb98-ed887ce7fa60', 6062, 'SUBDUCTION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > SUBDUCTION', 1);
INSERT INTO {schema}.keywords VALUES (7237, '4bc109b5-6788-4f64-8238-745bab3910dd', 6062, 'TECTONIC UPLIFT', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > TECTONIC PROCESSES > TECTONIC UPLIFT', 1);
INSERT INTO {schema}.keywords VALUES (7238, '9d258088-e5bd-42b9-a281-e566da10ea74', 6063, 'ENERGY DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL ENERGY > ENERGY DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7239, '64461e23-b3c1-4b99-b879-84e54bacdb24', 6063, 'ENERGY OUTPUT', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL ENERGY > ENERGY OUTPUT', 1);
INSERT INTO {schema}.keywords VALUES (7240, '1d2ac206-0977-4145-b334-baa6e13a0db6', 6064, 'AMBIENT TEMPERATURE', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL TEMPERATURE > AMBIENT TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (7241, '99d567bb-7767-4ea4-a135-a611eac6a669', 6064, 'TEMPERATURE GRADIENT', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL TEMPERATURE > TEMPERATURE GRADIENT', 1);
INSERT INTO {schema}.keywords VALUES (7242, '321d9086-fc85-40a3-a2e0-d24bc6765345', 6064, 'TEMPERATURE PROFILES', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL TEMPERATURE > TEMPERATURE PROFILES', 1);
INSERT INTO {schema}.keywords VALUES (7243, '5dee7d0e-e13e-4974-9750-79d5cd886c7a', 6066, 'ISOSTATIC ADJUSTMENTS', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > CRUSTAL MOTION > ISOSTATIC ADJUSTMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7244, 'aa6c2fe7-3261-4fd8-bed4-81403bc49086', 6066, 'OCEAN CRUST DEFORMATION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > CRUSTAL MOTION > OCEAN CRUST DEFORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7245, '9d184041-9848-4f76-affd-74f4e4fd7462', 6070, 'ANNUAL ELLIPTICAL COMPONENT', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > POLAR MOTION > ANNUAL ELLIPTICAL COMPONENT', 1);
INSERT INTO {schema}.keywords VALUES (7246, 'a983aad3-c72a-49e8-8de9-e0aaf35e14b3', 6070, 'CHANDLER CIRCULAR COMPONENT', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > POLAR MOTION > CHANDLER CIRCULAR COMPONENT', 1);
INSERT INTO {schema}.keywords VALUES (7247, 'd5d9bd6a-92c4-49ac-bddf-0077cf804ea7', 6071, 'ROTATIONAL RATE/SPEED', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > ROTATIONAL MOTION/VARIATIONS > ROTATIONAL RATE/SPEED', 1);
INSERT INTO {schema}.keywords VALUES (7248, '4bb526d7-2c14-43bc-a2a7-f166b5c41a3a', 6071, 'TIDAL FRICTION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > ROTATIONAL MOTION/VARIATIONS > TIDAL FRICTION', 1);
INSERT INTO {schema}.keywords VALUES (7249, '96427b44-91a8-4ace-8276-0117948878ee', 6072, 'ANGLE OF ELEVATION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > SATELLITE ORBITS/REVOLUTION > ANGLE OF ELEVATION', 1);
INSERT INTO {schema}.keywords VALUES (7250, '025d666e-a5bb-48b5-9890-129e60104611', 6072, 'ANGLE OF INCLINATION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > SATELLITE ORBITS/REVOLUTION > ANGLE OF INCLINATION', 1);
INSERT INTO {schema}.keywords VALUES (7251, 'e709d2f9-c110-4e71-b4da-ff1a7c382d99', 6072, 'ORBIT TYPE', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > SATELLITE ORBITS/REVOLUTION > ORBIT TYPE', 1);
INSERT INTO {schema}.keywords VALUES (7252, '53eeb68a-615d-42d0-9c6b-ddfe0d0eb2c7', 6072, 'ORBIT VELOCITY', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > SATELLITE ORBITS/REVOLUTION > ORBIT VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (7253, 'e72ba365-ea43-42ef-acd1-05ac5c46f29a', 6072, 'ORBITAL POSITION', 'EARTH SCIENCE > SOLID EARTH > GRAVITY/GRAVITATIONAL FIELD > SATELLITE ORBITS/REVOLUTION > ORBITAL POSITION', 1);
INSERT INTO {schema}.keywords VALUES (7254, '2440389a-d0d9-445a-9dce-908900f0c3a7', 6075, 'MAJOR ELEMENTS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > ELEMENTS > MAJOR ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7255, '63cf1bca-72c7-4f5e-8018-3d22befa7147', 6075, 'MINOR ELEMENTS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > ELEMENTS > MINOR ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7256, '334f47c1-fd13-483f-b493-e69a9e93d553', 6075, 'RADIOACTIVE ELEMENTS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > ELEMENTS > RADIOACTIVE ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7257, 'c3c898d7-14db-4536-bd86-f8f222167195', 6075, 'TRACE ELEMENTS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > ELEMENTS > TRACE ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7258, '43561874-c5c4-47d5-8daf-e99fab694042', 6076, 'GAS HYDRATES AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7259, '9589c9f5-fd13-4809-b26c-bd71db371836', 6076, 'GAS HYDRATES FORMATION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7260, '1f76b928-d41a-4fbd-9da7-b8602f0183bd', 6076, 'GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7261, '7a20b919-a6f6-453e-9055-a66a9da8594b', 6076, 'GAS HYDRATES VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7262, '53e3eeca-265b-42d8-ad64-bfcc2acdad26', 6077, 'IGNEOUS ROCK AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7263, '984d4966-070d-4f8c-85e7-83bb0fd804a8', 6077, 'IGNEOUS ROCK FORMATION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7264, 'a17a781d-01b0-470c-a4e2-e91ca8b1fbdc', 6077, 'IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7265, '16499bb4-95bd-4bc0-b8d8-1fd11ca7d44d', 6077, 'IGNEOUS ROCK VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7266, 'a1b409b9-bf98-490a-8af5-f64fcda17a54', 6078, 'METALS AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7267, '85d46af8-f6ce-490d-a971-0f03b301c1e4', 6078, 'METALS PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7268, 'fbc418a0-5d32-43ab-9f1f-e81b9d8534e1', 6078, 'METALS VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7269, '02a53a61-4fd2-4294-9dcc-071f701bc263', 6079, 'METAMORPHIC ROCK AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7270, 'a243624b-a9c8-4c53-84d1-bb0fe2a71ef6', 6079, 'METAMORPHIC ROCK FORMATION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7271, '2d38e7c6-8169-49e9-ab9d-0d0f690cce04', 6079, 'METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7272, '5d80d2d2-7841-4734-a8c5-5d60679e3830', 6079, 'METAMORPHIC ROCK VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7273, '6d75d735-7dac-42a2-8f87-2dfcbe3cf545', 6080, 'METEORITE AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7274, 'd45ccf89-7f8c-4a61-b46d-c34dca21c879', 6080, 'METEORITE ORIGIN', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE ORIGIN', 1);
INSERT INTO {schema}.keywords VALUES (7275, '3ff47a50-2f58-489b-96a7-74e1d40cf0f2', 6080, 'METEORITE PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7276, 'e468e55a-5bee-413e-8cbd-c9706e28eb93', 6080, 'METEORITE VERTICAL/GEOGRPAHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE VERTICAL/GEOGRPAHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7277, '239c04ba-6f82-4d4f-a60b-a1ee49301e0f', 6082, 'MINERAL AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7278, 'f6ce9d55-4183-4433-a615-4c4f01d7810b', 6082, 'MINERAL FORMATION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7279, 'da269095-7270-4a0d-8b43-2c85bd42dd90', 6082, 'MINERAL PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7280, 'cbac3817-116f-4280-b32d-d30bb0f37cbd', 6082, 'MINERAL VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7281, '56373f39-7c27-4a77-bb52-c4defee751f8', 6082, 'MINERALOIDS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERALOIDS', 1);
INSERT INTO {schema}.keywords VALUES (7282, '497ec0b6-a732-4d97-9e5a-09eaf5ed4607', 6083, 'NON-METALLIC MINERAL AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7283, '2b4d3c45-8713-4ec9-9565-866bb01be9f9', 6083, 'NON-METALLIC MINERAL FORMATION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7284, '42424cb5-aa02-4e7e-b164-b2a3324285c6', 6083, 'NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7285, '1980c6c6-50f0-45a1-9a28-668f1372c09e', 6083, 'NON-METALLIC MINERAL VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7286, '8b726747-6eba-4ce6-bfc6-ee84616a1862', 6084, 'COAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > COAL', 1);
INSERT INTO {schema}.keywords VALUES (7287, '701f2b6f-34b0-4f69-941e-c2c5545abc0b', 6084, 'SEDIMENTARY ROCK AGE DETERMINATIONS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK AGE DETERMINATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7288, '8777e995-2acc-40cd-b81a-f0c7b69df23e', 6084, 'SEDIMENTARY ROCK FORMATION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK FORMATION', 1);
INSERT INTO {schema}.keywords VALUES (7289, '609aeae6-388f-41a1-8813-a2e760e8fdb7', 6084, 'SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES', 1);
INSERT INTO {schema}.keywords VALUES (7290, '23706ac6-8f15-4548-b1c5-6594d825d56d', 6084, 'SEDIMENTARY ROCK VERTICAL/GEOGRAPHIC DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK VERTICAL/GEOGRAPHIC DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7291, '4bc185d3-e2c5-4acc-bce8-37fea7d8fc0b', 6056, 'EARTHQUAKE MAGNITUDE/INTENSITY', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES > EARTHQUAKE MAGNITUDE/INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (7292, '752d4f80-a418-4a75-a9eb-772222af1746', 6056, 'EARTHQUAKE OCCURRENCES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES > EARTHQUAKE OCCURRENCES', 1);
INSERT INTO {schema}.keywords VALUES (7293, '131c1e46-efca-4478-a5d1-d7193483bb96', 6056, 'EARTHQUAKE PREDICTIONS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES > EARTHQUAKE PREDICTIONS', 1);
INSERT INTO {schema}.keywords VALUES (7294, '688191e0-c70c-4cf9-a5b6-a26a2bca7198', 6056, 'SEISMIC PROFILE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES > SEISMIC PROFILE', 1);
INSERT INTO {schema}.keywords VALUES (7295, '8dd8d272-fb6d-4eec-882a-f3be98800b42', 6087, 'CRUSTAL MOTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > CRUSTAL MOTION', 1);
INSERT INTO {schema}.keywords VALUES (7296, '51ce7da1-b441-474f-b7e5-cedaa04903f7', 6087, 'FAULT MOVEMENT', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > FAULT MOVEMENT', 1);
INSERT INTO {schema}.keywords VALUES (7297, 'a71c3d9d-7144-4107-add5-0aed0c731dbc', 6087, 'FOLDS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > FOLDS', 1);
INSERT INTO {schema}.keywords VALUES (7298, '5e7a091a-894f-423f-a431-ab52cf205311', 6087, 'ISOSTATIC REBOUND', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > ISOSTATIC REBOUND', 1);
INSERT INTO {schema}.keywords VALUES (7299, '64ccd7be-577b-4784-8072-8c456aab2185', 6087, 'LITHOSPHERIC PLATE MOTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > LITHOSPHERIC PLATE MOTION', 1);
INSERT INTO {schema}.keywords VALUES (7300, '4adc15b8-0c18-4ccd-a6ec-75be82df5359', 6087, 'PLATE BOUNDARIES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > PLATE BOUNDARIES', 1);
INSERT INTO {schema}.keywords VALUES (7301, '5d7f7568-bfc3-4c11-b446-c4f6488c8ae9', 6087, 'STRAIN', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > STRAIN', 1);
INSERT INTO {schema}.keywords VALUES (7302, 'efe175a0-100b-404b-a702-2e179bee034a', 6087, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7303, '29dbe37e-22e6-4d02-844f-60359fbbc130', 6087, 'STRESS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > STRESS', 1);
INSERT INTO {schema}.keywords VALUES (7304, '0db0e1c8-6ba3-40c4-97c2-d78c9812692b', 6088, 'ERUPTION DYNAMICS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS', 1);
INSERT INTO {schema}.keywords VALUES (7305, '14e0d39a-ff1c-46d9-b162-481f80beac91', 6088, 'VOLCANO MAGNITUDE/INTENSITY', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > VOLCANO MAGNITUDE/INTENSITY', 1);
INSERT INTO {schema}.keywords VALUES (7306, 'd1ab518b-0152-48cf-a9c6-47c5920ed773', 6088, 'VOLCANO OCCURRENCES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > VOLCANO OCCURRENCES', 1);
INSERT INTO {schema}.keywords VALUES (7307, '3adb9c52-df47-4390-a682-56e1774e8cdb', 6088, 'VOLCANO PREDICTIONS', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > VOLCANO PREDICTIONS', 1);
INSERT INTO {schema}.keywords VALUES (7308, '2ba27dc1-e2e6-4ce5-be05-fb4e4dd5ab54', 6181, 'SNOW GRAIN SIZE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GLACIERS/ICE SHEETS > FIRN > SNOW GRAIN SIZE', 1);
INSERT INTO {schema}.keywords VALUES (7309, 'a957363b-2f2c-4169-a656-c2f24933eb72', 6191, 'AQUIFERS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER FEATURES > AQUIFERS', 1);
INSERT INTO {schema}.keywords VALUES (7310, 'c87c086a-933f-44c7-a128-33279b36d7b5', 6191, 'FRESHWATER SPRINGS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER FEATURES > FRESHWATER SPRINGS', 1);
INSERT INTO {schema}.keywords VALUES (7311, 'ecbe9f17-6012-4e39-a707-713973b7d167', 6191, 'WATER TABLE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER FEATURES > WATER TABLE', 1);
INSERT INTO {schema}.keywords VALUES (7312, 'dbeaaf9f-294c-4e45-ba9e-7be8cd449db1', 6192, 'AQUIFER RECHARGE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE', 1);
INSERT INTO {schema}.keywords VALUES (7313, '0976b778-91be-40e7-9ed7-ebbf214bb818', 6192, 'DISCHARGE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DISCHARGE', 1);
INSERT INTO {schema}.keywords VALUES (7314, 'd2d4ee50-99ed-4ee7-b957-22271a60c031', 6192, 'DISPERSION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DISPERSION', 1);
INSERT INTO {schema}.keywords VALUES (7315, '6a2107ab-38ab-42dc-beb0-8ba5f65e8022', 6192, 'DRAINAGE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DRAINAGE', 1);
INSERT INTO {schema}.keywords VALUES (7316, '638a22af-4e97-450e-a278-b81338443230', 6192, 'INFILTRATION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > INFILTRATION', 1);
INSERT INTO {schema}.keywords VALUES (7317, 'a1bf1e84-c4e7-4154-ad0a-4b9eedf45066', 6192, 'LAND SUBSIDENCE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > LAND SUBSIDENCE', 1);
INSERT INTO {schema}.keywords VALUES (7318, 'd64094ae-774b-4435-8f2e-a54d114e5555', 6192, 'PERCOLATION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > PERCOLATION', 1);
INSERT INTO {schema}.keywords VALUES (7319, '4a11a257-99c6-4f87-8884-2a2aa46a49fa', 6192, 'SALTWATER INTRUSION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SALTWATER INTRUSION', 1);
INSERT INTO {schema}.keywords VALUES (7320, '872a0464-884c-4d6f-8f06-0679329dadcc', 6192, 'SUBSURFACE FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SUBSURFACE FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7321, '272700c5-d762-452b-8e9f-130e3a51efb5', 6219, 'DRAINAGE BASINS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER FEATURES > DRAINAGE BASINS', 1);
INSERT INTO {schema}.keywords VALUES (7322, '3d64f625-fb84-4178-ad08-4be2dd15979b', 6219, 'LAKES/RESERVOIRS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER FEATURES > LAKES/RESERVOIRS', 1);
INSERT INTO {schema}.keywords VALUES (7323, '5e3c573f-a787-4afa-80a4-047c2c5d83f2', 6219, 'RIVERS/STREAMS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER FEATURES > RIVERS/STREAMS', 1);
INSERT INTO {schema}.keywords VALUES (7324, '4b276110-57bc-4ed6-b741-1ec0383fa962', 6219, 'WATER CHANNELS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER FEATURES > WATER CHANNELS', 1);
INSERT INTO {schema}.keywords VALUES (7325, 'd138302a-03b3-4cf7-95db-ac98f863c04f', 6219, 'WETLANDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER FEATURES > WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7326, '3609b843-d840-460c-b1a3-d4fcc69a32f6', 6220, 'AQUIFER RECHARGE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE', 1);
INSERT INTO {schema}.keywords VALUES (7327, '36a2999b-2255-4d4e-a249-40df3b7b3aaf', 6220, 'DISCHARGE/FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DISCHARGE/FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7328, '269c7277-fa8f-4c1c-bd8b-ab772c1df4e5', 6220, 'DRAINAGE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DRAINAGE', 1);
INSERT INTO {schema}.keywords VALUES (7329, '7fdc339e-017f-4e4b-89a3-12e441a40bad', 6220, 'FLOODS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > FLOODS', 1);
INSERT INTO {schema}.keywords VALUES (7330, '960037c5-57b1-4cdf-84be-4542beee7d5a', 6220, 'HYDROPATTERN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > HYDROPATTERN', 1);
INSERT INTO {schema}.keywords VALUES (7331, 'd4e8b5c5-9203-4982-82bc-2611b517ffdb', 6220, 'HYDROPERIOD', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > HYDROPERIOD', 1);
INSERT INTO {schema}.keywords VALUES (7332, 'c6c0c5dd-c0ca-4670-bbaa-c22d39e73570', 6220, 'INUNDATION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > INUNDATION', 1);
INSERT INTO {schema}.keywords VALUES (7333, 'f6a54329-486b-4d5f-b105-c639cec42351', 6220, 'RUNOFF', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > RUNOFF', 1);
INSERT INTO {schema}.keywords VALUES (7334, '5cb5d5b9-0c0b-497f-a4ea-a8cece52d13d', 6220, 'STAGE HEIGHT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > STAGE HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (7335, '6f52de55-f5f2-45c0-b83f-59dbfb1fe221', 6220, 'TOTAL SURFACE WATER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > TOTAL SURFACE WATER', 1);
INSERT INTO {schema}.keywords VALUES (7336, '42aa1fa1-56a9-4e96-8063-077bd7ba88d8', 6220, 'WATER DEPTH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > WATER DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (7337, '84784fef-5b76-45a0-91e0-28788e09fea6', 6220, 'WATER PRESSURE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > WATER PRESSURE', 1);
INSERT INTO {schema}.keywords VALUES (7338, '04922ba6-8f00-4f54-b80c-ce2414c91e2e', 6220, 'WATER YIELD', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > WATER YIELD', 1);
INSERT INTO {schema}.keywords VALUES (7339, 'b98123fc-6a87-4396-8e1a-ae7406e76ff6', 6221, 'WATERSHED BOUNDARIES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > WATERSHED CHARACTERISTICS > WATERSHED BOUNDARIES', 1);
INSERT INTO {schema}.keywords VALUES (7340, 'ae36ad48-85f2-42a0-958f-efec71c34cc0', 6221, 'WATERSHED DRAINAGE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > WATERSHED CHARACTERISTICS > WATERSHED DRAINAGE', 1);
INSERT INTO {schema}.keywords VALUES (7341, 'e12150d7-5bd3-4a22-8b9f-f887a1fe3096', 6221, 'WATERSHED LENGTH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > WATERSHED CHARACTERISTICS > WATERSHED LENGTH', 1);
INSERT INTO {schema}.keywords VALUES (7342, '2b37d67c-92a6-4188-8f1b-4462bd754577', 6221, 'WATERSHED SHAPE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > WATERSHED CHARACTERISTICS > WATERSHED SHAPE', 1);
INSERT INTO {schema}.keywords VALUES (7343, '0d209f3c-73b1-412d-828b-22b25da8fc3a', 6221, 'WATERSHED SLOPE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > WATERSHED CHARACTERISTICS > WATERSHED SLOPE', 1);
INSERT INTO {schema}.keywords VALUES (7344, '62ee81e7-9f5a-4af5-a086-f4c402c7d19d', 6222, 'ACID RAIN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > ACID RAIN', 1);
INSERT INTO {schema}.keywords VALUES (7345, 'fa892a9e-523b-424e-bf02-1a8d1e618985', 6222, 'ARSENIC', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > ARSENIC', 1);
INSERT INTO {schema}.keywords VALUES (7346, '3e666b9f-6cf5-4454-9a65-987e981cd80e', 6222, 'BARIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > BARIUM', 1);
INSERT INTO {schema}.keywords VALUES (7347, 'e5a658d5-74db-4022-894f-edc8d297767a', 6222, 'CALCIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > CALCIUM', 1);
INSERT INTO {schema}.keywords VALUES (7348, '31c913e1-9692-45b5-bce5-cca46fa1874d', 6222, 'CARCINOGENS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > CARCINOGENS', 1);
INSERT INTO {schema}.keywords VALUES (7349, '9ab53717-17f1-4259-b425-0eed19c31884', 6222, 'CHROMIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > CHROMIUM', 1);
INSERT INTO {schema}.keywords VALUES (7350, '78fb5691-136d-40f8-a834-6e6f4cd768ff', 6222, 'COPPER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > COPPER', 1);
INSERT INTO {schema}.keywords VALUES (7351, '4690d6a8-78cd-48bc-82f5-36fb16d4c52e', 6222, 'DISINFECTANTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > DISINFECTANTS', 1);
INSERT INTO {schema}.keywords VALUES (7352, '1b6e67ff-351f-490c-bb43-646ac71f52ea', 6222, 'HARMFUL ALGAL BLOOMS (HABs)', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > HARMFUL ALGAL BLOOMS (HABs)', 1);
INSERT INTO {schema}.keywords VALUES (7353, 'e848dbd1-b70a-4820-a630-98bd642ae357', 6222, 'INORGANIC MATTER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > INORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (7354, '0965eb7b-6bd3-48a3-aa2a-52d7e2dda8ad', 6222, 'IRON', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > IRON', 1);
INSERT INTO {schema}.keywords VALUES (7355, '6fe420c1-2285-4031-babe-f0243c59a617', 6222, 'LEAD', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > LEAD', 1);
INSERT INTO {schema}.keywords VALUES (7356, '38f99d8b-80af-439a-9d3f-1e72aef5d7c3', 6222, 'MAGNESIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > MAGNESIUM', 1);
INSERT INTO {schema}.keywords VALUES (7357, '961591ce-9207-47db-9aeb-11586371fa12', 6222, 'METALS/MINERALS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > METALS/MINERALS', 1);
INSERT INTO {schema}.keywords VALUES (7358, '9c90825c-a35f-4165-8248-e90ab869f8ec', 6222, 'ORGANIC MATTER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > ORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (7359, '6fff6994-a0d8-4f19-8d36-c9f354b08b19', 6222, 'PATHOGEN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > PATHOGEN', 1);
INSERT INTO {schema}.keywords VALUES (7360, 'bc1c6d8c-2e47-4a9f-aeb4-16b02bff4f19', 6222, 'PESTICIDES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > PESTICIDES', 1);
INSERT INTO {schema}.keywords VALUES (7361, 'aef23021-81c1-4540-a0a5-35c590142a6d', 6222, 'PETROLEUM HYDROCARBONS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > PETROLEUM HYDROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (7362, '072721be-eb8b-4ac4-9354-251dbf74ade0', 6222, 'POTASSIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > POTASSIUM', 1);
INSERT INTO {schema}.keywords VALUES (7363, 'b2318fb3-788c-4f36-a1d1-36670d2da747', 6222, 'SELENIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > SELENIUM', 1);
INSERT INTO {schema}.keywords VALUES (7364, '207da091-2cd5-49a7-950e-91a164e02637', 6222, 'SEWAGE OVERFLOWS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > SEWAGE OVERFLOWS', 1);
INSERT INTO {schema}.keywords VALUES (7365, '160cce6b-c9f5-45bf-9a51-ee477f446cce', 6222, 'TITANIUM', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > TITANIUM', 1);
INSERT INTO {schema}.keywords VALUES (7366, 'bf3aaf41-3502-49cf-89df-4613ce87c9c3', 6222, 'TOXIC CHEMICALS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > TOXIC CHEMICALS', 1);
INSERT INTO {schema}.keywords VALUES (7367, 'f2d6aa01-5070-4147-bae1-4b2cad2c3987', 6222, 'TRACE METALS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > TRACE METALS', 1);
INSERT INTO {schema}.keywords VALUES (7368, 'ab12b3d6-2cbf-4a5a-a410-1d23afe906d8', 6222, 'ZINC', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > CONTAMINANTS > ZINC', 1);
INSERT INTO {schema}.keywords VALUES (7588, 'a0c33d15-b76c-4a0d-abb7-6919102b2977', 6633, 'CANAL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > URBAN LANDS > CANAL', 1);
INSERT INTO {schema}.keywords VALUES (7369, 'a9b89557-c09f-4a4a-a1eb-47c632f8eb59', 6223, 'DISSOLVED CARBON DIOXIDE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > GASES > DISSOLVED CARBON DIOXIDE', 1);
INSERT INTO {schema}.keywords VALUES (7370, 'ac933400-3c8c-4db4-ac68-5e8ed06c8336', 6223, 'DISSOLVED GASES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > GASES > DISSOLVED GASES', 1);
INSERT INTO {schema}.keywords VALUES (7371, 'dc748b93-e7d6-419d-a9f0-f370556d6f8e', 6223, 'DISSOLVED NITROGEN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > GASES > DISSOLVED NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (7372, 'b632d0cc-d4b0-458e-a182-16bbd2a5ab05', 6223, 'DISSOLVED OXYGEN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > GASES > DISSOLVED OXYGEN', 1);
INSERT INTO {schema}.keywords VALUES (7373, '6f4e850f-84e4-466f-b5ad-2032ea2187ea', 6224, 'RADIOISOTOPES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > ISOTOPES > RADIOISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (7374, 'fb52b51d-8bb4-4b04-907b-c130ec706f85', 6224, 'STABLE ISOTOPES', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > ISOTOPES > STABLE ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (7375, '0ba2ccb3-332c-4ee6-a9c9-50dce5a6c0cc', 6225, 'HYDROCARBONS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS > HYDROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (7376, '9bdac7db-be34-4eed-91bc-28f6628ed044', 6225, 'INORGANIC MATTER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS > INORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (7377, '644e0f53-98a2-4512-a228-00f5e61fd93d', 6225, 'NITROGEN COMPOUNDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS > NITROGEN COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (7378, 'bf03dba8-2881-44ac-abfc-ba3353f67a24', 6225, 'NITROGEN', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS > NITROGEN', 1);
INSERT INTO {schema}.keywords VALUES (7379, 'ee92daf8-d0da-4476-b389-0485114cbbe9', 6225, 'ORGANIC MATTER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS > ORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (7380, '846d2db9-41cd-4ae8-b4ff-a34a9efb7428', 6225, 'PHOSPHOROUS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > NUTRIENTS > PHOSPHOROUS', 1);
INSERT INTO {schema}.keywords VALUES (7381, '6d2511f8-4503-4237-93a9-34a3b369fe00', 6226, 'SEDIMENTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > SOLIDS > SEDIMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7382, '9d8cb1dd-4b38-4b4e-8532-ab4eb72cd4ae', 6226, 'SUSPENDED SOLIDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > SOLIDS > SUSPENDED SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (7383, '7d82a1f7-aa6e-47c7-8eb3-78bfe2e4349b', 6226, 'TOTAL DISSOLVED SOLIDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > SOLIDS > TOTAL DISSOLVED SOLIDS', 1);
INSERT INTO {schema}.keywords VALUES (7384, 'a74059fe-6b15-4b55-8ea5-4a65b66c7e11', 6227, 'ALKALINITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > ALKALINITY', 1);
INSERT INTO {schema}.keywords VALUES (7385, '2ef34dc5-4d29-4820-963c-f830f46c0347', 6227, 'BIOCHEMICAL OXYGEN DEMAND (BOD)', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > BIOCHEMICAL OXYGEN DEMAND (BOD)', 1);
INSERT INTO {schema}.keywords VALUES (7386, 'de21632f-b614-4375-8f09-d14ab00d852b', 6227, 'CHLOROPHYLL CONCENTRATIONS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > CHLOROPHYLL CONCENTRATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7387, 'd14389d9-54f5-41a0-b8e8-dc9d8f87e4e2', 6227, 'CONDUCTIVITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > CONDUCTIVITY', 1);
INSERT INTO {schema}.keywords VALUES (7388, '53d36c39-3cb1-44db-9746-feee86cbe9d7', 6227, 'EUTROPHICATION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > EUTROPHICATION', 1);
INSERT INTO {schema}.keywords VALUES (7389, '344cbd30-a2e4-437e-9fc9-5e6b1c484bac', 6227, 'HYDROCARBONS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > HYDROCARBONS', 1);
INSERT INTO {schema}.keywords VALUES (7390, '6cf87a79-e8b0-4ff1-9039-f3ad1f1f17a7', 6227, 'INORGANIC MATTER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > INORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (7391, '45351e81-fcd4-46a1-9222-315946caefc7', 6227, 'LIGHT TRANSMISSION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > LIGHT TRANSMISSION', 1);
INSERT INTO {schema}.keywords VALUES (7392, '1886b524-1f51-447d-9805-d40859739a0e', 6227, 'NITROGEN COMPOUNDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > NITROGEN COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (7393, 'e82c0632-5a3c-4da2-ba10-55c0fc222580', 6227, 'ORGANIC MATTER', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > ORGANIC MATTER', 1);
INSERT INTO {schema}.keywords VALUES (7394, 'f9f5cedd-9a0e-4058-87ff-c97df63fc326', 6227, 'PHOSPHOROUS COMPOUNDS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > PHOSPHOROUS COMPOUNDS', 1);
INSERT INTO {schema}.keywords VALUES (7395, 'dac96944-5a5e-4b2a-802d-74627bb93db9', 6227, 'POTABILITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > POTABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7396, 'a38db528-3064-449d-ae70-af86997a11f4', 6227, 'SALINE CONCENTRATION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > SALINE CONCENTRATION', 1);
INSERT INTO {schema}.keywords VALUES (7397, '0eaf009f-f92b-48b5-8a71-9c44c80d03d4', 6227, 'TURBIDITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > TURBIDITY', 1);
INSERT INTO {schema}.keywords VALUES (7398, 'e8d6a9c3-864e-4d97-938f-a6203997c01f', 6227, 'WATER COLOR', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > WATER COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7399, '75a83951-a086-4d25-9ab0-c118b0e20383', 6227, 'WATER HARDNESS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > WATER HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7400, '4cc8def9-a825-4ede-9e34-4e11cf89488d', 6227, 'WATER ION CONCENTRATIONS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > WATER ION CONCENTRATIONS', 1);
INSERT INTO {schema}.keywords VALUES (7401, 'd05ac6d6-d397-4bf7-b62b-c270522de2a5', 6227, 'WATER ODOR', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > WATER ODOR', 1);
INSERT INTO {schema}.keywords VALUES (7402, '61594015-4ab4-4b38-ae4f-e31a4757b065', 6227, 'WATER TEMPERATURE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > WATER TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (7403, '475c95a4-fd1c-4015-825f-07f6529858b0', 6227, 'WATER TRACE ELEMENTS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > WATER TRACE ELEMENTS', 1);
INSERT INTO {schema}.keywords VALUES (7404, '14625f2a-4186-4377-a0d9-88998bb6b775', 6227, 'pH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER CHARACTERISTICS > pH', 1);
INSERT INTO {schema}.keywords VALUES (7405, 'a71d195e-ff30-4592-a22c-a82af92f3d1f', 6228, 'GLOBAL DRINKING WATER QUALITY INDEX', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER QUALITY INDEXES > GLOBAL DRINKING WATER QUALITY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7406, '4497eb1b-b64d-46ff-a18d-37d217430777', 6228, 'INDEX OF BIOTIC INTEGRITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER QUALITY INDEXES > INDEX OF BIOTIC INTEGRITY', 1);
INSERT INTO {schema}.keywords VALUES (7407, '989e0558-a5fb-4758-bb82-c7d0a6a9f319', 6228, 'NATIONAL SANITATION FOUNDATION WATER QUALITY INDEX', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER QUALITY INDEXES > NATIONAL SANITATION FOUNDATION WATER QUALITY INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7408, '4fbe9a29-e3f5-4e1f-9dcb-99b79485d3b2', 6228, 'TROPHIC STATE INDEX', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > WATER QUALITY/WATER CHEMISTRY > WATER QUALITY INDEXES > TROPHIC STATE INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7409, 'a5e36040-cc5e-46d1-aeee-f49902e943b2', 6293, 'DEWPOINT DEPRESSION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > DEW POINT TEMPERATURE > DEWPOINT DEPRESSION', 1);
INSERT INTO {schema}.keywords VALUES (7410, 'ce6a6b3a-df4f-4bd7-a931-7ee874ee9efe', 6294, '24 HOUR MAXIMUM TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > MAXIMUM/MINIMUM TEMPERATURE > 24 HOUR MAXIMUM TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (7411, '5c7f35d5-a3ec-4010-b1c3-6e98ac29dc3f', 6294, '24 HOUR MINIMUM TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > MAXIMUM/MINIMUM TEMPERATURE > 24 HOUR MINIMUM TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (7412, 'e56bcf72-f331-4545-948f-73fe0193b1bd', 6294, '6 HOUR MAXIMUM TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > MAXIMUM/MINIMUM TEMPERATURE > 6 HOUR MAXIMUM TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (7413, 'c9ab66f1-91c6-497a-b8d6-4688160b0e16', 6294, '6 HOUR MINIMUM TEMPERATURE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > SURFACE TEMPERATURE > MAXIMUM/MINIMUM TEMPERATURE > 6 HOUR MINIMUM TEMPERATURE', 1);
INSERT INTO {schema}.keywords VALUES (7414, '86fb8a31-35f6-4d0e-b4b4-f9cecf961a47', 6303, 'DEW POINT DEPRESSION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > DEW POINT TEMPERATURE > DEW POINT DEPRESSION', 1);
INSERT INTO {schema}.keywords VALUES (7415, '17ce714a-bd7e-41a2-ab3d-4865832f1f0a', 6305, 'DRY ADIABATIC LAPSE RATE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > VERTICAL PROFILES > DRY ADIABATIC LAPSE RATE', 1);
INSERT INTO {schema}.keywords VALUES (7416, '050771bb-27a3-4e47-bd1b-724d1d73e20c', 6305, 'ENVIRONMENTAL LAPSE RATE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > VERTICAL PROFILES > ENVIRONMENTAL LAPSE RATE', 1);
INSERT INTO {schema}.keywords VALUES (7417, '4fa883a3-e312-4dbe-870e-3272de4ac76a', 6305, 'INVERSION HEIGHT', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > VERTICAL PROFILES > INVERSION HEIGHT', 1);
INSERT INTO {schema}.keywords VALUES (7418, '65937e73-0cc0-4058-b7dc-12c418ba2ed5', 6305, 'SATURATED ADIABATIC LAPSE RATE', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC TEMPERATURE > UPPER AIR TEMPERATURE > VERTICAL PROFILES > SATURATED ADIABATIC LAPSE RATE', 1);
INSERT INTO {schema}.keywords VALUES (7419, '6b61a904-b92d-45ee-9061-aa5e61c29dd2', 6308, 'ABSOLUTE HUMIDITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > HUMIDITY > ABSOLUTE HUMIDITY', 1);
INSERT INTO {schema}.keywords VALUES (7420, 'ea308986-ad35-4482-948c-5eb1a01be836', 6308, 'HUMIDITY MIXING RATIO', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > HUMIDITY > HUMIDITY MIXING RATIO', 1);
INSERT INTO {schema}.keywords VALUES (7421, 'a249c68f-8249-4285-aad2-020b3c5aefc3', 6308, 'RELATIVE HUMIDITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > HUMIDITY > RELATIVE HUMIDITY', 1);
INSERT INTO {schema}.keywords VALUES (7422, 'ba2491a4-2498-4c9f-9adc-123078eef633', 6308, 'SATURATION SPECIFIC HUMIDITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > HUMIDITY > SATURATION SPECIFIC HUMIDITY', 1);
INSERT INTO {schema}.keywords VALUES (7423, '811391d2-4113-4d52-9c88-47d56afda481', 6308, 'SPECIFIC HUMIDITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR INDICATORS > HUMIDITY > SPECIFIC HUMIDITY', 1);
INSERT INTO {schema}.keywords VALUES (7424, 'f28060e0-1c51-41df-8451-6c98b3e77e8a', 6319, 'EFFECTIVE EVAPOTRANSPIRATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > EVAPOTRANSPIRATION > EFFECTIVE EVAPOTRANSPIRATION', 1);
INSERT INTO {schema}.keywords VALUES (7425, '6045993e-a656-40c1-853c-9db1fbb49171', 6319, 'POTENTIAL EVAPOTRANSPIRATION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WATER VAPOR > WATER VAPOR PROCESSES > EVAPOTRANSPIRATION > POTENTIAL EVAPOTRANSPIRATION', 1);
INSERT INTO {schema}.keywords VALUES (7426, '5f55961d-45b8-4330-8eee-0b9a9eb4f309', 6332, 'ANABATIC WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS > ANABATIC WINDS', 1);
INSERT INTO {schema}.keywords VALUES (7427, '2cf573dd-0ed7-4455-a233-5987b5a8b52a', 6332, 'BORA WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS > BORA WINDS', 1);
INSERT INTO {schema}.keywords VALUES (7428, 'c19501d9-bd86-4611-bd30-6a34dc763a35', 6332, 'FOEHN WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS > FOEHN WINDS', 1);
INSERT INTO {schema}.keywords VALUES (7429, 'd7d48399-62ac-4eca-9c09-14b9094a9444', 6332, 'KATABATIC WINDS', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS > KATABATIC WINDS', 1);
INSERT INTO {schema}.keywords VALUES (7430, '6520897f-c6b6-432e-b7d5-e99b33e6932e', 6332, 'MOUNTAIN BREEZES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS > MOUNTAIN BREEZES', 1);
INSERT INTO {schema}.keywords VALUES (7431, '4d005bfc-597b-4a99-971f-21d3d44b7b91', 6332, 'VALLEY BREEZES', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > LOCAL WINDS > OROGRAPHIC WINDS > VALLEY BREEZES', 1);
INSERT INTO {schema}.keywords VALUES (7432, '72edbeca-b608-4f2d-8aba-492c8e6615b8', 6357, 'POTENTIAL VORTICITY', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > VORTICITY > POTENTIAL VORTICITY', 1);
INSERT INTO {schema}.keywords VALUES (7433, '9e2f502b-a2d5-4bc8-8c8f-489aa0c68177', 6357, 'VORTICITY ADVECTION', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > VORTICITY > VORTICITY ADVECTION', 1);
INSERT INTO {schema}.keywords VALUES (7434, 'ef91f2b6-27e9-42ab-b8c6-4410aace0141', 6358, 'HORIZONTAL WIND SHEAR', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > WIND SHEAR > HORIZONTAL WIND SHEAR', 1);
INSERT INTO {schema}.keywords VALUES (7435, '1b0abf68-b069-4a0b-8081-35a36da9d4a7', 6358, 'VERTICAL WIND SHEAR', 'EARTH SCIENCE > ATMOSPHERE > ATMOSPHERIC WINDS > WIND DYNAMICS > WIND SHEAR > VERTICAL WIND SHEAR', 1);
INSERT INTO {schema}.keywords VALUES (7436, '1dc6063b-892d-4879-8551-1e346dd3f2e7', 6367, 'DOWNWARD MOISTURE FLUX', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > MOISTURE FLUX > DOWNWARD MOISTURE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (7437, '49cad94d-0e93-44cb-a8a2-8e83d603463b', 6367, 'UPWARD MOISTURE FLUX', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > MOISTURE FLUX > UPWARD MOISTURE FLUX', 1);
INSERT INTO {schema}.keywords VALUES (7438, '2d00d3c4-2ef3-49f6-9261-6184f6517b4f', 6371, 'KARMAN VORTEX STREET', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD DYNAMICS > VORTEX STREET > KARMAN VORTEX STREET', 1);
INSERT INTO {schema}.keywords VALUES (7439, 'ab702934-0959-45fc-a523-81e1aa0c09c8', 6380, 'ACCRETION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > DROPLET GROWTH > ACCRETION', 1);
INSERT INTO {schema}.keywords VALUES (7440, '8e484ec4-50fd-4c08-9c96-6ad483e170ad', 6380, 'AGGREGATION', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > DROPLET GROWTH > AGGREGATION', 1);
INSERT INTO {schema}.keywords VALUES (7441, 'd5d64790-db29-451d-b022-a461dac06228', 6380, 'COALESCENCE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > DROPLET GROWTH > COALESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7442, 'bee9f657-c115-4d73-a10c-7e05e00db574', 6382, 'SEDIMENTATION RATE', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > SEDIMENTATION > SEDIMENTATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7443, 'e1035388-6993-4143-966b-30ced627c2da', 6404, 'CUMULONIMBUS CALVUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULONIMBUS > CUMULONIMBUS CALVUS', 1);
INSERT INTO {schema}.keywords VALUES (7444, 'eec3cec2-1649-4507-b91d-3a25ab2200ee', 6404, 'CUMULONIMBUS CAPILLATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULONIMBUS > CUMULONIMBUS CAPILLATUS', 1);
INSERT INTO {schema}.keywords VALUES (7445, '772d8044-f11b-4b01-bc72-d7dd45cfe1b3', 6404, 'PYROCUMULONIMBUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULONIMBUS > PYROCUMULONIMBUS', 1);
INSERT INTO {schema}.keywords VALUES (7446, '29d6cd82-4762-4316-9fdd-29430dae7ad9', 6405, 'CUMULUS CASTELLANUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > CUMULUS CASTELLANUS', 1);
INSERT INTO {schema}.keywords VALUES (7447, '3bafe2e0-c1a7-4bee-a02e-ac66964b4d7f', 6405, 'CUMULUS CONGESTUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > CUMULUS CONGESTUS', 1);
INSERT INTO {schema}.keywords VALUES (7448, '6aa7422c-ad66-40b6-90cd-750f9158daee', 6405, 'CUMULUS HUMILIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > CUMULUS HUMILIS', 1);
INSERT INTO {schema}.keywords VALUES (7449, 'ba9a8dac-abb7-4580-938d-762b53bab71b', 6405, 'CUMULUS MEDIOCRIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > CUMULUS MEDIOCRIS', 1);
INSERT INTO {schema}.keywords VALUES (7450, '801846d5-622b-4937-83cf-9d387be73ac4', 6405, 'PYROCUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > PYROCUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (7451, 'e4f5faaa-36d9-4529-b667-7d4e39d3c67b', 6417, 'CIRRUS CLOUD SYSTEMS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > CIRRUS/SYSTEMS > CIRRUS CLOUD SYSTEMS', 1);
INSERT INTO {schema}.keywords VALUES (7452, 'd6ba91a1-a5f4-47e3-9485-89348235acb9', 6417, 'CIRRUS KELVIN-HELMHOLTZ COLOMBIAH', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/HIGH-LEVEL CLOUDS (OBSERVED/ANALYZED) > CIRRUS/SYSTEMS > CIRRUS KELVIN-HELMHOLTZ COLOMBIAH', 1);
INSERT INTO {schema}.keywords VALUES (7453, '30c9e32c-7dfe-430f-bd06-4cfa844076e2', 6420, 'ADVECTION FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG > ADVECTION FOG', 1);
INSERT INTO {schema}.keywords VALUES (7454, '09a1b23e-bd8b-4bb9-966b-2388328973d4', 6420, 'FRONTAL FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG > FRONTAL FOG', 1);
INSERT INTO {schema}.keywords VALUES (7455, 'cd4f6e31-14b5-468a-a15c-5ac0ce97bf35', 6420, 'ICE FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG > ICE FOG', 1);
INSERT INTO {schema}.keywords VALUES (7456, '99a0a2d2-5d77-4cf2-8fc0-90d12840b12d', 6420, 'RADIATION FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG > RADIATION FOG', 1);
INSERT INTO {schema}.keywords VALUES (7457, '50604404-fef4-4e17-a6a6-a88c0bd88c4f', 6420, 'STEAM FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG > STEAM FOG', 1);
INSERT INTO {schema}.keywords VALUES (7458, '3eefb892-0453-48b6-b619-b8fa3e7bbfc8', 6420, 'UPSLOPE FOG', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > FOG > UPSLOPE FOG', 1);
INSERT INTO {schema}.keywords VALUES (7459, 'b1d51b72-97d0-484c-b251-220f219965c2', 6422, 'MARINE STRATOCUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > MARINE STRATOCUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (7460, '5857260b-1de6-47c2-8f66-5c0dbac42e32', 6422, 'STRATOCUMULUS CUMILIFORMIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS CUMILIFORMIS', 1);
INSERT INTO {schema}.keywords VALUES (7461, 'bec5166e-1822-40f7-8f07-4d5167d8a565', 6422, 'STRATOCUMULUS UNDULATAS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS UNDULATAS', 1);
INSERT INTO {schema}.keywords VALUES (7462, '44415a90-bfe0-447a-93c9-6e4badc6871c', 6424, 'ALTOCUMULUS CASTELLANUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOCUMULUS > ALTOCUMULUS CASTELLANUS', 1);
INSERT INTO {schema}.keywords VALUES (7463, 'dbc7fed3-ad30-4e57-868e-bae478713a71', 6424, 'ALTOCUMULUS LENTICULARIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOCUMULUS > ALTOCUMULUS LENTICULARIS', 1);
INSERT INTO {schema}.keywords VALUES (7464, '73e102fa-3089-42c3-bd0f-4682f73fff0f', 6424, 'ALTOCUMULUS UNDULATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOCUMULUS > ALTOCUMULUS UNDULATUS', 1);
INSERT INTO {schema}.keywords VALUES (7465, '4da38a31-aac6-4080-96b0-c8ee2cb33158', 6425, 'ALTOSTRATUS UNDULATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOSTRATUS > ALTOSTRATUS UNDULATUS', 1);
INSERT INTO {schema}.keywords VALUES (7466, '88e39edc-bf9b-4c02-8a9d-83f9b6c01891', 6430, 'FREEZING DRIZZLE', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION > DRIZZLE > FREEZING DRIZZLE', 1);
INSERT INTO {schema}.keywords VALUES (7467, 'f9405e92-0c1c-4443-9cc4-45d662d8b5f2', 6432, 'ACID RAIN', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION > RAIN > ACID RAIN', 1);
INSERT INTO {schema}.keywords VALUES (7468, 'a90306f0-353c-4083-941a-0973a6fd6584', 6432, 'FREEZING RAIN', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > LIQUID PRECIPITATION > RAIN > FREEZING RAIN', 1);
INSERT INTO {schema}.keywords VALUES (7469, '5beaf99c-0675-4af3-9236-f55d8d206d85', 6442, 'SLEET', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > ICE PELLETS > SLEET', 1);
INSERT INTO {schema}.keywords VALUES (7470, '26087764-bd76-4a70-8dba-3c0cbadad6a7', 6442, 'SMALL HAIL', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > ICE PELLETS > SMALL HAIL', 1);
INSERT INTO {schema}.keywords VALUES (7471, '6a16461a-49b9-4887-802f-2320c6dc4dd2', 6443, 'SNOW GRAINS', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > SNOW > SNOW GRAINS', 1);
INSERT INTO {schema}.keywords VALUES (7472, 'c2815464-48b7-4dc1-90d6-0ab5a8b7c82b', 6443, 'SNOW PELLETS', 'EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > SOLID PRECIPITATION > SNOW > SNOW PELLETS', 1);
INSERT INTO {schema}.keywords VALUES (7473, '241d4bbb-3965-4595-93d3-8fe8c89fdab1', 6457, 'SUBTROPICAL DEPRESSION TRACK', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SUBTROPICAL CYCLONES > SUBTROPICAL DEPRESSION > SUBTROPICAL DEPRESSION TRACK', 1);
INSERT INTO {schema}.keywords VALUES (7474, '308beca2-b3c8-4cbb-aa9c-e1be605ca785', 6458, 'SUBTROPICAL STORM MOTION', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SUBTROPICAL CYCLONES > SUBTROPICAL STORM > SUBTROPICAL STORM MOTION', 1);
INSERT INTO {schema}.keywords VALUES (7475, 'c1a196a3-4134-473a-819e-369ab9656abb', 6458, 'SUBTROPICAL STORM TRACK', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > SUBTROPICAL CYCLONES > SUBTROPICAL STORM > SUBTROPICAL STORM TRACK', 1);
INSERT INTO {schema}.keywords VALUES (7476, '7067a3f8-2903-46b7-9189-af1189a15a43', 6474, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > ACCUMULATED CYCLONE ENERGY > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7477, 'fb890034-3ae6-4c91-941c-ae1483a13528', 6474, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > ACCUMULATED CYCLONE ENERGY > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7478, '5da932fa-2f4b-4f65-bad4-18c661816549', 6474, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > ACCUMULATED CYCLONE ENERGY > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7479, 'e89e331c-ca8e-4c25-be34-c81017bd019f', 6474, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > ACCUMULATED CYCLONE ENERGY > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7480, '074c2800-e458-4fa0-bcae-7f400d970650', 6474, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > ACCUMULATED CYCLONE ENERGY > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7481, '0d7ea0fa-987a-4429-85e7-754ca638e504', 6475, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > LANDFALL INTENSITY > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7482, '4354779d-94e6-4c38-973b-3a9bafa4eeb2', 6475, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > LANDFALL INTENSITY > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7483, '7aa4aea2-0f5b-4490-967b-7e339eaec507', 6475, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > LANDFALL INTENSITY > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7484, 'ab9dfb44-979e-495c-ad83-8d30a37018be', 6475, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > LANDFALL INTENSITY > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7485, 'dd5cbcc2-622a-4c3c-82b8-7e2869f8438a', 6475, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > LANDFALL INTENSITY > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7486, '1ab5b26c-8560-412c-8b7b-80921aff9fe1', 6476, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM 1-MINUTE SUSTAINED WIND > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7487, '93f7b0c1-ea76-431f-8cb0-0599eb51f928', 6476, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM 1-MINUTE SUSTAINED WIND > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7488, '58ddb82c-fbb2-4910-8259-d9c2df2555da', 6476, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM 1-MINUTE SUSTAINED WIND > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7489, 'dd54dfac-069b-4552-abfe-d182320189c7', 6476, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM 1-MINUTE SUSTAINED WIND > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7490, '53998f98-9bf6-4666-90c7-48f2e5730dae', 6476, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM 1-MINUTE SUSTAINED WIND > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7491, 'b5965fe4-fc00-4d9b-93f8-f03a6a369304', 6477, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM SURFACE WIND > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7492, '8807cdb6-56af-43d6-9efa-14d234d69374', 6477, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM SURFACE WIND > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7493, '40f7445f-1741-418e-9831-e2e3322daf5a', 6477, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM SURFACE WIND > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7494, 'a8258a99-866f-4e34-80ab-25239546ffb2', 6477, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM SURFACE WIND > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7495, '8e93861c-5f03-4892-96d7-cfac368e6c26', 6477, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM SURFACE WIND > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7496, 'd5f307ab-e5df-4c84-84e7-42822e3a4864', 6478, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM WIND GUST > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7497, '2d2a56cb-a99c-4001-9f41-0e04037e0d41', 6478, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM WIND GUST > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7498, '6e28bebd-0c5d-4bf3-8770-84d79c75e33c', 6478, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM WIND GUST > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7499, '4379a82a-c0fd-4d40-b1f3-3b516cac1a8e', 6478, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM WIND GUST > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7500, '536b666d-a4ad-4ec3-b7fc-282e884e53ee', 6478, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MAXIMUM WIND GUST > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7501, 'ef467c3c-0aed-4aa8-bfa5-67721e83e557', 6479, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MINIMUM CENTRAL PRESSURE > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7502, '3b1544bc-1711-4553-a643-5d8fba38a1f1', 6479, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MINIMUM CENTRAL PRESSURE > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7503, '50abff20-11a8-4aea-8425-c9a05b1d8d09', 6479, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MINIMUM CENTRAL PRESSURE > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7504, '5b70e02b-0ed2-42a0-9fe9-7a552d6819d1', 6479, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MINIMUM CENTRAL PRESSURE > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7505, 'cfb85bf2-9920-4e3f-bce3-3d8f68ab1436', 6479, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > MINIMUM CENTRAL PRESSURE > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7506, 'd038c99b-efbc-41f3-99a6-5d066fda5ecd', 6480, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > PEAK INTENSITY > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7507, '5730c1ba-7e4e-4d0e-adf3-053af4be97b4', 6480, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > PEAK INTENSITY > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7508, 'b21b9b00-5da4-47fc-b2a8-fc2ecd5bd912', 6480, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > PEAK INTENSITY > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7509, 'cbe89018-3eb6-4c8e-82c9-c540147a75e2', 6480, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > PEAK INTENSITY > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7510, '20da8cba-3546-4699-8809-01bffa6bccca', 6480, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > PEAK INTENSITY > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7511, 'c6ff6623-a24c-494c-804c-bc486b3de548', 6481, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 1) > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7512, 'fe4f3f33-7df3-439a-9382-d02140da29aa', 6482, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 2) > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7513, 'd678b2d9-9956-45a9-9a9f-95450fb4ca46', 6483, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 3) > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7514, '91843b75-9519-456a-89a5-1b1c221ebd4e', 6484, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 4) > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7515, '6f80bcdf-b778-4ecc-99aa-9f5779fd6f31', 6485, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > SAFFIR-SIMPSON SCALE AT LANDFALL (CATEGORY 5) > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7516, '00d89979-f1bb-4e95-b73e-6a0d8d924bd8', 6486, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE FORCE WIND EXTENT > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7517, 'd99d0464-db69-44fb-9b18-9469a08fe4b4', 6486, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE FORCE WIND EXTENT > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7518, 'ed71cef0-0e5a-49a0-83c6-f7dd02215290', 6486, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE FORCE WIND EXTENT > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7519, '713123e4-ebc8-49dd-bc8b-b9fbeaabeaad', 6486, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE FORCE WIND EXTENT > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7520, '6ee22b9c-f418-4b77-bb6b-f70d3e44afbc', 6486, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE FORCE WIND EXTENT > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7521, '63e53301-d263-4d09-a4be-f0c874646e23', 6488, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE MOTION > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7522, 'a8a40309-c4e5-46d7-ac39-1b7230766192', 6488, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE MOTION > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7523, '446a22b7-3ea1-43db-9176-47d4dac3ac93', 6488, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE MOTION > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7524, '7705e65c-90a1-451d-8898-ef5f170fa051', 6488, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE MOTION > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7525, '93ef0499-0b06-4f9a-885b-52e89563b3ec', 6488, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE MOTION > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7526, 'f4f4a7ad-73da-42f2-94f9-d9ecb81e0bf0', 6489, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE RADIUS > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7527, '41829fbf-2b76-4714-bf4a-e0d63b5472d5', 6489, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE RADIUS > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7528, '9928589d-0714-4b88-a8ad-11126dd97521', 6489, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE RADIUS > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7529, '5d51ef9b-f058-48ca-b1ea-c8d63a50a699', 6489, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE RADIUS > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7530, '09849cf3-df4d-40d3-a224-f30c6fe22c1f', 6489, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE RADIUS > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7531, '5d0a21f1-cc5d-481c-ad5f-7fe15deabc9c', 6490, 'CYCLONES (SW INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE TRACK > CYCLONES (SW INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7532, '72de9813-4c72-45bc-a216-be6ebd08bb6c', 6490, 'HURRICANES  (N. ATLANTIC/E. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE TRACK > HURRICANES  (N. ATLANTIC/E. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7533, 'e61fcc9f-bdb6-4dbc-94f2-52c4c64b6df9', 6490, 'SEVERE CYCLONIC STORMS (N. INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE TRACK > SEVERE CYCLONIC STORMS (N. INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7534, '8d27af08-6b2f-48d7-8e6b-bd57e93992ad', 6490, 'SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE TRACK > SEVERE TROPICAL CYCLONES (SW PACIFIC/SE INDIAN)', 1);
INSERT INTO {schema}.keywords VALUES (7535, 'b5a681af-5005-4182-922e-528ec8d514f1', 6490, 'TYPHOONS (WESTERN N. PACIFIC)', 'EARTH SCIENCE > ATMOSPHERE > WEATHER EVENTS > TROPICAL CYCLONES > TROPICAL CYCLONE TRACK > TYPHOONS (WESTERN N. PACIFIC)', 1);
INSERT INTO {schema}.keywords VALUES (7536, '973bd2bd-c201-4e8c-8c86-d2e849298310', 6502, 'ARACHNIDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CHELICERATES > ARACHNIDS', 1);
INSERT INTO {schema}.keywords VALUES (7537, 'e20c4981-7cbe-4f5c-9139-78b22ee7bfb6', 6503, 'AMPHIPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > AMPHIPODS', 1);
INSERT INTO {schema}.keywords VALUES (7538, '57e04385-5f7b-432b-8f0b-b26fc9e3d77d', 6503, 'BARNACLES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > BARNACLES', 1);
INSERT INTO {schema}.keywords VALUES (7539, '9443e3fb-5087-4aae-a311-35ab172c45ce', 6503, 'COPEPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > COPEPODS', 1);
INSERT INTO {schema}.keywords VALUES (7540, 'e631c681-5dad-48b2-83ce-943a1f0df47a', 6503, 'DECAPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > DECAPODS', 1);
INSERT INTO {schema}.keywords VALUES (7541, '4095dea9-3da1-4679-bccf-7fe637414910', 6503, 'EUPHAUSIIDS (KRILL)', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > EUPHAUSIIDS (KRILL)', 1);
INSERT INTO {schema}.keywords VALUES (7542, 'dcf06e40-74f1-4341-bc80-79dcd2e268b9', 6503, 'ISOPODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > ISOPODS', 1);
INSERT INTO {schema}.keywords VALUES (7543, 'bfda8569-896e-4efa-81e1-8f02af8b1017', 6503, 'MYSIDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > MYSIDS', 1);
INSERT INTO {schema}.keywords VALUES (7544, 'e91ca626-7afa-4e36-8a28-f8df6fc9d797', 6503, 'OSTRACODS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > CRUSTACEANS > OSTRACODS', 1);
INSERT INTO {schema}.keywords VALUES (7545, 'b23a3120-0b90-434d-81e6-988f62034e22', 6504, 'ENTOGNATHA', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > HEXAPODS > ENTOGNATHA', 1);
INSERT INTO {schema}.keywords VALUES (7546, '44e49605-e860-41d0-8ef8-cb74419f831d', 6504, 'INSECTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > HEXAPODS > INSECTS', 1);
INSERT INTO {schema}.keywords VALUES (7547, '582efbf1-ae9c-47f4-8155-c445f3816dd8', 6487, 'CENTIPEDES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > MYRIAPODS > CENTIPEDES', 1);
INSERT INTO {schema}.keywords VALUES (7548, 'd6db51cf-d2d0-4203-94c8-c884579e0cb0', 6487, 'MILLIPEDES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > ARTHROPODS > MYRIAPODS > MILLIPEDES', 1);
INSERT INTO {schema}.keywords VALUES (7549, 'dd4de9c8-e078-43cf-a7d8-78f289c8618e', 6505, 'HARD OR STONY CORALS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/HEXACORALS > HARD OR STONY CORALS', 1);
INSERT INTO {schema}.keywords VALUES (7550, '9c47c3f3-09ae-491f-994c-0322e2875a7e', 6505, 'SEA ANEMONES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/HEXACORALS > SEA ANEMONES', 1);
INSERT INTO {schema}.keywords VALUES (7551, 'c6b33bb7-9714-42b5-88d2-f16bd671b799', 6506, 'SEA FANS/SEA WHIPS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/OCTOCORALS > SEA FANS/SEA WHIPS', 1);
INSERT INTO {schema}.keywords VALUES (7552, '9f25a6bc-ccbd-44fd-a33f-36a2ed53827f', 6506, 'SEA PENS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/OCTOCORALS > SEA PENS', 1);
INSERT INTO {schema}.keywords VALUES (7553, '7836e8bd-176d-4e2f-9ac1-7f9d9a152b4e', 6506, 'SOFT CORALS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > CNIDARIANS > ANTHOZOANS/OCTOCORALS > SOFT CORALS', 1);
INSERT INTO {schema}.keywords VALUES (7554, '9273a48a-7ca4-4f1a-9347-7f6599b5a7e3', 6513, 'CLAMS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > BIVALVES > CLAMS', 1);
INSERT INTO {schema}.keywords VALUES (7555, 'bc60fbb8-f9e9-492e-9acf-0f47345cedf2', 6513, 'MUSSELS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > BIVALVES > MUSSELS', 1);
INSERT INTO {schema}.keywords VALUES (7556, 'b6782a30-639e-4d70-8290-81683d248b1f', 6513, 'OYSTERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > BIVALVES > OYSTERS', 1);
INSERT INTO {schema}.keywords VALUES (7557, '0d07a910-06bf-4607-90f8-422e1f35cfa0', 6514, 'SQUIDS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/INVERTEBRATES > MOLLUSKS > CEPHALOPODS > SQUIDS', 1);
INSERT INTO {schema}.keywords VALUES (7558, '4309af7d-76c8-4856-8ed3-20693600228b', 6539, 'ANCHOVIES/HERRINGS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > ANCHOVIES/HERRINGS', 1);
INSERT INTO {schema}.keywords VALUES (7559, '89530978-556a-44fd-88fa-5d42ce9c8b91', 6539, 'CATFISHES/MINNOWS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > CATFISHES/MINNOWS', 1);
INSERT INTO {schema}.keywords VALUES (7560, '340b843e-841e-40d9-97c2-d76cca66c65e', 6539, 'CODS/HADDOCKS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > CODS/HADDOCKS', 1);
INSERT INTO {schema}.keywords VALUES (7561, '74b0e517-8cde-45ad-b6fa-0849d4355928', 6539, 'FLOUNDERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > FLOUNDERS', 1);
INSERT INTO {schema}.keywords VALUES (7562, '4b9b8b32-93b4-4e8e-819d-55ee7f6a6480', 6539, 'NEEDLEFISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > NEEDLEFISHES', 1);
INSERT INTO {schema}.keywords VALUES (7563, '85b2ba83-b81c-45a6-98d1-07b36040fe45', 6539, 'PERCH-LIKE FISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > PERCH-LIKE FISHES', 1);
INSERT INTO {schema}.keywords VALUES (7564, '3179b46a-ce20-453c-9ebf-18a070a91dec', 6539, 'PUPFISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > PUPFISHES', 1);
INSERT INTO {schema}.keywords VALUES (7565, '0b8d5346-d10b-4e32-8179-7a51970c5e7f', 6539, 'SALMONS/TROUTS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > SALMONS/TROUTS', 1);
INSERT INTO {schema}.keywords VALUES (7566, '01549b6d-91e1-40de-bd7c-5ed5ee59d14e', 6539, 'STURGEONS/PADDLEFISHES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > STURGEONS/PADDLEFISHES', 1);
INSERT INTO {schema}.keywords VALUES (7567, '6831004a-34d7-42f5-a903-6c84a5e7590f', 6542, 'BEARS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CARNIVORES > BEARS', 1);
INSERT INTO {schema}.keywords VALUES (7568, '8d01f599-3a98-44b9-889f-43df92386d12', 6542, 'DOGS/FOXES/WOLVES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CARNIVORES > DOGS/FOXES/WOLVES', 1);
INSERT INTO {schema}.keywords VALUES (7569, 'd8973cd1-f3b4-4087-bf3b-25ac0732fb38', 6542, 'MARTENS/WEASELS/WOLVERINES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CARNIVORES > MARTENS/WEASELS/WOLVERINES', 1);
INSERT INTO {schema}.keywords VALUES (7570, 'eedb68d2-c487-4dc8-8292-c375e3e8b455', 6542, 'OTTERS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CARNIVORES > OTTERS', 1);
INSERT INTO {schema}.keywords VALUES (7571, '35cf1beb-a654-4ceb-ab6b-7e505c2144e7', 6542, 'SEALS/SEA LIONS/WALRUSES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CARNIVORES > SEALS/SEA LIONS/WALRUSES', 1);
INSERT INTO {schema}.keywords VALUES (7572, '5e0ce993-df7c-46e2-9942-3a242df75705', 6543, 'BALEEN WHALES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CETACEANS > BALEEN WHALES', 1);
INSERT INTO {schema}.keywords VALUES (7573, '1e2a4882-d1e9-4e1a-a2a5-efc449133bf5', 6543, 'TOOTHED WHALES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > CETACEANS > TOOTHED WHALES', 1);
INSERT INTO {schema}.keywords VALUES (7574, '33e2e026-e40b-4932-95a9-b2ca1a7aa407', 6546, 'CATTLE/SHEEP', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > EVEN-TOED UNGULATES > CATTLE/SHEEP', 1);
INSERT INTO {schema}.keywords VALUES (7575, '5557a4f3-8392-4df5-81a9-206c2a86da89', 6546, 'DEER/MOOSE', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > EVEN-TOED UNGULATES > DEER/MOOSE', 1);
INSERT INTO {schema}.keywords VALUES (7576, '108ece15-4588-4564-b803-dc1c17cf193e', 6546, 'HOGS/PIGS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > MAMMALS > EVEN-TOED UNGULATES > HOGS/PIGS', 1);
INSERT INTO {schema}.keywords VALUES (7577, 'e36c5faa-c772-4bb0-aeca-b361e160ce9d', 6552, 'SEAGRASS', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > ANGIOSPERMS (FLOWERING PLANTS) > MONOCOTS > SEAGRASS', 1);
INSERT INTO {schema}.keywords VALUES (7578, 'ab7eb13f-5fcb-4afa-8819-c37d36feeec1', 6567, 'COCCOLITHOPHORES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PLANTS > MICROALGAE > HAPTOPHYTES > COCCOLITHOPHORES', 1);
INSERT INTO {schema}.keywords VALUES (7579, 'e88cc54b-7a4b-4680-b441-4d10a4534cd9', 6573, 'COCCOLITHOPHORES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > PROTISTS > FLAGELLATES > HAPTOPHYTES > COCCOLITHOPHORES', 1);
INSERT INTO {schema}.keywords VALUES (7580, '2c74f390-9d82-4903-98e0-bddf0d3247fb', 6631, 'CROPLAND', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > AGRICULTURAL LANDS > CROPLAND', 1);
INSERT INTO {schema}.keywords VALUES (7581, '39fee18c-8572-4d72-a0ce-2a72942c4870', 6631, 'FOREST PLANTATION', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > AGRICULTURAL LANDS > FOREST PLANTATION', 1);
INSERT INTO {schema}.keywords VALUES (7582, '46a26fc7-95f0-409e-8bfa-eb623b3a3f8d', 6631, 'PASTURE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > AGRICULTURAL LANDS > PASTURE', 1);
INSERT INTO {schema}.keywords VALUES (7583, '3c8b236c-de02-491b-a506-91ecdc324a1c', 6631, 'RANGELAND', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > AGRICULTURAL LANDS > RANGELAND', 1);
INSERT INTO {schema}.keywords VALUES (7584, '7d8dcf2c-133f-47b2-9195-17dd263ec8a3', 6632, 'MINNING/DRILLING SITE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > RESOURCE DEVELOPMENT SITE > MINNING/DRILLING SITE', 1);
INSERT INTO {schema}.keywords VALUES (7585, '9ff1f885-108f-40cb-a054-4e076b8d648b', 6632, 'SOLAR FARM', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > RESOURCE DEVELOPMENT SITE > SOLAR FARM', 1);
INSERT INTO {schema}.keywords VALUES (7586, '39fa5f62-1c4e-4790-a768-1252c0b51c7b', 6632, 'WATER IMPOUNDMENT', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > RESOURCE DEVELOPMENT SITE > WATER IMPOUNDMENT', 1);
INSERT INTO {schema}.keywords VALUES (7587, '0c603a5b-d5e9-4e87-a8dc-2af456678dba', 6632, 'WIND FARM', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > RESOURCE DEVELOPMENT SITE > WIND FARM', 1);
INSERT INTO {schema}.keywords VALUES (7589, '3bd03ca9-4a63-44f1-b368-36f2400776e6', 6633, 'GARDEN', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > URBAN LANDS > GARDEN', 1);
INSERT INTO {schema}.keywords VALUES (7590, '2b1f7993-2d54-40de-abc4-3909f619ad4e', 6633, 'PARK', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > URBAN LANDS > PARK', 1);
INSERT INTO {schema}.keywords VALUES (7591, 'a9f2e036-f04f-46cc-a4e8-dfba30d9034c', 6633, 'ROADSIDE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > ANTHROPOGENIC/HUMAN INFLUENCED ECOSYSTEMS > URBAN LANDS > ROADSIDE', 1);
INSERT INTO {schema}.keywords VALUES (7592, '235996b1-b1a8-4c20-bb1f-711fb1a0c952', 6634, 'PHYTOPLANKTON', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > PLANKTON > PHYTOPLANKTON', 1);
INSERT INTO {schema}.keywords VALUES (7593, '0399b52c-e3de-4dcc-9eb6-b1e3acf2cf1b', 6634, 'ZOOPLANKTON', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > PLANKTON > ZOOPLANKTON', 1);
INSERT INTO {schema}.keywords VALUES (7594, '3e924e3a-eb5d-4f81-8981-1b9f622ddc82', 6635, 'ESTUARINE WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > ESTUARINE WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7595, 'dd22cc67-afd5-4b9e-8072-90651a191486', 6635, 'LACUSTRINE WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > LACUSTRINE WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7596, 'bc320625-d9ba-41f5-9336-57e86fd878f3', 6635, 'MARINE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > MARINE', 1);
INSERT INTO {schema}.keywords VALUES (7597, '291a51b8-07e5-4a66-8140-d140d69843db', 6635, 'MARSHES', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > MARSHES', 1);
INSERT INTO {schema}.keywords VALUES (7598, 'd400ab07-bde9-40cc-b70a-63eda730eab2', 6635, 'PALUSTRINE WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > PALUSTRINE WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7599, 'b70ef20c-7215-4a39-9479-dbff7c2fdca9', 6635, 'PEATLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > PEATLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7600, '41446bdc-89f6-4d84-a2a4-005390757235', 6635, 'RIPARIAN WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > RIPARIAN WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7601, '6cec3b57-1a7f-404d-afde-4de045ef0dd2', 6635, 'SWAMPS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > SWAMPS', 1);
INSERT INTO {schema}.keywords VALUES (7602, 'e72c39c5-5480-4602-bb37-216b5cc737dd', 6635, 'VERNAL POOL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > AQUATIC ECOSYSTEMS > WETLANDS > VERNAL POOL', 1);
INSERT INTO {schema}.keywords VALUES (7603, 'b23b9a47-d2aa-4e67-84d6-5fe2527d6fb6', 6636, 'MONTANE LAKE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > LAKE/POND > MONTANE LAKE', 1);
INSERT INTO {schema}.keywords VALUES (7604, '06a2da0f-5234-4d29-905b-153d88657eb9', 6636, 'SALINE LAKES', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > LAKE/POND > SALINE LAKES', 1);
INSERT INTO {schema}.keywords VALUES (7605, '5f76c978-1c8a-496e-bc6a-78ff7656f014', 6637, 'EPHEMERAL STREAM', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > RIVERS/STREAM > EPHEMERAL STREAM', 1);
INSERT INTO {schema}.keywords VALUES (7606, 'de9222a5-c3bc-470d-86dc-8b426ce61b76', 6637, 'HEADWATER STREAM', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > RIVERS/STREAM > HEADWATER STREAM', 1);
INSERT INTO {schema}.keywords VALUES (7607, '1b5d3b68-4f89-4772-b015-ce6f30cf0496', 6637, 'INTERMITTENT STREAM', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > RIVERS/STREAM > INTERMITTENT STREAM', 1);
INSERT INTO {schema}.keywords VALUES (7608, '0236a2e0-64d6-4763-bcd1-ea8bb3a117a1', 6637, 'PERENNIAL STREAM/RIVER', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > RIVERS/STREAM > PERENNIAL STREAM/RIVER', 1);
INSERT INTO {schema}.keywords VALUES (7609, 'bafaa203-0dc0-4167-a64a-d89ba16d8eb1', 6637, 'RIVER DELTA', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > FRESHWATER ECOSYSTEMS > RIVERS/STREAM > RIVER DELTA', 1);
INSERT INTO {schema}.keywords VALUES (7610, '290354cc-c670-4845-bb66-ef1974b1e2a2', 6638, 'COLD SEEP', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ABYSSAL > COLD SEEP', 1);
INSERT INTO {schema}.keywords VALUES (7611, 'bee69b66-3921-4883-920f-6a0bd85b614f', 6638, 'HYDROTHERMAL VENT', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ABYSSAL > HYDROTHERMAL VENT', 1);
INSERT INTO {schema}.keywords VALUES (7612, 'a61d1705-a6b7-4df3-9f8e-57e26029629c', 6640, 'BEACHES', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > BEACHES', 1);
INSERT INTO {schema}.keywords VALUES (7613, '8d38de3b-2d05-4ad2-a960-f47a66191319', 6640, 'DUNES', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > DUNES', 1);
INSERT INTO {schema}.keywords VALUES (7614, 'd609fc5c-8267-4e79-84ec-93629d52aba8', 6640, 'KELP FOREST', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > KELP FOREST', 1);
INSERT INTO {schema}.keywords VALUES (7615, '879d286b-9ea6-4e4d-bdd1-56a4c7ca1531', 6640, 'LAGOON', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > LAGOON', 1);
INSERT INTO {schema}.keywords VALUES (7616, '7c666111-3297-474b-ba7b-c93db3a52cb0', 6640, 'MANGROVE SWAMP', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > MANGROVE SWAMP', 1);
INSERT INTO {schema}.keywords VALUES (7617, '771b2919-ab55-4c71-8561-b4fb365da53f', 6640, 'MUDFLAT', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > MUDFLAT', 1);
INSERT INTO {schema}.keywords VALUES (7618, '80e51854-2f3f-447e-9786-6d2ccb0dd886', 6640, 'ROCKY INTERTIDAL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > ROCKY INTERTIDAL', 1);
INSERT INTO {schema}.keywords VALUES (7619, 'fbe91a4f-4d27-4cfe-ba1b-69a62e359a3d', 6640, 'SALT MARSH', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > SALT MARSH', 1);
INSERT INTO {schema}.keywords VALUES (7620, '9d0e3045-943e-460c-8bef-1db6fbf76341', 6640, 'SAV/SEA GRASS BED', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > COASTAL > SAV/SEA GRASS BED', 1);
INSERT INTO {schema}.keywords VALUES (7621, '155e730b-4e22-4962-adc5-a4b92543a442', 6642, 'BRACKISH MARSH', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ESTUARY > BRACKISH MARSH', 1);
INSERT INTO {schema}.keywords VALUES (7622, '63cd8427-07bd-4a46-b725-ca65da4bf9b6', 6642, 'MANGROVE SWAMP', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ESTUARY > MANGROVE SWAMP', 1);
INSERT INTO {schema}.keywords VALUES (7623, '86987ad2-21d2-496b-9119-350b3fb17455', 6642, 'MUDFLAT', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ESTUARY > MUDFLAT', 1);
INSERT INTO {schema}.keywords VALUES (7624, '5f6e1b08-caca-423b-80dc-7de3da7a2988', 6642, 'SAV/SEA GRASS BED', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > ESTUARY > SAV/SEA GRASS BED', 1);
INSERT INTO {schema}.keywords VALUES (7625, 'eb958dfb-5e38-401f-8b42-5f1273c75a4a', 6643, 'NERITIC ZONE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > PELAGIC > NERITIC ZONE', 1);
INSERT INTO {schema}.keywords VALUES (7626, '02d78090-d0b5-490d-92a8-b593172ab232', 6643, 'OCEANIC ZONE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > PELAGIC > OCEANIC ZONE', 1);
INSERT INTO {schema}.keywords VALUES (7627, 'fa3bc02d-31a7-4456-b716-a8b8f8393c86', 6644, 'CORAL REEF', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > REEF > CORAL REEF', 1);
INSERT INTO {schema}.keywords VALUES (7628, '758c00c3-03a3-4cef-9248-ab392d789148', 6644, 'OYSTER REEF', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > MARINE ECOSYSTEMS > REEF > OYSTER REEF', 1);
INSERT INTO {schema}.keywords VALUES (7629, '944d9d09-4317-4e9a-9aa5-dc4282be406e', 6645, 'ALPINE TUNDRA', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > ALPINE/TUNDRA > ALPINE TUNDRA', 1);
INSERT INTO {schema}.keywords VALUES (7630, '46ecf46f-a710-4589-82b2-34aebf35c3c0', 6645, 'ARCTIC TUNDRA', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > ALPINE/TUNDRA > ARCTIC TUNDRA', 1);
INSERT INTO {schema}.keywords VALUES (7631, '101950b9-00d3-4721-9af8-fa5d51b196c3', 6645, 'SUBALPINE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > ALPINE/TUNDRA > SUBALPINE', 1);
INSERT INTO {schema}.keywords VALUES (7632, '4f63746e-0e8b-4254-9d4a-a23a852f819f', 6647, 'DESERT SCRUB', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > DESERTS > DESERT SCRUB', 1);
INSERT INTO {schema}.keywords VALUES (7633, 'cafa8131-4a2d-4c8b-811c-0d64adf5fc06', 6648, 'BOREAL FOREST/TIAGA', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS > BOREAL FOREST/TIAGA', 1);
INSERT INTO {schema}.keywords VALUES (7634, '5d8236b5-bf5b-499f-a8e7-0cd80e00d261', 6648, 'TEMPERATE CONIFEROUS FOREST', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS > TEMPERATE CONIFEROUS FOREST', 1);
INSERT INTO {schema}.keywords VALUES (7635, 'a59dc6dc-5348-4e8b-aec2-20cdeb38b617', 6648, 'TEMPERATE DECIDUOUS FOREST', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS > TEMPERATE DECIDUOUS FOREST', 1);
INSERT INTO {schema}.keywords VALUES (7636, '9cde47e7-325b-465e-93a6-ae4d459c7945', 6648, 'TEMPERATE MIXED FOREST', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS > TEMPERATE MIXED FOREST', 1);
INSERT INTO {schema}.keywords VALUES (7637, '96ea0bde-7cf6-4601-8a49-116636f556cf', 6648, 'TEMPERATE RAINFOREST', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS > TEMPERATE RAINFOREST', 1);
INSERT INTO {schema}.keywords VALUES (7638, '89bb4e2b-dd39-44ed-a4d3-2b205e9fa68a', 6648, 'TROPICAL RAINFOREST', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > FORESTS > TROPICAL RAINFOREST', 1);
INSERT INTO {schema}.keywords VALUES (7639, 'ddb4ca0c-9b19-442d-8bcc-e664544d3fe9', 6649, 'MONTANE GRASSLAND', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > GRASSLANDS > MONTANE GRASSLAND', 1);
INSERT INTO {schema}.keywords VALUES (7640, 'd58dab07-f57e-47a9-8dcf-02a3e17f3533', 6649, 'SAVANNA', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > GRASSLANDS > SAVANNA', 1);
INSERT INTO {schema}.keywords VALUES (7641, '0cc6527e-d162-4951-9db7-a6afe5c631c0', 6654, 'CHAPARRAL', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > SHRUBLAND/SCRUB > CHAPARRAL', 1);
INSERT INTO {schema}.keywords VALUES (7642, '9409e1f9-f3a9-46fa-aaf9-0e685ca2adcb', 6654, 'MONTANE SHRUBLAND', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > SHRUBLAND/SCRUB > MONTANE SHRUBLAND', 1);
INSERT INTO {schema}.keywords VALUES (7643, '0e1f3f95-58b5-4f10-b239-850c66ed55ff', 6655, 'ESTUARINE WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > ESTUARINE WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7644, '686e66f7-27bf-4b67-b034-e0fdf0e47c0c', 6655, 'LACUSTRINE WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > LACUSTRINE WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7645, '8ef6f360-10d0-4dc5-8fcb-c532eb23fe5d', 6655, 'MARINE', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > MARINE', 1);
INSERT INTO {schema}.keywords VALUES (7646, '419877cb-0c17-44b0-9b3d-a2283887a7a6', 6655, 'MARSHES', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > MARSHES', 1);
INSERT INTO {schema}.keywords VALUES (7647, '6862d4d4-51fe-4fde-80eb-60d3ef08e88e', 6655, 'PALUSTRINE WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > PALUSTRINE WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7648, 'f3b5489d-6723-40bf-bd55-68a0f2fc1874', 6655, 'PEATLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > PEATLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7649, '1af675ae-9a65-4d91-970e-a8b9fcce0232', 6655, 'RIPARIAN WETLANDS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > RIPARIAN WETLANDS', 1);
INSERT INTO {schema}.keywords VALUES (7650, '8c05bcf2-d13b-44fd-b1a2-5ec797b2f851', 6655, 'SWAMPS', 'EARTH SCIENCE > BIOSPHERE > ECOSYSTEMS > TERRESTRIAL ECOSYSTEMS > WETLANDS > SWAMPS', 1);
INSERT INTO {schema}.keywords VALUES (7651, '9130e78a-882c-4a69-b1ae-0b775869c3de', 6668, 'THI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > HUMIDITY INDICES > TEMPERATURE-HUMIDITY INDEX > THI', 1);
INSERT INTO {schema}.keywords VALUES (7652, 'bcd11fd2-ddf4-4cd3-8507-c3bf6f40a934', 6669, 'WTVI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > HUMIDITY INDICES > WATER VAPOR TRANSPORT INDEX > WTVI', 1);
INSERT INTO {schema}.keywords VALUES (7653, 'db8eb32d-2f86-40ab-82af-b615b5a30db9', 6670, 'CUI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > OCEAN UPWELLING INDICES > OCEAN COASTAL UPWELLING INDEX > CUI', 1);
INSERT INTO {schema}.keywords VALUES (7654, 'b7ad62e0-f904-4429-b6db-6cc50b2281bc', 6681, 'CAR', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > CARIBBEAN INDEX > CAR', 1);
INSERT INTO {schema}.keywords VALUES (7655, 'f59ce66b-a76d-467c-bab1-6264f9f3bb70', 6682, 'NINO 4 INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > CENTRAL TROPICAL PACIFIC SST > NINO 4 INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7656, 'a084d58c-c4f6-40fa-a645-96d9bef021aa', 6683, 'NINO 3.4 INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > EAST CENTRAL TROPICAL PACIFIC SST > NINO 3.4 INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7657, '1c2e9a42-39d1-4b38-b752-3982f2a36ef4', 6684, 'NINO 1+2 INDEX', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > EXTREME EASTERN TROPICAL PACIFIC SST > NINO 1+2 INDEX', 1);
INSERT INTO {schema}.keywords VALUES (7658, '85586d78-1819-4ba7-ab5f-9f684640d730', 6687, 'NTA', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > NORTH TROPICAL ATLANTIC INDEX > NTA', 1);
INSERT INTO {schema}.keywords VALUES (7659, 'fbae11f2-f8db-44b8-bcb6-55471dca13a2', 6688, 'ONI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > OCEANIC NINO INDEX > ONI', 1);
INSERT INTO {schema}.keywords VALUES (7660, 'aaa9c9eb-9d46-4015-a735-8938e0ed4506', 6690, 'TNI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TRANS-NINO INDEX > TNI', 1);
INSERT INTO {schema}.keywords VALUES (7661, '88841897-1e84-4df0-a677-2da7adc3ce37', 6691, 'TNA', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TROPICAL NORTH ATLANTIC INDEX > TNA', 1);
INSERT INTO {schema}.keywords VALUES (7662, 'b625d811-6c7e-4204-abc8-2c72d07aba02', 6693, 'TSA', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > TROPICAL SOUTH ATLANTIC INDEX > TSA', 1);
INSERT INTO {schema}.keywords VALUES (7663, '1bbb19ba-49b7-47c2-b8c8-fa61bb615fb3', 6694, 'WHWP', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > SEA SURFACE TEMPERATURE INDICES > WESTERN HEMISPHERE WARM POOL > WHWP', 1);
INSERT INTO {schema}.keywords VALUES (7664, '690be4e9-c48c-4442-8b86-3d0a51abb0c1', 6695, 'AAO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ANTARCTIC OSCILLATION > AAO', 1);
INSERT INTO {schema}.keywords VALUES (7665, 'a135fceb-cf13-4186-9ad3-8d5db82312c9', 6696, 'AO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ARCTIC OSCILLATION > AO', 1);
INSERT INTO {schema}.keywords VALUES (7666, 'ddcc55bd-2047-4aa2-996c-409f940fbba9', 6697, 'AMM', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ATLANTIC MERIDIONAL MODE > AMM', 1);
INSERT INTO {schema}.keywords VALUES (7667, 'cc579f1f-6a72-425b-84c3-aa8070d4a0ec', 6698, 'AMO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > ATLANTIC MULTIDECADAL OSCILLATION LONG VERSION > AMO', 1);
INSERT INTO {schema}.keywords VALUES (7668, '94ecf3ab-aa20-4756-8e3b-629795b3d5b5', 6699, 'BEST', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > BIVARIATE ENSO TIMESERIES INDEX > BEST', 1);
INSERT INTO {schema}.keywords VALUES (7669, '45dd0a01-d428-4407-ba18-c074d3172b41', 6701, 'EA-JET', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EAST ATLANTIC JET PATTERN > EA-JET', 1);
INSERT INTO {schema}.keywords VALUES (7670, '739f9b7e-3ca7-4f0b-8ce2-68753fc0a6d9', 6702, 'EATL', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EAST ATLANTIC PATTERN > EATL', 1);
INSERT INTO {schema}.keywords VALUES (7671, 'bae01a02-ff03-4ad8-9080-3a4f89fa0dc6', 6703, 'EATL/WRUS', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EASTERN ATLANTIC WESTERN RUSSIA PATTERN > EATL/WRUS', 1);
INSERT INTO {schema}.keywords VALUES (7672, '334d9428-a178-4a5e-b758-a3675a122bef', 6704, 'EP/NP', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EASTERN PACIFIC OSCILLATION > EP/NP', 1);
INSERT INTO {schema}.keywords VALUES (7673, '54330626-f9b4-4c34-949a-9be427fdf51b', 6705, 'ENSO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > EL NINO SOUTHERN OSCILLATION (ENSO) > ENSO', 1);
INSERT INTO {schema}.keywords VALUES (7674, '2953da71-fe1d-4506-9bd6-445b92e2b443', 6709, 'MJO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > MADDEN-JULIAN OSCILLATION > MJO', 1);
INSERT INTO {schema}.keywords VALUES (7675, '087bffd1-f4f5-49ef-98d8-8e7d1169bfe8', 6710, 'MEI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > MULTIVARIATE ENSO INDEX > MEI', 1);
INSERT INTO {schema}.keywords VALUES (7676, '19631138-70c8-4922-8052-821ec5ce093b', 6711, 'NAO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTH ATLANTIC OSCILLATION > NAO', 1);
INSERT INTO {schema}.keywords VALUES (7677, 'b362dfd4-3901-4db9-9e39-bb29b6dad621', 6712, 'NPO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTH PACIFIC OSCILLATION > NPO', 1);
INSERT INTO {schema}.keywords VALUES (7678, '34b92cc2-7708-4e44-8c3f-4c23f62be944', 6713, 'NP', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTH PACIFIC PATTERN > NP', 1);
INSERT INTO {schema}.keywords VALUES (7679, '9a43235b-a7b7-4c76-b296-c01799b1f278', 6714, 'NOI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > NORTHERN OSCILLATION INDEX > NOI', 1);
INSERT INTO {schema}.keywords VALUES (7680, '8a31313b-e60e-47e8-b7bd-df0503e7c868', 6715, 'PDO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > PACIFIC DECADAL OSCILLATION > PDO', 1);
INSERT INTO {schema}.keywords VALUES (7681, 'ebddda06-097f-4454-9751-bb27c41aca37', 6716, 'PNA', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > PACIFIC/NORTH AMERICAN (PNA) PATTERN > PNA', 1);
INSERT INTO {schema}.keywords VALUES (7682, '15f42cd5-9822-4769-be88-3efe64205ce0', 6717, 'PT', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > Pacific Transition Index > PT', 1);
INSERT INTO {schema}.keywords VALUES (7683, 'e932c1de-a7b5-4cbc-9f56-a40234334b2e', 6718, 'QBO', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > QUASI-BIENNIAL OSCILLATION > QBO', 1);
INSERT INTO {schema}.keywords VALUES (7684, 'cafeff8b-c583-40e3-9a43-2b2b069b1df8', 6719, 'SOI', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > SOUTHERN OSCILLATION INDEX > SOI', 1);
INSERT INTO {schema}.keywords VALUES (7685, '8eac6c91-8af5-4b1b-8dc3-89cd4871915f', 6720, 'TNH', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > TROPICAL/NORTHERN HEMISPHERE PATTERN > TNH', 1);
INSERT INTO {schema}.keywords VALUES (7686, 'fe25c265-296d-4671-9e66-9b752b78bb60', 6721, 'WP', 'EARTH SCIENCE > CLIMATE INDICATORS > ATMOSPHERIC/OCEAN INDICATORS > TELECONNECTIONS > WEST PACIFIC INDEX > WP', 1);
INSERT INTO {schema}.keywords VALUES (7687, 'bd1834b0-4f8f-4616-b330-6205bff567c2', 6760, 'ISOTOPIC ANALYSIS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > TREE RINGS > ISOTOPIC ANALYSIS', 1);
INSERT INTO {schema}.keywords VALUES (7688, '6a0fc2ec-d1cf-43b5-8e97-6ab96811c02b', 6765, 'ARGON ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > ISOTOPES > ARGON ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (7689, 'e1138bec-7087-45f4-82b0-2e4029063381', 6765, 'NITROGEN ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > ISOTOPES > NITROGEN ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (7690, 'a1362cee-634d-40f4-b47f-901b328895c3', 6765, 'OXYGEN ISOTOPES', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > ISOTOPES > OXYGEN ISOTOPES', 1);
INSERT INTO {schema}.keywords VALUES (7691, '84b443b5-91d3-42d2-a48b-d2e157a39d5b', 6768, 'MICROPARTICLE CONCENTRATION', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > ICE CORE RECORDS > PARTICULATE MATTER > MICROPARTICLE CONCENTRATION', 1);
INSERT INTO {schema}.keywords VALUES (7692, 'a090a598-3ae6-4fc4-b248-97ec5226702a', 6772, 'CHARCOAL SEDIMENT', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > FIRE HISTORY > CHARCOAL SEDIMENT', 1);
INSERT INTO {schema}.keywords VALUES (7693, 'c9ba3275-2fe3-4619-b7c0-881d4f6fa34e', 6772, 'FIRE SCAR DATE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > FIRE HISTORY > FIRE SCAR DATE', 1);
INSERT INTO {schema}.keywords VALUES (7694, '0d8fc6d8-eba5-4da1-9a78-d69c23d9d78d', 6780, 'SEDIMENT THICKNESS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > LAND RECORDS > SEDIMENTS > SEDIMENT THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (7695, '6fb40553-a2ef-465a-b7d2-3401e3bfceac', 6793, 'SEDIMENT THICKNESS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > OCEAN/LAKE RECORDS > SEDIMENTS > SEDIMENT THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (7696, '88735956-6d46-41e1-8cbb-5dba20c33d8c', 6808, 'SEDIMENT THICKNESS', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > PALEOCLIMATE RECONSTRUCTIONS > SEDIMENTS > SEDIMENT THICKNESS', 1);
INSERT INTO {schema}.keywords VALUES (7697, '8a8fa93e-6424-46dd-ae97-d8afbac41b89', 6816, 'RIFTS', 'EARTH SCIENCE > CRYOSPHERE > GLACIERS/ICE SHEETS > ICE SHEETS > ICE SHEET MEASUREMENTS > RIFTS', 1);
INSERT INTO {schema}.keywords VALUES (7698, 'd6cad59b-327e-4f3f-a664-706224c470f9', 6857, 'TELE-EPIDEMIOLOGY', 'EARTH SCIENCE > HUMAN DIMENSIONS > {schema} HEALTH > DISEASES/EPIDEMICS > EPIDEMIOLOGY > TELE-EPIDEMIOLOGY', 1);
INSERT INTO {schema}.keywords VALUES (7699, 'f51acce1-eaf6-4de7-b279-5b58c3034aeb', 6866, 'CRESCENTIC (BARCHAN/TRANSVERSE) DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > CRESCENTIC (BARCHAN/TRANSVERSE) DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7700, 'cb6b9191-21ab-4a56-b43f-27e86f90f6d9', 6866, 'DOME DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > DOME DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7701, 'b5ee3496-6910-4971-8539-5aa084bfa9e1', 6866, 'LONGITUDINAL/LINEAR DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > LONGITUDINAL/LINEAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7702, 'c63be844-efa7-49f6-8089-c60111bbdffb', 6866, 'PARABOLIC DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > PARABOLIC DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7703, 'dc9dea65-e574-4bbb-9945-cd6d1cdbf6c1', 6866, 'STAR DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > STAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7704, 'dec3d35a-3ffa-4bea-b239-f8e74b498fb2', 6868, 'VENTIFACTS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > ABRASION > VENTIFACTS', 1);
INSERT INTO {schema}.keywords VALUES (7705, 'dabc0fc5-acac-48df-b32e-02c9166e8385', 6868, 'YARDANGS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > ABRASION > YARDANGS', 1);
INSERT INTO {schema}.keywords VALUES (7706, '5ce16b97-c91c-420c-9701-33d19d50b286', 6872, 'LOESS', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENT TRANSPORT > LOESS', 1);
INSERT INTO {schema}.keywords VALUES (7707, 'abe3a81a-3bac-450b-8006-304bee055289', 6872, 'MONADNOCK', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENT TRANSPORT > MONADNOCK', 1);
INSERT INTO {schema}.keywords VALUES (7708, '9ea3e92d-f772-4f39-a615-08b0e062ee9d', 6873, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7709, '02916754-4814-48ea-b8fc-ef50d7a7c5b5', 6873, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7710, 'a7b04d56-2a44-4a94-8d94-1911a7110f9d', 6873, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7711, '6c78ed6a-2dbc-4ced-acc2-d0246e0afedd', 6877, 'APRON REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > APRON REEF', 1);
INSERT INTO {schema}.keywords VALUES (7712, '8bbf1177-c74b-4f11-8f7d-40c5785312a1', 6877, 'ATOLL REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > ATOLL REEF', 1);
INSERT INTO {schema}.keywords VALUES (7713, '9ea0dbd4-2af5-4520-a831-32ee04d02ecc', 6877, 'BANK REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > BANK REEF', 1);
INSERT INTO {schema}.keywords VALUES (7714, 'e125e285-b547-47ea-b566-5dffce2bbcbd', 6877, 'BARRIER REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > BARRIER REEF', 1);
INSERT INTO {schema}.keywords VALUES (7715, 'b54234a2-3261-4c6e-8fd8-75230f3488c0', 6877, 'FRINGING REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > FRINGING REEF', 1);
INSERT INTO {schema}.keywords VALUES (7716, 'a722fea3-fe54-4995-8aec-407efe20dee9', 6877, 'PATCH REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > PATCH REEF', 1);
INSERT INTO {schema}.keywords VALUES (7717, '7f674559-6e36-4a13-ac0c-f61aa6a37d63', 6877, 'RIBBON REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > RIBBON REEF', 1);
INSERT INTO {schema}.keywords VALUES (7718, 'ec0692d8-1cce-4c89-a6ef-c35a5f812121', 6877, 'TABLE REEF', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > TABLE REEF', 1);
INSERT INTO {schema}.keywords VALUES (7719, 'f8b39934-bdce-4f90-8b86-a001c0af8b76', 6880, 'CRESCENTIC (BARCHAN/TRANSVERSE)', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > CRESCENTIC (BARCHAN/TRANSVERSE)', 1);
INSERT INTO {schema}.keywords VALUES (7720, '8971f15d-bee3-4eaf-a7dd-ceb005448b37', 6880, 'DOME DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > DOME DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7721, '386f4f36-26bd-4193-aa25-0c0ec2e5baae', 6880, 'LONGITUDINAL/LINEAR DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > LONGITUDINAL/LINEAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7722, 'db89fdd2-d911-4a75-9210-ce90db043358', 6880, 'PARABOLIC DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > PARABOLIC DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7723, '5a271522-fee4-4646-9c9a-a99385f00d9f', 6880, 'STAR DUNE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > STAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7724, '786c08f1-f3ed-4edd-8ec9-a69313906426', 6908, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7725, '40d7f7e1-e11a-410b-a1b6-78c4a961d631', 6908, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7726, '870803f5-8bbc-4e39-8372-ce21b0decb75', 6908, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7727, '186a08ed-b6fc-4963-adb6-2c5113d133e5', 6941, 'V SHAPED VALLEY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > VALLEY > V SHAPED VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (7728, 'ba0630cb-9a7e-4c4b-9675-c92aba7088ce', 6953, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7729, 'b976820e-6b8c-45f7-87a6-fa6474d39a35', 6953, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7730, 'e9c6d45a-787e-4099-bbf9-03d377cdb8d5', 6953, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7731, 'a78c3d42-ac89-4040-9f0d-4d864b8c4551', 6958, 'LONGITUDINAL CREVASSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES > LONGITUDINAL CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7732, 'f0bbea2f-2ef0-4e99-ad76-1aedbbedc016', 6958, 'MARGINAL CREVASSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES > MARGINAL CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7733, '6ba069ae-8561-44b7-9e59-d645d6bd725f', 6958, 'TRANSVERSE CREVASSES', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES > TRANSVERSE CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7734, 'd3ad1ced-39fa-4e3a-a75d-58e5393a2abe', 6970, 'LATERAL MORAINE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > LATERAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7735, '063fae56-f066-4023-84c2-daff8261b7fc', 6970, 'MEDIAL MORAINE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > MEDIAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7736, '5c242e01-40c4-4fca-a99d-48e4064f6c6f', 6970, 'RECESSIONAL MORAINE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > RECESSIONAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7737, 'b62123dd-1bf5-4222-a646-05d71d729c75', 6970, 'RIBBED/ROGAN MORAINE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > RIBBED/ROGAN MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7738, '16bd425e-9a14-41ac-900e-5b5c4f713dda', 6970, 'TERMINAL MORAINE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > TERMINAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7739, 'ee8dfdf6-0153-4067-ab3b-51794b01ee86', 6983, 'BASAL ICE FREEZING', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > FREEZE/THAW > BASAL ICE FREEZING', 1);
INSERT INTO {schema}.keywords VALUES (7740, '134fd984-9b26-4ceb-9084-3bffc0c5a321', 6993, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7741, '7fa9d5ef-690e-4daf-8503-363b6b1cb6e4', 6993, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > LAND SURFACE > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7742, '7b43eda3-899a-4afa-89be-2dbe527834c2', 7027, 'NORMALIZED DIFFERENCE VEGETATION INDEX (NDVI)', 'EARTH SCIENCE > LAND SURFACE > LAND USE/LAND COVER > LAND USE/LAND COVER CLASSIFICATION > VEGETATION INDEX > NORMALIZED DIFFERENCE VEGETATION INDEX (NDVI)', 1);
INSERT INTO {schema}.keywords VALUES (7743, '5c80c047-c02e-4c15-83ac-26b8b1a8f114', 7077, 'CRESCENTIC (BARCHAN/TRANSVERSE) DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > CRESCENTIC (BARCHAN/TRANSVERSE) DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7744, 'd5ff7545-0eec-4cad-90a5-019e03cdac47', 7077, 'DOME DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > DOME DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7745, 'db2d6cfb-70c3-4568-99a0-a25b3c3879dd', 7077, 'LONGITUDINAL/LINEAR DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > LONGITUDINAL/LINEAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7746, '4cce9a44-da57-4169-b89f-6b1460fcedb9', 7077, 'PARABOLIC DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > PARABOLIC DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7747, 'ce087840-ec71-4575-bca9-e807151cc376', 7077, 'STAR DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN LANDFORMS > DUNES > STAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7748, '2c15738b-839f-4b68-85bc-ece41e4ac6c9', 7079, 'VENTIFACTS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > ABRASION > VENTIFACTS', 1);
INSERT INTO {schema}.keywords VALUES (7749, '59d1b0f7-ef02-4fa4-8d47-7eda39794713', 7079, 'YARDANGS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > ABRASION > YARDANGS', 1);
INSERT INTO {schema}.keywords VALUES (7750, 'a83052ef-9b98-4cb3-9bed-b0c9059812e5', 7083, 'LOESS', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENT TRANSPORT > LOESS', 1);
INSERT INTO {schema}.keywords VALUES (7751, '8167592d-13bf-4225-9822-29e68bcd1b37', 7083, 'MONADNOCK', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENT TRANSPORT > MONADNOCK', 1);
INSERT INTO {schema}.keywords VALUES (7752, '34ea8c99-ff34-495b-b986-92a78b74a8e9', 7084, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7753, '6e5a6d68-5f99-4f0d-bde3-9f24268af426', 7084, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7754, 'a08cce11-9407-4b1f-b13e-0df87da03612', 7084, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > AEOLIAN PROCESSES > SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7755, '0e566bce-90bf-4a0a-a000-5bb5fb430788', 7088, 'APRON REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > APRON REEF', 1);
INSERT INTO {schema}.keywords VALUES (7756, '8c89ede4-94d8-4fd4-a3df-f9d42e9835eb', 7088, 'ATOLL REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > ATOLL REEF', 1);
INSERT INTO {schema}.keywords VALUES (7757, '57417a5e-4d86-4fb6-81d6-68bf9a3d1148', 7088, 'BANK REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > BANK REEF', 1);
INSERT INTO {schema}.keywords VALUES (7758, '5fde7781-d4f6-41a8-8428-f428b70c02dc', 7088, 'BARRIER REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > BARRIER REEF', 1);
INSERT INTO {schema}.keywords VALUES (7759, '0f5c48d1-5189-495d-b5a7-7ad596f0a5c4', 7088, 'FRINGING REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > FRINGING REEF', 1);
INSERT INTO {schema}.keywords VALUES (7760, 'a1451fce-9e69-4f2d-b2cf-27238a7577ce', 7088, 'PATCH REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > PATCH REEF', 1);
INSERT INTO {schema}.keywords VALUES (7761, 'b428ba89-4638-4989-90c1-f5e4f0d0a6f6', 7088, 'RIBBON REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > RIBBON REEF', 1);
INSERT INTO {schema}.keywords VALUES (7762, '5f4dc81d-0893-4eb9-b82a-6a070836aa16', 7088, 'TABLE REEF', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > CORAL REEFS > TABLE REEF', 1);
INSERT INTO {schema}.keywords VALUES (7763, 'fa47cab9-0aa4-4e16-8115-972f7f543920', 7091, 'CRESCENTIC (BARCHAN/TRANSVERSE) DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > CRESCENTIC (BARCHAN/TRANSVERSE) DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7764, '16a1f6b8-ea67-43fe-a47c-aad5250b4f59', 7091, 'DOME DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > DOME DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7765, '1810b08a-9377-4f01-a3cf-fdd549ad8ebf', 7091, 'LONGITUDINAL/LINEAR DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > LONGITUDINAL/LINEAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7766, '174fa36e-3a06-40a1-bc95-87e6799bdead', 7091, 'PARABOLIC DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > PARABOLIC DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7767, '94ab11dc-b70b-4705-bb25-c4d430722d28', 7091, 'STAR DUNE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL LANDFORMS > DUNES > STAR DUNE', 1);
INSERT INTO {schema}.keywords VALUES (7768, '9f4548ad-ec40-4d79-a973-552b2541a62d', 7119, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7769, '17d6838d-e05e-4f0f-a751-7dbd00d2a80a', 7119, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7770, '1203f04d-cd90-4f46-b2c1-998a3c182250', 7119, 'STRAITRAPHIC SEQUENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > SEDIMENTATION > STRAITRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7771, '2f5ceedb-afb6-47e6-8eac-8f220ef0b564', 7125, 'DEGRADATION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > COASTAL PROCESSES > WAVE EROSION > DEGRADATION', 1);
INSERT INTO {schema}.keywords VALUES (7772, 'fdb4c687-916e-48ec-858e-6009cc763de3', 7152, 'V SHAPPED VALLEY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL LANDFORMS > VALLEY > V SHAPPED VALLEY', 1);
INSERT INTO {schema}.keywords VALUES (7773, '09b4427b-9e8b-413a-83cd-f087b284cf61', 7164, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7774, '17747820-39de-4908-bb3d-8c2f94ddd6f4', 7164, 'SEDIMENT COMPOSITION', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION > SEDIMENT COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7775, '103f1165-1008-4caa-bf77-5259ae1a7a36', 7164, 'STRAITIGRAPHIC SEQUENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > FLUVIAL PROCESSES > SEDIMENTATION > STRAITIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7776, '429d0eba-2689-4674-9a8a-d88c4058b1bf', 7169, 'LONGITUDINAL CREVASSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES > LONGITUDINAL CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7777, 'bc803dca-2fdb-4dc0-bf02-f0b9399d6816', 7169, 'MARGINAL CREVASSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES > MARGINAL CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7778, '45101ace-ce83-4b56-bea6-c4eca9c693dd', 7169, 'TRANSVERSE CREVASSES', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > CREVASSES > TRANSVERSE CREVASSES', 1);
INSERT INTO {schema}.keywords VALUES (7779, 'a4f0e7c2-711e-4675-b7c8-f5430905aa89', 7181, 'LATERAL MORAINE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > LATERAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7780, '9d6c8fac-a5cd-4fbc-8283-1bc256c12a43', 7181, 'MEDIAL MORAINE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > MEDIAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7781, 'c4f0d15c-1f9b-40f3-b5d4-da1d6ebe6da8', 7181, 'RECESSIONAL MORAINE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > RECESSIONAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7782, 'a389919c-a6da-465e-b074-ea29b66a686b', 7181, 'RIBBED/ROGAN MORAINE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > RIBBED/ROGAN MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7783, '7886c3eb-e86e-4a84-9f2f-e398ecc82b2d', 7181, 'TERMINAL MORAINE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL LANDFORMS > MORAINES > TERMINAL MORAINE', 1);
INSERT INTO {schema}.keywords VALUES (7784, 'a72c8430-0b33-4167-b189-1309cc2048c5', 7194, 'BASAL ICE FREEZING', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > FREEZE/THAW > BASAL ICE FREEZING', 1);
INSERT INTO {schema}.keywords VALUES (7785, '7d10ff6d-efde-4f97-866b-7d771dd32b25', 7204, 'SEDIMENT CHEMISTRY', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENTATION > SEDIMENT CHEMISTRY', 1);
INSERT INTO {schema}.keywords VALUES (7786, 'c25fef4a-f346-4831-8015-7853886c4fc7', 7204, 'STRATIGRAPHIC SEQUENCE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > GLACIAL PROCESSES > SEDIMENTATION > STRATIGRAPHIC SEQUENCE', 1);
INSERT INTO {schema}.keywords VALUES (7787, 'bbfe00ab-ab63-40e0-8752-8f47d17c1d39', 7213, 'SUBSURFACE DRAINAGE', 'EARTH SCIENCE > SOLID EARTH > GEOMORPHIC LANDFORMS/PROCESSES > KARST PROCESSES > KARST HYDROLOGY > SUBSURFACE DRAINAGE', 1);
INSERT INTO {schema}.keywords VALUES (7788, 'f4573e47-3cce-49ec-98d3-b5b3bb51371e', 7241, 'TEMPERATURE GRADIENT RATE', 'EARTH SCIENCE > SOLID EARTH > GEOTHERMAL DYNAMICS > GEOTHERMAL TEMPERATURE > TEMPERATURE GRADIENT > TEMPERATURE GRADIENT RATE', 1);
INSERT INTO {schema}.keywords VALUES (7789, 'ec950d11-30a8-44c3-b1f3-8e93b131211f', 7260, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7790, 'c5bc5153-d8ed-455b-9a05-aebb1026e2fb', 7260, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7791, '8d396c19-6c45-44f6-9b59-53e1c3712622', 7260, 'COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7792, 'dfb9f260-ce31-4bdc-99af-f3a6f89f52a2', 7260, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7793, '26ea8426-2996-4b93-aff2-f3b9cd2f8a7a', 7260, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7794, '03939ec7-9310-4440-b761-c8a6b32f1f43', 7260, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7795, 'a4596f71-207c-4037-b3a1-7ab0cd12daec', 7260, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7796, '60e242ac-0f08-4574-bf92-b5e6536603cb', 7260, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7797, '2b1b868a-71ff-4a9e-9d32-371a4b91f1a3', 7260, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7798, '23da8344-174b-4931-b460-9fcfaf824ec9', 7260, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > GAS HYDRATES > GAS HYDRATES PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7799, '746a7f6e-8923-47a1-9e95-9103a1231fc4', 7264, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7800, '7ca1ab0a-2aa1-438c-b4c0-93dd8db37bb1', 7264, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7801, '2cb4e7de-fba7-420a-9137-ac10e298fd63', 7264, 'COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7802, '8cd774ee-2437-4790-ae2c-4492ecfc5013', 7264, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7803, '8443b43e-9512-4389-bc89-11c7510144f6', 7264, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7804, 'bd075d4b-1112-4290-920d-cf15280d54b8', 7264, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7805, 'e1e3f623-5a18-46a8-b8a8-22c082b643ad', 7264, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7806, '19791e07-39bf-4635-b695-a819e38e20ca', 7264, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7807, 'ba73a304-0302-40bc-af08-79d923054162', 7264, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7808, '92b21b46-90e1-4ea6-a5be-e2ce663a028d', 7264, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > IGNEOUS ROCKS > IGNEOUS ROCK PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7809, '37edb662-820e-410f-a45c-7a419bce0c8b', 7267, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7810, 'a2a5a2e1-6ac8-4bd4-9fe6-00f043bc148b', 7267, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7811, '1afa91ea-2b60-48d6-b065-093cd20408cd', 7267, 'COMPOSITION/STRUCTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/STRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (7812, 'ebebffc8-474e-46a9-b194-5cfe5a309e88', 7267, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7813, 'ebc1d1d7-98b7-4448-a6b0-80b15de99259', 7267, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7814, 'b727b561-f738-436d-bb96-137b455bb54a', 7267, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7815, 'af12ef6b-836b-40bf-959b-ec2d82c87389', 7267, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7816, 'f9385327-31fe-49a6-b3d6-073d6897ff4a', 7267, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7817, 'c3a008a8-0af3-4595-9c32-1fc8bee47c9f', 7267, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7818, '3ff1adcf-563f-47b3-902e-0231051dc8e7', 7267, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METALS > METALS PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7819, 'f433284b-5def-465b-a532-62f0961294d0', 7271, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7820, 'ee3df8b7-0b0b-40ed-b9fa-cc3205d95669', 7271, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7821, '9dbdb70e-7bea-4473-a7a9-9a7edf843af1', 7271, 'COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7822, 'abd86f50-fc17-4020-a6ac-f0066fc5f7ec', 7271, 'ELECTRICIAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > ELECTRICIAL', 1);
INSERT INTO {schema}.keywords VALUES (7823, '953aecfe-a93d-4994-906f-5a1f8c4baa76', 7271, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7824, 'f8740a28-ec13-4ce8-8541-2ecae035b297', 7271, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7825, '93aee4f9-2bcc-4208-b538-0c92f1ac1f42', 7271, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7826, '94bc302a-d9ce-4f8f-982b-08a35772e5e9', 7271, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7827, '3fa18e78-7b40-425b-8773-ad3f0dab7cf4', 7271, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7828, '0cbc201c-f58a-44a2-9515-f23eefc9be03', 7271, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METAMORPHIC ROCKS > METAMORPHIC ROCK PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7829, 'd9add64c-1764-4ddb-b088-71c77084a2f5', 7275, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7830, 'f54cb873-f20a-4476-835e-fd968c9b1937', 7275, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7831, '94370298-393b-4faa-bbb1-f8b6a47b9d56', 7275, 'COMPOSITION/STRUCTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/STRUCTURE', 1);
INSERT INTO {schema}.keywords VALUES (7832, '0de2a94f-9bd1-4ad0-b5b8-4a8237d049bf', 7275, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7833, 'a2c042a4-2658-48c1-a511-7a5dbff2b63d', 7275, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7834, '83aff0db-35fd-45f9-b409-692b17941f79', 7275, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7835, '651a6368-251e-45f6-8496-1f798de85db5', 7275, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7836, '547c2bee-40ce-4b23-8338-5fa7c6ad8a8d', 7275, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7837, '7b6d19eb-616b-45cf-a1e6-cc8b549128f1', 7275, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7838, 'a1d083b5-3233-4053-a479-4eb7d347c34b', 7275, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7839, '5a8bc1e7-a74d-4acc-9ac2-8fea047068a8', 7276, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > METEORITES > METEORITE VERTICAL/GEOGRPAHIC DISTRIBUTION > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7840, 'a40aafdc-dcc0-43f0-bc57-3a567631fa3b', 7279, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7841, 'd8bea85a-4578-410f-b58a-4927b8963aef', 7279, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7842, '9d828679-c6d3-4f74-9489-d9688509a025', 7279, 'COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7843, 'a9f3ac40-047e-4649-bf0f-03480d6174ae', 7279, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7844, '1545d45e-a4e6-43bd-a3ae-8d3a0a25b41e', 7279, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7845, '307f8625-b4cf-4856-9d62-b200e94429a2', 7279, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7846, '1c44d356-308d-4f92-8fe4-201edff3a02e', 7279, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7847, 'f2057998-1d06-4e58-9177-447942355d66', 7279, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7848, 'cef686dd-4efe-4e4a-b6ef-360879b20dc9', 7279, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7849, '3feb3e65-5a44-46db-ba7b-ceb695e4fb50', 7279, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > MINERALS > MINERAL PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7850, '6a22f994-b311-4042-b517-35612ccf2bb6', 7284, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7851, 'bac88c42-fd8d-4970-878d-441977f00ffc', 7284, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7852, 'f53dd88a-d2a0-4a97-bdcf-70e013461bbe', 7284, 'COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7853, 'ffc61516-ea33-48f3-94df-7065fea388ee', 7284, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7854, '70cebb8f-f944-4fe7-be08-1ed86d50eb7c', 7284, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7855, 'a8f6fca6-7a5e-49f7-9b32-813aaf42d0db', 7284, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7856, '2e806852-5790-484f-9aee-a7cfc6683ec0', 7284, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7857, '9911bf57-9d52-4fb3-a915-9e522e9845d5', 7284, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7858, '42632143-3d8c-40d9-a0ab-9fdffb98a6c9', 7284, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7859, '07d5a2e4-47ef-4bee-81a7-42ef2eb7a77c', 7284, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > NON-METALLIC MINERALS > NON-METALLIC MINERAL PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7860, 'b5ae8710-8c7e-48ab-bf0f-2f18b2598a5a', 7289, 'CLEAVAGE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > CLEAVAGE', 1);
INSERT INTO {schema}.keywords VALUES (7861, 'e0c40575-4033-4e91-9874-3cd83ce80bc1', 7289, 'COLOR', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > COLOR', 1);
INSERT INTO {schema}.keywords VALUES (7862, 'dbfa6bae-c59a-4c41-b3d1-12b3fd6b5641', 7289, 'COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7863, 'f5cd9ac7-6b10-44dd-8b1d-660a7a681518', 7289, 'ELECTRICAL', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > ELECTRICAL', 1);
INSERT INTO {schema}.keywords VALUES (7864, '99d75da3-aa22-4d29-9a56-7e0413665031', 7289, 'HARDNESS', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > HARDNESS', 1);
INSERT INTO {schema}.keywords VALUES (7865, '3e705ebc-c58f-460d-b5e7-1da05ee45cc1', 7289, 'LUMINESCENCE', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > LUMINESCENCE', 1);
INSERT INTO {schema}.keywords VALUES (7866, '1fca9e52-07fa-424b-b75a-ef1003e77b56', 7289, 'LUSTER', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > LUSTER', 1);
INSERT INTO {schema}.keywords VALUES (7867, '73e9349c-08db-4ca5-87f8-bbe785c25629', 7289, 'REFLECTION', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > REFLECTION', 1);
INSERT INTO {schema}.keywords VALUES (7868, '383eb3f9-49bb-4210-ab59-030eeb1f68c3', 7289, 'SPECIFIC GRAVITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > SPECIFIC GRAVITY', 1);
INSERT INTO {schema}.keywords VALUES (7869, '54a4a67a-b1ed-429b-876b-a595164a807c', 7289, 'STABILITY', 'EARTH SCIENCE > SOLID EARTH > ROCKS/MINERALS/CRYSTALS > SEDIMENTARY ROCKS > SEDIMENTARY ROCK PHYSICAL/OPTICAL PROPERTIES > STABILITY', 1);
INSERT INTO {schema}.keywords VALUES (7870, 'f66893ce-3ea6-4c52-bc27-bc322a41b748', 7294, 'SEISMIC BODY WAVES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES > SEISMIC PROFILE > SEISMIC BODY WAVES', 1);
INSERT INTO {schema}.keywords VALUES (7871, '02836842-3d46-46e0-a816-bd2f407f3fb3', 7294, 'SEISMIC SURFACE WAVES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > EARTHQUAKES > SEISMIC PROFILE > SEISMIC SURFACE WAVES', 1);
INSERT INTO {schema}.keywords VALUES (7872, 'a629b645-2c5f-48d6-8363-71bc636457d6', 7295, 'CRUSTAL MOTION DIRECTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > CRUSTAL MOTION > CRUSTAL MOTION DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (7873, '88a6ed54-6504-4787-9d98-d511d4f4ae83', 7295, 'CRUSTAL MOTION RATE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > CRUSTAL MOTION > CRUSTAL MOTION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7874, '399e5858-8238-451f-8da3-84dc9edfe9a2', 7296, 'FAULT MOVEMENT DIRECTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > FAULT MOVEMENT > FAULT MOVEMENT DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (7875, 'fbbd2aab-73d6-4945-bf1b-c6d543f3f79b', 7296, 'FAULT MOVEMENT RATE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > FAULT MOVEMENT > FAULT MOVEMENT RATE', 1);
INSERT INTO {schema}.keywords VALUES (7876, 'c185f7f5-0c62-489f-b365-9424e054de58', 7298, 'REBOUND DIRECTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > ISOSTATIC REBOUND > REBOUND DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (7877, 'f0b2ab0f-46eb-426b-924b-471e4d1b7598', 7298, 'REBOUND RATE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > ISOSTATIC REBOUND > REBOUND RATE', 1);
INSERT INTO {schema}.keywords VALUES (7878, '03b6b427-6be5-4452-a457-a9ea8c7f0473', 7299, 'PLATE MOTION DIRECTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > LITHOSPHERIC PLATE MOTION > PLATE MOTION DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (7879, '9cd46f88-24ba-4f2d-96b7-ab5a9333207b', 7299, 'PLATE MOTION RATE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > PLATE TECTONICS > LITHOSPHERIC PLATE MOTION > PLATE MOTION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7880, '372b4016-80ab-4126-b6d1-e847bbf0b44f', 7304, 'ASH/DUST COMPOSITION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > ASH/DUST COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7881, '89f66579-8de7-4c83-b75f-871bc8d378ac', 7304, 'ASH/DUST DISPERSION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > ASH/DUST DISPERSION', 1);
INSERT INTO {schema}.keywords VALUES (7882, '54b94cdf-b8e2-4c81-b5aa-5652f053244e', 7304, 'GAS/AEROSOL COMPOSITION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > GAS/AEROSOL COMPOSITION', 1);
INSERT INTO {schema}.keywords VALUES (7883, 'b1d60933-636e-48ff-b5a8-43afa60602f3', 7304, 'GAS/AEROSOL DISPERSION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > GAS/AEROSOL DISPERSION', 1);
INSERT INTO {schema}.keywords VALUES (7884, '0eb6fc71-dfb0-4451-85f7-08ceaf37c552', 7304, 'LAVA COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > LAVA COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7885, '9387a7bc-7356-41a5-9682-f5e71da5a858', 7304, 'LAVA SPEED/FLOW', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > LAVA SPEED/FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7886, '40f0a368-7261-43f7-839c-64e428270442', 7304, 'MAGMA COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > MAGMA COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7887, 'af04626c-fe27-4ac6-a948-e93debb6c2d6', 7304, 'MAGMA SPEED/FLOW', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > MAGMA SPEED/FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7888, '83cf8358-4fae-4f17-ba02-b8280f2b7209', 7304, 'PYROCLASTIC PARTICAL SIZE DISTRIBUTION', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > PYROCLASTIC PARTICAL SIZE DISTRIBUTION', 1);
INSERT INTO {schema}.keywords VALUES (7889, 'ab215b31-c540-40c0-9362-3f25ebc148bb', 7304, 'PYROCLASTICS COMPOSITION/TEXTURE', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > PYROCLASTICS COMPOSITION/TEXTURE', 1);
INSERT INTO {schema}.keywords VALUES (7890, 'd9cfb55b-50a2-44f5-b92a-47fe4aadc317', 7304, 'VOLCANIC EXPLOSIVITY', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > VOLCANIC EXPLOSIVITY', 1);
INSERT INTO {schema}.keywords VALUES (7891, '35941db2-59bf-4000-9232-df0beef02da7', 7304, 'VOLCANIC GASES', 'EARTH SCIENCE > SOLID EARTH > TECTONICS > VOLCANIC ACTIVITY > ERUPTION DYNAMICS > VOLCANIC GASES', 1);
INSERT INTO {schema}.keywords VALUES (7892, '04655f0e-81f1-411c-9cfe-994cd743701e', 7311, 'WATER TABLE DEPTH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER FEATURES > WATER TABLE > WATER TABLE DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (7893, 'ee3893bc-f0d6-445a-8982-f852785d5768', 7312, 'AQUIFER DEPTH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE > AQUIFER DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (7894, '2cd0b33e-4805-4930-ba84-fef6c625a9b4', 7312, 'RECHARGE AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE > RECHARGE AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7895, 'e89dc20d-0570-41ca-8039-38316332238a', 7312, 'RECHARGE FREQUENCY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE > RECHARGE FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (7896, '4f30855f-5bf1-46a8-b2ce-ce2fa00485ec', 7313, 'DISCHARGE AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DISCHARGE > DISCHARGE AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7897, 'd89d0e4d-0462-43a5-905e-c060db425e7b', 7313, 'DISCHARGE RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DISCHARGE > DISCHARGE RATE', 1);
INSERT INTO {schema}.keywords VALUES (7898, '1fa631de-797f-4649-aa26-9f814ddcdb9b', 7314, 'DISPERSION FREQUENCY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DISPERSION > DISPERSION FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (7899, '3a95742c-1355-40af-ac86-e24365a67b04', 7314, 'DISPERSION RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DISPERSION > DISPERSION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7900, '5ea5be7b-fdbb-4c50-9f54-c0bbd7dcc78c', 7315, 'DRAINAGE AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DRAINAGE > DRAINAGE AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7901, '3045e9ec-ac70-4d72-904a-54094357373a', 7315, 'DRAINAGE DIRECTION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > DRAINAGE > DRAINAGE DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (7902, '59ce52b5-0386-4b51-b5ac-049a0862e9cd', 7316, 'INFILTRATION AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > INFILTRATION > INFILTRATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7903, '55642a14-2ff4-4892-b61a-ae3ece7fbcd7', 7316, 'INFILTRATION FREQUENCY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > INFILTRATION > INFILTRATION FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (7904, 'd16cd32f-978d-4ab5-9711-f8189a748399', 7316, 'INFILTRATION RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > INFILTRATION > INFILTRATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7905, '2922e6fe-3d72-44d3-a972-2e3778194343', 7317, 'SUBSIDENCE AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > LAND SUBSIDENCE > SUBSIDENCE AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7906, '535b876d-9297-49c2-bdcd-4c33e02a47be', 7317, 'SUBSIDENCE RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > LAND SUBSIDENCE > SUBSIDENCE RATE', 1);
INSERT INTO {schema}.keywords VALUES (7907, '22566296-aea0-4f01-93c0-fb3256051f27', 7318, 'PERCOLATION AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > PERCOLATION > PERCOLATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7908, 'acdb39a8-1816-4d8d-bb80-38a94024035e', 7318, 'PERCOLATION RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > PERCOLATION > PERCOLATION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7909, '68034344-9c1c-4a5e-a64e-813f6ecf608c', 7319, 'INTRUSION AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SALTWATER INTRUSION > INTRUSION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7910, '310c5663-1825-46ed-8b64-d1ba7c93ff6d', 7319, 'INTRUSION RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SALTWATER INTRUSION > INTRUSION RATE', 1);
INSERT INTO {schema}.keywords VALUES (7911, '92bfc132-bc15-4952-99a7-763f109c1e7e', 7320, 'AVERAGE FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SUBSURFACE FLOW > AVERAGE FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7912, 'dd27825d-7b6e-4a70-9a45-c68d646a1cc5', 7320, 'FLOW VELOCITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SUBSURFACE FLOW > FLOW VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (7913, '48f02169-8eab-487d-a24b-4b36ec707b13', 7320, 'PEAK FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > GROUND WATER > GROUND WATER PROCESSES/MEASUREMENTS > SUBSURFACE FLOW > PEAK FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7914, '37e1daa7-503a-4d5c-b6d7-c18b71030bc6', 7326, 'AQUIFER DEPTH', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE > AQUIFER DEPTH', 1);
INSERT INTO {schema}.keywords VALUES (7915, 'f9c86356-381e-4f7e-9193-10c274eae41c', 7326, 'RECHARGE AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE > RECHARGE AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7916, '424652b2-92b2-4dee-9f77-016f905b1569', 7326, 'RECHARGE FREQUENCY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > AQUIFER RECHARGE > RECHARGE FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (7917, 'f8f16152-094e-4130-8346-2a9bba5872a0', 7327, 'AVERAGE FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DISCHARGE/FLOW > AVERAGE FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7918, '609f7831-5145-4a5c-bd58-d0b426058740', 7327, 'BASE FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DISCHARGE/FLOW > BASE FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7919, 'f77adcc6-e320-4fd9-80c9-958e75cd46d3', 7327, 'FLOW VELOCITY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DISCHARGE/FLOW > FLOW VELOCITY', 1);
INSERT INTO {schema}.keywords VALUES (7920, '231dd4ab-8b74-45ba-8933-09ab291594ea', 7327, 'PEAK FLOW', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DISCHARGE/FLOW > PEAK FLOW', 1);
INSERT INTO {schema}.keywords VALUES (7921, '71926eb5-b64c-42d9-be6a-26f7b2a5fbf1', 7328, 'DRAINAGE AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DRAINAGE > DRAINAGE AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7922, '97b68ee7-b729-4828-924d-d0758b43d8e9', 7328, 'DRAINAGE DIRECTION', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > DRAINAGE > DRAINAGE DIRECTION', 1);
INSERT INTO {schema}.keywords VALUES (7923, 'bf470637-8aea-47a8-b075-40b394303747', 7329, 'FLOOD FREQUENCY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > FLOODS > FLOOD FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (7924, '44278367-2c4d-4309-90a2-03244a12ae39', 7329, 'FLOOD LEVELS', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > FLOODS > FLOOD LEVELS', 1);
INSERT INTO {schema}.keywords VALUES (7925, 'ae35e34f-92de-4107-b277-abaf7a652f2d', 7332, 'INUNDATION AMOUNT', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > INUNDATION > INUNDATION AMOUNT', 1);
INSERT INTO {schema}.keywords VALUES (7926, '3265052b-38e1-472c-ab91-70b39b549854', 7332, 'INUNDATION FREQUENCY', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > INUNDATION > INUNDATION FREQUENCY', 1);
INSERT INTO {schema}.keywords VALUES (7927, '5af94668-05f5-41ee-aa65-82dca2a359fc', 7332, 'INUNDATION LEVEL', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > INUNDATION > INUNDATION LEVEL', 1);
INSERT INTO {schema}.keywords VALUES (7928, 'f54d4750-b9b3-47fa-b56a-a1d57fcbc978', 7333, 'RUNOFF RATE', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > RUNOFF > RUNOFF RATE', 1);
INSERT INTO {schema}.keywords VALUES (7929, '0eb4156f-e4ab-4e02-a473-df4b44290556', 7333, 'TOTAL RUNOFF', 'EARTH SCIENCE > TERRESTRIAL HYDROSPHERE > SURFACE WATER > SURFACE WATER PROCESSES/MEASUREMENTS > RUNOFF > TOTAL RUNOFF', 1);
INSERT INTO {schema}.keywords VALUES (7930, '889253e1-e189-4f75-bdc7-7e612b19e3ae', 7439, 'RIMING', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CLOUD MICROPHYSICS > DROPLET GROWTH > ACCRETION > RIMING', 1);
INSERT INTO {schema}.keywords VALUES (7931, '52f4dfb0-4583-4d82-8cb7-813ffaadd783', 7444, 'CUMULONIMBUS INCUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULONIMBUS > CUMULONIMBUS CAPILLATUS > CUMULONIMBUS INCUS', 1);
INSERT INTO {schema}.keywords VALUES (7932, '79668331-c50d-49da-aea6-83c94545f9e3', 7447, 'TOWERING CUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > CUMULUS CONGESTUS > TOWERING CUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (7933, 'ef4de9ce-01ee-4bf0-8814-abefd1bad4b9', 7448, 'FAIR WEATHER CUMULUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > CONVECTIVE CLOUDS/SYSTEMS (OBSERVED/ANALYZED) > CUMULUS > CUMULUS HUMILIS > FAIR WEATHER CUMULUS', 1);
INSERT INTO {schema}.keywords VALUES (7934, '53378c8d-0324-4473-8bbd-231aed830d26', 7460, 'STRATOCUMULUS CASTELLANUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS CUMILIFORMIS > STRATOCUMULUS CASTELLANUS', 1);
INSERT INTO {schema}.keywords VALUES (7935, '16e33a06-ae4b-48cd-be7f-ad44f3dfd23b', 7460, 'STRATOCUMULUS DIURNALIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS CUMILIFORMIS > STRATOCUMULUS DIURNALIS', 1);
INSERT INTO {schema}.keywords VALUES (7936, '3adff54b-cfc7-4ba0-ba06-7a06b8c4876a', 7460, 'STRATOCUMULUS MAMMATUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS CUMILIFORMIS > STRATOCUMULUS MAMMATUS', 1);
INSERT INTO {schema}.keywords VALUES (7937, '8fc75200-666d-4b59-a493-99e08e55e57d', 7460, 'STRATOCUMULUS VESPERALIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS CUMILIFORMIS > STRATOCUMULUS VESPERALIS', 1);
INSERT INTO {schema}.keywords VALUES (7938, '12adeea5-f3e7-4f72-a029-f1e52411de18', 7461, 'STRATOCUMULUS LENTICULARIS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS UNDULATAS > STRATOCUMULUS LENTICULARIS', 1);
INSERT INTO {schema}.keywords VALUES (7939, '53ade6b0-1b8c-4766-b9c1-4d40d1f69482', 7461, 'STRATOCUMULUS OPACUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS UNDULATAS > STRATOCUMULUS OPACUS', 1);
INSERT INTO {schema}.keywords VALUES (7940, '94fa2efc-0e7f-4dce-9f2a-0d6f34edcb92', 7461, 'STRATOCUMULUS PERLUCIDUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS UNDULATAS > STRATOCUMULUS PERLUCIDUS', 1);
INSERT INTO {schema}.keywords VALUES (7941, 'b962de0e-f115-4452-95be-7a4af6687bc3', 7461, 'STRATOCUMULUS TRANSLUCIDUS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/LOW LEVEL CLOUDS (OBSERVED/ANALYZED) > STRATOCUMULUS > STRATOCUMULUS UNDULATAS > STRATOCUMULUS TRANSLUCIDUS', 1);
INSERT INTO {schema}.keywords VALUES (7942, 'd5e72d73-22f6-4f4c-b937-b71d84960a1e', 7463, 'LENTICULAR CLOUDS', 'EARTH SCIENCE > ATMOSPHERE > CLOUDS > TROPOSPHERIC/MID-LEVEL CLOUDS (OBSERVED/ANALYZED) > ALTOCUMULUS > ALTOCUMULUS LENTICULARIS > LENTICULAR CLOUDS', 1);
INSERT INTO {schema}.keywords VALUES (7943, '1369d226-2b9b-4f69-a197-6e24523b21e7', 7563, 'TUNAS AND ALLIES', 'EARTH SCIENCE > BIOLOGICAL CLASSIFICATION > ANIMALS/VERTEBRATES > FISH > RAY-FINNED FISHES > PERCH-LIKE FISHES > TUNAS AND ALLIES', 1);
INSERT INTO {schema}.keywords VALUES (7944, '437f13e8-0b8a-44a2-a7fd-5b41a00299db', 7687, 'CARBON ISOTOPE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > TREE RINGS > ISOTOPIC ANALYSIS > CARBON ISOTOPE', 1);
INSERT INTO {schema}.keywords VALUES (7945, '89387757-3548-4fe0-a383-d8f935f07c71', 7687, 'HYDROGEN ISOTOPE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > TREE RINGS > ISOTOPIC ANALYSIS > HYDROGEN ISOTOPE', 1);
INSERT INTO {schema}.keywords VALUES (7946, 'e91ff41a-5cf5-460b-b765-c553ca2a4ae2', 7687, 'OXYGEN ISOTOPE', 'EARTH SCIENCE > CLIMATE INDICATORS > PALEOCLIMATE INDICATORS > BIOLOGICAL RECORDS > TREE RINGS > ISOTOPIC ANALYSIS > OXYGEN ISOTOPE', 1);


--
-- TOC entry 4844 (class 0 OID 19740)
-- Dependencies: 292
-- Data for Name: licenses; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.licenses VALUES (4, 'ODbL', 'Open Data Commons Open Database License', 'This record and associated data sets are made available under the Open Database License: http://opendatacommons.org/licenses/odbl/1.0/. Any rights in individual contents of the database are licensed under the Database Contents License: http://opendatacommons.org/licenses/dbcl/1.0/', NULL, 'https://opendatacommons.org/files/2018/02/odbl-10.txt', true, true, true);
INSERT INTO {schema}.licenses VALUES (5, 'ODC-by', 'Open Data Commons Attribution License v1.0', 'This record and associated data sets are made available under the Open Data Commons Attribution License: http://opendatacommons.org/licenses/by/1.0.This data is made available under the Open Data Commons Attribution License: http://opendatacommons.org/licenses/by/1.0', NULL, 'https://opendatacommons.org/files/2018/02/odc_by_1.0_{schema}_text.txt', true, false, true);
INSERT INTO {schema}.licenses VALUES (6, 'CC BY 4.0', 'Creative Commons Attribution 4.0 International', 'You are free to: Share — copy and redistribute the material in any medium or format; Adapt — remix, transform, and build upon the material; for any purpose, even commercially. Under the following terms: Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.  ShareAlike — If you remix, transform, or build upon the material, you must distribute your contributions under the same license as the original.', NULL, 'https://creativecommons.org/licenses/by/4.0/legalcode.txt', true, false, true);
INSERT INTO {schema}.licenses VALUES (7, 'CC BY-SA 4.0', 'Creative Commons Attribution-ShareAlike 4.0 International', 'You are free to: Share — copy and redistribute the material in any medium or format; Adapt — remix, transform, and build upon the material; for any purpose, even commercially. Under the following terms: Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.  ShareAlike — If you remix, transform, or build upon the material, you must distribute your contributions under the same license as the original.', NULL, 'https://creativecommons.org/licenses/by-sa/4.0/legalcode.txt', true, true, true);
INSERT INTO {schema}.licenses VALUES (8, 'CC BY-NC 4.0', 'Creative Commons Attribution-NonCommerical 4.0 International', 'You are free to: Share — copy and redistribute the material in any medium or format Adapt — remix, transform, and build upon the material. Under the following terms: Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.  NonCommercial — You may not use the material for commercial purposes.', NULL, 'https://creativecommons.org/licenses/by-nc/4.0/legalcode.txt ', true, false, false);
INSERT INTO {schema}.licenses VALUES (9, 'CC BY-NC-SA 4.0', 'Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International', 'You are free to: Share — copy and redistribute the material in any medium or format Adapt — remix, transform, and build upon the material. Under the following terms: Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.  NonCommercial — You may not use the material for commercial purposes.  ShareAlike — If you remix, transform, or build upon the material, you must distribute your contributions under the same license as the original.', NULL, 'https://creativecommons.org/licenses/by-nc-sa/4.0/legalcode.txt', true, true, false);
INSERT INTO {schema}.licenses VALUES (10, 'dl-by-de/2.0', 'Data licence Germany – attribution – version 2.0', 'Data and metadata may be (commercially and non-commercially) copied, printed, presented, altered, processed and transmitted to third parties; be merged with own and third party data; be integrated into internal and external business processes, products and applications if the user ensures that the source reference includes the name of the provider, the reference to this license and a reference to the dataset (URI) and that changes, editing, new designs or other amendments are marked in the source references.', NULL, 'http://www.govdata.de/dl-de/by-2-0', true, true, true);
INSERT INTO {schema}.licenses VALUES (11, 'GeoNutzV', 'Verordnung zur Festlegung der Nutzungsbestimmungen für die Bereitstellung von Geodaten des Bundes (GeoNutzV)', 'You are free to copy, print, present, alter, process and transmit this work to third parties for commercial and non-commercial use, to merge this work with own data and with the data of others and to combine it to form new and independent datasets, to integrate this work in internal and external business processes, products and applications in {schema} and non-{schema} electronic networks under the following conditions: You have to guarantee that all source notices, which are in the geodata, metadata or geodata service, or other legal notices are recognizable integrated in the optical background, You have to guarantee that all changes, deratived, new designs, or other variants be provided with a changing notice in the source notice, You have to guarantee that, if geodata holding authority requests this, the source notice will be deleted', '# Ordinance to Determine the Conditions for Use for the Provision of Spatial Data of the Federation (Verordnung zur Festlegung der Nutzungsbestimmungen für die Bereitstellung von Geodaten  – GeoNutzV)

Of 19 March 2013
On the basis of section 14 number 2 in conjunction with section 11 subs. 3 of the Spatial Data Access Act, of which section 14 number 2 was re-drafted by Article 1 number 4 and section 11 subs. 3 by Article 1 number 2 of the Act of 7 November 2012 (Federal Law Gazette [BGBl.] Part I p. 2289), the Federal Government herewith issues the following ordinance:

## Section 1: Objective and scope

This ordinance governs the conditions under which spatial data and services, including the appropriate metadata, in accordance with section 11 subs. 1 and 2 of the Spatial Data Access Act, are provided by the agencies holding spatial data in accordance with section 2 subs. 1 in conjunction with section 3 subs. 8 of the Spatial Data Access Act.


## Section 2: Uses

(1) Spatial data and services, including the appropriate metadata, shall be provided free of charge fo r all currently known purposes and for all purposes becoming known in the future of commercial and non-commercial use unless provided otherwise by special legal provision or third-party contractual or statutory rights stand in the way of such arrangement.


(2) The spatial data and metadata provided may in particular
1. be duplicated, printed out, presented, altered, processed and forwarded to third parties;
2. be placed together with own data and third-party data and combined to produce separate, new data sets;
3. be incorporated into internal and external business processes, products and applications in {schema} and non-{schema} electronic networks.

(3) The spatial data services provided may in particular
1. be combined with own services and third-party services;
2. be incorporated into internal and external business processes, products and applications in {schema} and non-{schema} electronic networks.


## Section 3: Sources references

Users shall ensure that

1. all source references and other legal information enclosed with the spatial data, metadata
    and spatial services are incorporated recognisably and optically linked;
2. alterations, processing, new designs or other adaptations are affixed with an indication of
    the alteration or, where the agency holding the spatial data so requires, the enclosed
    source reference is deleted.

## Section 4: Limited liability

If the agency holding the spatial data violates an obligation under {schema} law
incumbent on it vis-à-vis the user, its financing entity shall not be liable towards the user for
the damage resulting therefrom if the agency holding the spatial data is only guilty of
negligence. This shall not apply in the event of an injury to life, limb and health.

## Section 5: Entry into force
This ordinance shall come into force on the day after its promulgation.

Berlin, 19 March 2013
The Federal Chancellor
Dr. Angela Merkel
The Federal Minister
for the Environment, Nature Conservation and Nuclear Safety)
Peter Altmaier



', 'https://www.bmuv.de/fileadmin/Daten_BMU/Download_PDF/Strategien_Bilanzen_Gesetze/130309_geonutzv_bgbi_englisch_bf.pdf', true, true, true);


--
-- TOC entry 4846 (class 0 OID 19750)
-- Dependencies: 294
-- Data for Name: units; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.units VALUES (1, 'second', 's', 's');
INSERT INTO {schema}.units VALUES (2, 'meter', 'm', 'm');
INSERT INTO {schema}.units VALUES (3, 'kilogram', 'kg', 'kg');
INSERT INTO {schema}.units VALUES (4, 'ampere', 'A', 'A');
INSERT INTO {schema}.units VALUES (5, 'kelvin', 'K', 'K');
INSERT INTO {schema}.units VALUES (6, 'mole', 'mol', 'mol');
INSERT INTO {schema}.units VALUES (7, 'candela', 'cd', 'cd');
INSERT INTO {schema}.units VALUES (8, 'radian', 'rad', '1');
INSERT INTO {schema}.units VALUES (9, 'degree', 'deg', '0.0174533*rad');
INSERT INTO {schema}.units VALUES (10, 'hertz', 'Hz', 's^-1');
INSERT INTO {schema}.units VALUES (11, 'newton', 'N', 'kg*m*s^-2');
INSERT INTO {schema}.units VALUES (12, 'pascal', 'Pa', 'kg*m^-1*s^-2');
INSERT INTO {schema}.units VALUES (13, 'joule', 'J', 'kg*m^2*s^-2');
INSERT INTO {schema}.units VALUES (14, 'watt', 'W', 'kg*m^2*s^-3');
INSERT INTO {schema}.units VALUES (15, 'coulomb', 'C', 's*a');
INSERT INTO {schema}.units VALUES (16, 'volt', 'V', 'kg*m^3*s^-3*A^-1');
INSERT INTO {schema}.units VALUES (17, 'farad', 'F', 'kg^-1*m^-2*s^4*A^2');
INSERT INTO {schema}.units VALUES (18, 'ohm', 'ohm', 'kg*m^2*s^-3*A^-2');
INSERT INTO {schema}.units VALUES (19, 'siemens', 'S', 'kg^-1*m^-2*s^3*A^2');
INSERT INTO {schema}.units VALUES (20, 'lux', 'lx', 'm^-2*cd');
INSERT INTO {schema}.units VALUES (21, 'relative', '-', '1');
INSERT INTO {schema}.units VALUES (22, 'mass flux density per hour', 'cm^3/cm^2h', '10^-3*m^3*10^2*m^-2*3600^-1*s*-1');
INSERT INTO {schema}.units VALUES (23, 'hour', 'h', '3600*s');
INSERT INTO {schema}.units VALUES (24, 'megapascal', 'MPa', '10^6*kg*m^-1*s^-2');
INSERT INTO {schema}.units VALUES (25, 'millisiemens per centimeter', 'mS/cm', 'S*m^-1');
INSERT INTO {schema}.units VALUES (101, 'degree Celsius', 'C', 'K');
INSERT INTO {schema}.units VALUES (102, 'millimeter', '10^-3*m', NULL);
INSERT INTO {schema}.units VALUES (103, 'mm per day', 'mm/d', '10^-3*m*86400^-1*s^-1');
INSERT INTO {schema}.units VALUES (104, 'hectopascal', '10^2*Pa', NULL);
INSERT INTO {schema}.units VALUES (105, 'mm per hour', 'mm/h', '10^-3*m*3600^-1*s^-1');
INSERT INTO {schema}.units VALUES (106, 'mm per second', 'mm/s', '10^-3*m**s^-1');
INSERT INTO {schema}.units VALUES (107, 'meter per second', 'm/s', 'm*s^-1');
INSERT INTO {schema}.units VALUES (108, 'cubicmeter per second', 'm3/s', 'm^3*s^-1');
INSERT INTO {schema}.units VALUES (109, 'liter per second', 'l/s', '10^-3*m^3*s^-1');
INSERT INTO {schema}.units VALUES (112, 'percent', '%', '10^-2');
INSERT INTO {schema}.units VALUES (113, 'cm3/cm3', 'cm3/cm3', '1');
INSERT INTO {schema}.units VALUES (114, 'kg/kg', 'kg/kg', '1');
INSERT INTO {schema}.units VALUES (115, 'watt per squaremeter', 'W/m2', 'kg*m^2*s^-3*m^-2');


--
-- TOC entry 4864 (class 0 OID 19876)
-- Dependencies: 312
-- Data for Name: variables; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.variables VALUES (1, 'air temperature', 'Ta', '{air_temperature}', 101, 111);
INSERT INTO {schema}.variables VALUES (2, 'soil temperature', 'Ts', '{soil_temperature}', 101, 5736);
INSERT INTO {schema}.variables VALUES (3, 'water temperature', 'Tw', '{water_temperature}', 101, 7402);
INSERT INTO {schema}.variables VALUES (4, 'discharge', 'Q', '{discharge}', 108, 7327);
INSERT INTO {schema}.variables VALUES (5, 'air pressure', 'p', '{air_pressure}', 104, 109);
INSERT INTO {schema}.variables VALUES (6, 'relative humidity', 'RH', '{relative_humidity}', 112, 6308);
INSERT INTO {schema}.variables VALUES (7, 'daily rainfall sum', 'P', '{daily_rainfall_sum}', 103, 6434);
INSERT INTO {schema}.variables VALUES (8, 'rainfall intensity', 'Pi', '{rainfall_intensity}', 105, 6436);
INSERT INTO {schema}.variables VALUES (9, 'solar irradiance', 'SI', '{solar_irradiance}', 115, 5236);
INSERT INTO {schema}.variables VALUES (10, 'net radiation', 'Rn', '{net_radiation}', 115, 5227);
INSERT INTO {schema}.variables VALUES (11, 'gravimetric water content', 'u', '{gravimetric_water_content}', 114, 5727);
INSERT INTO {schema}.variables VALUES (12, 'volumetric water content', 'theta', '{volumetric_water_content}', 113, 5727);
INSERT INTO {schema}.variables VALUES (13, 'precision', 'sigma', '{precision}', 21, NULL);
INSERT INTO {schema}.variables VALUES (14, 'sap flow', 'Fm', '{sap_flow}', 22, 7424);
INSERT INTO {schema}.variables VALUES (15, 'matric potential', 'phi', '{matric_potential}', 24, NULL);
INSERT INTO {schema}.variables VALUES (16, 'bulk electrical conductivity', 'bEC', '{bulk_electrical_conductivity}', 25, 5111);
INSERT INTO {schema}.variables VALUES (17, 'specific electrical conductivity', 'sEC', '{specific_electrical_conductivity}', 25, 5111);
INSERT INTO {schema}.variables VALUES (18, 'river water level', 'L', '{river_water_level}', 2, NULL);
INSERT INTO {schema}.variables VALUES (19, 'evapotranspiration', 'ET', '{evapotranspiration}', 103, 6319);
INSERT INTO {schema}.variables VALUES (20, 'drainage', 'D', '{drainage}', 103, 7328);
INSERT INTO {schema}.variables VALUES (21, 'elevation', 'h', '{1}', 2, 7030);


--
-- TOC entry 4836 (class 0 OID 19699)
-- Dependencies: 284
-- Data for Name: entrygroup_types; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.entrygroup_types VALUES (1, 'Project', 'A Project groups datasets into a lager collection of datasets that have been collected or used in the same Campaign.');
INSERT INTO {schema}.entrygroup_types VALUES (2, 'Composite', 'A composite dataset groups a number of datasets that are inseparable.');
INSERT INTO {schema}.entrygroup_types VALUES (3, 'Split dataset', 'A split dataset groups a number of identical datasets that have to be split e.g. in case of different time scale resolution.');
INSERT INTO {schema}.entrygroup_types VALUES (4, 'Label', 'A Label groups different datasets into a larger collection of datasets, that are now a composite, but i.e. collected at the same site.');


--
-- TOC entry 4842 (class 0 OID 19731)
-- Dependencies: 290
-- Data for Name: person_roles; Type: TABLE DATA; Schema: {schema}; Owner: -
--

INSERT INTO {schema}.person_roles VALUES (1, 'author', 'the individual or organization whose name should appear first in the citation for the resource (for names that come after the first use co-author). while it is possible to have an author and principle investigator be the same individual or organization, author is not the same as nor synonymous with principle investigator. applicable mainly to documents, reports, memos, etc.');
INSERT INTO {schema}.person_roles VALUES (2, 'custodian', 'the individual or organization that has accountability and responsibility for the data and ensures appropriate care and maintenance of the resource.');
INSERT INTO {schema}.person_roles VALUES (3, 'distributor', 'the individual or organization that has accountability and responsibility for the data and ensures appropriate care and maintenance of the resource.');
INSERT INTO {schema}.person_roles VALUES (4, 'originator', 'the name of the individual or organization who is responsible for the data at the point when the data was first created. applicable for data sets that are an aggregation of two or more data sets or if the data set is the first instance of the signal having been converted into data.');
INSERT INTO {schema}.person_roles VALUES (5, 'owner', 'the individual or organization that has ownership of the resource.');
INSERT INTO {schema}.person_roles VALUES (6, 'pointOfContact', 'the individual or organization who is responsible for the initial triage of and answering questions related to the resource.');
INSERT INTO {schema}.person_roles VALUES (7, 'principalInvestigator', 'the individual or individuals who are the lead researchers for a grant (i.e. head of the laboratory, research group leader, etc.). if there are co-principal investigators then this field will repeat for each principle investigator. while it is possible to have a principal investigator and author be the same individual or organization, principal investigator is not the same nor synonymous with author.');
INSERT INTO {schema}.person_roles VALUES (8, 'processor', 'the name of the individual or organization who has processed the data in a manner such that the resource has been modified.');
INSERT INTO {schema}.person_roles VALUES (9, 'publisher', 'the individual or organization who prepares and issues the resource.');
INSERT INTO {schema}.person_roles VALUES (10, 'resourceProvider', 'the individual or organization that supplies or allocates the resource for another entity.');
INSERT INTO {schema}.person_roles VALUES (11, 'sponsor', 'the individual or organization who is providing sponsorship for the resource.');
INSERT INTO {schema}.person_roles VALUES (12, 'user', 'the individuals or organizations who are the intended consumers of the resource.');
INSERT INTO {schema}.person_roles VALUES (13, 'coAuthor', 'the individual(s) or organization(s) who name(s) should appear after the first name in a citation for the resource (use author to denote the first name in the citation). while it is possible to have a co-author and principal investigator/collaborator be the same individual or organization, co-author is no the same as nor synonymous with principle investigator or collaborator');
INSERT INTO {schema}.person_roles VALUES (14, 'collaborator', 'party who assists with the generation of the resource other than the principal investigator');
INSERT INTO {schema}.person_roles VALUES (15, 'contributor', 'the individuals or organizations whose contributions deserve recognition in the citation. contributor is mutually exclusive from author, co-author, principal investigator, and collaborator. use ISO MD_Identification credit field to identify individual or organizations that should be given acknowledgement only.');
INSERT INTO {schema}.person_roles VALUES (16, 'editor', 'the individual who has made a corrective or editorial change to the resource as part of a systematic revision process.');
INSERT INTO {schema}.person_roles VALUES (17, 'funder', 'the individual or organization which has provided all or part of the finances associated with the resource.');
INSERT INTO {schema}.person_roles VALUES (18, 'mediator', 'a class of entity that mediates access to the resource and for whom the resource is intended or useful');
INSERT INTO {schema}.person_roles VALUES (19, 'rightsHolder', 'he individual or organization who has ownership of the legal right to the resource.');
INSERT INTO {schema}.person_roles VALUES (20, 'stakeholder', 'an individual or organization who has an interest in the resource and/or is affected by or affects the actions of the resource');

--
-- TOC entry 4882 (class 0 OID 0)
-- Dependencies: 295
-- Name: datasource_types_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.datasource_types_id_seq', 10000, true);


--
-- TOC entry 4884 (class 0 OID 0)
-- Dependencies: 297
-- Name: datatypes_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.datatypes_id_seq', 10000, true);


--
-- TOC entry 4887 (class 0 OID 0)
-- Dependencies: 283
-- Name: entrygroup_types_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.entrygroup_types_id_seq', 10000, true);


--
-- TOC entry 4889 (class 0 OID 0)
-- Dependencies: 307
-- Name: keywords_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.keywords_id_seq', 10000, true);


--
-- TOC entry 4890 (class 0 OID 0)
-- Dependencies: 291
-- Name: licenses_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.licenses_id_seq', 10000, true);


--
-- TOC entry 4892 (class 0 OID 0)
-- Dependencies: 289
-- Name: person_roles_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.person_roles_id_seq', 10000, true);


--
-- TOC entry 4896 (class 0 OID 0)
-- Dependencies: 285
-- Name: thesaurus_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.thesaurus_id_seq', 10000, true);


--
-- TOC entry 4897 (class 0 OID 0)
-- Dependencies: 293
-- Name: units_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.units_id_seq', 10000, true);


--
-- TOC entry 4898 (class 0 OID 0)
-- Dependencies: 311
-- Name: variables_id_seq; Type: SEQUENCE SET; Schema: {schema}; Owner: -
--

SELECT pg_catalog.setval('{schema}.variables_id_seq', 10000, true);


-- Completed on 2024-10-06 08:24:10 CEST

--
-- PostgreSQL database dump complete
--

